@@ -50,11 +50,13 @@
 #include "config.h"
 #endif
 
+#include "helper.h"
+
 #ifndef VERSION
 #define VERSION "UNKNOWN VERSION"
 #endif
 
-int printUsage()
+static int printUsage()
 {
   printf("Usage: mwaw2svg [-h] [-v] [-t] [-b body | -o file.svg] <Mac Graphic/Presentation Document>\n");
   printf("\n");
@@ -70,7 +72,7 @@ int printUsage()
   return -1;
 }
 
-int printVersion()
+static int printVersion()
 {
   printf("mwaw2svg %s\n", VERSION);
   return 0;
@@ -114,36 +116,26 @@ int main(int argc, char *argv[])
     printUsage();
     return -1;
   }
-  librevenge::RVNGFileStream input(argv[optind]);
+  char const *file=argv[optind];
 
-  MWAWDocument::Type type;
   MWAWDocument::Kind kind;
   MWAWDocument::Confidence confidence = MWAWDocument::MWAW_C_NONE;
-  try {
-    confidence = MWAWDocument::isFileFormatSupported(&input, type, kind);
-  }
-  catch (...) {
-    confidence = MWAWDocument::MWAW_C_NONE;
-  }
-  if (confidence != MWAWDocument::MWAW_C_EXCELLENT) {
+  shared_ptr<librevenge::RVNGInputStream> input=libmwawHelper::isSupported(file, confidence, kind);
+  if (!input || confidence != MWAWDocument::MWAW_C_EXCELLENT) {
     printf("ERROR: Unsupported file format!\n");
     return 1;
   }
-  if (type == MWAWDocument::MWAW_T_UNKNOWN) {
-    printf("ERROR: can not determine the type of file!\n");
-    return 1;
-  }
   MWAWDocument::Result error=MWAWDocument::MWAW_R_OK;
   librevenge::RVNGStringVector vec;
 
   try {
     if (kind == MWAWDocument::MWAW_K_DRAW || kind == MWAWDocument::MWAW_K_PAINT) {
       librevenge::RVNGSVGDrawingGenerator listener(vec, "");
-      error = MWAWDocument::parse(&input, &listener);
+      error = MWAWDocument::parse(input.get(), &listener);
     }
     else if (kind == MWAWDocument::MWAW_K_PRESENTATION) {
       librevenge::RVNGSVGPresentationGenerator listener(vec);
-      error = MWAWDocument::parse(&input, &listener);
+      error = MWAWDocument::parse(input.get(), &listener);
     }
     else {
       fprintf(stderr,"ERROR: not a graphic/presentation document!\n");
@@ -158,22 +150,13 @@ int main(int argc, char *argv[])
   catch (...) {
     error=MWAWDocument::MWAW_R_UNKNOWN_ERROR;
   }
-  if (error == MWAWDocument::MWAW_R_FILE_ACCESS_ERROR)
-    fprintf(stderr, "ERROR: File Exception!\n");
-  else if (error == MWAWDocument::MWAW_R_PARSE_ERROR)
-    fprintf(stderr, "ERROR: Parse Exception!\n");
-  else if (error == MWAWDocument::MWAW_R_OLE_ERROR)
-    fprintf(stderr, "ERROR: File is an OLE document!\n");
-  else if (error != MWAWDocument::MWAW_R_OK)
-    fprintf(stderr, "ERROR: Unknown Error!\n");
-
-  if (error != MWAWDocument::MWAW_R_OK)
+  if (libmwawHelper::checkErrorAndPrintMessage(error))
     return 1;
 
   if (body) {
     for (unsigned i=0; i<vec.size(); ++i) {
       std::stringstream s;
-      s << body << (int) i << ".svg";
+      s << body << int(i) << ".svg";
       std::ofstream out(s.str().c_str());
       out << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>\n";
       out << "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"";
