@@ -63,14 +63,16 @@ struct Cell : public MWAWCell {
   //! the cell type
   enum Type { Text, Number, Date, Time, Picture, Formula, Memo, Unknown };
   //! constructor
-  Cell(Vec2i pos=Vec2i(0,0)) : MWAWCell(), m_type(Unknown), m_name(""), m_content(), m_formula(-1), m_isEmpty(false)
+  explicit Cell(MWAWVec2i pos=MWAWVec2i(0,0)) : MWAWCell(), m_type(Unknown), m_name(""), m_content(), m_formula(-1), m_pictureId(-1), m_isEmpty(false)
   {
     setPosition(pos);
   }
+  //! destructor
+  virtual ~Cell();
   //! returns true if the field has no content
   bool empty() const
   {
-    return m_content.empty();
+    return m_content.empty() && (m_type!=Picture || m_pictureId<=0);
   }
   //! the cell type
   Type m_type;
@@ -80,10 +82,16 @@ struct Cell : public MWAWCell {
   MWAWCellContent m_content;
   //! the formula id
   int m_formula;
+  //! picture id
+  int m_pictureId;
   //! flag to know if the cell is empty
   bool m_isEmpty;
 };
 
+Cell::~Cell()
+{
+}
+
 //! Internal: the spreadsheet of a BeagleWksDBParser
 struct Database {
   //! constructor
@@ -103,7 +111,7 @@ struct Database {
     return res;
   }
   //! update a field with the record data
-  void updateWithContent(Cell &cell, Vec2i const &pos, MWAWCellContent const &content) const;
+  void updateWithContent(Cell &cell, MWAWVec2i const &pos, MWAWCellContent const &content) const;
   //! the number of rows
   int m_numFields;
   //! the list of fields
@@ -116,7 +124,7 @@ struct Database {
   std::string m_name;
 };
 
-void Database::updateWithContent(Cell &cell, Vec2i const &pos, MWAWCellContent const &content) const
+void Database::updateWithContent(Cell &cell, MWAWVec2i const &pos, MWAWCellContent const &content) const
 {
   cell.setPosition(pos);
   switch (cell.m_type) {
@@ -132,7 +140,7 @@ void Database::updateWithContent(Cell &cell, Vec2i const &pos, MWAWCellContent c
   case Cell::Memo: {
     if (!content.isValueSet()) break;
     int id=int(0.1+content.m_value);
-    if (id<1 || id>(int) m_memos.size()) {
+    if (id<1 || id>static_cast<int>(m_memos.size())) {
       MWAW_DEBUG_MSG(("BeagleWksDBParserInternal::Database::updateWithContent: can not retrieve the memo content\n"));
       break;
     }
@@ -140,22 +148,19 @@ void Database::updateWithContent(Cell &cell, Vec2i const &pos, MWAWCellContent c
     cell.m_content.m_textEntry=m_memos[size_t(id-1)];
     break;
   }
-  case Cell::Picture: {
-    // content.m_value is the pictureId, but we have no way to retrieve the data, so...
-    static bool first=true;
-    if (first) {
-      first=false;
-      MWAW_DEBUG_MSG(("BeagleWksDBParserInternal::Database::updateWithContent: can not retrieve picture content is not implemented\n"));
-    }
-  }
+  case Cell::Picture:
+    cell.m_pictureId=int(0.1+content.m_value);
+    break;
+#if !defined(__clang__)
   default:
+#endif
   case Cell::Unknown:
     break;
   }
   MWAWCell::Format const &format=cell.getFormat();
   // change the reference date from 1/1/1904 to 1/1/1900
   if (format.m_format==MWAWCell::F_DATE && cell.m_content.isValueSet())
-    cell.m_content.setValue(cell.m_content.m_value+1462.);
+    cell.m_content.setValue(cell.m_content.m_value+1460.);
   // and try to update the 1D formula in 2D
   std::vector<MWAWCellContent::FormulaInstruction> &formula=cell.m_content.m_formula;
   for (size_t i=0; i<formula.size(); ++i) {
@@ -283,10 +288,10 @@ libmwaw::DebugFile &BeagleWksDBParser::rsrcAscii()
 ////////////////////////////////////////////////////////////
 // position and height
 ////////////////////////////////////////////////////////////
-Vec2f BeagleWksDBParser::getPageLeftTop() const
+MWAWVec2f BeagleWksDBParser::getPageLeftTop() const
 {
-  return Vec2f(float(getPageSpan().getMarginLeft()),
-               float(getPageSpan().getMarginTop()+m_state->m_headerHeight/72.0));
+  return MWAWVec2f(float(getPageSpan().getMarginLeft()),
+                   float(getPageSpan().getMarginTop()+m_state->m_headerHeight/72.0));
 }
 
 ////////////////////////////////////////////////////////////
@@ -294,8 +299,7 @@ Vec2f BeagleWksDBParser::getPageLeftTop() const
 ////////////////////////////////////////////////////////////
 void BeagleWksDBParser::parse(librevenge::RVNGSpreadsheetInterface *docInterface)
 {
-  assert(getInput().get() != 0);
-  if (!checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(0L))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
     // create the asciiFile
@@ -389,7 +393,7 @@ bool BeagleWksDBParser::createZones()
     MWAWEntry entry;
     entry.setBegin(input->readLong(4));
     entry.setLength(input->readLong(4));
-    entry.setId((int) input->readLong(2));
+    entry.setId(static_cast<int>(input->readLong(2)));
     if (entry.length()==0) continue;
     entry.setType(i==1?"Frame":"Unknown");
     f << entry.type() << "[" << entry.id() << "]="
@@ -443,7 +447,7 @@ bool BeagleWksDBParser::createZones()
   if (!readDatabase())
     return m_state->m_database.m_records.size()!=0;
   pos=input->tell();
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   if (N==0) {
     ascii().addPos(pos);
     ascii().addNote("_");
@@ -471,7 +475,7 @@ bool BeagleWksDBParser::createZones()
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
   pos=input->tell();
-  N=(int) input->readULong(2);
+  N=static_cast<int>(input->readULong(2));
   if (N==0) {
     ascii().addPos(pos);
     ascii().addNote("_");
@@ -488,9 +492,9 @@ bool BeagleWksDBParser::createZones()
   pos=input->tell();
   f.str("");
   f << "Entries(Memo):";
-  long dSz=(long) input->readULong(2);
+  long dSz=static_cast<long>(input->readULong(2));
   long endPos=pos+2+dSz;
-  N=(int)input->readULong(2);
+  N=static_cast<int>(input->readULong(2));
   if (dSz<2+2*long(N) || !input->checkPosition(endPos)) {
     MWAW_DEBUG_MSG(("BeagleWksDBParser::createZones: find data in UnkZone1\n"));
     f << "###";
@@ -504,9 +508,9 @@ bool BeagleWksDBParser::createZones()
     pos=input->tell();
     f.str("");
     f << "Memo-"<< i << ":";
-    int val=(int) input->readLong(1);
+    int val=static_cast<int>(input->readLong(1));
     if (val) f << "f0=" << val << ",";
-    int sSz=(int) input->readULong(1);
+    int sSz=static_cast<int>(input->readULong(1));
     if (pos+2+sSz>endPos) {
       MWAW_DEBUG_MSG(("BeagleWksDBParser::createZones: can not read a memo\n"));
       f << "###";
@@ -519,7 +523,7 @@ bool BeagleWksDBParser::createZones()
     memo.setLength(sSz);
     m_state->m_database.m_memos.push_back(memo);
     std::string text("");
-    for (int c=0; c<sSz; ++c) text+=(char) input->readULong(1);
+    for (int c=0; c<sSz; ++c) text+=char(input->readULong(1));
     f << text << ",";
     ascii().addPos(pos);
     ascii().addNote(f.str().c_str());
@@ -529,9 +533,9 @@ bool BeagleWksDBParser::createZones()
   pos=input->tell();
   f.str("");
   f << "Entries(UnknZone2):";
-  dSz=(long) input->readULong(2);
+  dSz=long(input->readULong(2));
   endPos=pos+6+dSz;
-  int val=(int)input->readULong(2);
+  int val=static_cast<int>(input->readULong(2));
   if ((dSz%2) || val!=0xeb || !input->checkPosition(endPos)) {
     MWAW_DEBUG_MSG(("BeagleWksDBParser::createZones: can not read zone2\n"));
     f << "###";
@@ -539,7 +543,7 @@ bool BeagleWksDBParser::createZones()
     ascii().addNote(f.str().c_str());
     return true;
   }
-  N=(int)input->readULong(2);
+  N=static_cast<int>(input->readULong(2));
   if (N) f << "N=" << N << ",";
   if (dSz==2*N) {
     f << "unkn=[";
@@ -562,9 +566,9 @@ bool BeagleWksDBParser::createZones()
     pos=input->tell();
     f.str("");
     f << "Entries(Formula):";
-    int id=(int) input->readLong(2);
-    if (id!=(int) i) f << "#id=" << id << ",";
-    dSz=(int) input->readULong(2);
+    int id=static_cast<int>(input->readLong(2));
+    if (id!=static_cast<int>(i)) f << "#id=" << id << ",";
+    dSz=static_cast<int>(input->readULong(2));
     endPos=pos+4+dSz;
     if (dSz==0 || !input->checkPosition(pos+4+dSz)) {
       MWAW_DEBUG_MSG(("BeagleWksDBParser::createZones: can not read a formula\n"));
@@ -575,7 +579,7 @@ bool BeagleWksDBParser::createZones()
     }
     std::vector<MWAWCellContent::FormulaInstruction> formula;
     std::string error("");
-    if (m_structureManager->readFormula(endPos, Vec2i(id,9), formula, error)) {
+    if (m_structureManager->readFormula(endPos, MWAWVec2i(id,9), formula, error)) {
       field.m_content.m_formula = formula;
       field.m_content.m_contentType = MWAWCellContent::C_FORMULA;
     }
@@ -649,20 +653,20 @@ bool BeagleWksDBParser::readPrintInfo()
   if (!info.read(input)) return false;
   f << "Entries(PrintInfo):"<< info;
 
-  Vec2i paperSize = info.paper().size();
-  Vec2i pageSize = info.page().size();
+  MWAWVec2i paperSize = info.paper().size();
+  MWAWVec2i pageSize = info.page().size();
   if (pageSize.x() <= 0 || pageSize.y() <= 0 ||
       paperSize.x() <= 0 || paperSize.y() <= 0) return false;
 
   // define margin from print info
-  Vec2i lTopMargin= -1 * info.paper().pos(0);
-  Vec2i rBotMargin=info.paper().pos(1) - info.page().pos(1);
+  MWAWVec2i lTopMargin= -1 * info.paper().pos(0);
+  MWAWVec2i rBotMargin=info.paper().pos(1) - info.page().pos(1);
 
   // move margin left | top
   int decalX = lTopMargin.x() > 14 ? lTopMargin.x()-14 : 0;
   int decalY = lTopMargin.y() > 14 ? lTopMargin.y()-14 : 0;
-  lTopMargin -= Vec2i(decalX, decalY);
-  rBotMargin += Vec2i(decalX, decalY);
+  lTopMargin -= MWAWVec2i(decalX, decalY);
+  rBotMargin += MWAWVec2i(decalX, decalY);
 
   // decrease right | bottom
   int rightMarg = rBotMargin.x() -10;
@@ -706,14 +710,14 @@ bool BeagleWksDBParser::readDatabase()
   f << "Entries(DbRow):";
   int val;
   for (int i=0; i<2; ++i) { // f0=0|1
-    val =(int) input->readLong(2);
+    val =static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
-  val =(int) input->readLong(2);
+  val =static_cast<int>(input->readLong(2));
   if (val!=7) f << "f2=" << val << ",";
-  int N=(int) input->readLong(2);
+  int N=static_cast<int>(input->readLong(2));
   f << "N=" << N << ",";
-  val =(int) input->readLong(2);
+  val =static_cast<int>(input->readLong(2));
   if (val) f << "f3=" << val << ",";
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
@@ -725,13 +729,13 @@ bool BeagleWksDBParser::readDatabase()
   pos=input->tell();
   f.str("");
   f << "Entries(DbFld):";
-  val =(int) input->readLong(2);
+  val =static_cast<int>(input->readLong(2));
   if (val) f << "f0=" << val << ",";
-  N=(int) input->readULong(2);
+  N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
-  val =(int) input->readLong(2);
+  val =static_cast<int>(input->readLong(2));
   if (val) f << "f1=" << val << ",";
-  int dSz =(int) input->readULong(2);
+  int dSz =static_cast<int>(input->readULong(2));
   f << "dSz=" << dSz << ",";
   if (dSz<14 || !input->checkPosition(pos+8+(N+1)*dSz)) {
     MWAW_DEBUG_MSG(("BeagleWksDBParser::readDatabase: can not find the database field format\n"));
@@ -745,7 +749,7 @@ bool BeagleWksDBParser::readDatabase()
 
   BeagleWksDBParserInternal::Database &database=m_state->m_database;
   size_t numFields=database.m_fields.size();
-  if (N+1>(int) numFields) {
+  if (N+1>static_cast<int>(numFields)) {
     MWAW_DEBUG_MSG(("BeagleWksDBParser::readDatabase: the number of field seems too small, must increase them\n"));
     database.m_fields.resize(size_t(N+1));
   }
@@ -754,9 +758,9 @@ bool BeagleWksDBParser::readDatabase()
     pos=input->tell();
     f.str("");
     f << "DbFld" << i << ":";
-    val=(int) input->readULong(2);
+    val=static_cast<int>(input->readULong(2));
     if (val!=1) f << "f0=" << val << ",";
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val!=0x4b) f << "f1=" << val << ",";
     // checkme: maybe we must use the read id here...
     BeagleWksDBParserInternal::Cell &field=database.m_fields[size_t(i)];
@@ -767,7 +771,7 @@ bool BeagleWksDBParser::readDatabase()
         input->seek(pos+dSz-2, librevenge::RVNG_SEEK_SET);
         ascii().addDelimiter(input->tell(),'|');
       }
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val!=i) f << "#id=" << val << ",";
     }
     input->seek(pos+dSz, librevenge::RVNG_SEEK_SET);
@@ -792,15 +796,15 @@ bool BeagleWksDBParser::readFormat(MWAWCell &cell, std::string &extra)
   libmwaw::DebugStream f;
   MWAWFont font;
   MWAWCell::Format format;
-  int val=(int) input->readULong(1);
+  int val=static_cast<int>(input->readULong(1));
   if (val) f << "f0=" << std::hex << val << std::dec << ",";
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
   if (val>0)
-    font.setSize((float) val);
-  val=(int) input->readLong(2);
+    font.setSize(float(val));
+  val=static_cast<int>(input->readLong(2));
   if (val>=0)
     font.setId(val);
-  int flag=(int) input->readULong(1);
+  int flag=static_cast<int>(input->readULong(1));
   uint32_t flags=0;
   if (flag&0x8) flags |= MWAWFont::boldBit;
   if (flag&0x10) flags |= MWAWFont::italicBit;
@@ -811,7 +815,7 @@ bool BeagleWksDBParser::readFormat(MWAWCell &cell, std::string &extra)
   f << font.getDebugString(getParserState()->m_fontConverter);
   if (flag&7) f << "flags=" << (flag&7) << ",";
 
-  int form=(int) input->readULong(1);
+  int form=static_cast<int>(input->readULong(1));
   if (form) {
     if (form & 0x10)
       format.m_thousandHasSeparator=true;
@@ -886,28 +890,28 @@ bool BeagleWksDBParser::readFormat(MWAWCell &cell, std::string &extra)
     f << format;
   }
 
-  val=(int) input->readULong(1);
+  val=static_cast<int>(input->readULong(1));
   if (val&0xF0) f << "col?="<<std::hex << (val>>4) << std::dec << ",";
   if (val&0xf) f << "bord?="<<std::hex << (val&0xF) << std::dec << ",";
 
-  val=(int) input->readULong(1);
+  val=static_cast<int>(input->readULong(1));
   switch ((val>>5)&7) {
   case 0:
-    cell.setHAlignement(MWAWCell::HALIGN_LEFT);
+    cell.setHAlignment(MWAWCell::HALIGN_LEFT);
     f << "left,";
     break;
   case 1:
-    cell.setHAlignement(MWAWCell::HALIGN_RIGHT);
+    cell.setHAlignment(MWAWCell::HALIGN_RIGHT);
     f << "right,";
     break;
   case 2:
-    cell.setHAlignement(MWAWCell::HALIGN_CENTER);
+    cell.setHAlignment(MWAWCell::HALIGN_CENTER);
     f << "center,";
     break;
   case 3: // default
     break;
   case 4:
-    cell.setHAlignement(MWAWCell::HALIGN_LEFT);
+    cell.setHAlignment(MWAWCell::HALIGN_LEFT);
     f << "filled,";
     break;
   default:
@@ -934,11 +938,11 @@ bool BeagleWksDBParser::readRow()
   long pos=input->tell();
   libmwaw::DebugStream f;
 
-  int id=(int) input->readLong(2);
+  int id=static_cast<int>(input->readLong(2));
   f << "DbRow" << id << ":";
-  int val=(int) input->readLong(2);
+  int val=static_cast<int>(input->readLong(2));
   if (val) f << "f0=" << val << ",";
-  long dSz=(long) input->readULong(2);
+  long dSz=long(input->readULong(2));
   long endPos=pos+6+dSz;
   if (dSz<18 || !input->checkPosition(pos+6+dSz)) {
     MWAW_DEBUG_MSG(("BeagleWksDBParser::readRow: can not find the database row %d\n", id));
@@ -947,13 +951,13 @@ bool BeagleWksDBParser::readRow()
     ascii().addNote(f.str().c_str());
     return false;
   }
-  val=(int) input->readLong(2); // 0|78|86
+  val=static_cast<int>(input->readLong(2)); // 0|78|86
   if (val) f << "f1=" << val << ",";
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val!=-1) f << "f2=" << val << ",";
   f << "fl?=[" << std::hex;
   for (int i=0; i<4; ++i) {
-    val=(int) input->readULong(2);
+    val=static_cast<int>(input->readULong(2));
     if (val) f << val << ",";
     else f << "_,";
   }
@@ -961,7 +965,7 @@ bool BeagleWksDBParser::readRow()
   // now a format
   f << "fId=" << input->readULong(2) << ",";
   f << "fSz=" << input->readULong(2) << ",";
-  val=(int) input->readULong(2);
+  val=static_cast<int>(input->readULong(2));
   if (val!=dSz) f << "#dSz1=" << val << ",";
 
   ascii().addPos(pos);
@@ -976,7 +980,7 @@ bool BeagleWksDBParser::readRow()
     if (pos>=endPos) break;
     f.str("");
     f << "DbRow" << id << "-" << fd << ":";
-    int fSz=(int) input->readULong(1);
+    int fSz=static_cast<int>(input->readULong(1));
     if (fSz==0xFF) {
       ascii().addPos(pos);
       ascii().addNote("_");
@@ -987,7 +991,7 @@ bool BeagleWksDBParser::readRow()
       MWAW_DEBUG_MSG(("BeagleWksDBParser::readRow: file size seems bad\n"));
       break;
     }
-    val=(int) input->readULong(1);
+    val=static_cast<int>(input->readULong(1));
     if (val!=0x20) f << "fl=" << std::hex << val << std::dec << ",";
     BeagleWksDBParserInternal::Cell const &field=database.m_fields[fd];
     MWAWCellContent content;
@@ -997,13 +1001,13 @@ bool BeagleWksDBParser::readRow()
     }
     else if (fSz) {
       for (int i=0; i<4; ++i) {
-        val=(int) input->readULong(2);
+        val=static_cast<int>(input->readULong(2));
         if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
       }
       switch (field.m_type) {
       case BeagleWksDBParserInternal::Cell::Formula:
         if (fSz>20) break;
-        val=(int) input->readULong(2);
+        val=static_cast<int>(input->readULong(2));
         if (val) f << "g0=" << std::hex << val << std::dec << ",";
       case BeagleWksDBParserInternal::Cell::Memo: // memoId
       case BeagleWksDBParserInternal::Cell::Picture: // pictId
@@ -1032,13 +1036,15 @@ bool BeagleWksDBParser::readRow()
         content.m_textEntry.setBegin(input->tell());
         content.m_textEntry.setEnd(pos+fSz+2);
         std::string text("");
-        while (input->tell()<pos+fSz+2) text+=(char) input->readULong(1);
+        while (input->tell()<pos+fSz+2) text+=char(input->readULong(1));
         f << text << ",";
       }
       break;
       case BeagleWksDBParserInternal::Cell::Unknown:
+#if !defined(__clang__)
       default:
-        f << "type=" << (int) field.m_type << ",";
+#endif
+        f << "type=" << static_cast<int>(field.m_type) << ",";
         break;
       }
     }
@@ -1073,12 +1079,12 @@ bool BeagleWksDBParser::readFields()
   }
   libmwaw::DebugStream f;
   f << "Entries(Field):";
-  int val=(int) input->readLong(2);
+  int val=static_cast<int>(input->readLong(2));
   if (val) f << "f0=" << val << ",";
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val!=0x2c) // may a type
     f << "f1=" << val << ",";
-  database.m_numFields=(int) input->readULong(2);
+  database.m_numFields=static_cast<int>(input->readULong(2));
   f << "num[fields]=" << database.m_numFields << ",";
   if (!input->checkPosition(pos+database.m_numFields*64)) {
     MWAW_DEBUG_MSG(("BeagleWksDBParser::readFields: can not find the fields zone\n"));
@@ -1090,13 +1096,12 @@ bool BeagleWksDBParser::readFields()
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
 
-  pos=input->tell();
   for (int fld=0; fld<database.m_numFields; ++fld) {
     pos=input->tell();
     f.str("");
     f << "Field-" << fld << ":";
     BeagleWksDBParserInternal::Cell field;
-    long dSz=(long) input->readULong(2);
+    long dSz=long(input->readULong(2));
     long endPos=pos+4+dSz;
     if (dSz<0x3c || !input->checkPosition(endPos)) {
       MWAW_DEBUG_MSG(("BeagleWksDBParser::readFields: can not read a field\n"));
@@ -1105,9 +1110,9 @@ bool BeagleWksDBParser::readFields()
       ascii().addNote(f.str().c_str());
       return false;
     }
-    int id=(int) input->readLong(2);
+    int id=static_cast<int>(input->readLong(2));
     if (id) f << "id=" << id << ",";
-    int sSz=(int) input->readULong(1);
+    int sSz=static_cast<int>(input->readULong(1));
     if (sSz+1>dSz) {
       MWAW_DEBUG_MSG(("BeagleWksDBParser::readFields: can not read a field\n"));
       f << "###";
@@ -1115,7 +1120,7 @@ bool BeagleWksDBParser::readFields()
       ascii().addNote(f.str().c_str());
       return false;
     }
-    for (int i=0; i<sSz; ++i) field.m_name += (char) input->readULong(1);
+    for (int i=0; i<sSz; ++i) field.m_name += char(input->readULong(1));
     f << "\"" << field.m_name << "\",";
     ascii().addDelimiter(input->tell(),'|');
     input->seek(endPos-10, librevenge::RVNG_SEEK_SET);
@@ -1123,7 +1128,7 @@ bool BeagleWksDBParser::readFields()
 
     MWAWCell::Format format;
     MWAWCellContent &content=field.m_content;
-    int type=(int) input->readLong(1);
+    int type=static_cast<int>(input->readLong(1));
     switch (type) {
     case 0:
       field.m_type = BeagleWksDBParserInternal::Cell::Text;
@@ -1173,7 +1178,7 @@ bool BeagleWksDBParser::readFields()
     }
     f << "form?=" << std::hex << input->readULong(1) << std::dec << ",";
     f << "id2=" << std::hex << input->readULong(4) << std::dec << ",";
-    val=(int) input->readLong(2); // 0|-1
+    val=static_cast<int>(input->readLong(2)); // 0|-1
     if (val!=-1) f << "g0=" << val << ",";
     f << "g1=" << input->readLong(2) << ",";
     database.m_fields.push_back(field);
@@ -1198,12 +1203,12 @@ bool BeagleWksDBParser::readLayouts()
   }
   libmwaw::DebugStream f;
   f << "Entries(Layout):";
-  int val=(int) input->readLong(2);
+  int val=static_cast<int>(input->readLong(2));
   if (val) f << "f0=" << val << ",";
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val!=0x29) // may a type
     f << "f1=" << val << ",";
-  int numLayouts=(int) input->readULong(2);
+  int numLayouts=static_cast<int>(input->readULong(2));
   f << "num[layout]=" << numLayouts << ",";
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
@@ -1221,8 +1226,8 @@ bool BeagleWksDBParser::readLayout(int id)
   f << "Layout-" << id << "[A]:";
 
   long pos=input->tell();
-  int readId=(int) input->readULong(1);
-  long dSz=(long) input->readULong(2);
+  int readId=static_cast<int>(input->readULong(1));
+  long dSz=long(input->readULong(2));
   long endPos=pos+1+dSz;
   if (dSz<100 || !input->checkPosition(endPos)) {
     MWAW_DEBUG_MSG(("BeagleWksDBParser::readLayouts: can find a layout\n"));
@@ -1232,11 +1237,11 @@ bool BeagleWksDBParser::readLayout(int id)
     return false;
   }
   if (readId!=id) f << "#id=" << readId << ",";
-  int val=(int) input->readLong(2);
+  int val=static_cast<int>(input->readLong(2));
   if (val) f << "f0=" << val << ",";
-  val=(int) input->readULong(1);
+  val=static_cast<int>(input->readULong(1));
   if (val!=readId) f << "#id1=" << val << ",";
-  int sSz=(int) input->readULong(1);
+  int sSz=static_cast<int>(input->readULong(1));
   if (sSz>30) {
     MWAW_DEBUG_MSG(("BeagleWksDBParser::readLayouts: can find layout string\n"));
     f << "###sSz=" << sSz << ",";
@@ -1245,24 +1250,24 @@ bool BeagleWksDBParser::readLayout(int id)
     return false;
   }
   std::string name("");
-  for (int i=0; i<sSz; ++i) name+=(char) input->readULong(1);
+  for (int i=0; i<sSz; ++i) name+=char(input->readULong(1));
   f << name << ",";
   input->seek(pos+37, librevenge::RVNG_SEEK_SET);
   f << "ids=[" << std::hex;
   for (int i=0; i<3; ++i) f << input->readULong(4) << ",";
   f << std::dec << "],";
-  val=(int) input->readLong(2); // small number
+  val=static_cast<int>(input->readLong(2)); // small number
   f << "N=" << val << ",";
   for (int i=0; i<6; ++i) { // f4=0|78, f5=0|68
     static int const expected[]= {0x100, 0, 0, 0, 0, 0xffff };
-    val = (int) input->readULong(2);
+    val = static_cast<int>(input->readULong(2));
     if (val!=expected[i])
       f << "f" << i+2 << "=" << std::hex << val << std::dec << ",";
   }
   f << "g0=" << std::hex << input->readULong(4) << std::dec << ",";
   f << "id2s=[" << std::hex;
   for (int i=0; i<4; ++i) {
-    val=(int) input->readULong(i==2 ? 2 : 4);
+    val=static_cast<int>(input->readULong(i==2 ? 2 : 4));
     if (val)
       f << val << ",";
     else
@@ -1283,7 +1288,7 @@ bool BeagleWksDBParser::readLayout(int id)
   }
   f << "],";
   for (int i=0; i<3; ++i) {
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   f << "id=" << std::hex << input->readULong(4) << std::dec << ",";
@@ -1296,7 +1301,7 @@ bool BeagleWksDBParser::readLayout(int id)
   f.str("");
   f << "Layout-" << id << "[C]:";
   for (int i=0; i<8; i++) {
-    val=(int) input->readLong(1);
+    val=static_cast<int>(input->readLong(1));
     if (val==1) f << "fl" << i << ",";
     else if (val) f << "fl" << i << "=" << val << ",";
   }
@@ -1341,7 +1346,7 @@ bool BeagleWksDBParser::readLayout(int id)
   pos=input->tell();
   f.str("");
   f << "Layout-" << id << "[D]:";
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   if (!input->checkPosition(pos+2+2*N)) {
     MWAW_DEBUG_MSG(("BeagleWksDBParser::readLayouts: can find zone D\n"));
@@ -1361,9 +1366,9 @@ bool BeagleWksDBParser::readLayout(int id)
   pos=input->tell();
   f.str("");
   f << "Layout-" << id << "[fields]:";
-  val=(int) input->readULong(2);
-  int type=(int) input->readULong(2);
-  N=(int) input->readULong(2);
+  val=static_cast<int>(input->readULong(2));
+  int type=static_cast<int>(input->readULong(2));
+  N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   if (type!=0x5a || !input->checkPosition(pos+6+36*N)) {
     MWAW_DEBUG_MSG(("BeagleWksDBParser::readLayouts: can find field zone \n"));
@@ -1379,9 +1384,9 @@ bool BeagleWksDBParser::readLayout(int id)
     pos=input->tell();
     f.str("");
     f << "Layout-" << id << "[field" << i << "]:";
-    id=(int) input->readLong(2);
+    id=static_cast<int>(input->readLong(2));
     if (id!=i) f << "id[field]=" << val << ",";
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val!=0x4b) f << "f0=" << val << ",";
     for (int j=0; j<2; ++j) { // j=0: field name, j=1: field content
       std::string extra("");
@@ -1393,7 +1398,7 @@ bool BeagleWksDBParser::readLayout(int id)
     }
     for (int j=0; j<2; ++j) {
       int dim[4];
-      for (int k=0; k<4; ++k) dim[k]=(int) input->readLong(2);
+      for (int k=0; k<4; ++k) dim[k]=static_cast<int>(input->readLong(2));
       f << "box" << j << "=" << dim[1] << "x" << dim[0] << "<->" << dim[3] << "x" << dim[2] << ",";
     }
     ascii().addPos(pos);
@@ -1404,9 +1409,9 @@ bool BeagleWksDBParser::readLayout(int id)
   pos=input->tell();
   f.str("");
   f << "Layout-" << id << "[list]:";
-  dSz=(int) input->readULong(2);
-  type=(int) input->readLong(2);
-  N=(int) input->readULong(2);
+  dSz=static_cast<int>(input->readULong(2));
+  type=static_cast<int>(input->readLong(2));
+  N=static_cast<int>(input->readULong(2));
   endPos=pos+6+dSz;
   if (2*N>dSz || type!=0x75 || !input->checkPosition(endPos)) {
     MWAW_DEBUG_MSG(("BeagleWksDBParser::readLayouts: can read zone F\n"));
@@ -1440,7 +1445,7 @@ bool BeagleWksDBParser::sendPageFrames()
 
 bool BeagleWksDBParser::sendFrame(BeagleWksStructManager::Frame const &frame)
 {
-  MWAWPosition fPos(Vec2f(0,0), frame.m_dim, librevenge::RVNG_POINT);
+  MWAWPosition fPos(MWAWVec2f(0,0), frame.m_dim, librevenge::RVNG_POINT);
 
   fPos.setPagePos(frame.m_page > 0 ? frame.m_page : 1, frame.m_origin);
   fPos.setRelativePosition(MWAWPosition::Page);
@@ -1448,12 +1453,12 @@ bool BeagleWksDBParser::sendFrame(BeagleWksStructManager::Frame const &frame)
 
   MWAWGraphicStyle style=MWAWGraphicStyle::emptyStyle();
   style.setBorders(frame.m_bordersSet, frame.m_border);
-  return sendPicture(frame.m_pictId, fPos, style);
+  return sendPicture(frame.m_pictId, fPos, true, style);
 }
 
 // read/send picture (edtp resource)
 bool BeagleWksDBParser::sendPicture
-(int pId, MWAWPosition const &pictPos, MWAWGraphicStyle const &style)
+(int pId, MWAWPosition const &pictPos, bool readEDTP, MWAWGraphicStyle const &style)
 {
   MWAWSpreadsheetListenerPtr listener=getSpreadsheetListener();
   if (!listener) {
@@ -1471,10 +1476,10 @@ bool BeagleWksDBParser::sendPicture
   }
 
   librevenge::RVNGBinaryData data;
-  if (!m_structureManager->readPicture(pId, data))
+  if (!m_structureManager->readPicture(pId, data, readEDTP))
     return false;
 
-  listener->insertPicture(pictPos, data, "image/pict", style);
+  listener->insertPicture(pictPos, MWAWEmbeddedObject(data, "image/pict"), style);
   return true;
 }
 
@@ -1496,7 +1501,7 @@ bool BeagleWksDBParser::sendText(MWAWEntry entry, bool /*headerFooter*/)
   while (!input->isEnd()) {
     long pos=input->tell();
     if (pos>=endPos) break;
-    unsigned char c = (unsigned char) input->readULong(1);
+    unsigned char c = static_cast<unsigned char>(input->readULong(1));
     switch (c) {
     case 0x9:
       listener->insertTab();
@@ -1505,7 +1510,7 @@ bool BeagleWksDBParser::sendText(MWAWEntry entry, bool /*headerFooter*/)
       listener->insertEOL();
       break;
     default:
-      listener->insertCharacter((unsigned char) c);
+      listener->insertCharacter(static_cast<unsigned char>(c));
       break;
     }
   }
@@ -1528,14 +1533,14 @@ bool BeagleWksDBParser::sendDatabase()
   std::vector<std::vector<MWAWCellContent> > const &records=database.m_records;
   size_t numRecords=records.size();
   // fixme: use first layout colWidth here
-  listener->openSheet(std::vector<float>(numRecords,76), librevenge::RVNG_POINT, "Sheet0");
+  listener->openSheet(std::vector<float>(1,76), librevenge::RVNG_POINT, std::vector<int>(1,static_cast<int>(numRecords)), "Sheet0");
   for (size_t r=0; r<numRecords; ++r) {
     std::vector<MWAWCellContent> const &row=records[r];
     listener->openSheetRow(12, librevenge::RVNG_POINT);
     for (size_t c=0; c<row.size(); ++c) {
       if (c>=numFields) break;
       BeagleWksDBParserInternal::Cell field=fields[c];
-      database.updateWithContent(field, Vec2i(int(c),int(r)), row[c]);
+      database.updateWithContent(field, MWAWVec2i(int(c),int(r)), row[c]);
       if (field.empty()) continue;
 
       MWAWCellContent const &content=field.m_content;
@@ -1544,7 +1549,7 @@ bool BeagleWksDBParser::sendDatabase()
         listener->setFont(field.getFont());
         input->seek(content.m_textEntry.begin(), librevenge::RVNG_SEEK_SET);
         while (!input->isEnd() && input->tell()<content.m_textEntry.end()) {
-          unsigned char ch=(unsigned char) input->readULong(1);
+          unsigned char ch=static_cast<unsigned char>(input->readULong(1));
           if (ch==0xd)
             listener->insertEOL();
           else if (ch<30) {
@@ -1555,6 +1560,13 @@ bool BeagleWksDBParser::sendDatabase()
             listener->insertCharacter(ch);
         }
       }
+      else if (field.m_type==BeagleWksDBParserInternal::Cell::Picture && field.m_pictureId>=0) {
+        std::string cellName("Sheet0.");
+        cellName+=MWAWCell::getBasicCellName(field.position()+MWAWVec2i(1,1));
+        MWAWPosition position(MWAWVec2f(0,0), MWAWVec2f(76,12), librevenge::RVNG_POINT); // changeme
+        position.setAnchorToCell(librevenge::RVNGString(cellName.c_str()));
+        sendPicture(field.m_pictureId, position, false);
+      }
       listener->closeSheetCell();
     }
     listener->closeSheetRow();
@@ -1589,7 +1601,7 @@ bool BeagleWksDBParser::checkHeader(MWAWHeader *header, bool strict)
     return false;
   }
   for (int i=0; i < 9; ++i) { // f2=f6=1 other 0
-    int val=(int) input->readLong(2);
+    int val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   setVersion(1);
@@ -1616,7 +1628,7 @@ bool BeagleWksDBParser::checkHeader(MWAWHeader *header, bool strict)
   MWAWEntry entry;
   entry.setBegin(input->readLong(4));
   entry.setLength(input->readLong(4));
-  entry.setId((int) input->readLong(2)); // in fact nFonts
+  entry.setId(static_cast<int>(input->readLong(2))); // in fact nFonts
   entry.setType("FontNames");
   f << "fontNames[ptr]=" << std::hex << entry.begin() << "<->" << entry.end()
     << std::dec << ",nFonts=" << entry.id() << ",";
