@@ -117,10 +117,10 @@ libmwaw::DebugFile &BeagleWksParser::rsrcAscii()
 ////////////////////////////////////////////////////////////
 // position and height
 ////////////////////////////////////////////////////////////
-Vec2f BeagleWksParser::getPageLeftTop() const
+MWAWVec2f BeagleWksParser::getPageLeftTop() const
 {
-  return Vec2f(float(getPageSpan().getMarginLeft()),
-               float(getPageSpan().getMarginTop()+m_state->m_headerHeight/72.0));
+  return MWAWVec2f(float(getPageSpan().getMarginLeft()),
+                   float(getPageSpan().getMarginTop()+m_state->m_headerHeight/72.0));
 }
 
 ////////////////////////////////////////////////////////////
@@ -159,8 +159,7 @@ void BeagleWksParser::newPage(int number)
 ////////////////////////////////////////////////////////////
 void BeagleWksParser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  assert(getInput().get() != 0);
-  if (!checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(0L))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
     // create the asciiFile
@@ -276,7 +275,7 @@ bool BeagleWksParser::createZones()
     MWAWEntry entry;
     entry.setBegin(input->readLong(4));
     entry.setLength(input->readLong(4));
-    entry.setId((int) input->readLong(2));
+    entry.setId(static_cast<int>(input->readLong(2)));
     if (entry.length()==0) continue;
     entry.setType(i==1?"Frame":"Unknown");
     f << entry.type() << "[" << entry.id() << "]="
@@ -379,7 +378,7 @@ bool BeagleWksParser::sendPageFrames()
 
 bool BeagleWksParser::sendFrame(BeagleWksStructManager::Frame const &frame)
 {
-  MWAWPosition fPos(Vec2f(0,0), frame.m_dim, librevenge::RVNG_POINT);
+  MWAWPosition fPos(MWAWVec2f(0,0), frame.m_dim, librevenge::RVNG_POINT);
   MWAWGraphicStyle style=MWAWGraphicStyle::emptyStyle();
   if (frame.m_charAnchor)
     fPos.setRelativePosition(MWAWPosition::Char);
@@ -409,20 +408,20 @@ bool BeagleWksParser::readPrintInfo()
   if (!info.read(input)) return false;
   f << "Entries(PrintInfo):"<< info;
 
-  Vec2i paperSize = info.paper().size();
-  Vec2i pageSize = info.page().size();
+  MWAWVec2i paperSize = info.paper().size();
+  MWAWVec2i pageSize = info.page().size();
   if (pageSize.x() <= 0 || pageSize.y() <= 0 ||
       paperSize.x() <= 0 || paperSize.y() <= 0) return false;
 
   // define margin from print info
-  Vec2i lTopMargin= -1 * info.paper().pos(0);
-  Vec2i rBotMargin=info.paper().pos(1) - info.page().pos(1);
+  MWAWVec2i lTopMargin= -1 * info.paper().pos(0);
+  MWAWVec2i rBotMargin=info.paper().pos(1) - info.page().pos(1);
 
   // move margin left | top
   int decalX = lTopMargin.x() > 14 ? lTopMargin.x()-14 : 0;
   int decalY = lTopMargin.y() > 14 ? lTopMargin.y()-14 : 0;
-  lTopMargin -= Vec2i(decalX, decalY);
-  rBotMargin += Vec2i(decalX, decalY);
+  lTopMargin -= MWAWVec2i(decalX, decalY);
+  rBotMargin += MWAWVec2i(decalX, decalY);
 
   // decrease right | bottom
   int rightMarg = rBotMargin.x() -10;
@@ -503,7 +502,7 @@ bool BeagleWksParser::readLastZone()
     MWAW_DEBUG_MSG(("BeagleWksParser::readLastZone: the page margins seem bad\n"));
     f << "###";
   }
-  int val=(int) input->readLong(2);
+  int val=static_cast<int>(input->readLong(2));
   if (val!=1) f << "firstPage=" << val << ",";
   ascii().addDelimiter(input->tell(),'|');
   ascii().addPos(pos);
@@ -524,11 +523,11 @@ bool BeagleWksParser::readLastZone()
   f.str("");
   f << "LastZone-D:";
   for (int i=0; i < 2; ++i) { // always 0 excepted one time f0=0x263,f1=-7
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   for (int i=0; i < 140; ++i) { // a list of flags ? all 1 expected f3=-1
-    val=(int) input->readLong(1);
+    val=static_cast<int>(input->readLong(1));
     if (val!=1) f << "g" << i << "=" << val << ",";
   }
   ascii().addPos(pos);
@@ -537,13 +536,13 @@ bool BeagleWksParser::readLastZone()
   pos=input->tell();
   f.str("");
   f << "LastZone-E:";
-  val=(int)input->readLong(4); // a big number, a dim?
+  val=static_cast<int>(input->readLong(4)); // a big number, a dim?
   if (val) f << "dim?=" << double(val)/65536. << ",";
-  val=(int) input->readLong(2); // 1|2|3|4
+  val=static_cast<int>(input->readLong(2)); // 1|2|3|4
   if (val) f << "f0=" << val << ",";
   for (int i=0; i<4; ++i) {
     static int const expectedVal[]= {0x6c, 0xc, 0, 0x21};
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val != expectedVal[i])
       f << "f" << i+1 << "=" << val << ",";
   }
@@ -581,7 +580,7 @@ bool BeagleWksParser::sendPicture
   if (!m_structureManager->readPicture(pId, data))
     return false;
 
-  listener->insertPicture(pictPos, data, "image/pict", style);
+  listener->insertPicture(pictPos, MWAWEmbeddedObject(data, "image/pict"), style);
   return true;
 }
 
@@ -612,7 +611,7 @@ bool BeagleWksParser::checkHeader(MWAWHeader *header, bool strict)
     return false;
   }
   for (int i=0; i<9; ++i) { // f2=f6=1 other 0
-    int val=(int) input->readLong(2);
+    int val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   setVersion(1);
@@ -639,7 +638,7 @@ bool BeagleWksParser::checkHeader(MWAWHeader *header, bool strict)
   MWAWEntry entry;
   entry.setBegin(input->readLong(4));
   entry.setLength(input->readLong(4));
-  entry.setId((int) input->readLong(2)); // in fact nFonts
+  entry.setId(static_cast<int>(input->readLong(2))); // in fact nFonts
   entry.setType("FontNames");
   f << "fontNames[ptr]=" << std::hex << entry.begin() << "<->" << entry.end()
     << std::dec << ",nFonts=" << entry.id() << ",";
