@@ -66,6 +66,8 @@ struct Cell : public MWAWCell {
   {
     setPosition(pos);
   }
+  //! destructor
+  virtual ~Cell();
   //! the cell content
   MWAWCellContent m_content;
   //! the formula id
@@ -74,6 +76,10 @@ struct Cell : public MWAWCell {
   bool m_isEmpty;
 };
 
+Cell::~Cell()
+{
+}
+
 //! Internal: the spreadsheet of a BeagleWksSSParser
 struct Spreadsheet {
   //! constructor
@@ -85,7 +91,7 @@ struct Spreadsheet {
   //! returns the height of a row in point
   double getRowHeight(int row) const
   {
-    if (row<0 || row>=(int) m_heightRows.size() || m_heightRows[size_t(row)]<0)
+    if (row<0 || row>=static_cast<int>(m_heightRows.size()) || m_heightRows[size_t(row)]<0)
       return 16.;
     return m_heightRows[size_t(row)];
   }
@@ -94,7 +100,7 @@ struct Spreadsheet {
   {
     double res=getRowHeight(row);
     numRepeated=1;
-    if (row<0 || row>=(int) m_heightRows.size())
+    if (row<0 || row>=static_cast<int>(m_heightRows.size()))
       numRepeated=1000;
     else {
       for (size_t r=size_t(row+1); r<m_heightRows.size(); ++r) {
@@ -452,7 +458,7 @@ bool BeagleWksSSParser::createZones()
     MWAWEntry entry;
     entry.setBegin(input->readLong(4));
     entry.setLength(input->readLong(4));
-    entry.setId((int) input->readLong(2));
+    entry.setId(static_cast<int>(input->readLong(2)));
     if (entry.length()==0) continue;
     entry.setType(i==1?"Frame":"Unknown");
     f << entry.type() << "[" << entry.id() << "]="
@@ -626,7 +632,7 @@ bool BeagleWksSSParser::readChartZone()
   pos = input->tell();
   for (int i=0; i < 4; ++i) {
     static int const expectedValues[5]= {1, 0xF, 0x4000, 0x100 };
-    int val= (int) input->readULong(2);
+    int val= static_cast<int>(input->readULong(2));
     if (val != expectedValues[i])
       f << "f" << i+1 << "=" << std::hex << val << std::dec << ",";
   }
@@ -634,7 +640,7 @@ bool BeagleWksSSParser::readChartZone()
   ascii().addNote(f.str().c_str());
   while (!input->isEnd()) {
     pos=input->tell();
-    long sz=(long) input->readULong(2);
+    long sz=long(input->readULong(2));
     if (sz==0) {
       ascii().addPos(pos);
       ascii().addNote("Chart:_");
@@ -658,17 +664,17 @@ bool BeagleWksSSParser::readChart()
   }
   libmwaw::DebugStream f;
   f << "Chart-header:";
-  int val=(int) input->readULong(2);
+  int val=static_cast<int>(input->readULong(2));
   f << "f0=" << std::hex << val << std::dec << ",";
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val!=0x12) f << "f1=" << val << ",";
   bool findRange=false;
   shared_ptr<BeagleWksSSParserInternal::Chart> chart(new BeagleWksSSParserInternal::Chart(m_state->m_spreadsheetName, *this));
   MWAWBox2i serieRange;
   for (int i=0; i<2; ++i) {
     long actPos=input->tell();
-    int dSz=(int) input->readULong(2);
-    int sSz=(int) input->readULong(1);
+    int dSz=static_cast<int>(input->readULong(2));
+    int sSz=static_cast<int>(input->readULong(1));
     if (sSz+1!=dSz && sSz+2!=dSz) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       MWAW_DEBUG_MSG(("BeagleWksSSParser::readChart: can not read the chart\n"));
@@ -679,23 +685,23 @@ bool BeagleWksSSParser::readChart()
     }
     std::string name("");
     for (int c=0; c<sSz; ++c)
-      name += (char) input->readULong(1);
-    if (i==1 && sSz>=5 && (int) name.length()==sSz) {
+      name += char(input->readULong(1));
+    if (i==1 && sSz>=5 && static_cast<int>(name.length())==sSz) {
       size_t cPos=0;
       for (int c=0; c<2; c++) {
-        if (cPos+1>=(size_t) sSz) break;
+        if (cPos+1>=size_t(sSz)) break;
         char ch=name[cPos++];
         if (ch<'A' || ch>'Z') break;
         int col=int(ch-'A')+1;
         ch=name[cPos++];
         if (ch>='A' && ch<='Z') {
           col=26*col+int(ch-'A')+1;
-          if (cPos+1>=(size_t) sSz) break;
+          if (cPos+1>=size_t(sSz)) break;
           ch=name[cPos++];
         }
         if (ch<'1' || ch>'9') break;
         int row=ch-'0';
-        while (cPos<(size_t)sSz && name[cPos]>='0' && name[cPos]<='9') {
+        while (cPos<size_t(sSz) && name[cPos]>='0' && name[cPos]<='9') {
           row=row*10+int(name[cPos++]-'0');
         }
         if (c==0)
@@ -705,7 +711,7 @@ bool BeagleWksSSParser::readChart()
           findRange=true;
           break;
         }
-        if (cPos>=(size_t)sSz || name[cPos++]!=':')
+        if (cPos>=size_t(sSz) || name[cPos++]!=':')
           break;
       }
     }
@@ -722,7 +728,7 @@ bool BeagleWksSSParser::readChart()
   pos=input->tell();
   f.str("");
   f << "Chart-B:";
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
   MWAWChart::Axis axis[2];
   switch (val) {
   case 1: // show
@@ -736,13 +742,13 @@ bool BeagleWksSSParser::readChart()
     f << "#show[label]=" << val << ",";
     break;
   }
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
   if (val) f << "f0=" << val << ",";
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
   f << "f1=" << val << ",";
   for (int i=0; i<7; ++i) {
     int dim[2];
-    for (int j=0; j<2; ++j) dim[j]=(int) input->readLong(2);
+    for (int j=0; j<2; ++j) dim[j]=static_cast<int>(input->readLong(2));
     if (dim[0]||dim[1])
       f << "dim" << i << "?=" << dim[0] << "x" << dim[1] << ",";
   }
@@ -754,12 +760,12 @@ bool BeagleWksSSParser::readChart()
   f << "Chart-C:";
   for (int i=0; i<3; ++i) {
     int const expectedVal[3]= {0xe, 0, 0x21};
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val!=expectedVal[i]) f << "f" << i << "=" << val << ",";
   }
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   f << "f3=" << val << ",";
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
 
   axis[1].m_type=MWAWChart::Axis::A_Numeric;
   switch (val) {
@@ -773,7 +779,7 @@ bool BeagleWksSSParser::readChart()
     f << "#yScale="<<val << ",";
     break;
   }
-  val=(int) input->readLong(1);
+  val=static_cast<int>(input->readLong(1));
 
   axis[0].m_type=MWAWChart::Axis::A_Sequence;
   switch (val) {
@@ -792,7 +798,7 @@ bool BeagleWksSSParser::readChart()
   }
   axis[0].m_showGrid=axis[1].m_showGrid=false;
   for (int i=0; i<4; ++i) {
-    val=(int) input->readLong(1);
+    val=static_cast<int>(input->readLong(1));
     if (!val) continue;
     char const *(wh[4])= {"draw[grid]", "draw[value]", "auto[scale]", "flip[RowCol]"};
     f << wh[i];
@@ -811,9 +817,9 @@ bool BeagleWksSSParser::readChart()
       f << "###";
     f << wh[i] << "=" << value << ",";
   }
-  val=(int) input->readULong(1); // always 0?
+  val=static_cast<int>(input->readULong(1)); // always 0?
   if (val) f << "g0=" << val << ",";
-  val=(int) input->readULong(1);
+  val=static_cast<int>(input->readULong(1));
   MWAWChart::Series::Type serieType=MWAWChart::Series::S_Bar;
   switch (val) {
   case 0x19:
@@ -860,7 +866,7 @@ bool BeagleWksSSParser::readChart()
   long endPos = pos+67;
   f.str("");
   f << "Chart-D:";
-  int sSz=(int) input->readULong(1);
+  int sSz=static_cast<int>(input->readULong(1));
   if (pos+1+sSz <= endPos) {
     MWAWChart::TextZone title;
     title.m_type=MWAWChart::TextZone::T_Title;
@@ -870,7 +876,7 @@ bool BeagleWksSSParser::readChart()
     chart->add(title);
     std::string name("");
     for (int c=0; c<sSz; ++c)
-      name += (char) input->readULong(1);
+      name += char(input->readULong(1));
     f << "\"" << name << "\",";
   }
   else
@@ -884,7 +890,7 @@ bool BeagleWksSSParser::readChart()
       series.m_range=MWAWBox2i(MWAWVec2i(serieRange[0][0], r),
                                MWAWVec2i(serieRange[1][0], r));
       series.m_type=serieType;
-      unsigned char gray=(unsigned char)((r%4)*30);
+      unsigned char gray=static_cast<unsigned char>((r%4)*30);
       series.m_style.m_lineWidth=1;
       series.m_style.m_lineColor=MWAWColor(gray,gray,gray);
       series.m_style.setSurfaceColor(MWAWColor(gray,gray,gray));
@@ -916,17 +922,17 @@ bool BeagleWksSSParser::readSpreadsheet()
   }
   libmwaw::DebugStream f;
   f << "Entries(Spreadsheet):";
-  int val= (int) input->readLong(2);
+  int val= static_cast<int>(input->readLong(2));
   if (val!=7)
     f << "f1=" << val << ",";
   BeagleWksSSParserInternal::Spreadsheet &sheet=m_state->m_spreadsheet;
-  sheet.m_numRows=(int) input->readLong(2)+1;
+  sheet.m_numRows=static_cast<int>(input->readLong(2))+1;
   f << "num[row]=" << sheet.m_numRows << ",";
-  val= (int) input->readLong(2);
+  val= static_cast<int>(input->readLong(2));
   if (val!=-1)
     f << "f2=" << val << ",";
   for (int i=0; i < 3; ++i) { // g0=0|73|89, other 0
-    val=(int) input->readULong(1);
+    val=static_cast<int>(input->readULong(1));
     if (val)
       f << "g" << i << "=" << std::hex << val << std::dec << ",";
   }
@@ -944,8 +950,8 @@ bool BeagleWksSSParser::readRowSheet(BeagleWksSSParserInternal::Spreadsheet &she
   long pos=input->tell();
   libmwaw::DebugStream f;
   f << "Entries(Row):";
-  int row=(int)input->readLong(2);
-  long fSz=(long) input->readULong(4);
+  int row=static_cast<int>(input->readLong(2));
+  long fSz=long(input->readULong(4));
   long endPos=pos+6+fSz;
   if (fSz<18 || row <= sheet.m_lastReadRow || row >= sheet.m_numRows || !input->checkPosition(endPos)) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -953,18 +959,18 @@ bool BeagleWksSSParser::readRowSheet(BeagleWksSSParserInternal::Spreadsheet &she
   }
   sheet.m_lastReadRow=row;
   f << "row=" << row << ",";
-  int val=(int) input->readLong(2);
+  int val=static_cast<int>(input->readLong(2));
   if (val && val!=int(fSz))
     f << "#sz=" << val << ",";
-  int h=(int) input->readLong(2);
+  int h=static_cast<int>(input->readLong(2));
   if (h!=-1)
     f << "height=" << h << ",";
   sheet.m_heightRows.resize(size_t(row)+1, -1);
   sheet.m_heightRows[size_t(row)]=h;
   input->seek(10, librevenge::RVNG_SEEK_CUR); // junk
-  int N=(int) input->readLong(2)+1;
+  int N=static_cast<int>(input->readLong(2))+1;
   f << "N=" << N << ",";
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val!=fSz && val) {
     if (val+1 > N) N=val+1;
     f << "unkn=" << val << ",";
@@ -991,7 +997,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
 {
   MWAWInputStreamPtr &input= getInput();
   long pos=input->tell();
-  int cSize=(int) input->readULong(1);
+  int cSize=static_cast<int>(input->readULong(1));
   long endPos=pos+2+cSize+((cSize%2)?1:0);
   libmwaw::DebugStream f;
   f << "Entries(Cell)[" << cell.position() << "]:";
@@ -1004,7 +1010,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
   }
   MWAWCell::Format format;
 
-  int val=(int) input->readULong(1);
+  int val=static_cast<int>(input->readULong(1));
   bool isFormula=val&0x80;
   if (isFormula) f << "formula,";
   int type=(val>>4)&7;
@@ -1016,18 +1022,18 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
       ascii().addDelimiter(pos+10,'|');
     // first read the flags which indicated what is filled
     input->seek(pos+9, librevenge::RVNG_SEEK_SET);
-    int wh=(int) input->readULong(1);
+    int wh=static_cast<int>(input->readULong(1));
     if (wh) {
       f << "style=[";
       input->seek(pos+2, librevenge::RVNG_SEEK_SET);
       MWAWFont font(3);
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val>0)
-        font.setSize((float) val);
-      val=(int) input->readLong(2);
+        font.setSize(float(val));
+      val=static_cast<int>(input->readLong(2));
       if (val>=0)
         font.setId(val);
-      int flag = (int) input->readULong(1);
+      int flag = static_cast<int>(input->readULong(1));
       uint32_t flags=0;
       MWAWColor col;
       if (flag&7 && m_state->getColor(flag&7, col))
@@ -1040,7 +1046,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
       font.setFlags(flags);
       cell.setFont(font);
       f << font.getDebugString(getParserState()->m_fontConverter);
-      int form=(int) input->readULong(1);
+      int form=static_cast<int>(input->readULong(1));
       if (form) {
         if (form & 0x10)
           format.m_thousandHasSeparator=true;
@@ -1114,11 +1120,11 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
           format.m_digits=(form & 0xf);
         f << format;
       }
-      val=(int) input->readULong(1);
+      val=static_cast<int>(input->readULong(1));
       if (val>>4) {
         int cId=(val>>4);
         if (cId<5) { // first five gray colors, white, lightgray, ... black
-          unsigned char gray=(unsigned char)((4-cId)*0x40);
+          unsigned char gray=static_cast<unsigned char>((4-cId)*0x40);
           cell.setBackgroundColor(MWAWColor(gray,gray,gray));
         }
         else if (m_state->getColor(cId-3,col))
@@ -1203,7 +1209,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
       content.m_contentType=MWAWCellContent::C_FORMULA;
       if (format.m_format==MWAWCell::F_UNKNOWN)
         format.m_format=MWAWCell::F_NUMBER;
-      cell.m_formula=(int) input->readULong(2);
+      cell.m_formula=static_cast<int>(input->readULong(2));
       f << "id[formula]=" << cell.m_formula << ",";
     }
     else
@@ -1238,7 +1244,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
       content.m_contentType=MWAWCellContent::C_FORMULA;
       if (format.m_format==MWAWCell::F_UNKNOWN)
         format.m_format=MWAWCell::F_TEXT;
-      cell.m_formula=(int) input->readULong(2);
+      cell.m_formula=static_cast<int>(input->readULong(2));
       f << "id[formula]=" << cell.m_formula << ",";
     }
     else
@@ -1247,7 +1253,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
     content.m_textEntry.setLength(cSize-8-(isFormula?2:0));
     std::string text("");
     for (long i=0; i < content.m_textEntry.length(); ++i)
-      text+=(char) input->readULong(1);
+      text+=char(input->readULong(1));
     f << "\"" << text << "\",";
     break;
   }
@@ -1274,7 +1280,7 @@ bool BeagleWksSSParser::readZone0()
   long pos=input->tell();
   libmwaw::DebugStream f;
   f << "Entries(Zone0):";
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   if (!input->checkPosition(pos+8+3*N)) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
@@ -1295,11 +1301,11 @@ bool BeagleWksSSParser::readColumnWidths(BeagleWksSSParserInternal::Spreadsheet
   long pos=input->tell();
   libmwaw::DebugStream f;
   f << "Entries(Columns):";
-  int N=(int) input->readLong(2);
+  int N=static_cast<int>(input->readLong(2));
   f << "N=" << N << ",";
-  int val=(int) input->readLong(2);
+  int val=static_cast<int>(input->readLong(2));
   if (val) f << "f0=" << val << ",";
-  int dSz=(int) input->readULong(2);
+  int dSz=static_cast<int>(input->readULong(2));
   if (N<-1 || (N>=0 && dSz<=0) || !input->checkPosition(pos+6+(N+1)*dSz)) {
     MWAW_DEBUG_MSG(("BeagleWksSSParser::Zone&: header seems odd\n"));
     f << "###";
@@ -1315,15 +1321,15 @@ bool BeagleWksSSParser::readColumnWidths(BeagleWksSSParserInternal::Spreadsheet
     f.str("");
     f << "Columns-" << i << ":";
     if (dSz >= 8) {
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val==1) f << "set,";
       else if (val) f << "#set=" << val << ",";
-      int w=(int) input->readLong(2);
+      int w=static_cast<int>(input->readLong(2));
       sheet.m_widthCols.push_back(w);
       if (w>0)
         f << "w=" << w << ",";
       for (int j=0; j<2; ++j) {
-        val=(int) input->readULong(2);
+        val=static_cast<int>(input->readULong(2));
         if (val!=0xFFFF)
           f << "f" << j << "=" << std::hex << val << std::dec << ",";
       }
@@ -1352,8 +1358,8 @@ bool BeagleWksSSParser::readFormula(BeagleWksSSParserInternal::Spreadsheet &shee
     else
       f << "Formula-" << id << ":";
     ++id;
-    int row=(int) input->readULong(2);
-    int col=(int) input->readULong(2);
+    int row=static_cast<int>(input->readULong(2));
+    int col=static_cast<int>(input->readULong(2));
     if (row==0x4000 && col==0x4000) {
       f << "last,";
       ascii().addPos(pos);
@@ -1361,7 +1367,7 @@ bool BeagleWksSSParser::readFormula(BeagleWksSSParserInternal::Spreadsheet &shee
       return true;
     }
     f << "pos=" << col << "x" << row << ",";
-    int dataSz=(int) input->readULong(2);
+    int dataSz=static_cast<int>(input->readULong(2));
     if (!dataSz || !input->checkPosition(pos+6+dataSz)) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       break;
@@ -1453,7 +1459,7 @@ bool BeagleWksSSParser::sendText(MWAWEntry entry, bool /*headerFooter*/)
   while (!input->isEnd()) {
     long pos=input->tell();
     if (pos>=endPos) break;
-    unsigned char c = (unsigned char) input->readULong(1);
+    unsigned char c = static_cast<unsigned char>(input->readULong(1));
     switch (c) {
     case 0x9:
       listener->insertTab();
@@ -1462,7 +1468,7 @@ bool BeagleWksSSParser::sendText(MWAWEntry entry, bool /*headerFooter*/)
       listener->insertEOL();
       break;
     default:
-      listener->insertCharacter((unsigned char) c);
+      listener->insertCharacter(static_cast<unsigned char>(c));
       break;
     }
   }
@@ -1506,20 +1512,20 @@ bool BeagleWksSSParser::sendSpreadsheet()
         double h=sheet.getRowHeight(prevRow+1, numRepeat);
         if (cell.position()[1]<prevRow+1+numRepeat)
           numRepeat=cell.position()[1]-1-prevRow;
-        listener->openSheetRow((float) h, librevenge::RVNG_POINT, numRepeat);
+        listener->openSheetRow(float(h), librevenge::RVNG_POINT, numRepeat);
         prevRow+=numRepeat;
       }
     }
     if (cell.position()[1] > prevRow) {
       if (prevRow != -1) listener->closeSheetRow();
-      listener->openSheetRow((float) sheet.getRowHeight(++prevRow), librevenge::RVNG_POINT);
+      listener->openSheetRow(float(sheet.getRowHeight(++prevRow)), librevenge::RVNG_POINT);
     }
     listener->openSheetCell(cell, cell.m_content);
     if (cell.m_content.m_textEntry.valid()) {
       listener->setFont(cell.isFontSet() ? cell.getFont() : MWAWFont());
       input->seek(cell.m_content.m_textEntry.begin(), librevenge::RVNG_SEEK_SET);
       while (!input->isEnd() && input->tell()<cell.m_content.m_textEntry.end()) {
-        unsigned char c=(unsigned char) input->readULong(1);
+        unsigned char c=static_cast<unsigned char>(input->readULong(1));
         if (c==0xd)
           listener->insertEOL();
         else
@@ -1559,7 +1565,7 @@ bool BeagleWksSSParser::checkHeader(MWAWHeader *header, bool strict)
     return false;
   }
   for (int i=0; i < 9; ++i) { // f2=f6=1 other 0
-    int val=(int) input->readLong(2);
+    int val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   setVersion(1);
@@ -1586,7 +1592,7 @@ bool BeagleWksSSParser::checkHeader(MWAWHeader *header, bool strict)
   MWAWEntry entry;
   entry.setBegin(input->readLong(4));
   entry.setLength(input->readLong(4));
-  entry.setId((int) input->readLong(2)); // in fact nFonts
+  entry.setId(static_cast<int>(input->readLong(2))); // in fact nFonts
   entry.setType("FontNames");
   f << "fontNames[ptr]=" << std::hex << entry.begin() << "<->" << entry.end()
     << std::dec << ",nFonts=" << entry.id() << ",";
