@@ -137,7 +137,7 @@ libmwaw::DebugFile &BeagleWksStructManager::rsrcAscii()
 ////////////////////////////////////////////////////////////
 bool BeagleWksStructManager::readFrame(MWAWEntry const &entry)
 {
-  if (entry.length()!=156*(long)entry.id()) {
+  if (entry.length()!=156*long(entry.id())) {
     MWAW_DEBUG_MSG(("BeagleWksStructManager::readFrame: the entry seems bad\n"));
     return false;
   }
@@ -149,39 +149,39 @@ bool BeagleWksStructManager::readFrame(MWAWEntry const &entry)
     long pos=input->tell(), begPos=pos;
     libmwaw::DebugStream f;
     f << "Entries(Frame)[" << i << "]:";
-    int type=(int) input->readULong(2);
+    int type=static_cast<int>(input->readULong(2));
     int val;
     switch (type) {
     case 0x8000: {
       f << "picture,";
-      val=(int) input->readLong(2); // 1|8
+      val=static_cast<int>(input->readLong(2)); // 1|8
       if (val) f << "f0=" << val << ",";
       ascii().addDelimiter(input->tell(),'|');
       input->seek(pos+40, librevenge::RVNG_SEEK_SET);
       ascii().addDelimiter(input->tell(),'|');
       for (int j=0; j < 5; ++j) { // f1=5, f3=2, f5=e|13
-        val=(int) input->readLong(2);
+        val=static_cast<int>(input->readLong(2));
         if (val) f << "f" << j+1 << "=" << val << ",";
       }
       double dim[4];
       for (int j=0; j<4; ++j)
         dim[j]=double(input->readLong(4))/65536.;
       f << "dim?=" << dim[1] << "x" << dim[0] << "<->" << dim[3] << "x" << dim[2] << ",";
-      val =(int) input->readLong(2);
+      val =static_cast<int>(input->readLong(2));
       if (val) f << "f6=" << val << ",";
       break;
     }
     case 0xffff: {
       f << "attachment,";
       for (int j=0; j<2; ++j) { // f0=0, f1=4ef8
-        val=(int) input->readLong(2);
+        val=static_cast<int>(input->readLong(2));
         if (val) f << "f" << j << "=" << val << ",";
       }
-      int fSz=(int)input->readULong(1);
+      int fSz=static_cast<int>(input->readULong(1));
       if (fSz>0 && fSz<32) {
         std::string name("");
         for (int c=0; c < fSz; c++)
-          name+=(char) input->readLong(1);
+          name+=char(input->readLong(1));
         f << name << ",";
       }
       else {
@@ -204,7 +204,7 @@ bool BeagleWksStructManager::readFrame(MWAWEntry const &entry)
 
     pos=input->tell();
     f.str("");
-    val=(int) input->readULong(2); // afc, 1df, 1dd, f34, a5a8
+    val=static_cast<int>(input->readULong(2)); // afc, 1df, 1dd, f34, a5a8
     f << "f0=" << std::hex << val << std::dec << ",";
     f << "PTR=" << std::hex << input->readULong(4) << std::dec << ",";
     float orig[2];
@@ -213,19 +213,19 @@ bool BeagleWksStructManager::readFrame(MWAWEntry const &entry)
     frame.m_origin=MWAWVec2f(orig[1],orig[0]);
     f << "PTR1=" << std::hex << input->readULong(4) << std::dec << ",";
 
-    frame.m_page=(int) input->readLong(2);
+    frame.m_page=static_cast<int>(input->readLong(2));
     float dim[2];
     for (int j=0; j<2; ++j)
       dim[j]=float(input->readLong(2));
     frame.m_dim=MWAWVec2f(dim[1],dim[0]);
     f << "dim=" << dim[1] << "x" << dim[0] << ",";
     for (int j=0; j<4; ++j) { // f1=0|05b1 other 0
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val) f << "f" << j+1 << "=" << std::hex << val << std::dec << ",";
     }
-    frame.m_id=(int) input->readLong(2);
+    frame.m_id=static_cast<int>(input->readLong(2));
     for (int j=0; j<2; ++j) { // 0
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val) f << "g" << j << "=" << std::hex << val << std::dec << ",";
     }
     frame.m_extra=f.str();
@@ -242,7 +242,7 @@ bool BeagleWksStructManager::readFrame(MWAWEntry const &entry)
     if (val) f << "f0=" << val << ",";
     val=int(input->readULong(4)); // big number
     f << "PTR=" << std::hex << val << std::dec << ",";
-    frame.m_border.m_width = (double) input->readLong(2);
+    frame.m_border.m_width = double(input->readLong(2));
     if (frame.m_border.m_width > 0)
       f << "borderSize=" << frame.m_border.m_width << ",";
     val=int(input->readLong(2)); // 0
@@ -251,7 +251,7 @@ bool BeagleWksStructManager::readFrame(MWAWEntry const &entry)
     if (val) f << "offset=" << double(val)/65536. << ",";
     val=int(input->readLong(2)); // 0
     if (val) f << "f2=" << val << ",";
-    int flags=(int) input->readLong(2);
+    int flags=static_cast<int>(input->readLong(2));
     frame.m_wrap=(flags&3);
     switch (frame.m_wrap) { // textaround
     case 0: // none
@@ -298,7 +298,7 @@ bool BeagleWksStructManager::readFrame(MWAWEntry const &entry)
     }
     flags &= 0xFE04;
     if (flags) f << "fl=" << std::hex << flags << std::dec << ",";
-    frame.m_pictId=(int)input->readULong(2);
+    frame.m_pictId=static_cast<int>(input->readULong(2));
     f << "pId=" << frame.m_pictId << ",";
     ascii().addDelimiter(input->tell(),'|');
     input->seek(18, librevenge::RVNG_SEEK_CUR);
@@ -308,7 +308,7 @@ bool BeagleWksStructManager::readFrame(MWAWEntry const &entry)
     val=int(input->readLong(4));
     if (val) f << "textAround[offsR/L]=" << double(val)/65536. << ",";
     for (int j=0; j<2; ++j) { // g0,g1=0 or g0,g1=5c0077c (dim?)
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val) f << "g" << j << "=" << val << ",";
     }
     ascii().addPos(pos);
@@ -341,7 +341,7 @@ bool BeagleWksStructManager::readFontNames(MWAWEntry const &entry)
     pos = input->tell();
     f.str("");
     f << "Entries(FontNames)[" << i << "]:";
-    int fSz=(int) input->readULong(1);
+    int fSz=static_cast<int>(input->readULong(1));
     if (pos+1+fSz>endPos) {
       MWAW_DEBUG_MSG(("BeagleWksStructManager::readFontNames: can not read font %d\n", i));
       f << "###";
@@ -352,7 +352,7 @@ bool BeagleWksStructManager::readFontNames(MWAWEntry const &entry)
     }
     std::string name("");
     for (int c=0; c < fSz; ++c)
-      name+=(char) input->readULong(1);
+      name+=char(input->readULong(1));
     if (!name.empty())
       m_state->m_fileIdFontIdList.push_back(m_parserState->m_fontConverter->getId(name));
 
@@ -382,28 +382,28 @@ bool BeagleWksStructManager::readDocumentInfo()
   long pos=input->tell();
   libmwaw::DebugStream f;
   f << "Entries(DocInfo):";
-  long dSz=(int) input->readULong(2);
+  long dSz=static_cast<int>(input->readULong(2));
   long endPos=pos+dSz+4;
   if (dSz<0x226 || !input->checkPosition(endPos)) {
     MWAW_DEBUG_MSG(("BeagleWksStructManager::readDocumentInfo: can not find the database zone\n"));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
   }
-  int id=(int) input->readLong(2);
+  int id=static_cast<int>(input->readLong(2));
   if (id!=1) f << "id=" << id << ",";
   std::string what("");
   for (int i=0; i < 4; ++i) // dosu
-    what+=(char) input->readLong(1);
+    what+=char(input->readLong(1));
   f << what << ",";
   int val;
   for (int i=0; i < 3; ++i) { // 961/2101, 0, 0
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if ((i==0 && val!=0x961) || (i&&val))
       f << "f" << i+2 << "=" << val << ",";
   }
   f << "ids=[";
   for (int i=0; i < 2; ++i)
-    f << std::hex << (long) input->readULong(4) << std::dec << ",";
+    f << std::hex << long(input->readULong(4)) << std::dec << ",";
   f << "],";
   double margins[4];
   f << "margins=[";
@@ -428,7 +428,7 @@ bool BeagleWksStructManager::readDocumentInfo()
   int numRemains=int(endPos-512-input->tell());
   f << "fls=[";
   for (int i=0; i < numRemains; ++i) { // [_,_,_,_,_,1,]
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     if (val) f << val << ",";
     else f << "_,";
   }
@@ -443,13 +443,13 @@ bool BeagleWksStructManager::readDocumentInfo()
       f << "DocInfo[header]:";
     else
       f << "DocInfo[footer]:";
-    int fSz = (int) input->readULong(1);
+    int fSz = static_cast<int>(input->readULong(1));
     MWAWEntry &entry=st==0 ? m_state->m_header : m_state->m_footer;
     entry.setBegin(input->tell());
     entry.setLength(fSz);
     std::string name("");
     for (int i=0; i<fSz; ++i)
-      name+=(char) input->readULong(1);
+      name+=char(input->readULong(1));
     f << name;
     input->seek(pos+256, librevenge::RVNG_SEEK_SET);
     ascii().addPos(pos);
@@ -465,42 +465,42 @@ bool BeagleWksStructManager::readDocumentPreferences()
   long pos=input->tell();
   libmwaw::DebugStream f;
   f << "Entries(Preferences):";
-  long dSz=(long) input->readULong(2);
+  long dSz=long(input->readULong(2));
   long endPos=pos+dSz+4;
   if (dSz<0x2e || !input->checkPosition(endPos)) {
     MWAW_DEBUG_MSG(("BeagleWksStructManager::readDocumentInfo: can not find the database zone\n"));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
   }
-  int id=(int) input->readLong(2);
+  int id=static_cast<int>(input->readLong(2));
   if (id!=0xa) f << "id=" << id << ",";
   std::string what="";
   for (int i=0; i < 4; ++i) // pref
-    what+=(char) input->readLong(1);
+    what+=char(input->readLong(1));
   f << what << ",";
   for (int i=0; i < 3; ++i) { // always 0
-    int val=(int) input->readLong(2);
+    int val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i+2 << "=" << val << ",";
   }
   f << "ids=[";
   for (int i=0; i < 2; i++)
-    f << std::hex << (long) input->readULong(4) << std::dec << ",";
+    f << std::hex << long(input->readULong(4)) << std::dec << ",";
   f << "],";
-  int val=(int) input->readULong(2); // 0|22d8|4ead|e2c8
+  int val=static_cast<int>(input->readULong(2)); // 0|22d8|4ead|e2c8
   if (val)
     f << "fl?=" << std::hex << val << std::dec << ",";
   for (int i=0; i < 8; i++) {
     static int const(expectedValues[])= {1,4/*or 2*/,3,2,2,1,1,1 };
-    val=(int) input->readLong(1);
+    val=static_cast<int>(input->readLong(1));
     if (val!=expectedValues[i])
       f << "g" << i << "=" << val << ",";
   }
   for (int i=0; i < 8; ++i) { // 1,a|e, 0, 21, 3|4, 6|7|9, d|13, 3|5: related to font?
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val)
       f << "h" << i << "=" << val << ",";
   }
-  val=(int) input->readULong(2); //0|10|3e|50|c8|88|98
+  val=static_cast<int>(input->readULong(2)); //0|10|3e|50|c8|88|98
   if (val)
     f << "h8=" <<  std::hex << val << std::dec << ",";
   input->seek(endPos, librevenge::RVNG_SEEK_SET);
@@ -532,7 +532,7 @@ bool BeagleWksStructManager::readwPos(MWAWEntry const &entry)
   f << "Entries(Windows):";
   int dim[4];
   for (int i=0; i < 4; ++i)
-    dim[i]=(int) input->readLong(2);
+    dim[i]=static_cast<int>(input->readLong(2));
 
   f << "dim=" << dim[1] << "x" << dim[0] << "<->"
     << dim[3] << "x" << dim[2] << ",";
@@ -556,13 +556,13 @@ bool BeagleWksStructManager::readFontStyle(MWAWEntry const &entry)
 
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Entries(FontStyle)[" << std::hex << entry.id() << std::dec << "]:";
-  int fSz=(int) input->readLong(2);
+  int fSz=static_cast<int>(input->readLong(2));
   if (fSz) f << "fSz=" << fSz << ",";
-  int fl=(int) input->readLong(2);
+  int fl=static_cast<int>(input->readLong(2));
   if (fl) f << "flags=" << std::hex << fl << std::dec << ",";
-  int id=(int) input->readLong(2);
+  int id=static_cast<int>(input->readLong(2));
   if (id) f << "fId=" << id << ",";
-  int val=(int) input->readLong(2);
+  int val=static_cast<int>(input->readLong(2));
   if (val) f << "color?=" << val << ",";
   ascFile.addPos(pos-4);
   ascFile.addNote(f.str().c_str());
@@ -631,7 +631,7 @@ bool BeagleWksStructManager::readCellInFormula(MWAWVec2i actPos, MWAWCellContent
   int pos[2];
   bool absolute[2] = { true, true};
   for (int dim = 0; dim < 2; dim++) {
-    int val = (int) getInput()->readULong(2);
+    int val = static_cast<int>(getInput()->readULong(2));
     if ((val & 0xF000) == 0); // absolue value ?
     else {
       val &= 0x7FFF;
@@ -716,7 +716,7 @@ bool BeagleWksStructManager::readFormula(long endPos, MWAWVec2i const &position,
     double val;
     long pos = input->tell();
     if (pos > endPos) return false;
-    int wh = (int) input->readULong(1);
+    int wh = static_cast<int>(input->readULong(1));
     int arity = 0;
     bool isNan;
     MWAWCellContent::FormulaInstruction instr;
@@ -773,17 +773,17 @@ bool BeagleWksStructManager::readFormula(long endPos, MWAWVec2i const &position,
     }
     case 0x5:
       instr.m_type=MWAWCellContent::FormulaInstruction::F_Long;
-      instr.m_longValue=(double) input->readLong(4);
+      instr.m_longValue=double(input->readLong(4));
       break;
     case 0x6: {
       instr.m_type=MWAWCellContent::FormulaInstruction::F_Text;
-      int fSz=(int) input->readULong(1);
+      int fSz=static_cast<int>(input->readULong(1));
       if (input->tell()+fSz > endPos) {
         ok=false;
         break;
       }
       for (int i=0; i<fSz; ++i) {
-        char c = (char) input->readULong(1);
+        char c = char(input->readULong(1));
         if (c==0) {
           ok = i+1==fSz;
           break;
@@ -805,13 +805,13 @@ bool BeagleWksStructManager::readFormula(long endPos, MWAWVec2i const &position,
         std::stringstream s;
         s << "Funct" << std::hex << wh << std::dec;
         instr.m_content=s.str();
-        arity = (int) input->readLong(1);
+        arity = static_cast<int>(input->readLong(1));
       }
       else {
         instr.m_content=BeagleWksStructManagerInternal::s_listFunctions[wh].m_name;
         ok=!instr.m_content.empty();
         arity = BeagleWksStructManagerInternal::s_listFunctions[wh].m_arity;
-        if (arity == -1) arity = (int) input->readLong(1);
+        if (arity == -1) arity = static_cast<int>(input->readLong(1));
       }
       break;
     }
@@ -824,7 +824,7 @@ bool BeagleWksStructManager::readFormula(long endPos, MWAWVec2i const &position,
       continue;
     }
     size_t numElt = stack.size();
-    if ((int) numElt < arity) {
+    if (static_cast<int>(numElt) < arity) {
       f.str("");
       f << instr.m_content << "[##" << arity << "]";
       error=f.str();
@@ -844,14 +844,14 @@ bool BeagleWksStructManager::readFormula(long endPos, MWAWVec2i const &position,
           child.push_back(instr);
         }
         std::vector<MWAWCellContent::FormulaInstruction> const &node=
-          stack[size_t((int)numElt-arity+i)];
+          stack[size_t(static_cast<int>(numElt)-arity+i)];
         child.insert(child.end(), node.begin(), node.end());
       }
       instr.m_content=")";
       child.push_back(instr);
 
-      stack.resize(size_t((int) numElt-arity+1));
-      stack[size_t((int)numElt-arity)] = child;
+      stack.resize(size_t(static_cast<int>(numElt)-arity+1));
+      stack[size_t(static_cast<int>(numElt)-arity)] = child;
       continue;
     }
     if (arity==1) {
