@@ -164,9 +164,7 @@ void EDocParser::newPage(int number)
 ////////////////////////////////////////////////////////////
 void EDocParser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  assert(getInput().get() != 0 && getRSRCParser());
-
-  if (!checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !getRSRCParser() || !checkHeader(0L))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
     checkHeader(0L);
@@ -360,7 +358,7 @@ bool EDocParser::sendPicture(int pictId, bool compressed)
     MWAW_DEBUG_MSG(("EDocParser::sendPicture: oops can not find an input\n"));
     return false;
   }
-  Box2f box;
+  MWAWBox2f box;
   MWAWPict::ReadResult res = MWAWPictData::check(pictInput, dataSz,box);
   if (res == MWAWPict::MWAW_R_BAD) {
     MWAW_DEBUG_MSG(("EDocParser::sendPicture: can not find the picture\n"));
@@ -368,13 +366,12 @@ bool EDocParser::sendPicture(int pictId, bool compressed)
   }
   pictInput->seek(0,librevenge::RVNG_SEEK_SET);
   shared_ptr<MWAWPict> thePict(MWAWPictData::get(pictInput, dataSz));
-  MWAWPosition pictPos=MWAWPosition(Vec2f(0,0),box.size(), librevenge::RVNG_POINT);
+  MWAWPosition pictPos=MWAWPosition(MWAWVec2f(0,0),box.size(), librevenge::RVNG_POINT);
   pictPos.setRelativePosition(MWAWPosition::Char);
   if (thePict) {
-    librevenge::RVNGBinaryData fData;
-    std::string type;
-    if (thePict->getBinary(fData,type))
-      getTextListener()->insertPicture(pictPos, fData, type);
+    MWAWEmbeddedObject picture;
+    if (thePict->getBinary(picture))
+      getTextListener()->insertPicture(pictPos, picture);
   }
   return true;
 }
@@ -422,7 +419,7 @@ bool EDocParser::readFontsName(MWAWEntry const &entry)
   f << "Entries(FontsName):";
   if (entry.id()!=128)
     f << "#id=" << entry.id() << ",";
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   ascFile.addPos(pos-4);
   ascFile.addNote(f.str().c_str());
@@ -435,7 +432,7 @@ bool EDocParser::readFontsName(MWAWEntry const &entry)
 
     f.str("");
     f << "FontsName-" << i << ":";
-    int fSz=(int) input->readULong(1);
+    int fSz=static_cast<int>(input->readULong(1));
     if (!fSz || fSz >= 255) {
       f << "##" << fSz << ",";
       MWAW_DEBUG_MSG(("EDocParser::readFontsName: the font name %d seems bad\n", i));
@@ -443,12 +440,12 @@ bool EDocParser::readFontsName(MWAWEntry const &entry)
     else {
       std::string name("");
       for (int c=0; c < fSz; c++)
-        name += (char)  input->readULong(1);
+        name += char(input->readULong(1));
       f << "\"" << name << "\",";
     }
     input->seek(pos+32, librevenge::RVNG_SEEK_SET);
     for (int j = 0; j < 112; j++) { // always 0 .
-      int val = (int) input->readLong(2);
+      int val = static_cast<int>(input->readLong(2));
       if (val) f << "f" << j << "=" << val << ",";
     }
     ascFile.addPos(pos);
@@ -486,18 +483,18 @@ bool EDocParser::sendIndex()
   std::stringstream ss;
   for (size_t i=0; i <  m_state->m_indexList.size(); i++) {
     EDocParserInternal::Index const &index = m_state->m_indexList[i];
-    para.m_margins[0] = 0.3f*float(index.m_levelId+1);
+    para.m_margins[0] = 0.3*double(index.m_levelId+1);
     getTextListener()->setParagraph(para);
     getTextListener()->setFont(actFont);
     for (size_t c=0; c < index.m_text.length(); c++)
-      getTextListener()->insertCharacter((unsigned char)index.m_text[c]);
+      getTextListener()->insertCharacter(static_cast<unsigned char>(index.m_text[c]));
 
     if (index.m_page >= 0) {
       getTextListener()->setFont(cFont);
       getTextListener()->insertTab();
       ss.str("");
       ss << index.m_page;
-      getTextListener()->insertUnicodeString(ss.str().c_str());
+      getTextListener()->insertUnicodeString(librevenge::RVNGString(ss.str().c_str()));
     }
     getTextListener()->insertEOL();
   }
@@ -522,13 +519,13 @@ bool EDocParser::readIndex(MWAWEntry const &entry)
   f << "Entries(Index):";
   if (entry.id()!=128)
     f << "#id=" << entry.id() << ",";
-  int val=(int) input->readULong(2);
+  int val=static_cast<int>(input->readULong(2));
   if (val) // 100 ?
     f << "f0=" << std::hex << val << std::dec << ",";
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   for (int i = 0; i < 8; i++) { // always 0
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val)
       f << "f" << i << "=" << val << ",";
   }
@@ -551,17 +548,17 @@ bool EDocParser::readIndex(MWAWEntry const &entry)
       return false;
     }
     EDocParserInternal::Index index;
-    val = (int) input->readULong(1); // 0|80
+    val = static_cast<int>(input->readULong(1)); // 0|80
     if (val) f << "fl=" << std::hex << val << std::dec << ",";
-    index.m_levelId = (int) input->readULong(1);
-    index.m_page = (int) input->readLong(2);
+    index.m_levelId = static_cast<int>(input->readULong(1));
+    index.m_page = static_cast<int>(input->readLong(2));
     // f1: y pos, other 0
     for (int j = 0; j < 4; j++) {
-      val = (int) input->readLong(2);
+      val = static_cast<int>(input->readLong(2));
       if (val)
         f << "f" << j << "=" << val << ",";
     }
-    int fSz = (int) input->readULong(1);
+    int fSz = static_cast<int>(input->readULong(1));
     if (pos+13+fSz > endPos) {
       index.m_extra=f.str();
       f.str("");
@@ -574,7 +571,7 @@ bool EDocParser::readIndex(MWAWEntry const &entry)
     }
     std::string text("");
     for (int j = 0; j < fSz; j++)
-      text += (char) input->readULong(1);
+      text += char(input->readULong(1));
     index.m_text=text;
     index.m_extra=f.str();
     m_state->m_indexList.push_back(index);
@@ -609,13 +606,13 @@ bool EDocParser::readInfo(MWAWEntry const &entry)
     f << "#id=" << entry.id() << ",";
   int val;
   for (int i = 0; i < 4; i++) { // f0=0, other big number
-    val = (int) input->readULong(2);
+    val = static_cast<int>(input->readULong(2));
     if (val)
       f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
   // creator, file name
   for (int i = 0; i < 2; i++) {
-    int sz=(int) input->readULong(1);
+    int sz=static_cast<int>(input->readULong(1));
     if (sz > 31) {
       MWAW_DEBUG_MSG(("EDocParser::readInfo: can not read string %d\n", i));
       f << "###,";
@@ -623,18 +620,18 @@ bool EDocParser::readInfo(MWAWEntry const &entry)
     else {
       std::string name("");
       for (int c=0; c < sz; c++)
-        name += (char) input->readULong(1);
+        name += char(input->readULong(1));
       f << name << ",";
     }
     input->seek(pos+8+(i+1)*32, librevenge::RVNG_SEEK_SET);
   }
   for (int i = 0; i < 5; i++) { // always 4, 0, 210, 0, 0 ?
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     if (val)
       f << "g" << i << "=" << val << ",";
   }
   int dim[2];
-  for (int i = 0; i < 2; i++) dim[i] = (int) input->readLong(2);
+  for (int i = 0; i < 2; i++) dim[i] = static_cast<int>(input->readLong(2));
   f << "dim?=" << dim[1] << "x" << dim[0] << ",";
   if (dim[1]>100 && dim[1]<2000 && dim[0]>100 && dim[0]< 2000) {
     getPageSpan().setFormLength(double(dim[0])/72.);
@@ -644,18 +641,18 @@ bool EDocParser::readInfo(MWAWEntry const &entry)
     MWAW_DEBUG_MSG(("EDocParser::readInfo: the page dimension seems bad\n"));
     f << "###,";
   }
-  int N=(int) input->readLong(2);
+  int N=static_cast<int>(input->readLong(2));
   f << "numPict?=" << N << ","; // seems ok in eDcR, but no in eSRD
   for (int i = 0; i < 2; i++) { // fl0=hasIndex ?, fl1=0
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     if (val)
       f << "fl" << i << "=" << val << ",";
   }
-  val = (int) input->readLong(2); // 0 or bf
+  val = static_cast<int>(input->readLong(2)); // 0 or bf
   if (val)
     f << "g5=" << val << ",";
   for (int i = 0; i < 3; i++) { // 3 big number: some size?
-    val = (int) input->readULong(4);
+    val = static_cast<int>(input->readULong(4));
     if (val)
       f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
@@ -675,7 +672,7 @@ namespace EDocParserInternal
 //! very low structure to help uncompress data
 struct DeflateStruct {
   //! constructor
-  DeflateStruct(long size) : m_toWrite(size), m_data(size_t(size), 0), m_dataPos(0),
+  explicit DeflateStruct(long size) : m_toWrite(size), m_data(size_t(size), 0), m_dataPos(0),
     m_circQueue(0x2000,0), m_circQueuePos(0), m_numDelayed(0), m_delayedChar('\0')
   {
   }
@@ -711,7 +708,7 @@ struct DeflateStruct {
     dt.clear();
     if (m_dataPos==0) return false;
     unsigned char const *firstPos=&m_data[0];
-    dt.append(firstPos, (unsigned long)m_dataPos);
+    dt.append(firstPos, static_cast<unsigned long>(m_dataPos));
     return true;
   }
 protected:
@@ -800,11 +797,11 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
 
   libmwaw::DebugStream f;
   f << "Entries(CompressZone):";
-  if ((long) input->readULong(4)!=length) {
+  if (long(input->readULong(4))!=length) {
     MWAW_DEBUG_MSG(("EDocParser::decodeZone: unexpected zone size\n"));
     return false;
   }
-  long zoneSize=(long) input->readULong(4);
+  long zoneSize=long(input->readULong(4));
   f << "sz[final]=" << std::hex << zoneSize << std::dec << ",";
 
   if (!zoneSize) {
@@ -828,10 +825,10 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
       pos=input->tell();
       f.str("");
       f << "CompressZone[data" << st << "]:";
-      int num=(int)input->readULong(1);
+      int num=static_cast<int>(input->readULong(1));
       f << "num=" << num << ",";
       if (num > maxData[st] || pos+1+num > endPos) {
-        MWAW_DEBUG_MSG(("EDocParser::decodeZone: find unexpected num of data : %x for zone %d\n", num, st));
+        MWAW_DEBUG_MSG(("EDocParser::decodeZone: find unexpected num of data : %d for zone %d\n", num, st));
         f << "###";
 
         ascFile.addPos(pos);
@@ -841,10 +838,10 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
       std::multimap<int,int> mapData;
       originalValues[st].resize(size_t(maxData[st])*2, 0);
       for (int i = 0; i < num; i++) {
-        val=(int) input->readULong(1);
+        val=static_cast<int>(input->readULong(1));
         for (int b=0; b < 2; b++) {
           int byte= b==0 ? (val>>4) : (val&0xF);
-          originalValues[st][size_t(2*i+b)]=(unsigned char) byte;
+          originalValues[st][size_t(2*i+b)]=static_cast<unsigned char>(byte);
           if (byte==0)
             continue;
           mapData.insert(std::multimap<int,int>::value_type(byte,2*i+b));
@@ -856,7 +853,7 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
       for (it=mapData.begin(); it != mapData.end(); ++it) {
         int n=0x8000>>(it->first);
         if (writePos+n>0x8000) {
-          MWAW_DEBUG_MSG(("EDocParser::decodeZone: find unexpected value writePos=%x for zone %d\n",writePos+n, st));
+          MWAW_DEBUG_MSG(("EDocParser::decodeZone: find unexpected value writePos=%x for zone %d\n",static_cast<unsigned int>(writePos+n), st));
 
           f << "###";
 
@@ -865,7 +862,7 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
           return false;
         }
         for (int j = 0; j < n; j++)
-          vectors32K[st][size_t(writePos++)]=(unsigned char) it->second;
+          vectors32K[st][size_t(writePos++)]=static_cast<unsigned char>(it->second);
       }
 
       ascFile.addPos(pos);
@@ -874,43 +871,43 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
     pos = input->tell();
     int byte=0;
     long maxBlockSz=0xFFF0;
-    unsigned int value=((unsigned int)input->readULong(2))<<16;
+    unsigned int value=(static_cast<unsigned int>(input->readULong(2)))<<16;
     while (maxBlockSz) {
       if (deflate.isEnd() || input->tell()>endPos) break;
       int ind0=(value>>16);
       if (ind0 & 0x8000) {
-        int ind1 = (int) vectors32K[0][size_t(ind0&0x7FFF)];
+        int ind1 = static_cast<int>(vectors32K[0][size_t(ind0&0x7FFF)]);
         int byt1=originalValues[0][size_t(ind1)]+1;
         if (byte<byt1) {
           value = (value<<byte);
           byt1 -= byte;
-          value |= (unsigned int)input->readULong(2);
+          value |= static_cast<unsigned int>(input->readULong(2));
           byte=16;
         }
         value=(value<<byt1);
         byte-=byt1;
 
-        deflate.push((unsigned char) ind1);
+        deflate.push(static_cast<unsigned char>(ind1));
         maxBlockSz-=2;
         continue;
       }
 
-      int ind1 = (int) vectors32K[1][size_t(ind0)];
+      int ind1 = static_cast<int>(vectors32K[1][size_t(ind0)]);
       int byt1 = originalValues[1][size_t(ind1)]+1;
       if (byte<byt1) {
         value = (value<<byte);
         byt1 -= byte;
-        value |= (unsigned int)input->readULong(2);
+        value |= static_cast<unsigned int>(input->readULong(2));
         byte=16;
       }
       value=(value<<byt1);
       byte-=byt1;
-      int ind2 = (int) vectors32K[2][size_t(value>>17)];
+      int ind2 = static_cast<int>(vectors32K[2][size_t(value>>17)]);
       int byt2=originalValues[2][size_t(ind2)];
       if (byte<byt2) {
         value = (value<<byte);
         byt2 -= byte;
-        value |= (unsigned int)input->readULong(2);
+        value |= static_cast<unsigned int>(input->readULong(2));
         byte=16;
       }
       value=(value<<byt2);
@@ -921,7 +918,7 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
       if (byte<byt3) {
         value = (value<<byte);
         byt3 -= byte;
-        value |= (unsigned int)input->readULong(2);
+        value |= static_cast<unsigned int>(input->readULong(2));
         byte=16;
       }
       value=(value<<byt3);
@@ -937,8 +934,8 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
     ascFile.addNote("CompressZone[after]");
   }
   bool res = deflate.getBinaryData(data);
-#if defined(DEBUG_WITH_FILES)
   ascFile.skipZone(pos,input->tell()-1);
+#if defined(DEBUG_WITH_FILES)
   if (res) {
     static int volatile cPictName = 0;
     libmwaw::DebugStream f2;
