@@ -159,6 +159,8 @@ class Cell : public MWAWCell
 public:
   /// constructor
   Cell() : m_content(), m_pictEntry() { }
+  //! destructor
+  virtual ~Cell();
   //! returns true if the cell do contain any content
   bool isEmpty() const
   {
@@ -171,6 +173,10 @@ public:
   MWAWEntry m_pictEntry;
 };
 
+Cell::~Cell()
+{
+}
+
 /** a field of a GreatWksDBParser */
 struct Field {
   //! the file type
@@ -298,9 +304,11 @@ std::ostream &operator<<(std::ostream &o, Field const &field)
     break;
   case Field::F_Unknown:
     break;
+#if !defined(__clang__)
   default:
     MWAW_DEBUG_MSG(("GreatWksDBParser::Field:operator<<: find unexpected type\n"));
     break;
+#endif
   }
   if (field.m_id>=0) o << "id=" << field.m_id << ",";
   if (!field.m_name.empty()) o << "name=" << field.m_name << ",";
@@ -329,7 +337,7 @@ public:
     if (m_rowCellsMap.find(pos[1])==m_rowCellsMap.end())
       m_rowCellsMap[pos[1]]=std::vector<Cell>();
     std::vector<Cell> &cells=m_rowCellsMap.find(pos[1])->second;
-    if (pos[0]>=(int) cells.size())
+    if (pos[0]>=static_cast<int>(cells.size()))
       cells.resize(m_fieldList.size());
     cells[size_t(pos[0])]=cell;
     return true;
@@ -337,7 +345,7 @@ public:
   //! returns the row size in point
   int getRowHeight(int row) const
   {
-    if (row>=0&&row<(int) m_heightRows.size())
+    if (row>=0&&row<static_cast<int>(m_heightRows.size()))
       return m_heightRows[size_t(row)];
     return m_heightDefault;
   }
@@ -751,26 +759,26 @@ bool GreatWksDBParser::readHeader()
     m_state->m_blocks.push_back(block);
     f << block << ",";
     for (int j=0; j<4; ++j) {
-      int val=(int) input->readULong(2);
+      int val=static_cast<int>(input->readULong(2));
       if (val)
         f << "f" << j << "[" << i << "]=" << val << ",";
     }
   }
   // an odd entry block (only 2 ptr), does this means that this zone has a size less than 512?
   GreatWksDBParserInternal::BlockHeader block;
-  for (int i=0; i<2; ++i) block.m_ptr[i]=(long) input->readULong(4);
+  for (int i=0; i<2; ++i) block.m_ptr[i]=long(input->readULong(4));
   block.m_ptr[2]=block.m_ptr[1];
   block.m_name="RecList";
   m_state->m_blocks.push_back(block);
   f << block << ",";
 
-  int val=(int) input->readLong(2); // always 0
+  int val=static_cast<int>(input->readLong(2)); // always 0
   if (val) f << "f4=" << val << ",";
-  int numRecords=(int) input->readLong(2);
+  int numRecords=static_cast<int>(input->readLong(2));
   m_state->m_database.m_numRecords=numRecords;
   f << "num[records]=" << numRecords << ",";
   for (int i=0; i<16; ++i) { // find h1=h9=h11=h13=numRecords, h3=h7=1|11, h14=2, h15=1
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (i==1 || i==9 || i==11 || i==13) {
       if (val==numRecords) continue;
       if (i==9) f << "act[record]=" << val << ",";
@@ -786,9 +794,9 @@ bool GreatWksDBParser::readHeader()
   f << "Entries(Zones):";
   std::vector<MWAWEntry> zones;
   for (int i=0; i<9; ++i) {
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
-    long ptr=(long) input->readULong(2);
+    long ptr=long(input->readULong(2));
     MWAWEntry entry;
     entry.setBegin(ptr);
     zones.push_back(entry);
@@ -798,15 +806,15 @@ bool GreatWksDBParser::readHeader()
   }
   if (vers==1) {
     for (int i=0; i<40; ++i) {
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val!=-1) f << "g" << i << "=" << val << ",";
     }
   }
   else {
     // no sure what is the maximal number of potential added zones
     for (int i=0; i<20; ++i) {
-      long ptr=(long) input->readULong(2);
-      val=(int) input->readLong(2);
+      long ptr=long(input->readULong(2));
+      val=static_cast<int>(input->readLong(2));
       if (val) f << "g" << i << "=" << val << ",";
       MWAWEntry entry;
       entry.setBegin(ptr);
@@ -826,7 +834,7 @@ bool GreatWksDBParser::readHeader()
     MWAWEntry &entry=zones[i];
     if (!entry.begin() || entry.begin()==0xFFFF) continue;
     if (!checkSmallZone(entry)) {
-      MWAW_DEBUG_MSG(("GreatWksDBParser::readHeader: find a bad zone %d\n", (int) i));
+      MWAW_DEBUG_MSG(("GreatWksDBParser::readHeader: find a bad zone %d\n", static_cast<int>(i)));
       entry.setLength(0);
       continue;
     }
@@ -860,7 +868,7 @@ bool GreatWksDBParser::readBlockHeader(GreatWksDBParserInternal::BlockHeader &en
 {
   MWAWInputStreamPtr input = getInput();
   if (!input->checkPosition(input->tell()+12)) return false;
-  for (int i=0; i<3; ++i) entry.m_ptr[i]=(long) input->readULong(4);
+  for (int i=0; i<3; ++i) entry.m_ptr[i]=long(input->readULong(4));
   return true;
 }
 
@@ -885,7 +893,7 @@ shared_ptr<GreatWksDBParserInternal::Block> GreatWksDBParser::createBlock(GreatW
     f.str("");
     f << "Entries(BlockHeader):";
     input->seek(pos, librevenge::RVNG_SEEK_SET);
-    int type=(int) input->readULong(1);
+    int type=static_cast<int>(input->readULong(1));
     f << "type=" << std::hex << type << std::dec << ",";
     if ((type&0xF0) != 0x40) {
       MWAW_DEBUG_MSG(("GreatWksDBParser::createBlock: find old block type\n"));
@@ -894,22 +902,22 @@ shared_ptr<GreatWksDBParserInternal::Block> GreatWksDBParser::createBlock(GreatW
       ascii().addNote(f.str().c_str());
       return res;
     }
-    int val=(int) input->readULong(1);
+    int val=static_cast<int>(input->readULong(1));
     if (val!=0x7F) // find fl=0 with type=44
       f << "fl=" << std::hex << val << std::dec << ",";
     GreatWksDBParserInternal::Block::Zone zone;
-    zone.m_N = (int) input->readULong(2);
+    zone.m_N = static_cast<int>(input->readULong(2));
     if (zone.m_N)
       f << "N=" << zone.m_N << ",";
     if ((type&0x4)==0)
-      zone.m_dataSize = (int) input->readULong(2);
+      zone.m_dataSize = static_cast<int>(input->readULong(2));
     if (zone.m_dataSize)
       f << "dataSize=" << zone.m_dataSize << ",";
     if (type==0x41 || type==0x44) { // link to type or to flag
-      val=(int) input->readULong(4);
+      val=static_cast<int>(input->readULong(4));
       if (val) f << "prev=" << std::hex << val << std::dec << ",";
     }
-    long next=(int) input->readULong(4);
+    long next=static_cast<int>(input->readULong(4));
     if (next) {
       f << "next=" << std::hex << next << std::dec << ",";
       if ((next&0x1FF)) {
@@ -1002,7 +1010,7 @@ bool GreatWksDBParser::readFreeList(GreatWksDBParserInternal::Block &block)
          excepted on time where it is 8, dataSz
        */
       unsigned long values[2];
-      for (int j=0; j<2; ++j) values[j]=(unsigned long) input->readULong(4);
+      for (int j=0; j<2; ++j) values[j]=static_cast<unsigned long>(input->readULong(4));
       if ((values[0]&0xFF000000)==0x40000000) {
         unsigned long tmp=values[0];
         values[0]=values[1];
@@ -1051,8 +1059,8 @@ bool GreatWksDBParser::readRowLinks(GreatWksDBParserInternal::Block &block)
     f.str("");
     f << "Entries(" << header.m_name << "):ptrs=[";
     for (int i=0; i<zone.m_N; ++i) {
-      long ptr=(long) input->readULong(4);
-      int id=(int) input->readLong(4);
+      long ptr=long(input->readULong(4));
+      int id=static_cast<int>(input->readLong(4));
       if (ptr) {
         MWAWEntry entry;
         entry.setBegin(ptr);
@@ -1147,11 +1155,11 @@ bool GreatWksDBParser::checkSmallZone(MWAWEntry &entry)
   if (!input->checkPosition(entry.begin()+6)) return false;
 
   input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
-  int id=(int) input->readLong(2);
+  int id=static_cast<int>(input->readLong(2));
   entry.setId(id);
   /* the zone with id=10 is in fact a list of zone with id=10, so
      its length will be underestimate */
-  entry.setLength(6+(long) input->readULong(4));
+  entry.setLength(6+long(input->readULong(4)));
   if (id>=0 && id<15) {
     static char const *(names[])= {
       "Zone0A", "Field", "FrmLink", "Zone3A", "Zone4A", "ListFrmula", "ListSummary", "Zone7A",
@@ -1187,11 +1195,11 @@ bool GreatWksDBParser::readRowRecords(MWAWEntry const &entry)
   libmwaw::DebugStream f;
   f << "Entries(RowRec):";
   // probably type=0 followed by ?
-  int val=(int) input->readULong(2);
+  int val=static_cast<int>(input->readULong(2));
   if (val!=0xFF) f << "f0=" << std::hex << val << std::dec << ",";
-  long dSz=(long) input->readULong(4);
+  long dSz=long(input->readULong(4));
   long endPos=pos+6+dSz;
-  if (!input->checkPosition(endPos)) {
+  if (dSz<0 || !input->checkPosition(endPos)) {
     MWAW_DEBUG_MSG(("GreatWksDBParser::readRowRecords: the size seems bad\n"));
     f << "###";
     ascii().addPos(pos);
@@ -1222,7 +1230,7 @@ bool GreatWksDBParser::readRowRecords(MWAWEntry const &entry)
     cell.setFormat(field.m_format);
     switch (field.m_type) {
     case GreatWksDBParserInternal::Field::F_Text: {
-      int sSz=(int) input->readULong(1);
+      int sSz=static_cast<int>(input->readULong(1));
       if (pos+1+sSz>endPos) {
         MWAW_DEBUG_MSG(("GreatWksDBParser::readRowRecords: the string length seems bad\n"));
         f << "###";
@@ -1235,7 +1243,7 @@ bool GreatWksDBParser::readRowRecords(MWAWEntry const &entry)
       database.addCell(MWAWVec2i(field.m_id, entry.id()), cell);
 
       std::string text("");
-      for (int i=0; i<sSz; ++i) text+=(char) input->readULong(1);
+      for (int i=0; i<sSz; ++i) text+=char(input->readULong(1));
       f << text << ",";
       // realign to a multiple of 2
       if ((sSz%2)==0) input->seek(1,librevenge::RVNG_SEEK_CUR);
@@ -1290,7 +1298,7 @@ bool GreatWksDBParser::readRowRecords(MWAWEntry const &entry)
       break;
     }
     case GreatWksDBParserInternal::Field::F_Picture: {
-      long pSz=(int) input->readULong(4);
+      long pSz=static_cast<int>(input->readULong(4));
       if (pos+4+pSz>endPos) {
         MWAW_DEBUG_MSG(("GreatWksDBParser::readRowRecords: the picture length seems bad\n"));
         f << "###";
@@ -1317,7 +1325,7 @@ bool GreatWksDBParser::readRowRecords(MWAWEntry const &entry)
       break;
     }
     case GreatWksDBParserInternal::Field::F_Memo: {
-      long mSz=(int) input->readULong(4);
+      long mSz=static_cast<int>(input->readULong(4));
       if (pos+4+mSz>endPos) {
         MWAW_DEBUG_MSG(("GreatWksDBParser::readRowRecords: the memo length seems bad\n"));
         f << "###";
@@ -1342,7 +1350,9 @@ bool GreatWksDBParser::readRowRecords(MWAWEntry const &entry)
       break;
     }
     case GreatWksDBParserInternal::Field::F_Unknown:
+#if !defined(__clang__)
     default:
+#endif
       ok=false;
       break;
     }
@@ -1354,7 +1364,7 @@ bool GreatWksDBParser::readRowRecords(MWAWEntry const &entry)
   pos=input->tell();
   if (pos+2==endPos) {
     // seems ok to find 0 here
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val) {
       f.str("");
       f << "RowRec[end]:" << val << ",";
@@ -1380,7 +1390,7 @@ bool GreatWksDBParser::readFormula(long endPos, std::vector<MWAWCellContent::For
   formula.resize(0);
   MWAWInputStreamPtr input = getInput();
   long pos=input->tell();
-  long dSz=(long) input->readULong(2);
+  long dSz=long(input->readULong(2));
   long endHeader=pos+2+dSz;
   if (dSz<2 || endHeader > endPos) {
     MWAW_DEBUG_MSG(("GreatWksDBParser::readFormula: can not read a formula\n"));
@@ -1397,18 +1407,18 @@ bool GreatWksDBParser::readFormula(long endPos, std::vector<MWAWCellContent::For
   f << "]" << error << ",";
 
   input->seek(endHeader, librevenge::RVNG_SEEK_SET);
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   if (endHeader+2*(N+1)>endPos) {
     MWAW_DEBUG_MSG(("GreatWksDBParser::readFormula: can not read a formula field(II)\n"));
     return false;
   }
-  int val=(int) input->readLong(2); // Here I find always 2, the field size ?
+  int val=static_cast<int>(input->readLong(2)); // Here I find always 2, the field size ?
   if (val!=2) f << "g0=" << val << ",";
   std::vector<int> varList;
   if (N) {
     f << "list[varId]=[";
     for (int i=0; i<N; ++i) {
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       varList.push_back(val);
       f << val << ",";
     }
@@ -1420,7 +1430,7 @@ bool GreatWksDBParser::readFormula(long endPos, std::vector<MWAWCellContent::For
     MWAWCellContent::FormulaInstruction &instr=formula[l];
     if (instr.m_type!=MWAWCellContent::FormulaInstruction::F_Cell)
       continue;
-    if (id>=(int) varList.size() || varList[size_t(id)]<=0) {
+    if (id>=static_cast<int>(varList.size()) || varList[size_t(id)]<=0) {
       MWAW_DEBUG_MSG(("GreatWksDBParser::readFormula: can not associated a cell with field\n"));
       f << "###";
       formula.resize(0);
@@ -1442,7 +1452,7 @@ bool GreatWksDBParser::readFormulaResult(long endPos, GreatWksDBParserInternal::
   MWAWInputStreamPtr input = getInput();
   long pos=input->tell();
   if (pos+2>endPos) return false;
-  int type=(int) input->readLong(2);
+  int type=static_cast<int>(input->readLong(2));
   switch (type) {
   case 0: // average
   case 1: // summary
@@ -1464,7 +1474,7 @@ bool GreatWksDBParser::readFormulaResult(long endPos, GreatWksDBParserInternal::
   }
   case 7: {
     // checkme
-    int sSz=(int) input->readULong(1);
+    int sSz=static_cast<int>(input->readULong(1));
     if (pos+3+sSz>endPos) {
       MWAW_DEBUG_MSG(("GreatWksSSParser::readFormulaResult: can not read a string value\n"));
       return false;
@@ -1478,7 +1488,7 @@ bool GreatWksDBParser::readFormulaResult(long endPos, GreatWksDBParserInternal::
     cell.setFormat(format);
     std::string text("");
     for (int i=0; i<sSz; ++i)
-      text += (char) input->readULong(1);
+      text += char(input->readULong(1));
     f << "\"" << text << "\",";
     if ((sSz%2)==0)
       input->seek(1, librevenge::RVNG_SEEK_CUR);
@@ -1486,9 +1496,9 @@ bool GreatWksDBParser::readFormulaResult(long endPos, GreatWksDBParserInternal::
   }
   case 8: { // bool or long
     if (pos+4>endPos) return false;
-    int val=(int) input->readLong(2);
+    int val=static_cast<int>(input->readLong(2));
     cell.m_content.m_contentType=MWAWCellContent::C_NUMBER;
-    cell.m_content.setValue((double) val);
+    cell.m_content.setValue(double(val));
     f << input->readLong(2) << ",";
     break;
   }
@@ -1525,9 +1535,9 @@ bool GreatWksDBParser::readFields(MWAWEntry const &entry)
   libmwaw::DebugStream f;
   f << "Entries(Field):";
   input->seek(entry.begin()+6, librevenge::RVNG_SEEK_SET);
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
-  int dSz=(int) input->readULong(2);
+  int dSz=static_cast<int>(input->readULong(2));
   if ((vers==1 && dSz<0x3c) || (vers==2 && dSz<0x3e) || entry.length()<10+N*dSz) {
     MWAW_DEBUG_MSG(("GreatWksDBParser::readFields: the number of data seems bad\n"));
     f << "###";
@@ -1565,21 +1575,21 @@ bool GreatWksDBParser::readFields(MWAWEntry const &entry)
       }
       f.str("");
       f << "Field[summary]:";
-      int val=(int) input->readULong(2); // 10a or 180
+      int val=static_cast<int>(input->readULong(2)); // 10a or 180
       if (val!=0x10a) f << "fl=" << std::hex << val << std::dec << ",";
-      field.m_summaryType=(int) input->readULong(2);
+      field.m_summaryType=static_cast<int>(input->readULong(2));
       if (field.m_summaryType > 0 && field.m_summaryType < 6) {
         static char const *(wh[]) = { "", "average", "count", "total", "minimum", "maximum" };
         f << wh[field.m_summaryType] << ",";
       }
       else
         f << "#type=" << field.m_summaryType << ",";
-      field.m_summaryField=(int)input->readLong(2)-1;
+      field.m_summaryField=static_cast<int>(input->readLong(2))-1;
       f << "field=" << field.m_summaryField << ",";
-      val=(int) input->readULong(2); // 1e0 or 14
+      val=static_cast<int>(input->readULong(2)); // 1e0 or 14
       if (val!=0x1e0) f << "f0=" << std::hex << val << std::dec << ",";
       for (int i=0; i<5; ++i) { // always 0
-        val=(int) input->readULong(2);
+        val=static_cast<int>(input->readULong(2));
         if (val)  f << "f" << i+1 << "=" << val << ",";
       }
 
@@ -1610,7 +1620,7 @@ bool GreatWksDBParser::readField(GreatWksDBParserInternal::Field &field)
   MWAWInputStreamPtr input = getInput();
   long pos=input->tell();
   if (!input->checkPosition(pos+0x3c)) return false;
-  int type=(int) input->readLong(2);
+  int type=static_cast<int>(input->readLong(2));
   libmwaw::DebugStream f;
   MWAWCell::Format &format = field.m_format;
   switch (type) {
@@ -1654,30 +1664,30 @@ bool GreatWksDBParser::readField(GreatWksDBParserInternal::Field &field)
   }
   int val;
   if (version()==2) { // always 5?
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val!=5) f << "f0=" << val << ",";
   }
   for (int i=0; i<8; ++i) { // fl0-6=0|1, fl7=2c|38|ee|c4
-    val=(int) input->readULong(1);
+    val=static_cast<int>(input->readULong(1));
     if (val) f << "fl" << i << "=" << std::hex << val << std::dec << ",";
   }
-  val=(int) input->readLong(2); // always 0
+  val=static_cast<int>(input->readLong(2)); // always 0
   if (val) f << "f1=" << val << ",";
   /* f2=f3=f4=0 excepted
      for formula find 8,5bb2b4,1b or 4,5bb200,5
      for summary find 0,0,05bb254 and 0,0,5bb268
   */
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val) f << "f2=" << val << ",";
   for (int i=0; i<2; ++i) {
-    val=(int) input->readULong(4);
+    val=static_cast<int>(input->readULong(4));
     if (val) f << "f" << 3+i << "=" << std::hex << val << std::dec << ",";
   }
-  val=(int) input->readLong(2); // always 0
+  val=static_cast<int>(input->readLong(2)); // always 0
   if (val) f << "f5=" << val << ",";
-  field.m_linkZone=(long) input->readULong(2);
-  field.m_id=(int) input->readLong(2)-1;
-  int fSz=(int) input->readULong(1);
+  field.m_linkZone=long(input->readULong(2));
+  field.m_id=static_cast<int>(input->readLong(2))-1;
+  int fSz=static_cast<int>(input->readULong(1));
   if (fSz>31) {
     MWAW_DEBUG_MSG(("GreatWksDBParser::readField: the name field size seems to big\n"));
     f << "###";
@@ -1685,7 +1695,7 @@ bool GreatWksDBParser::readField(GreatWksDBParserInternal::Field &field)
   }
   else {
     std::string name("");
-    for (int i=0; i<fSz; ++i) name+=(char) input->readULong(1);
+    for (int i=0; i<fSz; ++i) name+=char(input->readULong(1));
     field.m_name=name;
   }
   field.m_extra=f.str();
@@ -1706,9 +1716,9 @@ bool GreatWksDBParser::readFieldAuxis(MWAWEntry const &entry)
   libmwaw::DebugStream f;
   f << "Entries(Field):";
   input->seek(entry.begin()+6, librevenge::RVNG_SEEK_SET);
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
-  int dSz=(int) input->readULong(2);
+  int dSz=static_cast<int>(input->readULong(2));
   if (vers==1 || (vers==2 && dSz<0x46) || entry.length()<10+N*dSz) {
     MWAW_DEBUG_MSG(("GreatWksDBParser::readFieldAuxis: the number of data seems bad\n"));
     f << "###";
@@ -1719,7 +1729,7 @@ bool GreatWksDBParser::readFieldAuxis(MWAWEntry const &entry)
   ascii().addPos(entry.begin());
   ascii().addNote(f.str().c_str());
   GreatWksDBParserInternal::Database &database=m_state->m_database;
-  if (N>(int) database.m_fieldList.size()) {
+  if (N>static_cast<int>(database.m_fieldList.size())) {
     MWAW_DEBUG_MSG(("GreatWksDBParser::readFieldAuxis: the field list seems too short\n"));
     database.m_fieldList.resize(size_t(N));
   }
@@ -1728,13 +1738,13 @@ bool GreatWksDBParser::readFieldAuxis(MWAWEntry const &entry)
     GreatWksDBParserInternal::Field &field=database.m_fieldList[size_t(i)];
     f.str("");
     f << "FldAuxi-" << i << ":";
-    int val=(int) input->readLong(2);
+    int val=static_cast<int>(input->readLong(2));
     if (val) {
       // checkme: find val=10 for a sequence with increment=10, so...
       f << "type[increment]=" << val << ",";
       field.m_isSequence=true;
     }
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val==1) {
       f << "isUnique[number],";
       // let use a sequence
@@ -1743,19 +1753,19 @@ bool GreatWksDBParser::readFieldAuxis(MWAWEntry const &entry)
     else if (val)
       f << "isUnique[number]=" << val << ",";
     for (int j=0; j<2; ++j) { // always 0?
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val) f << "f" << j << "=" << val << ",";
     }
-    field.m_firstNumber=(int) input->readLong(2);
+    field.m_firstNumber=static_cast<int>(input->readLong(2));
     if (field.m_firstNumber!=1)
       f << "first[sequence]=" << field.m_firstNumber << ",";
-    val=(int) input->readLong(2); // always 0
+    val=static_cast<int>(input->readLong(2)); // always 0
     if (val) f << "f2=" << val << ",";
-    field.m_incrementNumber=(int) input->readLong(2);
+    field.m_incrementNumber=static_cast<int>(input->readLong(2));
     if (field.m_incrementNumber!=1)
       f << "increment[sequence]=" << field.m_incrementNumber << ",";
     for (int j=0; j < 28; ++j) { // always 0
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val) f << "f" << j << "=" << val << ",";
     }
     input->seek(pos+dSz, librevenge::RVNG_SEEK_SET);
@@ -1788,7 +1798,7 @@ bool GreatWksDBParser::readFieldRecords(GreatWksDBParserInternal::Field &field)
     f << "Entries(FldRec)[" << field.m_id << "]:type=" << int(field.m_type) << ",";
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     int const N=zone.m_N;
-    int const dSz=(int) zone.m_dataSize;
+    int const dSz=static_cast<int>(zone.m_dataSize);
     if (field.m_type==GreatWksDBParserInternal::Field::F_Text) {
       if (!input->checkPosition(pos+dSz+N*5)) {
         MWAW_DEBUG_MSG(("GreatWksDBParser::readFieldRecords: can not read a text zone\n"));
@@ -1798,20 +1808,20 @@ bool GreatWksDBParser::readFieldRecords(GreatWksDBParserInternal::Field &field)
         continue;
       }
       for (int i=0; i<6; ++i) { // always 0?
-        int val=(int) input->readLong(2);
+        int val=static_cast<int>(input->readLong(2));
         if (val) f << "f" << i << "=" << val << ",";
       }
       std::vector<int> positions, rows;
       // first read the list of positions
       input->seek(pos+dSz, librevenge::RVNG_SEEK_SET);
       for (int i=0; i<N; ++i)
-        positions.push_back((int) input->readULong(1));
+        positions.push_back(static_cast<int>(input->readULong(1)));
       // now read a list of small int: the row number
       for (int i=0; i<N; ++i)
-        rows.push_back((int) input->readULong(4));
+        rows.push_back(static_cast<int>(input->readULong(4)));
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       int actPos=0;
-      for (size_t i=0; i<(size_t)N; ++i) {
+      for (size_t i=0; i<size_t(N); ++i) {
         int nextPos= i+1==size_t(N) ? dSz : positions[i+1];
         if (actPos!=positions[i] || nextPos>dSz) {
           MWAW_DEBUG_MSG(("GreatWksDBParser::readFieldRecords: can not read a text zone, pb with a position\n"));
@@ -1825,7 +1835,7 @@ bool GreatWksDBParser::readFieldRecords(GreatWksDBParserInternal::Field &field)
         std::string text("");
         bool findEmptyChar=false;
         while (actPos<nextPos) {
-          char c=(char) input->readULong(1);
+          char c=char(input->readULong(1));
           // c==0 can indicate an empty field
           if (c) text += c;
           else findEmptyChar=true;
@@ -1849,7 +1859,7 @@ bool GreatWksDBParser::readFieldRecords(GreatWksDBParserInternal::Field &field)
       }
       for (int i=0; i<N; ++i) {
         long fPos=input->tell();
-        int row=(int) input->readLong(4);
+        int row=static_cast<int>(input->readLong(4));
         double value;
         bool isNan;
         if (!input->readDouble10(value, isNan)) {
@@ -1898,11 +1908,11 @@ bool GreatWksDBParser::readFieldLinks(GreatWksDBParserInternal::Field &field)
   input->seek(field.m_linkZone, librevenge::RVNG_SEEK_SET);
   libmwaw::DebugStream f;
   f << "Entries(FldLink)[" << field.m_id << "]:";
-  int val=(int) input->readLong(2);
+  int val=static_cast<int>(input->readLong(2));
   if (val!=0xa) f << "#type=" << val << ",";
-  val=(int) input->readLong(2); // always 0
+  val=static_cast<int>(input->readLong(2)); // always 0
   if (val) f << "f0=" << val << ",";
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val!=0x14) f << "f1=" << val << ",";
   if (!readBlockHeader(field.m_recordBlock)) {
     MWAW_DEBUG_MSG(("GreatWksDBParser::readFieldLinks: the zone position seems bad\n"));
@@ -1929,8 +1939,8 @@ bool GreatWksDBParser::readIntList(MWAWEntry const &entry, std::vector<int> &lis
   }
   MWAWInputStreamPtr input = getInput();
   input->seek(entry.begin()+6, librevenge::RVNG_SEEK_SET);
-  int N=(int) input->readULong(2);
-  int dSz=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
+  int dSz=static_cast<int>(input->readULong(2));
   if (entry.length()!=10+N*dSz || dSz!=2) {
     MWAW_DEBUG_MSG(("GreatWksDBParser::readIntList: the N or dSz value seems bad\n"));
     return false;
@@ -1941,7 +1951,7 @@ bool GreatWksDBParser::readIntList(MWAWEntry const &entry, std::vector<int> &lis
   ascii().addNote("_");
 
   for (int i=0; i<N; ++i)
-    list.push_back((int) input->readLong(2));
+    list.push_back(static_cast<int>(input->readLong(2)));
 
   return true;
 }
@@ -1962,9 +1972,9 @@ bool GreatWksDBParser::readFormLinks(MWAWEntry const &entry)
   libmwaw::DebugStream f;
   f << "Entries(" << entry.name() << "):";
   input->seek(entry.begin()+6, librevenge::RVNG_SEEK_SET);
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
-  int dSz=(int) input->readULong(2);
+  int dSz=static_cast<int>(input->readULong(2));
   if (entry.length()!=10+N*dSz || dSz<4) {
     MWAW_DEBUG_MSG(("GreatWksDBParser::readFormLinks: the number of data seems bad\n"));
     f << "###";
@@ -1979,9 +1989,9 @@ bool GreatWksDBParser::readFormLinks(MWAWEntry const &entry)
     long pos=input->tell();
     f.str("");
     f << entry.name() << "-" << i << ":";
-    int val=(int) input->readLong(2); // always 0?
+    int val=static_cast<int>(input->readLong(2)); // always 0?
     if (val) f << "f0=" << val << ",";
-    int ptr=(int) input->readULong(2);
+    int ptr=static_cast<int>(input->readULong(2));
     if (ptr) {
       MWAWEntry zone;
       zone.setBegin(ptr);
@@ -2032,7 +2042,7 @@ bool GreatWksDBParser::readForm(MWAWEntry const &entry)
   f << "f0=" << std::hex << input->readULong(4) << std::dec << ",";
   // small number between 1 and 4
   f << "id=" << input->readLong(2) << ",";
-  int sSz=(int) input->readULong(1);
+  int sSz=static_cast<int>(input->readULong(1));
   if (sSz>32) {
     f << "###";
     MWAW_DEBUG_MSG(("GreatWksDBParser::readForm: the string size seems bad\n"));
@@ -2041,7 +2051,7 @@ bool GreatWksDBParser::readForm(MWAWEntry const &entry)
     return false;
   }
   std::string text("");
-  for (int i=0; i<sSz; ++i) text+=(char) input->readULong(1);
+  for (int i=0; i<sSz; ++i) text+=char(input->readULong(1));
   f << text << ",";
   input->seek(pos+44, librevenge::RVNG_SEEK_SET);
   ascii().addDelimiter(input->tell(),'|');
@@ -2081,12 +2091,12 @@ bool GreatWksDBParser::readZone12(MWAWEntry const &entry)
 
   int val;
   for (int i=0; i<4; ++i) { // f0=f1=0, f2=f3=1
-    val=(int) input->readLong(1);
+    val=static_cast<int>(input->readLong(1));
     if (val) f << "f" << i << "=" << val << ",";
   }
   if (vers==2) // b0|2a
     f << "g0=" << input->readLong(2) << ",";
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val) // 66|67|7a
     f << "g1=" << val << ",";
   ascii().addPos(entry.begin());
@@ -2111,9 +2121,9 @@ bool GreatWksDBParser::readSmallZone(MWAWEntry const &entry)
   libmwaw::DebugStream f;
   f << "Entries(" << entry.name() << "):";
   input->seek(entry.begin()+6, librevenge::RVNG_SEEK_SET);
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
-  int dSz=(int) input->readULong(2);
+  int dSz=static_cast<int>(input->readULong(2));
   if (entry.length()!=10+N*dSz) {
     MWAW_DEBUG_MSG(("GreatWksDBParser::readSmallZone: the number of data seems bad\n"));
     f << "###";
@@ -2149,8 +2159,8 @@ bool GreatWksDBParser::sendDatabase()
   std::vector<GreatWksDBParserInternal::Field> const &fields = database.m_fieldList;
   size_t numFields=fields.size();
   // fixme: use first layout colWidth here
-  listener->openSheet(std::vector<float>(1,76), librevenge::RVNG_POINT, std::vector<int>(1,(int)numFields), "Sheet0");
-  int r=0, numRows=(int) database.m_rowCellsMap.size();
+  listener->openSheet(std::vector<float>(1,76), librevenge::RVNG_POINT, std::vector<int>(1,static_cast<int>(numFields)), "Sheet0");
+  int r=0, numRows=static_cast<int>(database.m_rowCellsMap.size());
   std::map<int, std::vector<GreatWksDBParserInternal::Cell> >::const_iterator rIt;
   for (rIt=database.m_rowCellsMap.begin(); rIt != database.m_rowCellsMap.end(); ++rIt, ++r) {
     std::vector<GreatWksDBParserInternal::Cell> const &row=rIt->second;
@@ -2168,7 +2178,7 @@ bool GreatWksDBParser::sendDatabase()
       if (field.m_type==GreatWksDBParserInternal::Field::F_Text && content.m_textEntry.valid()) {
         input->seek(content.m_textEntry.begin(), librevenge::RVNG_SEEK_SET);
         while (!input->isEnd() && input->tell()<content.m_textEntry.end()) {
-          unsigned char ch=(unsigned char) input->readULong(1);
+          unsigned char ch=static_cast<unsigned char>(input->readULong(1));
           if (ch==0xd)
             listener->insertEOL();
           else if (ch<30) {
