@@ -69,9 +69,7 @@ struct Frame {
   {
   }
   //! destructor
-  virtual ~Frame()
-  {
-  }
+  virtual ~Frame();
   //! return the frame type
   virtual Type getType() const
   {
@@ -151,7 +149,7 @@ struct Frame {
   //! the data size ( if know)
   long m_dataSize;
   //! the zone bdbox
-  Box2f m_box;
+  MWAWBox2f m_box;
   //! the page
   int m_page;
   //! extra data
@@ -160,6 +158,10 @@ struct Frame {
   mutable bool m_parsed;
 };
 
+Frame::~Frame()
+{
+}
+
 ////////////////////////////////////////
 //! Internal: a unknown zone of a GreatWksGraph
 struct FrameBad : public Frame {
@@ -167,6 +169,8 @@ struct FrameBad : public Frame {
   FrameBad() : Frame()
   {
   }
+  //! destructor
+  ~FrameBad();
   //! return the frame type
   virtual Type getType() const
   {
@@ -174,13 +178,19 @@ struct FrameBad : public Frame {
   }
 };
 
+FrameBad::~FrameBad()
+{
+}
+
 ////////////////////////////////////////
 //! Internal: the basic shape of a GreatWksGraph
 struct FrameShape : public Frame {
   //! constructor
-  FrameShape(Frame const &frame) : Frame(frame), m_shape(), m_lineArrow(0), m_lineFormat(0)
+  explicit FrameShape(Frame const &frame) : Frame(frame), m_shape(), m_lineArrow(0), m_lineFormat(0)
   {
   }
+  //! destructor
+  ~FrameShape();
   //! return the frame type
   virtual Type getType() const
   {
@@ -213,19 +223,19 @@ struct FrameShape : public Frame {
   void updateStyle(MWAWGraphicStyle &style) const
   {
     if (m_shape.m_type!=MWAWGraphicShape::Line) {
-      style.m_arrows[0]=style.m_arrows[1]=false;
+      style.m_arrows[0]=style.m_arrows[1]=MWAWGraphicStyle::Arrow();
       style.m_lineDashWidth.resize(0);
     }
     else if (m_lineArrow > 1) {
       switch (m_lineArrow) {
       case 2:
-        style.m_arrows[1]=true;
+        style.m_arrows[1]=MWAWGraphicStyle::Arrow::plain();
         break;
       case 3:
-        style.m_arrows[0]=true;
+        style.m_arrows[0]=MWAWGraphicStyle::Arrow::plain();
         break;
       case 4:
-        style.m_arrows[0]=style.m_arrows[1]=true;
+        style.m_arrows[0]=style.m_arrows[1]=MWAWGraphicStyle::Arrow::plain();
         break;
       default:
         break;
@@ -243,13 +253,19 @@ private:
   FrameShape &operator=(FrameShape const &);
 };
 
+FrameShape::~FrameShape()
+{
+}
+
 ////////////////////////////////////////
 //! Internal: the group zone of a GreatWksGraph
 struct FrameGroup : public Frame {
   //! constructor
-  FrameGroup(Frame const &frame) : Frame(frame), m_numChild(0), m_childList()
+  explicit FrameGroup(Frame const &frame) : Frame(frame), m_numChild(0), m_childList()
   {
   }
+  //! destructor
+  virtual ~FrameGroup();
   //! return the frame type
   virtual Type getType() const
   {
@@ -268,13 +284,19 @@ struct FrameGroup : public Frame {
   std::vector<int> m_childList;
 };
 
+FrameGroup::~FrameGroup()
+{
+}
+
 ////////////////////////////////////////
 //! Internal: the picture zone of a GreatWksGraph
 struct FramePicture : public Frame {
   //! constructor
-  FramePicture(Frame const &frame) : Frame(frame), m_entry()
+  explicit FramePicture(Frame const &frame) : Frame(frame), m_entry()
   {
   }
+  //! destructor
+  virtual ~FramePicture();
   //! return the frame type
   virtual Type getType() const
   {
@@ -291,14 +313,20 @@ struct FramePicture : public Frame {
   MWAWEntry m_entry;
 };
 
+FramePicture::~FramePicture()
+{
+}
+
 ////////////////////////////////////////
 //! Internal: the text zone of a GreatWksGraph
 struct FrameText : public Frame {
   //! constructor
-  FrameText(Frame const &frame) : Frame(frame), m_entry(), m_rotate(0)
+  explicit FrameText(Frame const &frame) : Frame(frame), m_entry(), m_rotate(0)
   {
     m_flip[0]=m_flip[1]=false;
   }
+  //! destructor
+  virtual ~FrameText();
   //! return the frame type
   virtual Type getType() const
   {
@@ -339,13 +367,19 @@ struct FrameText : public Frame {
   int m_rotate;
 };
 
+FrameText::~FrameText()
+{
+}
+
 ////////////////////////////////////////
 //! Internal: the DBField zone of a GreatWksGraph
 struct FrameDBField : public Frame {
   //! constructor
-  FrameDBField(Frame const &frame) : Frame(frame)
+  explicit FrameDBField(Frame const &frame) : Frame(frame)
   {
   }
+  //! destructor
+  virtual ~FrameDBField();
   //! return the frame type
   virtual Type getType() const
   {
@@ -358,6 +392,10 @@ struct FrameDBField : public Frame {
   }
 };
 
+FrameDBField::~FrameDBField()
+{
+}
+
 ////////////////////////////////////////
 //! Internal: a list of graphic corresponding to a page
 struct Zone {
@@ -427,8 +465,10 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType)
     MWAW_DEBUG_MSG(("GreatWksGraphInternal::SubDocument::parse: no listener\n"));
     return;
   }
-  assert(m_graphParser);
-
+  if (!m_graphParser) {
+    MWAW_DEBUG_MSG(("GreatWksGraphInternal::SubDocument::parse: no parser\n"));
+    return;
+  }
   long pos = m_input->tell();
   m_graphParser->sendTextbox(m_zone,listener);
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -505,7 +545,7 @@ bool GreatWksGraph::readPatterns(MWAWEntry const &entry)
 
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Entries(Pattern):";
-  int N=(int) input->readLong(2);
+  int N=static_cast<int>(input->readLong(2));
   f << "N=" << N << ",";
   if (2+8*N!=int(entry.length())) {
     f << "###";
@@ -521,10 +561,10 @@ bool GreatWksGraph::readPatterns(MWAWEntry const &entry)
     f.str("");
     f << "Pattern-" << i << ":";
     MWAWGraphicStyle::Pattern pat;
-    pat.m_dim=Vec2i(8,8);
+    pat.m_dim=MWAWVec2i(8,8);
     pat.m_data.resize(8);
     for (size_t j=0; j < 8; ++j)
-      pat.m_data[j]=(unsigned char) input->readLong(1);
+      pat.m_data[j]=static_cast<unsigned char>(input->readLong(1));
     f << pat;
     input->seek(pos+8, librevenge::RVNG_SEEK_SET);
     ascFile.addPos(pos);
@@ -548,10 +588,10 @@ bool GreatWksGraph::readPalettes(MWAWEntry const &entry)
 
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Entries(Palette):";
-  int val=(int) input->readLong(2);
+  int val=static_cast<int>(input->readLong(2));
   if (val!=2)
     f << "#f0=" << val << ",";
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val!=8)
     f << "#f1=" << val << ",";
   ascFile.addPos(pos-4);
@@ -576,7 +616,7 @@ bool GreatWksGraph::readPalettes(MWAWEntry const &entry)
     else f << "Colors-" << i << ":";
     unsigned char col[3];
     for (int j=0; j < 3; ++j)
-      col[j]=(unsigned char)(input->readULong(2)>>8);
+      col[j]=static_cast<unsigned char>(input->readULong(2)>>8);
     f << MWAWColor(col[0], col[1], col[2]) << ",";
     input->seek(pos+6, librevenge::RVNG_SEEK_SET);
     ascFile.addPos(pos);
@@ -608,7 +648,7 @@ bool GreatWksGraph::isGraphicZone()
   int dim[4];
   for (int st=0; st<2; ++st) {
     for (int i=0; i<4; ++i)
-      dim[i]=(int) input->readLong(2);
+      dim[i]=static_cast<int>(input->readLong(2));
     if (dim[0]>=dim[2] || dim[1]>=dim[3] || dim[2]<=0 || dim[3]<=0) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       return false;
@@ -651,7 +691,7 @@ bool GreatWksGraph::readGraphicZone()
   for (int st=0; st<2; ++st) {
     int dim[4];
     for (int i=0; i<4; ++i)
-      dim[i]=(int) input->readLong(2);
+      dim[i]=static_cast<int>(input->readLong(2));
     f << "dim" << st << "=" << dim[1] << "x" << dim[0]
       << "<->"<< dim[3] << "x" << dim[2] << ",";
   }
@@ -755,7 +795,7 @@ bool GreatWksGraph::findGraphicZone()
       continue;
 
     input->seek(actPos-decal, librevenge::RVNG_SEEK_SET);
-    int N=(int) input->readULong(2);
+    int N=static_cast<int>(input->readULong(2));
     if (input->readLong(2)!=0x36 || !input->checkPosition(actPos-decal+4+0x36*N)) {
       input->seek(actPos+4, librevenge::RVNG_SEEK_SET);
       continue;
@@ -792,12 +832,12 @@ bool GreatWksGraph::isPageFrames()
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   if (hasPageUnknown) {
     input->seek(2, librevenge::RVNG_SEEK_CUR); // page or 1c for spreadsheet
-    sz=(long) input->readULong(4);
+    sz=long(input->readULong(4));
     endPos=input->tell()+sz;
   }
   long zoneSz[4]= {0,0,0,0};
   for (int i=0; i<nZones; ++i)
-    zoneSz[i]=(long) input->readULong(4);
+    zoneSz[i]=long(input->readULong(4));
   if (hasPageUnknown &&
       (6+sz<headerSize+4*nZones || zoneSz[0]+zoneSz[1]+zoneSz[2]>sz ||
        !input->checkPosition(endPos))) {
@@ -816,8 +856,8 @@ bool GreatWksGraph::isPageFrames()
     pos=input->tell();
     if (pos==endPos)
       return true;
-    int nData=(int) input->readLong(2);
-    int fSz=(int) input->readLong(2);
+    int nData=static_cast<int>(input->readLong(2));
+    int fSz=static_cast<int>(input->readLong(2));
     if (nData<0 || (nData!=0 && fSz!=expectedSz[i]) || nData*fSz+4 > zoneSz[i]) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       return false;
@@ -848,16 +888,16 @@ bool GreatWksGraph::readStyle(MWAWGraphicStyle &style)
   if (!input->checkPosition(endPos))
     return false;
 
-  int val=(int) input->readLong(2);
+  int val=static_cast<int>(input->readLong(2));
   if (val) f << "used=" << val << ",";
   float dim[2];
   for (int i=0; i <2; ++i)
     dim[i]=float(input->readLong(4))/65536.f;
-  if (dim[0]<dim[1] || dim[0]>dim[1]) f << "lineWidth[real]=" << Vec2f(dim[1],dim[0]) << ",";
+  if (dim[0]<dim[1] || dim[0]>dim[1]) f << "lineWidth[real]=" << MWAWVec2f(dim[1],dim[0]) << ",";
   style.m_lineWidth=(dim[1]+dim[0])/2.f;
   if (vers==1) {
     for (int i=0; i < 2; ++i) { // two flags 0|1
-      val=(int) input->readULong(1);
+      val=static_cast<int>(input->readULong(1));
       if (val==0 || val==1) {
         if (i==0)
           style.m_lineOpacity=float(val);
@@ -869,15 +909,15 @@ bool GreatWksGraph::readStyle(MWAWGraphicStyle &style)
     }
     MWAWGraphicStyle::Pattern patterns[2];
     for (int i=0; i < 2; ++i) {
-      patterns[i].m_dim=Vec2i(8,8);
+      patterns[i].m_dim=MWAWVec2i(8,8);
       patterns[i].m_data.resize(8);
       for (size_t j=0; j < 8; ++j)
-        patterns[i].m_data[j]=(unsigned char) input->readULong(1);
+        patterns[i].m_data[j]=static_cast<unsigned char>(input->readULong(1));
     }
     for (int i=0; i < 4; ++i) {
       unsigned char col[3];
       for (int j=0; j < 3; ++j)
-        col[j]=(unsigned char)(input->readULong(2)>>8);
+        col[j]=static_cast<unsigned char>(input->readULong(2)>>8);
       patterns[i/2].m_colors[1-i%2]=MWAWColor(col[0], col[1], col[2]);
     }
     if (!patterns[0].getUniqueColor(style.m_lineColor)) {
@@ -897,27 +937,27 @@ bool GreatWksGraph::readStyle(MWAWGraphicStyle &style)
   }
   MWAWGraphicStyle::Pattern patterns[2];
   for (int i=0; i < 4; ++i) {
-    val=(int) input->readULong(2);
+    val=static_cast<int>(input->readULong(2));
     if (val) f << "col" << i << "=" << std::hex << val << std::dec << ",";
     unsigned char col[3];
     for (int j=0; j < 3; ++j)
-      col[j]=(unsigned char)(input->readULong(2)>>8);
+      col[j]=static_cast<unsigned char>(input->readULong(2)>>8);
     patterns[i/2].m_colors[1-i%2]=MWAWColor(col[0], col[1], col[2]);
   }
-  val=(int) input->readULong(2);
+  val=static_cast<int>(input->readULong(2));
   if (val) f << "col4=" << std::hex << val << std::dec << ",";
   for (int i=0; i < 2; ++i) {
-    val=(int) input->readULong(2); // small number
+    val=static_cast<int>(input->readULong(2)); // small number
     if (i==0)
       style.m_lineOpacity=val ? 1.0 : 0.0;
     else
       style.m_surfaceOpacity=val ? 1.0 : 0.0;
     if (val>1)
       f << "pat" << i << "=" << val << ",";
-    patterns[i].m_dim=Vec2i(8,8);
+    patterns[i].m_dim=MWAWVec2i(8,8);
     patterns[i].m_data.resize(8);
     for (size_t j=0; j < 8; ++j)
-      patterns[i].m_data[j]=(unsigned char) input->readULong(1);
+      patterns[i].m_data[j]=static_cast<unsigned char>(input->readULong(1));
   }
   if (!patterns[0].getUniqueColor(style.m_lineColor)) {
     f << "linePattern=[" << patterns[0] << "],";
@@ -930,10 +970,10 @@ bool GreatWksGraph::readStyle(MWAWGraphicStyle &style)
       style.setPattern(patterns[1]);
   }
 
-  val=(int) input->readULong(2);
+  val=static_cast<int>(input->readULong(2));
   if (val!=1) f << "patId=" << val << ",";
 
-  int nDash=val==1 ? 1 : (int)input->readULong(2);
+  int nDash=val==1 ? 1 : static_cast<int>(input->readULong(2));
   if (nDash<0||nDash>6) {
     MWAW_DEBUG_MSG(("GreatWksGraph::readStyle: can not read number of line dash\n"));
     f << "#nDash=" << nDash << ",";
@@ -956,9 +996,9 @@ bool GreatWksGraph::readStyle(MWAWGraphicStyle &style)
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   ascFile.addDelimiter(pos+92,'|'); // some data?
   ascFile.addDelimiter(input->tell(),'|');
-  int gradId=(int) input->readLong(2);
+  int gradId=static_cast<int>(input->readLong(2));
   if (gradId) f << "gradientId=" << gradId << ",";
-  int gradType=(int) input->readLong(2);
+  int gradType=static_cast<int>(input->readLong(2));
   if (gradId>=1 && gradId<=16 && (gradType>=1&&gradType<=3)) {
     style.m_gradientStopList.resize(2);
     style.m_gradientStopList[0]=MWAWGraphicStyle::GradientStop(0.0, MWAWColor::white());
@@ -1004,14 +1044,14 @@ bool GreatWksGraph::readStyle(MWAWGraphicStyle &style)
       break;
     case 9:
       if (gradType!=3) style.m_gradientType = MWAWGraphicStyle::G_None;
-      style.m_gradientPercentCenter=Vec2f(.5f,.5f);
+      style.m_gradientPercentCenter=MWAWVec2f(.5f,.5f);
       style.m_gradientStopList[0]=MWAWGraphicStyle::GradientStop(0.0, MWAWColor::black());
       style.m_gradientStopList[1]=MWAWGraphicStyle::GradientStop(1.0, MWAWColor::white());
       style.m_gradientType=MWAWGraphicStyle::G_Square;
       break;
     case 10:
       if (gradType!=3) style.m_gradientType = MWAWGraphicStyle::G_None;
-      style.m_gradientPercentCenter=Vec2f(.5f,.5f);
+      style.m_gradientPercentCenter=MWAWVec2f(.5f,.5f);
       style.m_gradientType=MWAWGraphicStyle::G_Square;
       break;
     case 11:
@@ -1056,27 +1096,27 @@ bool GreatWksGraph::readStyle(MWAWGraphicStyle &style)
   for (size_t i=0; i < 2; ++i) {
     unsigned char col[3];
     for (int j=0; j < 3; ++j)
-      col[j]=(unsigned char)(input->readULong(2)>>8);
+      col[j]=static_cast<unsigned char>(input->readULong(2)>>8);
     f << "grad[col" << i << "]=" << MWAWColor(col[0], col[1], col[2]) << ",";
   }
   input->seek(2, librevenge::RVNG_SEEK_CUR); // junk ?
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   switch (val) {
   case 1: // none
     break;
   case 2:
-    style.m_arrows[1]=true;
+    style.m_arrows[1]=MWAWGraphicStyle::Arrow::plain();
     break;
   case 3:
-    style.m_arrows[0]=true;
+    style.m_arrows[0]=MWAWGraphicStyle::Arrow::plain();
     break;
   case 4:
-    style.m_arrows[0]=style.m_arrows[1]=true;
+    style.m_arrows[0]=style.m_arrows[1]=MWAWGraphicStyle::Arrow::plain();
     break;
   default:
     f << "#lineArrows=" << val << ",";
   }
-  val=(int) input->readLong(2);
+  val=static_cast<int>(input->readLong(2));
   if (val!=1)
     f << "#lineArrow[unset],";
   style.m_extra=f.str();
@@ -1107,7 +1147,7 @@ bool GreatWksGraph::readLineFormat(std::string &extra)
 
   // find: f0=1, f1=0, f2=9|c f3=3|5, f5=c|f, f0+a dim?
   for (int i=0; i<5; ++i) {
-    int val=(int) input->readLong(2);
+    int val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
 
@@ -1139,30 +1179,30 @@ bool GreatWksGraph::readPageFrames()
   long endPos=-1;
   GreatWksGraphInternal::Zone pageZone;
   if (isSpreadsheet) {
-    int val=(int) input->readLong(2);
+    int val=static_cast<int>(input->readLong(2));
     if (val != 0x1c) {
       MWAW_DEBUG_MSG(("GreatWksGraph::readPageFrames: oops unexpected key word\n"));
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       return false;
     }
-    endPos=pos+6+(long)input->readULong(4);
+    endPos=pos+6+long(input->readULong(4));
   }
   else if (hasPageUnknown) {
-    pageZone.m_page = (int)input->readLong(2);
+    pageZone.m_page = static_cast<int>(input->readLong(2));
     f << "page=" << pageZone.m_page << ",";
-    endPos=pos+6+(long)input->readULong(4);
+    endPos=pos+6+long(input->readULong(4));
   }
   static char const *(wh[])= {"head", "gstyle", "root", "unknown"};
   long zoneSz[4]= {0,0,0,0};
   for (int i=0; i < nZones; ++i) {
-    zoneSz[i] = (long) input->readULong(4);
+    zoneSz[i] = long(input->readULong(4));
     if (zoneSz[i])
       f << wh[i] << "[sz]=" << std::hex << zoneSz[i] << std::dec << ",";
   }
 
   int z=0;
   long zoneEnd=input->tell()+zoneSz[z++];
-  int nFrames=(int) input->readLong(2);
+  int nFrames=static_cast<int>(input->readLong(2));
   input->seek(2, librevenge::RVNG_SEEK_CUR);
   f << "nFrames=" << nFrames << ",";
   ascFile.addPos(pos);
@@ -1172,7 +1212,8 @@ bool GreatWksGraph::readPageFrames()
     pos = input->tell();
     f.str("");
     f << "GFrame[head]-F" << i+1 << ":";
-    shared_ptr<GreatWksGraphInternal::Frame> zone=readFrameHeader();
+    shared_ptr<GreatWksGraphInternal::Frame> zone;
+    if (pos+0x36<=zoneEnd) zone=readFrameHeader();
     if (!zone) {
       MWAW_DEBUG_MSG(("GreatWksGraph::readPageFrames: oops graphic detection is probably bad\n"));
       f << "###";
@@ -1195,7 +1236,7 @@ bool GreatWksGraph::readPageFrames()
 
   pos=input->tell();
   zoneEnd=pos+zoneSz[z++];
-  int nData=(int) input->readLong(2);
+  int nData=static_cast<int>(input->readLong(2));
   input->seek(2, librevenge::RVNG_SEEK_CUR);
   f.str("");
   f << "Entries(GStyle): N=" << nData << ",";
@@ -1207,7 +1248,7 @@ bool GreatWksGraph::readPageFrames()
     f.str("");
     f << "GStyle-S" << i+1 << ":";
     MWAWGraphicStyle style;
-    if (!readStyle(style))
+    if (pos+gDataSize>zoneEnd || !readStyle(style))
       f << "###";
     else
       f << style;
@@ -1226,7 +1267,7 @@ bool GreatWksGraph::readPageFrames()
   if (vers==1) {
     pos=input->tell();
     zoneEnd=pos+zoneSz[z++];
-    nData=(int) input->readLong(2);
+    nData=static_cast<int>(input->readLong(2));
     input->seek(2, librevenge::RVNG_SEEK_CUR);
     f.str("");
     f << "Entries(GLineFormat): N=" << nData << ",";
@@ -1256,12 +1297,17 @@ bool GreatWksGraph::readPageFrames()
 
   pos = input->tell();
   zoneEnd=pos+zoneSz[z++];
-  int nRoots=(int) input->readLong(2);
+  int nRoots=static_cast<int>(input->readLong(2));
   input->seek(2, librevenge::RVNG_SEEK_CUR);
   f.str("");
   f << "GFrame[roots]: N=" << nRoots << ",roots=[";
   for (int i=0; i < nRoots; ++i) {
-    int val = (int) input->readLong(2);
+    if (input->tell()+2>zoneEnd) {
+      MWAW_DEBUG_MSG(("GreatWksGraph::readPageFrames: can not read some roots\n"));
+      f << "###";
+      break;
+    }
+    int val = static_cast<int>(input->readLong(2));
     if (val==0) {
       f << "_,";
       continue;
@@ -1446,8 +1492,8 @@ shared_ptr<GreatWksGraphInternal::Frame> GreatWksGraph::readFrameHeader()
 
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
-  zone.m_type=(int) input->readLong(1);
-  int locked=(int)input->readLong(1);
+  zone.m_type=static_cast<int>(input->readLong(1));
+  int locked=static_cast<int>(input->readLong(1));
   if (zone.m_type<0||zone.m_type>16||locked<0||locked>1) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return res;
@@ -1460,21 +1506,21 @@ shared_ptr<GreatWksGraphInternal::Frame> GreatWksGraph::readFrameHeader()
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return res;
   }
-  zone.m_box=Box2f(Vec2f(dim[1],dim[0]),Vec2f(dim[3],dim[2]));
-  zone.m_styleId=(int) input->readULong(2);
-  zone.m_parent=(int) input->readULong(2);
-  zone.m_order=(int) input->readULong(2);
+  zone.m_box=MWAWBox2f(MWAWVec2f(dim[1],dim[0]),MWAWVec2f(dim[3],dim[2]));
+  zone.m_styleId=static_cast<int>(input->readULong(2));
+  zone.m_parent=static_cast<int>(input->readULong(2));
+  zone.m_order=static_cast<int>(input->readULong(2));
   switch (zone.m_type) {
   case 1: {
     GreatWksGraphInternal::FrameText *textBox = new GreatWksGraphInternal::FrameText(zone);
     res.reset(textBox);
-    res->m_dataSize=(long) input->readULong(4);
-    long val=(long) input->readULong(2);
+    res->m_dataSize=long(input->readULong(4));
+    long val=long(input->readULong(2));
     if (val&1) textBox->m_flip[0]=true;
     if (val&2) textBox->m_flip[1]=true;
     val &= 0xFFFC;
     if (val) f << "#flip=" << val << ",";
-    textBox->m_rotate=(int) input->readLong(2);
+    textBox->m_rotate=static_cast<int>(input->readLong(2));
     if (vers==2) // checkme odd
       textBox->m_rotate = -textBox->m_rotate;
     val=input->readLong(2); // 0 or 100
@@ -1483,32 +1529,32 @@ shared_ptr<GreatWksGraphInternal::Frame> GreatWksGraph::readFrameHeader()
   }
   case 11:
     res.reset(new GreatWksGraphInternal::FramePicture(zone));
-    res->m_dataSize=(long) input->readULong(4);
+    res->m_dataSize=long(input->readULong(4));
     break;
   case 15: {
     GreatWksGraphInternal::FrameGroup *grp=new GreatWksGraphInternal::FrameGroup(zone);
     res.reset(grp);
-    grp->m_numChild=(int) input->readULong(2);
+    grp->m_numChild=static_cast<int>(input->readULong(2));
     break;
   }
   case 2: {
     GreatWksGraphInternal::FrameShape *graph=new GreatWksGraphInternal::FrameShape(zone);
     res.reset(graph);
     if (vers==1) {
-      graph->m_lineArrow=(int) input->readLong(2);
-      graph->m_lineFormat=(int) input->readLong(2);
+      graph->m_lineArrow=static_cast<int>(input->readLong(2));
+      graph->m_lineFormat=static_cast<int>(input->readLong(2));
     }
     float points[4];
     for (int i=0; i<4; ++i)
       points[i]=float(input->readLong(4))/65536;
-    graph->m_shape=MWAWGraphicShape::line(Vec2f(points[1],points[0]), Vec2f(points[3],points[2]));
+    graph->m_shape=MWAWGraphicShape::line(MWAWVec2f(points[1],points[0]), MWAWVec2f(points[3],points[2]));
     break;
   }
   case 4: {
     GreatWksGraphInternal::FrameShape *graph=new GreatWksGraphInternal::FrameShape(zone);
     res.reset(graph);
-    int roundType = (int) input->readLong(2);
-    float cornerDim = (float) input->readLong(2);
+    int roundType = static_cast<int>(input->readLong(2));
+    float cornerDim = float(input->readLong(2));
     graph->m_shape = MWAWGraphicShape::rectangle(zone.m_box);
     switch (roundType) {
     case 1: // normal
@@ -1531,8 +1577,8 @@ shared_ptr<GreatWksGraphInternal::Frame> GreatWksGraph::readFrameHeader()
     res.reset(graph);
     int fileAngle[2];
     for (int i=0; i < 2; ++i) // angles
-      fileAngle[i]=(int) input->readLong(2);
-    int type=(int) input->readLong(1); // 0:open, 1: close
+      fileAngle[i]=static_cast<int>(input->readLong(2));
+    int type=static_cast<int>(input->readLong(1)); // 0:open, 1: close
     if (type==1) f << "closed,";
     else if (type) f << "#type=" << type << ",";
 
@@ -1543,13 +1589,23 @@ shared_ptr<GreatWksGraphInternal::Frame> GreatWksGraph::readFrameHeader()
     }
     else if (fileAngle[1]==360)
       angle[0]=int(90-fileAngle[0]-359);
-    while (angle[1] > 360) {
-      angle[0]-=360;
-      angle[1]-=360;
+    if (angle[1]>360) {
+      int numLoop=int(angle[1]/360)-1;
+      angle[0]-=numLoop*360;
+      angle[1]-=numLoop*360;
+      while (angle[1] > 360) {
+        angle[0]-=360;
+        angle[1]-=360;
+      }
     }
-    while (angle[0] < -360) {
-      angle[0]+=360;
-      angle[1]+=360;
+    if (angle[0] < -360) {
+      int numLoop=int(angle[0]/360)+1;
+      angle[0]-=numLoop*360;
+      angle[1]-=numLoop*360;
+      while (angle[0] < -360) {
+        angle[0]+=360;
+        angle[1]+=360;
+      }
     }
     // we must compute the real bd box
     float minVal[2] = { 0, 0 }, maxVal[2] = { 0, 0 };
@@ -1566,20 +1622,20 @@ shared_ptr<GreatWksGraphInternal::Frame> GreatWksGraph::readFrameHeader()
       if (actVal[1] < minVal[1]) minVal[1] = actVal[1];
       else if (actVal[1] > maxVal[1]) maxVal[1] = actVal[1];
     }
-    Box2f circleBox=zone.m_box;
+    MWAWBox2f circleBox=zone.m_box;
     // we have the shape box, we need to reconstruct the circle box
     if (maxVal[0]>minVal[0] && maxVal[1]>minVal[1]) {
       float scaling[2]= { (zone.m_box[1][0]-zone.m_box[0][0])/(maxVal[0]-minVal[0]),
                           (zone.m_box[1][1]-zone.m_box[0][1])/(maxVal[1]-minVal[1])
                         };
       float constant[2]= { zone.m_box[0][0]-minVal[0] *scaling[0], zone.m_box[0][1]-minVal[1] *scaling[1]};
-      circleBox=Box2f(Vec2f(constant[0]-scaling[0], constant[1]-scaling[1]),
-                      Vec2f(constant[0]+scaling[0], constant[1]+scaling[1]));
+      circleBox=MWAWBox2f(MWAWVec2f(constant[0]-scaling[0], constant[1]-scaling[1]),
+                          MWAWVec2f(constant[0]+scaling[0], constant[1]+scaling[1]));
     }
     if (type==1)
-      graph->m_shape = MWAWGraphicShape::pie(zone.m_box, circleBox, Vec2f(float(angle[0]), float(angle[1])));
+      graph->m_shape = MWAWGraphicShape::pie(zone.m_box, circleBox, MWAWVec2f(float(angle[0]), float(angle[1])));
     else
-      graph->m_shape = MWAWGraphicShape::arc(zone.m_box, circleBox, Vec2f(float(angle[0]), float(angle[1])));
+      graph->m_shape = MWAWGraphicShape::arc(zone.m_box, circleBox, MWAWVec2f(float(angle[0]), float(angle[1])));
     break;
   }
   case 3: // rect: no data
@@ -1594,7 +1650,7 @@ shared_ptr<GreatWksGraphInternal::Frame> GreatWksGraph::readFrameHeader()
   case 10: {
     GreatWksGraphInternal::FrameDBField *field=new GreatWksGraphInternal::FrameDBField(zone);
     res.reset(field);
-    field->m_dataSize=(long) input->readULong(4);
+    field->m_dataSize=long(input->readULong(4));
     break;
   }
   case 7:
@@ -1603,7 +1659,7 @@ shared_ptr<GreatWksGraphInternal::Frame> GreatWksGraph::readFrameHeader()
     GreatWksGraphInternal::FrameShape *graph=new GreatWksGraphInternal::FrameShape(zone);
     res.reset(graph);
     graph->m_shape = zone.m_type==12 ? MWAWGraphicShape::path(zone.m_box) : MWAWGraphicShape::polygon(zone.m_box);
-    graph->m_dataSize=(long) input->readULong(4);
+    graph->m_dataSize=long(input->readULong(4));
     break;
   }
   default:
@@ -1663,7 +1719,7 @@ bool GreatWksGraph::readFrameExtraData(GreatWksGraphInternal::Frame &frame, int
       MWAW_DEBUG_MSG(("GreatWksGraph::readFrameExtraData: unexpected type for basic graph\n"));
       return false;
     }
-    int nPt=(int) input->readLong(2);
+    int nPt=static_cast<int>(input->readLong(2));
     long endData=pos+10+8*nPt;
     if (pos+frame.m_dataSize > endData)
       endData=pos+frame.m_dataSize;
@@ -1678,11 +1734,11 @@ bool GreatWksGraph::readFrameExtraData(GreatWksGraphInternal::Frame &frame, int
     f << "pt=[";
     GreatWksGraphInternal::FrameShape &graph=static_cast<GreatWksGraphInternal::FrameShape &>(frame);
     float pt[2];
-    std::vector<Vec2f> vertices;
+    std::vector<MWAWVec2f> vertices;
     for (int p=0; p<nPt; ++p) {
       pt[0]=float(input->readLong(4))/65536.f;
       pt[1]=float(input->readLong(4))/65536.f;
-      vertices.push_back(Vec2f(pt[1],pt[0]));
+      vertices.push_back(MWAWVec2f(pt[1],pt[0]));
       f << pt[1] << "x" << pt[0] << ",";
     }
     f << "],";
@@ -1738,7 +1794,7 @@ bool GreatWksGraph::readFrameExtraData(GreatWksGraphInternal::Frame &frame, int
     return true;
   }
   case 15: {
-    int nGrp=(int) input->readLong(2);
+    int nGrp=static_cast<int>(input->readLong(2));
     if (nGrp<0 || (endPos>0 && pos+4+2*nGrp>endPos) ||
         (endPos<0 && !input->checkPosition(pos+4+2*nGrp))) {
       MWAW_DEBUG_MSG(("GreatWksGraph::readFrameExtraData: unexpected number of group\n"));
@@ -1756,11 +1812,11 @@ bool GreatWksGraph::readFrameExtraData(GreatWksGraphInternal::Frame &frame, int
       f << "###[N=" << group.m_numChild << "]";
       MWAW_DEBUG_MSG(("GreatWksGraph::readFrameExtraData: unexpected number of group child\n"));
     }
-    int val=(int) input->readLong(2); // always 2
+    int val=static_cast<int>(input->readLong(2)); // always 2
     if (val!=2) f << "f0=" << val << ",";
     f << "grpId=[";
     for (int j=0; j < nGrp; ++j) {
-      val = (int) input->readLong(2);
+      val = static_cast<int>(input->readLong(2));
       group.m_childList.push_back(val);
       f << val << ",";
     }
@@ -1789,28 +1845,27 @@ bool GreatWksGraph::sendTextbox(GreatWksGraphInternal::FrameText const &text, Gr
   MWAWGraphicStyle style;
   if (text.m_styleId>=1 && text.m_styleId <= int(zone.m_styleList.size()))
     style = zone.m_styleList[size_t(text.m_styleId-1)];
-  Vec2f fSz=pos.size();
+  MWAWVec2f fSz=pos.size();
   // increase slightly x and set y to atleast
-  Vec2f newSz(fSz[0]+3,fSz[1]);
+  MWAWVec2f newSz(fSz[0]+3,fSz[1]);
   if (listener->getType()==MWAWListener::Graphic)
-    return sendTextboxAsGraphic(Box2f(pos.origin(),pos.origin()+newSz), text, style, listener);
+    return sendTextboxAsGraphic(MWAWBox2f(pos.origin(),pos.origin()+newSz), text, style, listener);
 
   MWAWPosition finalPos(pos);
-  finalPos.setSize(Vec2f(newSz[0],-newSz[1]));
+  finalPos.setSize(MWAWVec2f(newSz[0],-newSz[1]));
   if ((text.hasTransform() || style.hasPattern() || style.hasGradient()) &&
       m_document.canSendTextboxAsGraphic(text.m_entry)) {
-    Box2f box(Vec2f(0,0),newSz);
+    MWAWBox2f box(MWAWVec2f(0,0),newSz);
     MWAWGraphicEncoder graphicEncoder;
     MWAWGraphicListenerPtr graphicListener
     (new MWAWGraphicListener(*m_parserState, box, &graphicEncoder));
     graphicListener->startDocument();
     bool ok=sendTextboxAsGraphic(box, text, style, graphicListener);
     graphicListener->endDocument();
-    librevenge::RVNGBinaryData data;
-    std::string type;
-    if (!graphicEncoder.getBinaryResult(data, type) || !ok)
+    MWAWEmbeddedObject picture;
+    if (!graphicEncoder.getBinaryResult(picture) || !ok)
       return false;
-    listener->insertPicture(finalPos, data, type);
+    listener->insertPicture(finalPos, picture);
     return true;
   }
 
@@ -1822,7 +1877,7 @@ bool GreatWksGraph::sendTextbox(GreatWksGraphInternal::FrameText const &text, Gr
   return true;
 }
 
-bool GreatWksGraph::sendTextboxAsGraphic(Box2f const &box, GreatWksGraphInternal::FrameText const &text,
+bool GreatWksGraph::sendTextboxAsGraphic(MWAWBox2f const &box, GreatWksGraphInternal::FrameText const &text,
     MWAWGraphicStyle const &style, MWAWListenerPtr listener)
 {
   libmwaw::SubDocumentType subdocType;
@@ -1832,12 +1887,12 @@ bool GreatWksGraph::sendTextboxAsGraphic(Box2f const &box, GreatWksGraphInternal
   }
   shared_ptr<MWAWSubDocument> doc(new GreatWksGraphInternal::SubDocument(*this, m_parserState->m_input, text.m_entry));
 
-  Vec2f fSz=box.size();
-  Box2f textBox=Box2f(box[0],box[0]+Vec2f(fSz[0],-fSz[1]));
+  MWAWVec2f fSz=box.size();
+  MWAWBox2f textBox=MWAWBox2f(box[0],box[0]+MWAWVec2f(fSz[0],-fSz[1]));
   /* rotation are multiple of 90, so we can use the inverse rotation to find
      the original box */
   if (text.m_rotate)
-    textBox=libmwaw::rotateBoxFromCenter(box, (float) -text.m_rotate);
+    textBox=libmwaw::rotateBoxFromCenter(box, -float(text.m_rotate));
   MWAWPosition textPos(textBox[0], textBox.size(), librevenge::RVNG_POINT);
   textPos.m_anchorTo=MWAWPosition::Page;
   textPos.m_wrapping = MWAWPosition::WBackground;
@@ -1864,13 +1919,10 @@ bool GreatWksGraph::sendPicture(MWAWEntry const &entry, MWAWPosition pos)
   long actPos = input->tell();
 
   input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
-  shared_ptr<MWAWPict> thePict(MWAWPictData::get(input, (int)entry.length()));
-  if (thePict) {
-    librevenge::RVNGBinaryData data;
-    std::string type;
-    if (thePict->getBinary(data,type))
-      listener->insertPicture(pos, data, type);
-  }
+  shared_ptr<MWAWPict> thePict(MWAWPictData::get(input, static_cast<int>(entry.length())));
+  MWAWEmbeddedObject picture;
+  if (thePict && thePict->getBinary(picture))
+    listener->insertPicture(pos, picture);
 
 #ifdef DEBUG_WITH_FILES
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
@@ -1901,7 +1953,7 @@ bool GreatWksGraph::sendGroup(GreatWksGraphInternal::FrameGroup const &group, Gr
 bool GreatWksGraph::canCreateGraphic(GreatWksGraphInternal::FrameGroup const &group, GreatWksGraphInternal::Zone const &zone)
 {
   size_t numChilds=group.m_childList.size();
-  int numFrames=(int) zone.m_frameList.size();
+  int numFrames=static_cast<int>(zone.m_frameList.size());
   if (!numChilds) return true;
   int page=group.m_page;
   for (size_t c=0; c<numChilds; ++c) {
@@ -1928,7 +1980,9 @@ bool GreatWksGraph::canCreateGraphic(GreatWksGraphInternal::FrameGroup const &gr
     }
     case GreatWksGraphInternal::Frame::T_BAD:
     case GreatWksGraphInternal::Frame::T_UNSET:
+#if !defined(__clang__)
     default:
+#endif
       break;
     }
   }
@@ -1939,7 +1993,7 @@ void GreatWksGraph::sendGroup(GreatWksGraphInternal::FrameGroup const &group, Gr
 {
   if (!listener) return;
   size_t numChilds=group.m_childList.size();
-  int numFrames=(int) zone.m_frameList.size();
+  int numFrames=static_cast<int>(zone.m_frameList.size());
   if (!numChilds) return;
   for (size_t c=0; c<numChilds; ++c) {
     int childId=group.m_childList[c];
@@ -1947,7 +2001,7 @@ void GreatWksGraph::sendGroup(GreatWksGraphInternal::FrameGroup const &group, Gr
     shared_ptr<GreatWksGraphInternal::Frame> frame=zone.m_frameList[size_t(childId-1)];
     if (!frame) continue;
 
-    Box2f const &box=frame->m_box;
+    MWAWBox2f const &box=frame->m_box;
     MWAWGraphicStyle style;
     if (frame->m_styleId>=1 && frame->m_styleId <= int(zone.m_styleList.size()))
       style = zone.m_styleList[size_t(frame->m_styleId-1)];
@@ -1957,21 +2011,23 @@ void GreatWksGraph::sendGroup(GreatWksGraphInternal::FrameGroup const &group, Gr
       shape.updateStyle(style);
       MWAWPosition shapePos(box[0], box.size(), librevenge::RVNG_POINT);
       shapePos.m_anchorTo=MWAWPosition::Page;
-      listener->insertPicture(shapePos, shape.m_shape, style);
+      listener->insertShape(shapePos, shape.m_shape, style);
       break;
     }
     case GreatWksGraphInternal::Frame::T_GROUP:
       sendGroup(static_cast<GreatWksGraphInternal::FrameGroup const &>(*frame), zone,listener);
       break;
     case GreatWksGraphInternal::Frame::T_TEXT:
-      sendTextboxAsGraphic(Box2f(box[0],box[1]+Vec2f(3,0)),
+      sendTextboxAsGraphic(MWAWBox2f(box[0],box[1]+MWAWVec2f(3,0)),
                            static_cast<GreatWksGraphInternal::FrameText const &>(*frame), style, listener);
       break;
     case GreatWksGraphInternal::Frame::T_DBFIELD:
     case GreatWksGraphInternal::Frame::T_PICTURE:
     case GreatWksGraphInternal::Frame::T_BAD:
     case GreatWksGraphInternal::Frame::T_UNSET:
+#if !defined(__clang__)
     default:
+#endif
       break;
     }
   }
@@ -1989,8 +2045,8 @@ void GreatWksGraph::sendGroupChild(GreatWksGraphInternal::FrameGroup const &grou
 
   bool isDraw=listener->getType()==MWAWListener::Graphic;
   int numDataToMerge=0;
-  int numFrames=(int) zone.m_frameList.size();
-  Box2f partialBdBox;
+  int numFrames=static_cast<int>(zone.m_frameList.size());
+  MWAWBox2f partialBdBox;
   MWAWPosition partialPos(pos);
 
   for (size_t c=0; c<numChilds; ++c) {
@@ -2017,11 +2073,13 @@ void GreatWksGraph::sendGroupChild(GreatWksGraphInternal::FrameGroup const &grou
       case GreatWksGraphInternal::Frame::T_PICTURE:
       case GreatWksGraphInternal::Frame::T_BAD:
       case GreatWksGraphInternal::Frame::T_UNSET:
+#if !defined(__clang__)
       default:
+#endif
         break;
       }
     }
-    Box2f box=frame->m_box;
+    MWAWBox2f box=frame->m_box;
     bool isLast=false;
     if (canMerge) {
       if (numDataToMerge == 0)
@@ -2055,31 +2113,32 @@ void GreatWksGraph::sendGroupChild(GreatWksGraphInternal::FrameGroup const &grou
           shape.updateStyle(style);
           MWAWPosition shapePos(box[0], box.size(), librevenge::RVNG_POINT);
           shapePos.m_anchorTo=MWAWPosition::Page;
-          graphicListener->insertPicture(shapePos, shape.m_shape, style);
+          graphicListener->insertShape(shapePos, shape.m_shape, style);
           break;
         }
         case GreatWksGraphInternal::Frame::T_GROUP:
           sendGroup(static_cast<GreatWksGraphInternal::FrameGroup const &>(*child), zone,graphicListener);
           break;
         case GreatWksGraphInternal::Frame::T_TEXT:
-          sendTextboxAsGraphic(Box2f(box[0],box[1]+Vec2f(3,0)),
+          sendTextboxAsGraphic(MWAWBox2f(box[0],box[1]+MWAWVec2f(3,0)),
                                static_cast<GreatWksGraphInternal::FrameText const &>(*child), style, graphicListener);
           break;
         case GreatWksGraphInternal::Frame::T_DBFIELD:
         case GreatWksGraphInternal::Frame::T_PICTURE:
         case GreatWksGraphInternal::Frame::T_BAD:
         case GreatWksGraphInternal::Frame::T_UNSET:
+#if !defined(__clang__)
         default:
+#endif
           break;
         }
       }
       graphicListener->endDocument();
-      librevenge::RVNGBinaryData data;
-      std::string type;
-      if (graphicEncoder.getBinaryResult(data,type)) {
+      MWAWEmbeddedObject picture;
+      if (graphicEncoder.getBinaryResult(picture)) {
         partialPos.setOrigin(pos.origin()+partialBdBox[0]-group.m_box[0]);
         partialPos.setSize(partialBdBox.size());
-        listener->insertPicture(partialPos, data, type);
+        listener->insertPicture(partialPos, picture);
         if (isLast)
           break;
         childNotSent=c;
@@ -2118,9 +2177,9 @@ bool GreatWksGraph::sendShape(GreatWksGraphInternal::FrameShape const &graph, Gr
     style = zone.m_styleList[size_t(graph.m_styleId-1)];
   graph.updateStyle(style);
   MWAWPosition finalPos(pos);
-  finalPos.setOrigin(pos.origin()-Vec2f(2,2));
-  finalPos.setSize(pos.size()+Vec2f(4,4));
-  listener->insertPicture(finalPos,graph.m_shape, style);
+  finalPos.setOrigin(pos.origin()-MWAWVec2f(2,2));
+  finalPos.setSize(pos.size()+MWAWVec2f(4,4));
+  listener->insertShape(finalPos,graph.m_shape, style);
   return true;
 }
 
@@ -2134,9 +2193,9 @@ bool GreatWksGraph::sendFrame(shared_ptr<GreatWksGraphInternal::Frame> frame, Gr
   frame->m_parsed=true;
   MWAWInputStreamPtr &input= m_parserState->m_input;
   long pos=input->tell();
-  Vec2f LTPos(0,0);
+  MWAWVec2f LTPos(0,0);
   if (m_parserState->m_kind==MWAWDocument::MWAW_K_DRAW)
-    LTPos=72.0*Vec2f(float(m_mainParser->getPageSpan().getMarginLeft()), float(m_mainParser->getPageSpan().getMarginTop()));
+    LTPos=72.0f*MWAWVec2f(float(m_mainParser->getPageSpan().getMarginLeft()), float(m_mainParser->getPageSpan().getMarginTop()));
   MWAWPosition fPos(frame->m_box[0]+LTPos,frame->m_box.size(),librevenge::RVNG_POINT);
   fPos.setRelativePosition(MWAWPosition::Page);
   fPos.setPage(frame->m_page<0 ? 1: frame->m_page);
@@ -2159,7 +2218,9 @@ bool GreatWksGraph::sendFrame(shared_ptr<GreatWksGraphInternal::Frame> frame, Gr
   // do me
   case GreatWksGraphInternal::Frame::T_BAD:
   case GreatWksGraphInternal::Frame::T_UNSET:
+#if !defined(__clang__)
   default:
+#endif
     ok=false;
   }
   input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -2176,9 +2237,9 @@ bool GreatWksGraph::sendPageFrames(GreatWksGraphInternal::Zone const &zone)
   zone.m_parsed=true;
   for (size_t f=0; f < zone.m_rootList.size(); f++) {
     int id=zone.m_rootList[f]-1;
-    if (id<0 || !zone.m_frameList[(size_t) id])
+    if (id<0 || !zone.m_frameList[size_t(id)])
       continue;
-    shared_ptr<GreatWksGraphInternal::Frame> frame=zone.m_frameList[(size_t) id];
+    shared_ptr<GreatWksGraphInternal::Frame> frame=zone.m_frameList[size_t(id)];
     if (frame->m_parsed)
       continue;
     sendFrame(frame,zone);
