@@ -99,7 +99,9 @@ std::ostream &operator<<(std::ostream &o, PLC const &plc)
     o << "Rb";
     break;
   case P_Unknown:
+#if !defined(__clang__)
   default:
+#endif
     o << "#Unkn";
     break;
   }
@@ -161,6 +163,8 @@ struct Paragraph : public MWAWParagraph {
   Paragraph() : MWAWParagraph(), m_deltaSpacing(0)
   {
   }
+  //! destructor
+  ~Paragraph();
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, Paragraph const &ind)
   {
@@ -172,6 +176,10 @@ struct Paragraph : public MWAWParagraph {
   float m_deltaSpacing;
 };
 
+Paragraph::~Paragraph()
+{
+}
+
 ////////////////////////////////////////
 //! Internal: the header/footer zone of a LightWayTxtText
 struct HFZone {
@@ -216,8 +224,10 @@ std::ostream &operator<<(std::ostream &o, HFZone const &hf)
   case MWAWParagraph::JustificationFullAllLines:
     o << "just=fullAllLines, ";
     break;
+#if !defined(__clang__)
   default:
     o << "#just=" << hf.m_justify << ", ";
+#endif
   }
   o << hf.m_extra;
   return o;
@@ -413,7 +423,7 @@ bool LightWayTxtText::sendMainText()
   while (1) {
     long actPos = input->tell();
     bool done =  input->isEnd() || (endPos>=0&&actPos>=endPos);
-    char c = done ? (char) 0 : (char) input->readULong(1);
+    char c = done ? char(0) : char(input->readULong(1));
     if (c==0xd || done) {
       f2.str("");
       f2 << "Entries(TextContent):" << f.str();
@@ -467,7 +477,9 @@ bool LightWayTxtText::sendMainText()
       case LightWayTxtTextInternal::P_StyleU:
       case LightWayTxtTextInternal::P_StyleV:
       case LightWayTxtTextInternal::P_Unknown:
+#if !defined(__clang__)
       default:
+#endif
         break;
       }
     }
@@ -480,7 +492,7 @@ bool LightWayTxtText::sendMainText()
       listener->setFont(final.m_font);
       if (final.m_pictId>0) {
         m_mainParser->sendGraphic(final.m_pictId);
-        if (c==(char)0xca)
+        if (c==char(0xca))
           continue;
       }
     }
@@ -498,7 +510,7 @@ bool LightWayTxtText::sendMainText()
       break;
 
     default:
-      listener->insertCharacter((unsigned char)c, input);
+      listener->insertCharacter(static_cast<unsigned char>(c), input);
       break;
     }
   }
@@ -523,7 +535,7 @@ bool LightWayTxtText::readFonts(MWAWEntry const &entry)
   libmwaw::DebugStream f;
   f << "Entries(Fonts)[" << entry.id() << "]:";
   entry.setParsed(true);
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   if (long(N*20+2) != entry.length()) {
     MWAW_DEBUG_MSG(("LightWayTxtText::readFonts: the number of entry seems bad\n"));
@@ -542,11 +554,11 @@ bool LightWayTxtText::readFonts(MWAWEntry const &entry)
     LightWayTxtTextInternal::Font font;
     f.str("");
     long cPos = input->readLong(4);
-    font.m_height = (int) input->readLong(2);
-    float sz = (float) input->readLong(2);
-    font.m_font.setId((int) input->readULong(2));
+    font.m_height = static_cast<int>(input->readLong(2));
+    float sz = float(input->readLong(2));
+    font.m_font.setId(static_cast<int>(input->readULong(2)));
     uint32_t flags=0;
-    int flag=(int) input->readULong(1);
+    int flag=static_cast<int>(input->readULong(1));
     if (flag&0x1) flags |= MWAWFont::boldBit;
     if (flag&0x2) flags |= MWAWFont::italicBit;
     if (flag&0x4) font.m_font.setUnderlineStyle(MWAWFont::Line::Simple);
@@ -555,15 +567,15 @@ bool LightWayTxtText::readFonts(MWAWEntry const &entry)
     if (flag&0x20) font.m_font.setDeltaLetterSpacing(-1);
     if (flag&0x40) font.m_font.setDeltaLetterSpacing(1);
     if (flag&0x80) f << "#fl80,";
-    int val = (int) input->readULong(1); // always 0?
+    int val = static_cast<int>(input->readULong(1)); // always 0?
     if (val) f << "#f0=" << val << ",";
     font.m_font.setFlags(flags);
-    font.m_font.setSize((float) input->readLong(2));
+    font.m_font.setSize(float(input->readLong(2)));
     if (sz < font.m_font.size() || sz > font.m_font.size())
       f << "#sz=" << sz << ",";
     unsigned char col[3];
     for (int j=0; j < 3; j++)
-      col[j] = (unsigned char)(input->readULong(2)>>8);
+      col[j] = static_cast<unsigned char>(input->readULong(2)>>8);
     if (col[0] || col[1] || col[2])
       font.m_font.setColor(MWAWColor(col[0],col[1],col[2]));
     font.m_font.m_extra=f.str();
@@ -598,7 +610,7 @@ bool LightWayTxtText::readFont2(MWAWEntry const &entry)
   libmwaw::DebugStream f;
   f << "Entries(Font2)[" << entry.id() << "]:";
   entry.setParsed(true);
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   if (entry.length() != N*10+2) {
     f << "###";
@@ -619,7 +631,7 @@ bool LightWayTxtText::readFont2(MWAWEntry const &entry)
     LightWayTxtTextInternal::Font font;
 
     long cPos = input->readLong(4);
-    uint32_t flag = (uint32_t) input->readULong(2), flags=0;
+    uint32_t flag = static_cast<uint32_t>(input->readULong(2)), flags=0;
     switch ((flag>>3)&7) {
     case 0:
       break;
@@ -696,7 +708,7 @@ bool LightWayTxtText::readFont2(MWAWEntry const &entry)
       break;
     }
     if (flag >> 12) {
-      MWAWColor col=0;
+      MWAWColor col(0);
       if (getColor(int(flag >> 12), col)) {
         font.m_font.setOverlineColor(col);
         font.m_font.setStrikeOutColor(col);
@@ -708,7 +720,7 @@ bool LightWayTxtText::readFont2(MWAWEntry const &entry)
     flag &= 0x0004;
     if (flag) f << "flags=#" << std::hex << flag << std::dec << ",";
     /* fl0=0|2|b|40|42|..|a0 */
-    long val = (long) input->readULong(1);
+    long val = long(input->readULong(1));
     MWAWColor backColor(MWAWColor::black());
     if ((val & 0xf0) && !getColor(int(val>>4), backColor))
       f << "#backColorId=" << (val>>4) << ",";
@@ -726,7 +738,7 @@ bool LightWayTxtText::readFont2(MWAWEntry const &entry)
     // 0: 0%, .. 10:100%, 11:border
     if (val & 0xf)
       f << "backPatternId=" << (val&0xf) << ",";
-    flag = (uint32_t) input->readULong(1);
+    flag = static_cast<uint32_t>(input->readULong(1));
     switch (flag&7) {
     case 0:
       break;
@@ -748,7 +760,7 @@ bool LightWayTxtText::readFont2(MWAWEntry const &entry)
     if (flag&8) f << "write[hor],";
     if (flag & 0xF0)
       f << "#pos2=" << std::hex << (flag&0xF0) << std::dec << ",";
-    font.m_pictId = (int) input->readULong(2);
+    font.m_pictId = static_cast<int>(input->readULong(2));
     font.m_font.setFlags(flags);
     font.m_font.m_extra = f.str();
     plc.m_id = i;
@@ -790,7 +802,7 @@ bool LightWayTxtText::readRulers(MWAWEntry const &entry)
   libmwaw::DebugStream f;
   f << "Entries(Ruler)[" << entry.id() << "]:";
   entry.setParsed(true);
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   if (entry.length() != N*84+2) {
     f << "###";
@@ -812,16 +824,16 @@ bool LightWayTxtText::readRulers(MWAWEntry const &entry)
     f.str("");
     long cPos = input->readLong(4);
     para.m_marginsUnit = librevenge::RVNG_POINT;
-    para.m_margins[0] = (int) input->readLong(2);
-    para.m_margins[1] = (int) input->readLong(2);
-    para.m_margins[2] = (int) input->readLong(2);
+    para.m_margins[0] = static_cast<int>(input->readLong(2));
+    para.m_margins[1] = static_cast<int>(input->readLong(2));
+    para.m_margins[2] = static_cast<int>(input->readLong(2));
     para.m_margins[0] = para.m_margins[0].get()-para.m_margins[1].get();
 
-    long val = (int) input->readLong(2);
+    long val = static_cast<int>(input->readLong(2));
     if (val)
-      para.m_spacings[1]=para.m_spacings[2]=float(val)/72.f;
-    para.m_deltaSpacing = (float) input->readLong(2);
-    long flag = (long) input->readULong(1);
+      para.m_spacings[1]=para.m_spacings[2]=double(val)/72.;
+    para.m_deltaSpacing = float(input->readLong(2));
+    long flag = long(input->readULong(1));
     switch (flag) {
     case 0:
       break; // left
@@ -837,16 +849,16 @@ bool LightWayTxtText::readRulers(MWAWEntry const &entry)
     default:
       f << "#justify=" << flag << ",";
     }
-    int numTabs = (int) input->readULong(1);
+    int numTabs = static_cast<int>(input->readULong(1));
     if (numTabs > 16) {
       MWAW_DEBUG_MSG(("LightWayTxtText::readRulers: the numbers of tabs seems bad\n"));
       f << "###nTabs=" << numTabs << ",";
       numTabs=0;
     }
-    uint32_t tabsType = (uint32_t) input->readULong(4);
+    uint32_t tabsType = static_cast<uint32_t>(input->readULong(4));
     for (int j = 0; j < numTabs; j++) {
       MWAWTabStop tab;
-      tab.m_position = float(input->readLong(2))/72.f;
+      tab.m_position = double(input->readLong(2))/72.;
       switch (tabsType&3) {
       case 1:
         tab.m_alignment = MWAWTabStop::CENTER;
@@ -865,7 +877,7 @@ bool LightWayTxtText::readRulers(MWAWEntry const &entry)
       para.m_tabs->push_back(tab);
     }
     input->seek(pos+52, librevenge::RVNG_SEEK_SET);
-    uint32_t tabsLeader = (uint32_t) input->readULong(4);
+    uint32_t tabsLeader = static_cast<uint32_t>(input->readULong(4));
     for (int j = 0; j < numTabs; j++) {
       uint16_t leader=0;
       switch (tabsLeader&3) {
@@ -887,16 +899,16 @@ bool LightWayTxtText::readRulers(MWAWEntry const &entry)
       (*para.m_tabs)[size_t(j)].m_leaderCharacter = leader;
     }
     for (int j = 0; j < 3; j++) { // g0=0|0b13
-      val = (int) input->readLong(2);
+      val = static_cast<int>(input->readLong(2));
       if (val)
         f << "g" << j << "=" << std::hex << val << std::dec << ",";
     }
     for (int j = 0; j < 2; j++) { // g5=5|14
-      val = (long) input->readULong(1);
+      val = long(input->readULong(1));
       if (val) f << "g" << j+3 << "=" << val << ",";
     }
     for (int j = 0; j < 10; j++) { // always 0
-      val = (int) input->readLong(2);
+      val = static_cast<int>(input->readLong(2));
       if (val)
         f << "h" << j << "=" << std::hex << val << std::dec << ",";
     }
@@ -937,14 +949,14 @@ bool LightWayTxtText::sendHeaderFooter(bool header)
   MWAWInputStreamPtr input = m_mainParser->rsrcInput();
   input->seek(zone.m_pos.begin(), librevenge::RVNG_SEEK_SET);
 
-  int numChar = (int) zone.m_pos.length();
+  int numChar = static_cast<int>(zone.m_pos.length());
   std::string str("");
   for (int c = 0; c < numChar; c++) {
     if (input->isEnd()) {
       MWAW_DEBUG_MSG(("LightWayTxtText::sendHeaderFooter: can not read end of text\n"));
       break;
     }
-    str += (char) input->readULong(1);
+    str += char(input->readULong(1));
   }
   std::string::const_iterator it = str.begin();
   while (it!=str.end()) {
@@ -973,7 +985,7 @@ bool LightWayTxtText::sendHeaderFooter(bool header)
       listener->insertEOL();
       continue;
     }
-    listener->insertCharacter((unsigned char) c);
+    listener->insertCharacter(static_cast<unsigned char>(c));
   }
   return true;
 }
@@ -996,10 +1008,10 @@ bool LightWayTxtText::readDocumentHF(MWAWEntry const &entry)
 
   for (int s=0; s < 2; s++) {
     LightWayTxtTextInternal::HFZone zone;
-    zone.m_height = (int) input->readLong(2);
-    zone.m_numChar = (int) input->readLong(2);
+    zone.m_height = static_cast<int>(input->readLong(2));
+    zone.m_numChar = static_cast<int>(input->readLong(2));
     // ruler align
-    int flag = (int) input->readULong(1); // [012]
+    int flag = static_cast<int>(input->readULong(1)); // [012]
     f2.str("");
     switch (flag) {
     case 0:
@@ -1017,7 +1029,7 @@ bool LightWayTxtText::readDocumentHF(MWAWEntry const &entry)
       f2 << "#justify=" << flag << ",";
     }
     uint32_t flags=0;
-    flag=(int) input->readULong(1);
+    flag=static_cast<int>(input->readULong(1));
     if (flag&0x1) flags |= MWAWFont::boldBit;
     if (flag&0x2) flags |= MWAWFont::italicBit;
     if (flag&0x4) zone.m_font.setUnderlineStyle(MWAWFont::Line::Simple);
@@ -1027,11 +1039,11 @@ bool LightWayTxtText::readDocumentHF(MWAWEntry const &entry)
     if (flag&0x40) zone.m_font.setDeltaLetterSpacing(1);
     if (flag&0x80) f2 << "#fl80,";
     zone.m_font.setFlags(flags);
-    zone.m_font.setId((int) input->readULong(2));
-    zone.m_font.setSize((float) input->readULong(2));
+    zone.m_font.setId(static_cast<int>(input->readULong(2)));
+    zone.m_font.setSize(float(input->readULong(2)));
     unsigned char col[3];
     for (int j=0; j < 3; j++)
-      col[j] = (unsigned char)(input->readULong(2)>>8);
+      col[j] = static_cast<unsigned char>(input->readULong(2)>>8);
     if (col[0] || col[1] || col[2])
       zone.m_font.setColor(MWAWColor(col[0],col[1],col[2]));
     long val = input->readLong(2); // can be 0x200
@@ -1072,7 +1084,7 @@ bool LightWayTxtText::readDocumentHF(MWAWEntry const &entry)
   }
   std::string name(""); // something like <NAME>(<PAGE>)
   for (int i = 0; i < numRemains; i++)
-    name += (char) input->readULong(1);
+    name += char(input->readULong(1));
   f << name << ",";
   ascFile.addPos(pos);
   ascFile.addNote(f.str().c_str());
@@ -1097,7 +1109,7 @@ bool LightWayTxtText::readStyleU(MWAWEntry const &entry)
   libmwaw::DebugStream f;
   f << "Entries(StyleU)[" << entry.id() << "]:";
   entry.setParsed(true);
-  int N=(int) input->readULong(4);
+  int N=static_cast<int>(input->readULong(4));
   f << "N=" << N << ",";
   if (entry.length() != N*8+4) {
     f << "###";
@@ -1116,7 +1128,7 @@ bool LightWayTxtText::readStyleU(MWAWEntry const &entry)
     pos = input->tell();
     f.str("");
     long cPos = input->readLong(4);
-    long flag = (long) input->readULong(2); // 2022
+    long flag = long(input->readULong(2)); // 2022
     if (flag)
       f << "flag=" << std::hex << flag << std::dec << ",";
     long val = input->readLong(2); // always 0
@@ -1149,7 +1161,7 @@ bool LightWayTxtText::readRuby(MWAWEntry const &entry)
   libmwaw::DebugStream f;
   f << "Entries(Ruby)[" << entry.id() << "]:";
   entry.setParsed(true);
-  int N=(int) input->readULong(4);
+  int N=static_cast<int>(input->readULong(4));
   f << "N=" << N << ",";
   if (entry.length() != N*6+4) {
     f << "###";
@@ -1168,8 +1180,8 @@ bool LightWayTxtText::readRuby(MWAWEntry const &entry)
     pos = input->tell();
     f.str("");
     long cPos = input->readLong(4);
-    f << "n[text]=" << (int) input->readULong(1) << ",";
-    f << "n[ruby]=" << (int) input->readULong(1) << ",";
+    f << "n[text]=" << static_cast<int>(input->readULong(1)) << ",";
+    f << "n[ruby]=" << static_cast<int>(input->readULong(1)) << ",";
     plc.m_id = i;
     plc.m_extra = f.str();
     m_state->m_plcMap.insert(std::map<long, LightWayTxtTextInternal::PLC>::value_type(cPos, plc));
@@ -1198,9 +1210,9 @@ bool LightWayTxtText::readUnknownStyle(MWAWEntry const &entry)
   f << "Entries(" << entry.type() << ")[" << entry.id() << "]:";
   entry.setParsed(true);
   int numSz=2;
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   if (!N) {
-    N=(int) input->readULong(2);
+    N=static_cast<int>(input->readULong(2));
     numSz+=2;
   }
   f << "N=" << N << ",";
