@@ -64,9 +64,11 @@ namespace MWAWGraphicListenerInternal
 /** the global graphic state of MWAWGraphicListener */
 struct GraphicState {
   //! constructor
-  GraphicState(std::vector<MWAWPageSpan> const &pageList) :
-    m_pageList(pageList), m_metaData(), m_isDocumentStarted(false), m_isAtLeastOnePageOpened(false),
-    m_isHeaderFooterStarted(false), m_sentListMarkers(), m_subDocuments()
+  explicit GraphicState(std::vector<MWAWPageSpan> const &pageList) :
+    m_pageList(pageList), m_metaData(),
+    m_isDocumentStarted(false), m_isPageSpanOpened(false), m_isMasterPageSpanOpened(false), m_isAtLeastOnePageOpened(false),
+    m_isHeaderFooterStarted(false), m_pageSpan(), m_sentListMarkers(), m_subDocuments(),
+    m_section()
   {
   }
   //! destructor
@@ -79,14 +81,22 @@ struct GraphicState {
   librevenge::RVNGPropertyList m_metaData;
   /** a flag to know if the document is open */
   bool m_isDocumentStarted;
+  //! true if a page is open
+  bool m_isPageSpanOpened;
+  //! true if a masterpage is open
+  bool m_isMasterPageSpanOpened;
   /** true if the first page has been open */
   bool m_isAtLeastOnePageOpened;
   /** a flag to know if the header footer is started */
   bool m_isHeaderFooterStarted;
+  ///! the current page span
+  MWAWPageSpan m_pageSpan;
   /// the list of marker corresponding to sent list
   std::vector<int> m_sentListMarkers;
   //! the list of actual subdocument
   std::vector<MWAWSubDocumentPtr> m_subDocuments;
+  //! a section used to return a bad section
+  MWAWSection m_section;
 };
 
 /** the state of a MWAWGraphicListener */
@@ -102,7 +112,7 @@ struct State {
     return m_inNote || m_isTextBoxOpened || m_isTableCellOpened;
   }
   //! the origin position
-  Vec2f m_origin;
+  MWAWVec2f m_origin;
   //! a buffer to stored the text
   librevenge::RVNGString m_textBuffer;
 
@@ -110,12 +120,9 @@ struct State {
   MWAWFont m_font;
   //! the paragraph
   MWAWParagraph m_paragraph;
-  //! true if a page is open
-  bool m_isPageSpanOpened;
   //! the list of list
   shared_ptr<MWAWList> m_list;
 
-  bool m_isTextBoxOpened;
   //! a flag to know if openFrame was called
   bool m_isFrameOpened;
   //! the frame position
@@ -123,6 +130,12 @@ struct State {
   //! the frame style
   MWAWGraphicStyle m_frameStyle;
 
+  //! a flag to know if we are in a textbox
+  bool m_isTextBoxOpened;
+  //! a flag to know if openGroup was called
+  bool m_isGroupOpened;
+  //! a flag to know if openLayer was called
+  bool m_isLayerOpened;
   bool m_isSpanOpened;
   bool m_isParagraphOpened;
   bool m_isListElementOpened;
@@ -136,7 +149,6 @@ struct State {
   bool m_isTableColumnOpened;
   bool m_isTableCellOpened;
 
-  MWAWPageSpan m_pageSpan;
   unsigned m_currentPage;
   int m_numPagesRemainingInSpan;
   int m_currentPageNumber;
@@ -152,13 +164,14 @@ private:
 };
 
 State::State() : m_origin(0,0),
-  m_textBuffer(""), m_font(20,12)/* default time 12 */, m_paragraph(), m_isPageSpanOpened(false), m_list(),
-  m_isTextBoxOpened(false), m_isFrameOpened(false), m_framePosition(), m_frameStyle(),
+  m_textBuffer(""), m_font(20,12)/* default time 12 */, m_paragraph(), m_list(),
+  m_isFrameOpened(false), m_framePosition(), m_frameStyle(), m_isTextBoxOpened(false),
+  m_isGroupOpened(false), m_isLayerOpened(false),
   m_isSpanOpened(false), m_isParagraphOpened(false), m_isListElementOpened(false),
   m_firstParagraphInPageSpan(true), m_listOrderedLevels(),
   m_isTableOpened(false), m_isTableRowOpened(false), m_isTableColumnOpened(false),
   m_isTableCellOpened(false),
-  m_pageSpan(), m_currentPage(0), m_numPagesRemainingInSpan(0), m_currentPageNumber(1),
+  m_currentPage(0), m_numPagesRemainingInSpan(0), m_currentPageNumber(1),
   m_inLink(false), m_inNote(false), m_inSubDocument(false), m_subDocumentType(libmwaw::DOC_NONE)
 {
 }
@@ -170,14 +183,14 @@ MWAWGraphicListener::MWAWGraphicListener(MWAWParserState &parserState, std::vect
 {
 }
 
-MWAWGraphicListener::MWAWGraphicListener(MWAWParserState &parserState, Box2f const &box, librevenge::RVNGDrawingInterface *documentInterface) : MWAWListener(),
+MWAWGraphicListener::MWAWGraphicListener(MWAWParserState &parserState, MWAWBox2f const &box, librevenge::RVNGDrawingInterface *documentInterface) : MWAWListener(),
   m_ds(), m_ps(new MWAWGraphicListenerInternal::State), m_psStack(), m_parserState(parserState), m_documentInterface(documentInterface)
 {
   MWAWPageSpan pageSpan;
   pageSpan.setMargins(0);
   pageSpan.setPageSpan(1);
-  pageSpan.setFormWidth(box.size().x()/72.);
-  pageSpan.setFormLength(box.size().y()/72.);
+  pageSpan.setFormWidth(double(box.size().x())/72.);
+  pageSpan.setFormLength(double(box.size().y())/72.);
   m_ds.reset(new MWAWGraphicListenerInternal::GraphicState(std::vector<MWAWPageSpan>(1, pageSpan)));
   m_ps->m_origin=box[0];
 }
@@ -200,7 +213,7 @@ void MWAWGraphicListener::insertChar(uint8_t character)
     return;
   }
   if (!m_ps->m_isSpanOpened) _openSpan();
-  m_ps->m_textBuffer.append((char) character);
+  m_ps->m_textBuffer.append(char(character));
 }
 
 void MWAWGraphicListener::insertCharacter(unsigned char c)
@@ -212,13 +225,13 @@ void MWAWGraphicListener::insertCharacter(unsigned char c)
   int unicode = m_parserState.m_fontConverter->unicode(m_ps->m_font.id(), c);
   if (unicode == -1) {
     if (c < 0x20) {
-      MWAW_DEBUG_MSG(("MWAWGraphicListener::insertCharacter: Find odd char %x\n", int(c)));
+      MWAW_DEBUG_MSG(("MWAWGraphicListener::insertCharacter: Find odd char %x\n", static_cast<unsigned int>(c)));
     }
     else
-      MWAWGraphicListener::insertChar((uint8_t) c);
+      MWAWGraphicListener::insertChar(static_cast<uint8_t>(c));
   }
   else
-    MWAWGraphicListener::insertUnicode((uint32_t) unicode);
+    MWAWGraphicListener::insertUnicode(static_cast<uint32_t>(unicode));
 }
 
 int MWAWGraphicListener::insertCharacter(unsigned char c, MWAWInputStreamPtr &input, long endPos)
@@ -246,13 +259,13 @@ int MWAWGraphicListener::insertCharacter(unsigned char c, MWAWInputStreamPtr &in
   }
   if (unicode == -1) {
     if (c < 0x20) {
-      MWAW_DEBUG_MSG(("MWAWGraphicListener::insertCharacter: Find odd char %x\n", int(c)));
+      MWAW_DEBUG_MSG(("MWAWGraphicListener::insertCharacter: Find odd char %x\n", static_cast<unsigned int>(c)));
     }
     else
-      MWAWGraphicListener::insertChar((uint8_t) c);
+      MWAWGraphicListener::insertChar(static_cast<uint8_t>(c));
   }
   else
-    MWAWGraphicListener::insertUnicode((uint32_t) unicode);
+    MWAWGraphicListener::insertUnicode(static_cast<uint32_t>(unicode));
 
   return int(pos-debPos);
 }
@@ -368,54 +381,18 @@ void MWAWGraphicListener::insertField(MWAWField const &field)
     MWAW_DEBUG_MSG(("MWAWGraphicListener::setParagraph: called outside a text zone\n"));
     return;
   }
-  switch (field.m_type) {
-  case MWAWField::None:
-    break;
-  case MWAWField::PageCount:
-  case MWAWField::PageNumber:
-  case MWAWField::Title: {
+  librevenge::RVNGPropertyList propList;
+  if (field.addTo(propList)) {
     _flushText();
     _openSpan();
-    librevenge::RVNGPropertyList propList;
-    if (field.m_type==MWAWField::Title)
-      propList.insert("librevenge:field-type", "text:title");
-    else {
-      propList.insert("style:num-format", libmwaw::numberingTypeToString(field.m_numberingType).c_str());
-      if (field.m_type == MWAWField::PageNumber)
-        propList.insert("librevenge:field-type", "text:page-number");
-      else
-        propList.insert("librevenge:field-type", "text:page-count");
-    }
     m_documentInterface->insertField(propList);
-    break;
+    return;
   }
-  case MWAWField::Database:
-    if (field.m_data.length())
-      MWAWGraphicListener::insertUnicodeString(field.m_data.c_str());
-    else
-      MWAWGraphicListener::insertUnicodeString("#DATAFIELD#");
-    break;
-  case MWAWField::Date:
-  case MWAWField::Time: {
-    std::string format(field.m_DTFormat);
-    if (format.length()==0) {
-      if (field.m_type==MWAWField::Date)
-        format="%m/%d/%y";
-      else
-        format="%I:%M:%S %p";
-    }
-    time_t now = time(0L);
-    struct tm timeinfo;
-    if (localtime_r(&now, &timeinfo)) {
-      char buf[256];
-      strftime(buf, 256, format.c_str(), &timeinfo);
-      MWAWGraphicListener::insertUnicodeString(librevenge::RVNGString(buf));
-    }
-    break;
-  }
-  default:
+  librevenge::RVNGString text=field.getString();
+  if (!text.empty())
+    MWAWGraphicListener::insertUnicodeString(text);
+  else {
     MWAW_DEBUG_MSG(("MWAWGraphicListener::insertField: must not be called with type=%d\n", int(field.m_type)));
-    break;
   }
 }
 
@@ -473,8 +450,8 @@ void MWAWGraphicListener::endDocument(bool /*delayed*/)
     MWAW_DEBUG_MSG(("MWAWGraphicListener::endDocument: no data have been send\n"));
     _openPageSpan();
   }
-  if (m_ps->m_isPageSpanOpened)
-    _closePageSpan();
+  if (m_ds->m_isPageSpanOpened)
+    _closePageSpan(m_ds->m_isMasterPageSpanOpened);
   m_documentInterface->endDocument();
   m_ds->m_isDocumentStarted=false;
   *m_ds=MWAWGraphicListenerInternal::GraphicState(std::vector<MWAWPageSpan>());
@@ -483,7 +460,14 @@ void MWAWGraphicListener::endDocument(bool /*delayed*/)
 ///////////////////
 // document
 ///////////////////
-void MWAWGraphicListener::setDocumentLanguage(std::string locale)
+void MWAWGraphicListener::setDocumentMetaData(librevenge::RVNGPropertyList const &meta)
+{
+  librevenge::RVNGPropertyList::Iter i(meta);
+  for (i.rewind(); i.next();)
+    m_ds->m_metaData.insert(i.key(), i()->getStr());
+}
+
+void MWAWGraphicListener::setDocumentLanguage(std::string const &locale)
 {
   if (!locale.length()) return;
   m_ds->m_metaData.insert("librevenge:language", locale.c_str());
@@ -496,7 +480,7 @@ bool MWAWGraphicListener::isDocumentStarted() const
 
 bool MWAWGraphicListener::canWriteText() const
 {
-  return m_ps->m_isPageSpanOpened && m_ps->isInTextZone();
+  return m_ds->m_isPageSpanOpened && m_ps->isInTextZone();
 }
 
 ///////////////////
@@ -504,19 +488,42 @@ bool MWAWGraphicListener::canWriteText() const
 ///////////////////
 bool MWAWGraphicListener::isPageSpanOpened() const
 {
-  return m_ps->m_isPageSpanOpened;
+  return m_ds->m_isPageSpanOpened;
 }
 
 MWAWPageSpan const &MWAWGraphicListener::getPageSpan()
 {
-  if (!m_ps->m_isPageSpanOpened)
+  if (!m_ds->m_isPageSpanOpened)
     _openPageSpan();
-  return m_ps->m_pageSpan;
+  return m_ds->m_pageSpan;
+}
+
+bool MWAWGraphicListener::openMasterPage(MWAWPageSpan &masterPage)
+{
+  if (m_ds->m_isMasterPageSpanOpened) {
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::openMasterPage: a master page is already opened\n"));
+    return false;
+  }
+  if (!m_ds->m_isDocumentStarted)
+    startDocument();
+  if (m_ds->m_isPageSpanOpened)
+    _closePageSpan();
+
+  librevenge::RVNGPropertyList propList;
+  masterPage.getPageProperty(propList);
+  propList.insert("svg:width",72.*masterPage.getFormWidth(), librevenge::RVNG_POINT);
+  propList.insert("svg:height",72.*masterPage.getFormLength(), librevenge::RVNG_POINT);
+
+  m_documentInterface->startMasterPage(propList);
+  m_ds->m_isPageSpanOpened = m_ds->m_isMasterPageSpanOpened = true;
+
+  // checkme: can we send some header/footer if some exists
+  return true;
 }
 
 void MWAWGraphicListener::_openPageSpan(bool sendHeaderFooters)
 {
-  if (m_ps->m_isPageSpanOpened)
+  if (m_ds->m_isPageSpanOpened)
     return;
 
   if (!m_ds->m_isDocumentStarted)
@@ -531,7 +538,7 @@ void MWAWGraphicListener::_openPageSpan(bool sendHeaderFooters)
   std::vector<MWAWPageSpan>::iterator it = m_ds->m_pageList.begin();
   m_ps->m_currentPage++;
   while (true) {
-    actPage+=(unsigned)it->getPageSpan();
+    actPage+=static_cast<unsigned>(it->getPageSpan());
     if (actPage >= m_ps->m_currentPage) break;
     if (++it == m_ds->m_pageList.end()) {
       MWAW_DEBUG_MSG(("MWAWGraphicListener::_openPageSpan: can not find current page, use the previous one\n"));
@@ -545,16 +552,16 @@ void MWAWGraphicListener::_openPageSpan(bool sendHeaderFooters)
   currentPage.getPageProperty(propList);
   propList.insert("librevenge:is-last-page-span", ++it == m_ds->m_pageList.end());
   // now add data for embedded graph
-  propList.insert("svg:x",m_ps->m_origin.x(), librevenge::RVNG_POINT);
-  propList.insert("svg:y",m_ps->m_origin.y(), librevenge::RVNG_POINT);
+  propList.insert("svg:x",double(m_ps->m_origin.x()), librevenge::RVNG_POINT);
+  propList.insert("svg:y",double(m_ps->m_origin.y()), librevenge::RVNG_POINT);
   propList.insert("svg:width",72.*currentPage.getFormWidth(), librevenge::RVNG_POINT);
   propList.insert("svg:height",72.*currentPage.getFormLength(), librevenge::RVNG_POINT);
   propList.insert("librevenge:enforce-frame",true);
 
-  if (!m_ps->m_isPageSpanOpened)
+  if (!m_ds->m_isPageSpanOpened)
     m_documentInterface->startPage(propList);
-  m_ps->m_isPageSpanOpened = true;
-  m_ps->m_pageSpan = currentPage;
+  m_ds->m_isPageSpanOpened = true;
+  m_ds->m_pageSpan = currentPage;
 
   // we insert the header footer
   if (sendHeaderFooters)
@@ -565,12 +572,19 @@ void MWAWGraphicListener::_openPageSpan(bool sendHeaderFooters)
   m_ps->m_numPagesRemainingInSpan = (currentPage.getPageSpan() - 1);
 }
 
-void MWAWGraphicListener::_closePageSpan()
+void MWAWGraphicListener::_closePageSpan(bool masterPage)
 {
-  if (!m_ps->m_isPageSpanOpened)
+  if (!m_ds->m_isPageSpanOpened)
     return;
 
-  m_ps->m_isPageSpanOpened = false;
+  if (masterPage && !m_ds->m_isMasterPageSpanOpened) {
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::endDocument:no master page are opened\n"));
+    return;
+  }
+  if (!masterPage && m_ds->m_isMasterPageSpanOpened) {
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::endDocument:a master page are opened\n"));
+    return;
+  }
   if (m_ps->m_inSubDocument) {
     MWAW_DEBUG_MSG(("MWAWGraphicListener::endDocument: we are in a sub document\n"));
     _endSubDocument();
@@ -587,7 +601,11 @@ void MWAWGraphicListener::_closePageSpan()
     m_ps->m_paragraph.m_listLevelIndex = 0;
     _changeList(); // flush the list exterior
   }
-  m_documentInterface->endPage();
+  m_ds->m_isPageSpanOpened = m_ds->m_isMasterPageSpanOpened = false;
+  if (masterPage)
+    m_documentInterface->endMasterPage();
+  else
+    m_documentInterface->endPage();
 }
 
 ///////////////////
@@ -686,7 +704,7 @@ void MWAWGraphicListener::_closeListElement()
 
 int MWAWGraphicListener::_getListId() const
 {
-  size_t newLevel= (size_t) m_ps->m_paragraph.m_listLevelIndex.get();
+  size_t newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get());
   if (newLevel == 0) return -1;
   int newListId = m_ps->m_paragraph.m_listId.get();
   if (newListId > 0) return newListId;
@@ -711,7 +729,11 @@ void MWAWGraphicListener::_changeList()
     _closeParagraph();
 
   size_t actualLevel = m_ps->m_listOrderedLevels.size();
-  size_t newLevel= (size_t) m_ps->m_paragraph.m_listLevelIndex.get();
+  size_t newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get());
+  if (newLevel>100) {
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::_changeList: find level=%d, set it to 100\n", static_cast<int>(newLevel)));
+    newLevel=100;
+  }
   int newListId = newLevel>0 ? _getListId() : -1;
   bool changeList = newLevel &&
                     (m_ps->m_list && m_ps->m_list->getId()!=newListId);
@@ -734,7 +756,7 @@ void MWAWGraphicListener::_changeList()
     }
     m_parserState.m_listManager->needToSend(newListId, m_ds->m_sentListMarkers);
     m_ps->m_list = theList;
-    m_ps->m_list->setLevel((int)newLevel);
+    m_ps->m_list->setLevel(static_cast<int>(newLevel));
   }
 
   m_ps->m_listOrderedLevels.resize(newLevel, false);
@@ -747,7 +769,7 @@ void MWAWGraphicListener::_changeList()
     m_ps->m_listOrderedLevels[i-1] = ordered;
 
     librevenge::RVNGPropertyList level;
-    m_ps->m_list->addTo(int(i), level);
+    m_ps->m_list->addTo(int(i), level, m_parserState.m_fontManager);
     if (ordered)
       m_documentInterface->openOrderedListLevel(level);
     else
@@ -847,7 +869,7 @@ bool MWAWGraphicListener::insertHeader(MWAWSubDocumentPtr subDocument, libreveng
     return false;
   }
   // we do not have any header interface, so mimick it by creating a textbox
-  MWAWPosition pos(Vec2f(20,20), Vec2f(-20,-10), librevenge::RVNG_POINT); // fixme
+  MWAWPosition pos(MWAWVec2f(20,20), MWAWVec2f(-20,-10), librevenge::RVNG_POINT); // fixme
   pos.m_anchorTo=MWAWPosition::Page;
   if (!openFrame(pos))
     return false;
@@ -871,7 +893,7 @@ bool MWAWGraphicListener::insertFooter(MWAWSubDocumentPtr subDocument, libreveng
 
   // we do not have any header interface, so mimick it by creating a textbox
   MWAWPageSpan page(getPageSpan()); // fixme
-  MWAWPosition pos(Vec2f(20,72.f*float(page.getFormLength())-40.f), Vec2f(-20,-10), librevenge::RVNG_POINT);
+  MWAWPosition pos(MWAWVec2f(20,72.f*float(page.getFormLength())-40.f), MWAWVec2f(-20,-10), librevenge::RVNG_POINT);
   pos.m_anchorTo=MWAWPosition::Page;
   if (!openFrame(pos))
     return false;
@@ -891,8 +913,7 @@ bool MWAWGraphicListener::insertFooter(MWAWSubDocumentPtr subDocument, libreveng
 MWAWSection const &MWAWGraphicListener::getSection() const
 {
   MWAW_DEBUG_MSG(("MWAWGraphicListener::getSection: must not be called\n"));
-  static MWAWSection s_section;
-  return s_section;
+  return m_ds->m_section;
 }
 
 bool MWAWGraphicListener::openSection(MWAWSection const &)
@@ -912,12 +933,18 @@ void MWAWGraphicListener::insertBreak(BreakType breakType)
     break;
   case SoftPageBreak:
   case PageBreak:
-    if (!m_ps->m_isPageSpanOpened)
+    if (m_ds->m_isMasterPageSpanOpened) {
+      MWAW_DEBUG_MSG(("MWAWGraphicListener::insertBreak: can not insert a page break in master page definition\n"));
+      break;
+    }
+    if (!m_ds->m_isPageSpanOpened)
       _openPageSpan();
     _closePageSpan();
     break;
+#if !defined(__clang__)
   default:
     break;
+#endif
   }
 }
 
@@ -964,23 +991,25 @@ void MWAWGraphicListener::insertNote(MWAWNote const &, MWAWSubDocumentPtr &subDo
 // picture/textbox
 ///////////////////
 
-void MWAWGraphicListener::insertPicture
+void MWAWGraphicListener::insertShape
 (MWAWPosition const &pos, MWAWGraphicShape const &shape, MWAWGraphicStyle const &style)
 {
   if (!m_ds->m_isDocumentStarted) {
-    MWAW_DEBUG_MSG(("MWAWGraphicListener::insertPicture: the document is not started\n"));
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::insertShape: the document is not started\n"));
     return;
   }
-  if (!m_ps->m_isPageSpanOpened)
+  if (!m_ds->m_isPageSpanOpened)
     _openPageSpan();
   if (m_ps->m_isFrameOpened) {
-    MWAW_DEBUG_MSG(("MWAWGraphicListener::insertPicture: a frame is already open\n"));
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::insertShape: a frame is already open\n"));
     return;
   }
 
   librevenge::RVNGPropertyList list, shapePList;
   style.addTo(list, shape.getType()==MWAWGraphicShape::Line);
   m_documentInterface->setStyle(list);
+  if (pos.order() > 0)
+    shapePList.insert("draw:z-index", pos.order());
   switch (shape.addTo(1.f/pos.getInvUnitScale(librevenge::RVNG_POINT)*pos.origin()-m_ps->m_origin, style.hasSurface(), shapePList)) {
   case MWAWGraphicShape::C_Ellipse:
     m_documentInterface->drawEllipse(shapePList);
@@ -999,14 +1028,15 @@ void MWAWGraphicListener::insertPicture
     break;
   case MWAWGraphicShape::C_Bad:
     break;
+#if !defined(__clang__)
   default:
-    MWAW_DEBUG_MSG(("MWAWGraphicListener::insertPicture: unexpected shape\n"));
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::insertShape: unexpected shape\n"));
     break;
+#endif
   }
 }
 
-void MWAWGraphicListener::insertPicture
-(MWAWPosition const &pos, const librevenge::RVNGBinaryData &binaryData, std::string type, MWAWGraphicStyle const &style)
+void MWAWGraphicListener::insertPicture(MWAWPosition const &pos, MWAWEmbeddedObject const &picture, MWAWGraphicStyle const &style)
 {
   if (!m_ds->m_isDocumentStarted) {
     MWAW_DEBUG_MSG(("MWAWGraphicListener::insertPicture: the document is not started\n"));
@@ -1016,7 +1046,7 @@ void MWAWGraphicListener::insertPicture
     MWAW_DEBUG_MSG(("MWAWGraphicListener::insertPicture: a frame is already open\n"));
     return;
   }
-  if (!m_ps->m_isPageSpanOpened)
+  if (!m_ds->m_isPageSpanOpened)
     _openPageSpan();
   librevenge::RVNGPropertyList list;
   style.addTo(list);
@@ -1024,9 +1054,20 @@ void MWAWGraphicListener::insertPicture
 
   list.clear();
   _handleFrameParameters(list, pos, style);
-  list.insert("librevenge:mime-type", type.c_str());
-  list.insert("office:binary-data", binaryData);
-  m_documentInterface->drawGraphicObject(list);
+  float rotate = style.m_rotate;
+  if (style.m_flip[0]&&style.m_flip[1]) rotate += 180.f;
+  if (rotate<0||rotate>0) {
+    list.insert("librevenge:rotate", double(rotate), librevenge::RVNG_GENERIC);
+    float pointFactor =1.f/pos.getInvUnitScale(librevenge::RVNG_POINT);
+    MWAWVec2f size=pointFactor*pos.size();
+    if (size[0]<0) size[0]=-size[0];
+    if (size[1]<0) size[1]=-size[1];
+    MWAWVec2f center=pointFactor*pos.origin()-m_ps->m_origin+0.5f*size;
+    list.insert("librevenge:rotate-cx",double(center[0]), librevenge::RVNG_POINT);
+    list.insert("librevenge:rotate-cy",double(center[1]), librevenge::RVNG_POINT);
+  }
+  if (picture.addTo(list))
+    m_documentInterface->drawGraphicObject(list);
 }
 
 void MWAWGraphicListener::insertTextBox
@@ -1036,7 +1077,7 @@ void MWAWGraphicListener::insertTextBox
     MWAW_DEBUG_MSG(("MWAWGraphicListener::insertTextBox: the document is not started\n"));
     return;
   }
-  if (!m_ps->m_isPageSpanOpened)
+  if (!m_ds->m_isPageSpanOpened)
     _openPageSpan();
   float pointFactor =1.f/pos.getInvUnitScale(librevenge::RVNG_POINT);
   if (m_ps->m_isTextBoxOpened) {
@@ -1052,13 +1093,13 @@ void MWAWGraphicListener::insertTextBox
   // flip does not works on text, so we ignore it...
   if (style.m_flip[0]&&style.m_flip[1]) rotate += 180.f;
   if (rotate<0||rotate>0) {
-    propList.insert("librevenge:rotate", rotate);
-    Vec2f size=pointFactor*pos.size();
+    propList.insert("librevenge:rotate", double(rotate), librevenge::RVNG_GENERIC);
+    MWAWVec2f size=pointFactor*pos.size();
     if (size[0]<0) size[0]=-size[0];
     if (size[1]<0) size[1]=-size[1];
-    Vec2f center=pointFactor*pos.origin()-m_ps->m_origin+0.5f*size;
-    propList.insert("librevenge:rotate-cx",center[0], librevenge::RVNG_POINT);
-    propList.insert("librevenge:rotate-cy",center[1], librevenge::RVNG_POINT);
+    MWAWVec2f center=pointFactor*pos.origin()-m_ps->m_origin+0.5f*size;
+    propList.insert("librevenge:rotate-cx",double(center[0]), librevenge::RVNG_POINT);
+    propList.insert("librevenge:rotate-cy",double(center[1]), librevenge::RVNG_POINT);
   }
   m_documentInterface->startTextObject(propList);
   handleSubDocument(pointFactor*pos.origin(), subDocument, libmwaw::DOC_TEXT_BOX);
@@ -1066,13 +1107,13 @@ void MWAWGraphicListener::insertTextBox
   closeFrame();
 }
 
-void MWAWGraphicListener::insertGroup(Box2f const &bdbox, MWAWSubDocumentPtr subDocument)
+void MWAWGraphicListener::insertGroup(MWAWBox2f const &bdbox, MWAWSubDocumentPtr subDocument)
 {
   if (!m_ds->m_isDocumentStarted || m_ps->isInTextZone()) {
     MWAW_DEBUG_MSG(("MWAWGraphicListener::insertGroup: can not insert a group\n"));
     return;
   }
-  if (!m_ps->m_isPageSpanOpened)
+  if (!m_ds->m_isPageSpanOpened)
     _openPageSpan();
   handleSubDocument(bdbox[0], subDocument, libmwaw::DOC_GRAPHIC_GROUP);
 }
@@ -1091,7 +1132,6 @@ void MWAWGraphicListener::insertTable
 
   _pushParsingState();
   _startSubDocument();
-  m_ps->m_isPageSpanOpened = true;
   m_ps->m_subDocumentType = libmwaw::DOC_TABLE;
 
   shared_ptr<MWAWListener> listen(this, MWAW_shared_ptr_noop_deleter<MWAWGraphicListener>());
@@ -1112,7 +1152,7 @@ void MWAWGraphicListener::openTable(MWAWTable const &table)
   if (!m_ps->m_isFrameOpened) {
     if (m_ps->m_isTextBoxOpened) {
       MWAW_DEBUG_MSG(("MWAWGraphicListener::openTable: must not be called inside a textbox\n"));
-      MWAWPosition pos(m_ps->m_origin, Vec2f(400,100), librevenge::RVNG_POINT);
+      MWAWPosition pos(m_ps->m_origin, MWAWVec2f(400,100), librevenge::RVNG_POINT);
       pos.m_anchorTo=MWAWPosition::Page;
       openTable(pos, table, MWAWGraphicStyle::emptyStyle());
       return;
@@ -1175,9 +1215,9 @@ void MWAWGraphicListener::openTableRow(float h, librevenge::RVNGUnit unit, bool
   propList.insert("librevenge:is-header-row", headerRow);
 
   if (h > 0)
-    propList.insert("style:row-height", h, unit);
+    propList.insert("style:row-height", double(h), unit);
   else if (h < 0)
-    propList.insert("style:min-row-height", -h, unit);
+    propList.insert("style:min-row-height", double(-h), unit);
   m_documentInterface->openTableRow(propList);
   m_ps->m_isTableRowOpened = true;
 }
@@ -1192,7 +1232,7 @@ void MWAWGraphicListener::closeTableRow()
   m_documentInterface->closeTableRow();
 }
 
-void MWAWGraphicListener::addEmptyTableCell(Vec2i const &pos, Vec2i span)
+void MWAWGraphicListener::addEmptyTableCell(MWAWVec2i const &pos, MWAWVec2i span)
 {
   if (!m_ps->m_isTableRowOpened) {
     MWAW_DEBUG_MSG(("MWAWGraphicListener::addEmptyTableCell: called with m_isTableRowOpened=false\n"));
@@ -1244,7 +1284,7 @@ void MWAWGraphicListener::closeTableCell()
 }
 
 ///////////////////
-// frame
+// frame/group
 ///////////////////
 bool MWAWGraphicListener::openFrame(MWAWPosition const &pos, MWAWGraphicStyle const &style)
 {
@@ -1260,7 +1300,7 @@ bool MWAWGraphicListener::openFrame(MWAWPosition const &pos, MWAWGraphicStyle co
     MWAW_DEBUG_MSG(("MWAWGraphicListener::openFrame: called but a frame is already opened\n"));
     return false;
   }
-  if (!m_ps->m_isPageSpanOpened)
+  if (!m_ds->m_isPageSpanOpened)
     _openPageSpan();
   m_ps->m_isFrameOpened = true;
   m_ps->m_framePosition=pos;
@@ -1277,6 +1317,80 @@ void MWAWGraphicListener::closeFrame()
   m_ps->m_isFrameOpened = false;
 }
 
+bool  MWAWGraphicListener::openGroup(MWAWPosition const &pos)
+{
+  if (!m_ds->m_isDocumentStarted) {
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::openGroup: the document is not started\n"));
+    return false;
+  }
+  if (m_ps->m_isTableOpened || m_ps->isInTextZone()) {
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::openGroup: called in table or in a text zone\n"));
+    return false;
+  }
+  if (!m_ds->m_isPageSpanOpened)
+    _openPageSpan();
+
+  librevenge::RVNGPropertyList propList;
+  _handleFrameParameters(propList, pos, MWAWGraphicStyle::emptyStyle());
+
+  _pushParsingState();
+  _startSubDocument();
+  m_ps->m_isGroupOpened = true;
+
+  m_documentInterface->openGroup(propList);
+
+  return true;
+}
+
+void  MWAWGraphicListener::closeGroup()
+{
+  if (!m_ps->m_isGroupOpened) {
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::closeGroup: called but no group is already opened\n"));
+    return;
+  }
+  _endSubDocument();
+  _popParsingState();
+  m_documentInterface->closeGroup();
+}
+
+bool MWAWGraphicListener::openLayer(librevenge::RVNGString const &layerName)
+{
+  if (!m_ds->m_isDocumentStarted) {
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::openLayer: the document is not started\n"));
+    return false;
+  }
+  if (m_ps->m_isTableOpened || m_ps->isInTextZone()) {
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::openLayer: called in table or in a text zone\n"));
+    return false;
+  }
+  if (m_ps->m_isLayerOpened) {
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::openLayer: called but layer is already opened\n"));
+    return false;
+  }
+  if (!m_ds->m_isPageSpanOpened)
+    _openPageSpan();
+
+  _pushParsingState();
+  _startSubDocument();
+  m_ps->m_isLayerOpened = true;
+
+  librevenge::RVNGPropertyList propList;
+  propList.insert("draw:layer", layerName);
+  m_documentInterface->startLayer(propList);
+  return true;
+}
+
+void  MWAWGraphicListener::closeLayer()
+{
+  if (!m_ps->m_isLayerOpened) {
+    MWAW_DEBUG_MSG(("MWAWGraphicListener::closeLayer: called but no layer is already opened\n"));
+    return;
+  }
+  m_documentInterface->endLayer();
+  _endSubDocument();
+  _popParsingState();
+}
+
 void MWAWGraphicListener::_handleFrameParameters(librevenge::RVNGPropertyList &list, MWAWPosition const &pos, MWAWGraphicStyle const &style)
 {
   if (!m_ds->m_isDocumentStarted)
@@ -1286,9 +1400,9 @@ void MWAWGraphicListener::_handleFrameParameters(librevenge::RVNGPropertyList &l
   float pointFactor = pos.getInvUnitScale(librevenge::RVNG_POINT);
   float inchFactor=pos.getInvUnitScale(librevenge::RVNG_INCH);
   // first compute the origin ( in given unit and in point)
-  Vec2f origin = pos.origin()-pointFactor*m_ps->m_origin;
-  Vec2f originPt = (1.f/pointFactor)*pos.origin()-m_ps->m_origin;
-  Vec2f size = pos.size();
+  MWAWVec2f origin = pos.origin()-pointFactor*m_ps->m_origin;
+  MWAWVec2f originPt = (1.f/pointFactor)*pos.origin()-m_ps->m_origin;
+  MWAWVec2f size = pos.size();
   // checkme: do we still need to do that ?
   if (style.hasGradient(true)) {
     if (style.m_rotate<0 || style.m_rotate>0) {
@@ -1298,10 +1412,10 @@ void MWAWGraphicListener::_handleFrameParameters(librevenge::RVNGPropertyList &l
     librevenge::RVNGPropertyList rectList;
     m_documentInterface->setStyle(rectList);
     rectList.clear();
-    rectList.insert("svg:x",originPt[0], librevenge::RVNG_POINT);
-    rectList.insert("svg:y",originPt[1], librevenge::RVNG_POINT);
-    rectList.insert("svg:width",size.x()>0 ? size.x() : -size.x(), unit);
-    rectList.insert("svg:height",size.y()>0 ? size.y() : -size.y(), unit);
+    rectList.insert("svg:x",double(originPt[0]), librevenge::RVNG_POINT);
+    rectList.insert("svg:y",double(originPt[1]), librevenge::RVNG_POINT);
+    rectList.insert("svg:width",size.x()>0 ? double(size.x()) : double(-size.x()), unit);
+    rectList.insert("svg:height",size.y()>0 ? double(size.y()) : double(-size.y()), unit);
     m_documentInterface->drawRectangle(rectList);
 
     list.insert("draw:stroke", "none");
@@ -1310,25 +1424,24 @@ void MWAWGraphicListener::_handleFrameParameters(librevenge::RVNGPropertyList &l
   else
     style.addTo(list);
 
-  list.insert("svg:x",originPt[0], librevenge::RVNG_POINT);
-  list.insert("svg:y",originPt[1], librevenge::RVNG_POINT);
+  list.insert("svg:x",double(originPt[0]), librevenge::RVNG_POINT);
+  list.insert("svg:y",double(originPt[1]), librevenge::RVNG_POINT);
   if (size.x()>0)
-    list.insert("svg:width",size.x(), unit);
+    list.insert("svg:width",double(size.x()), unit);
   else if (size.x()<0)
-    list.insert("fo:min-width",-size.x(), unit);
+    list.insert("fo:min-width",double(-size.x()), unit);
   if (size.y()>0)
-    list.insert("svg:height",size.y(), unit);
+    list.insert("svg:height",double(size.y()), unit);
   else if (size.y()<0)
-    list.insert("fo:min-height",-size.y(), unit);
+    list.insert("fo:min-height",double(-size.y()), unit);
   if (pos.order() > 0)
     list.insert("draw:z-index", pos.order());
-
   if (pos.naturalSize().x() > 4*pointFactor && pos.naturalSize().y() > 4*pointFactor) {
-    list.insert("librevenge:naturalWidth", pos.naturalSize().x(), pos.unit());
-    list.insert("librevenge:naturalHeight", pos.naturalSize().y(), pos.unit());
+    list.insert("librevenge:naturalWidth", double(pos.naturalSize().x()), pos.unit());
+    list.insert("librevenge:naturalHeight", double(pos.naturalSize().y()), pos.unit());
   }
-  Vec2f TLClip = (1.f/pointFactor)*pos.leftTopClipping();
-  Vec2f RBClip = (1.f/pointFactor)*pos.rightBottomClipping();
+  MWAWVec2f TLClip = (1.f/pointFactor)*pos.leftTopClipping();
+  MWAWVec2f RBClip = (1.f/pointFactor)*pos.rightBottomClipping();
   if (TLClip[0] > 0 || TLClip[1] > 0 || RBClip[0] > 0 || RBClip[1] > 0) {
     // in ODF1.2 we need to separate the value with ,
     std::stringstream s;
@@ -1347,6 +1460,10 @@ void MWAWGraphicListener::_handleFrameParameters(librevenge::RVNGPropertyList &l
     list.insert("style:wrap", "run-through");
     list.insert("style:run-through", "foreground");
   }
+  else if (pos.m_wrapping ==  MWAWPosition::WParallel) {
+    list.insert("style:wrap", "parallel");
+    list.insert("style:run-through", "foreground");
+  }
   else if (pos.m_wrapping ==  MWAWPosition::WRunThrough)
     list.insert("style:wrap", "run-through");
   else
@@ -1355,49 +1472,51 @@ void MWAWGraphicListener::_handleFrameParameters(librevenge::RVNGPropertyList &l
     MWAW_DEBUG_MSG(("MWAWGraphicListener::_handleFrameParameters: only page anchor is implemented\n"));
   }
   else {
-    double w = m_ps->m_pageSpan.getFormWidth();
-    double h = m_ps->m_pageSpan.getFormLength();
-    w *= inchFactor;
-    h *= inchFactor;
+    double w = m_ds->m_pageSpan.getFormWidth();
+    double h = m_ds->m_pageSpan.getFormLength();
+    w *= double(inchFactor);
+    h *= double(inchFactor);
     double newPosition;
     switch (pos.m_yPos) {
     case MWAWPosition::YFull:
       list.insert("svg:height", double(h), unit);
     // fallthrough intended
     case MWAWPosition::YTop:
-      if (origin[1] < 0.0 || origin[1] > 0.0) {
+      if (origin[1] < 0 || origin[1] > 0) {
         list.insert("style:vertical-pos", "from-top");
-        newPosition = origin[1];
-        if (newPosition > h -pos.size()[1])
-          newPosition = h - pos.size()[1];
+        newPosition = double(origin[1]);
+        if (newPosition > h -double(pos.size()[1]))
+          newPosition = h - double(pos.size()[1]);
         list.insert("svg:y", double(newPosition), unit);
       }
       else
         list.insert("style:vertical-pos", "top");
       break;
     case MWAWPosition::YCenter:
-      if (origin[1] < 0.0 || origin[1] > 0.0) {
+      if (origin[1] < 0 || origin[1] > 0) {
         list.insert("style:vertical-pos", "from-top");
-        newPosition = (h - pos.size()[1])/2.0;
-        if (newPosition > h -pos.size()[1]) newPosition = h - pos.size()[1];
+        newPosition = (h - double(pos.size()[1]))/2.0;
+        if (newPosition > h -double(pos.size()[1])) newPosition = h - double(pos.size()[1]);
         list.insert("svg:y", double(newPosition), unit);
       }
       else
         list.insert("style:vertical-pos", "middle");
       break;
     case MWAWPosition::YBottom:
-      if (origin[1] < 0.0 || origin[1] > 0.0) {
+      if (origin[1] < 0 || origin[1] > 0) {
         list.insert("style:vertical-pos", "from-top");
-        newPosition = h - pos.size()[1]-origin[1];
-        if (newPosition > h -pos.size()[1]) newPosition = h -pos.size()[1];
+        newPosition = h - double(pos.size()[1])-double(origin[1]);
+        if (newPosition > h -double(pos.size()[1])) newPosition = h -double(pos.size()[1]);
         else if (newPosition < 0) newPosition = 0;
         list.insert("svg:y", double(newPosition), unit);
       }
       else
         list.insert("style:vertical-pos", "bottom");
       break;
+#if !defined(__clang__)
     default:
       break;
+#endif
     }
 
     switch (pos.m_xPos) {
@@ -1405,7 +1524,7 @@ void MWAWGraphicListener::_handleFrameParameters(librevenge::RVNGPropertyList &l
       list.insert("svg:width", double(w), unit);
     // fallthrough intended
     case MWAWPosition::XLeft:
-      if (origin[0] < 0.0 || origin[0] > 0.0) {
+      if (origin[0] < 0 || origin[0] > 0) {
         list.insert("style:horizontal-pos", "from-left");
         list.insert("svg:x", double(origin[0]), unit);
       }
@@ -1413,47 +1532,48 @@ void MWAWGraphicListener::_handleFrameParameters(librevenge::RVNGPropertyList &l
         list.insert("style:horizontal-pos", "left");
       break;
     case MWAWPosition::XRight:
-      if (origin[0] < 0.0 || origin[0] > 0.0) {
+      if (origin[0] < 0 || origin[0] > 0) {
         list.insert("style:horizontal-pos", "from-left");
-        list.insert("svg:x",double(w - pos.size()[0] + origin[0]), unit);
+        list.insert("svg:x",double(w - double(pos.size()[0]) + double(origin[0])), unit);
       }
       else
         list.insert("style:horizontal-pos", "right");
       break;
     case MWAWPosition::XCenter:
-      if (origin[0] < 0.0 || origin[0] > 0.0) {
+      if (origin[0] < 0 || origin[0] > 0) {
         list.insert("style:horizontal-pos", "from-left");
-        list.insert("svg:x", double((w - pos.size()[0])/2. + origin[0]), unit);
+        list.insert("svg:x", double((w - double(pos.size()[0]))/2. + double(origin[0])), unit);
       }
       else
         list.insert("style:horizontal-pos", "center");
       break;
+#if !defined(__clang__)
     default:
       break;
+#endif
     }
 
   }
   float const padding = 0; // fillme
-  list.insert("fo:padding-top",padding, librevenge::RVNG_POINT);
-  list.insert("fo:padding-bottom",padding, librevenge::RVNG_POINT);
-  list.insert("fo:padding-left",padding, librevenge::RVNG_POINT);
-  list.insert("fo:padding-right",padding, librevenge::RVNG_POINT);
+  list.insert("fo:padding-top",double(padding), librevenge::RVNG_POINT);
+  list.insert("fo:padding-bottom",double(padding), librevenge::RVNG_POINT);
+  list.insert("fo:padding-left",double(padding), librevenge::RVNG_POINT);
+  list.insert("fo:padding-right",double(padding), librevenge::RVNG_POINT);
 }
 
 ///////////////////
 // subdocument
 ///////////////////
-void MWAWGraphicListener::handleSubDocument(Vec2f const &orig, MWAWSubDocumentPtr subDocument, libmwaw::SubDocumentType subDocumentType)
+void MWAWGraphicListener::handleSubDocument(MWAWVec2f const &orig, MWAWSubDocumentPtr subDocument, libmwaw::SubDocumentType subDocumentType)
 {
   if (!m_ds->m_isDocumentStarted) {
     MWAW_DEBUG_MSG(("MWAWGraphicListener::handleSubDocument: the graphic is not started\n"));
     return;
   }
-  if (!m_ps->m_isPageSpanOpened)
+  if (!m_ds->m_isPageSpanOpened)
     _openPageSpan();
-  Vec2f actOrigin=m_ps->m_origin;
+  MWAWVec2f actOrigin=m_ps->m_origin;
   _pushParsingState();
-  m_ps->m_isPageSpanOpened=true;
   m_ps->m_origin=actOrigin-orig;
   _startSubDocument();
   m_ps->m_subDocumentType = subDocumentType;
