@@ -127,12 +127,18 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
         return res;
       }
     }
-    else if (creator=="CDrw") { // CHANGEME: ClarisDraw
+    else if (creator=="CDrw") {
       if (type=="dDrw" || type=="dDst" || type=="iLib") {
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CLARISDRAW, 1, MWAWDocument::MWAW_K_DRAW));
         return res;
       }
     }
+    else if (creator=="CRDW") {
+      if (type=="CKDT") {
+        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CRICKETDRAW, 1, MWAWDocument::MWAW_K_DRAW));
+        return res;
+      }
+    }
     else if (creator=="C#+A") { // solo
       if (type=="C#+D" || type=="C#+F") {
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_RAGTIME, 5));
@@ -145,6 +151,12 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
         return res;
       }
     }
+    else if (creator=="FHA2") {
+      if (type=="FHD2" || type=="FHT2") {
+        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_FREEHAND, 2, MWAWDocument::MWAW_K_DRAW));
+        return res;
+      }
+    }
     else if (creator=="FS03") {
       if (type=="WRT+") {
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_WRITERPLUS, 1));
@@ -171,6 +183,12 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
         return res;
       }
     }
+    else if (creator=="GM01") {
+      if (type=="GfMt") {
+        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MOUSEWRITE, 1));
+        return res;
+      }
+    }
     else if (creator=="HMiw") {   // japonese
       if (type=="IWDC") {
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_HANMACWORDJ,1));
@@ -207,6 +225,12 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
         return res;
       }
     }
+    else if (creator=="MAXW") {
+      if (type=="MWCT") {
+        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MAXWRITE, 1));
+        return res;
+      }
+    }
     else if (creator=="MD40") {
       if (type=="MDDC" || type=="MSYM") {
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MACDRAFT, 4, MWAWDocument::MWAW_K_DRAW));
@@ -338,6 +362,18 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
         return res;
       }
     }
+    else if (creator=="PPT3") {
+      if (type=="SLD3") {
+        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_POWERPOINT, 3, MWAWDocument::MWAW_K_PRESENTATION));
+        return res;
+      }
+    }
+    else if (creator=="PPNT") {
+      if (type=="SLDS") {
+        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_POWERPOINT, 2, MWAWDocument::MWAW_K_PRESENTATION));
+        return res;
+      }
+    }
     else if (creator=="PSIP") {
       if (type=="AWWP") {
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MICROSOFTWORKS, 1));
@@ -394,8 +430,8 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
         return res;
       }
     }
-    else if (creator==std::string("St")+(char) 0xd8+"l") { //  argh, not standart character
-      std::string type1=std::string("TEd")+(char)0xb6; // argh, not standart character
+    else if (creator==std::string("St")+char(0xd8)+"l") { //  argh, not standart character
+      std::string type1=std::string("TEd")+char(0xb6); // argh, not standart character
       if (type==type1) {
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_STYLE, 1));
         return res;
@@ -455,6 +491,12 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
         return res;
       }
     }
+    else if (creator=="aca3") {
+      if (type=="acf3" || type=="act3") {
+        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_FREEHAND, 1, MWAWDocument::MWAW_K_DRAW));
+        return res;
+      }
+    }
     else if (creator=="dPro") {
       if (type=="dDoc") {
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MACDRAWPRO, 1, MWAWDocument::MWAW_K_DRAW));
@@ -619,7 +661,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
     if (val[2]==0 || val[2]==0x4432) { // D2
       MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a MacDraw II file\n"));
       res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MACDRAWPRO, 0, MWAWDocument::MWAW_K_DRAW));
-      return res;
+      // can also be a classic apple pict, so let's continue
     }
   }
   if (val[0]==0x5354 && val[1]==0x4154 && (val[2]==0 || val[2]==0x4432)) {
@@ -655,6 +697,16 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
     res.push_back(MWAWHeader(MWAWDocument::MWAW_T_HANMACWORDJ, 1));
     return res;
   }
+  if (val[0]==0x6163 && val[1]==0x6633 && val[2]<9) {
+    MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a FreeHand v1\n"));
+    res.push_back(MWAWHeader(MWAWDocument::MWAW_T_FREEHAND, 1, MWAWDocument::MWAW_K_DRAW));
+    return res;
+  }
+  if (val[0]==0x4648 && val[1]==0x4432 && val[2]<20) {
+    MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a FreeHand v2\n"));
+    res.push_back(MWAWHeader(MWAWDocument::MWAW_T_FREEHAND, 2, MWAWDocument::MWAW_K_DRAW));
+    return res;
+  }
   if (val[0]==3 && val[1]==0x4d52 && val[2]==0x4949 && val[3]==0x80) { // MRII
     res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MORE, 2));
     return res;
@@ -703,7 +755,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
       res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MICROSOFTWORKS, 4));
     else if (mainOle && mainOle->size()>18) {
       mainOle->seek(16, librevenge::RVNG_SEEK_SET);
-      int value=(int) mainOle->readULong(2);
+      int value=static_cast<int>(mainOle->readULong(2));
       switch (value) {
       case 2:
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MICROSOFTWORKS, 4, MWAWDocument::MWAW_K_DATABASE));
@@ -748,11 +800,25 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
     if (vers >= 0)
       res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MICROSOFTWORD, vers));
   }
+  if (val[0]==0xbad && val[1]==0xdeed && val[2]==0 && (val[3]>=2 && val[3]<=3)) {
+    MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a Presentation file\n"));
+    res.push_back(MWAWHeader(MWAWDocument::MWAW_T_POWERPOINT, val[3], MWAWDocument::MWAW_K_PRESENTATION));
+  }
+  if (val[0]==0xedde && val[1]==0xad0b && val[3]==0 && (val[2]&0xFF)==0) {
+    int vers=(val[2]>>8);
+    if (vers>=2 && vers<=3) {
+      MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a Presentation file\n"));
+      res.push_back(MWAWHeader(MWAWDocument::MWAW_T_POWERPOINT, vers, MWAWDocument::MWAW_K_PRESENTATION));
+    }
+  }
   if (val[0]==0x4348 && val[1]==0x4e4b && val[2]==0x100 && val[3]==0) {
     MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a Style file\n"));
     res.push_back(MWAWHeader(MWAWDocument::MWAW_T_STYLE, 1));
   }
-
+  if (val[0]==0x0447 && val[1]==0x4d30 && val[2]==0x3400) { // ^DGM04
+    MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a MouseWrite file\n"));
+    res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MOUSEWRITE, 1));
+  }
   // ----------- less discriminant ------------------
   if (val[0] == 0x2e && val[1] == 0x2e) {
     MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a MacWrite II file\n"));
@@ -770,7 +836,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
   // ----------- other ------------------
   if (val[0]==0 && val[1]==0 && val[2]==0 && val[3]==0) {
     input->seek(8, librevenge::RVNG_SEEK_SET);
-    int value=(int) input->readULong(1);
+    int value=static_cast<int>(input->readULong(1));
     if (value==0x4 || value==0x44) {
       MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a WriteNow 1.0 or 2.0 file\n"));
       res.push_back(MWAWHeader(MWAWDocument::MWAW_T_WRITENOW, 2));
@@ -803,7 +869,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
     }
     if (vers > 0 && input->size()>16) {
       input->seek(16, librevenge::RVNG_SEEK_SET);
-      int value=(int) input->readULong(2);
+      int value=static_cast<int>(input->readULong(2));
       switch (value) {
       case 1:
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MICROSOFTWORKS, vers));
@@ -835,7 +901,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
   }
   if (val[0] == 0x1000) {
     input->seek(10, librevenge::RVNG_SEEK_SET);
-    int value=(int) input->readULong(2);
+    int value=static_cast<int>(input->readULong(2));
     // 1: bitmap, 2: vectorized graphic
     if (value==1)
       res.push_back(MWAWHeader(MWAWDocument::MWAW_T_SUPERPAINT, 1, MWAWDocument::MWAW_K_PAINT));
@@ -846,6 +912,29 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
     MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a potential PixelPaint file\n"));
     res.push_back(MWAWHeader(MWAWDocument::MWAW_T_PIXELPAINT, (val[1]==0x7FFF) ? 1  : 2, MWAWDocument::MWAW_K_PAINT));
   }
+  if (val[0]>=1 && val[0]<=4) {
+    int sSz=(val[1]>>8);
+    if (sSz>=6 && sSz<=8) {
+      // check if we find a date
+      input->seek(3, librevenge::RVNG_SEEK_SET);
+      bool ok=true;
+      int numSlash=0;
+      for (int i=0; i<sSz; ++i) {
+        char c=char(input->readULong(1));
+        if (c>='0' && c<='9')
+          continue;
+        if (c=='/')
+          ++numSlash;
+        else {
+          ok=false;
+          break;
+        }
+      }
+      if (ok && numSlash==2)
+        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CRICKETDRAW, 1, MWAWDocument::MWAW_K_DRAW));
+    }
+  }
+
   //
   // check for pict
   //
@@ -853,7 +942,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
     if (!input->checkPosition(512*st+13))
       break;
     input->seek(512*st+10, librevenge::RVNG_SEEK_SET);
-    int value=(int) input->readULong(2);
+    int value=static_cast<int>(input->readULong(2));
     if (value==0x1101) {
       res.push_back(MWAWHeader(MWAWDocument::MWAW_T_APPLEPICT, 1, MWAWDocument::MWAW_K_DRAW));
       break;
@@ -879,9 +968,9 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
           ok=false;
           break;
         }
-        int wh=(int) input->readULong(1);
+        int wh=static_cast<int>(input->readULong(1));
         if (wh>=0x81) {
-          int color=(int) input->readULong(1);
+          int color=static_cast<int>(input->readULong(1));
           // consider that repeat color is anormal...
           if (col+(0x101-wh)>72 || (lastColor>=0 && color==lastColor)) {
             ok=false;
