@@ -75,11 +75,11 @@ enum { PageBreakBit=0x1, ColumnBreakBit=0x2 };
 //! a class to store the document state of a MWAWSpreadsheetListener
 struct DocumentState {
   //! constructor
-  DocumentState(std::vector<MWAWPageSpan> const &pageList) :
-    m_pageList(pageList), m_metaData(), m_footNoteNumber(0), m_smallPictureNumber(0),
+  explicit DocumentState(std::vector<MWAWPageSpan> const &pageList) :
+    m_pageList(pageList), m_pageSpan(), m_metaData(), m_footNoteNumber(0), m_smallPictureNumber(0),
     m_isDocumentStarted(false), m_isSheetOpened(false), m_isSheetRowOpened(false),
     m_sentListMarkers(), m_numberingIdMap(),
-    m_subDocuments()
+    m_subDocuments(), m_section()
   {
   }
   //! destructor
@@ -89,6 +89,8 @@ struct DocumentState {
 
   //! the pages definition
   std::vector<MWAWPageSpan> m_pageList;
+  //! the current page span
+  MWAWPageSpan m_pageSpan;
   //! the document meta data
   librevenge::RVNGPropertyList m_metaData;
 
@@ -103,7 +105,8 @@ struct DocumentState {
   /** a map cell's format to id */
   std::map<MWAWCell::Format,int,MWAWCell::CompareFormat> m_numberingIdMap;
   std::vector<MWAWSubDocumentPtr> m_subDocuments; /** list of document actually open */
-
+  /// empty section used by getSection() to return a section
+  MWAWSection m_section;
 private:
   DocumentState(const DocumentState &);
   DocumentState &operator=(const DocumentState &);
@@ -155,7 +158,6 @@ struct State {
   bool m_isTableColumnOpened;
   bool m_isTableCellOpened;
 
-  MWAWPageSpan m_pageSpan;
   unsigned m_currentPage;
   int m_numPagesRemainingInSpan;
   int m_currentPageNumber;
@@ -196,7 +198,7 @@ State::State() :
   m_isTableOpened(false), m_isTableRowOpened(false), m_isTableColumnOpened(false),
   m_isTableCellOpened(false),
 
-  m_pageSpan(), m_currentPage(0), m_numPagesRemainingInSpan(0), m_currentPageNumber(1),
+  m_currentPage(0), m_numPagesRemainingInSpan(0), m_currentPageNumber(1),
 
   m_listOrderedLevels(),
 
@@ -213,14 +215,14 @@ MWAWSpreadsheetListener::MWAWSpreadsheetListener(MWAWParserState &parserState, s
 {
 }
 
-MWAWSpreadsheetListener::MWAWSpreadsheetListener(MWAWParserState &parserState, Box2f const &box, librevenge::RVNGSpreadsheetInterface *documentInterface) : MWAWListener(),
+MWAWSpreadsheetListener::MWAWSpreadsheetListener(MWAWParserState &parserState, MWAWBox2f const &box, librevenge::RVNGSpreadsheetInterface *documentInterface) : MWAWListener(),
   m_ds(), m_ps(new MWAWSpreadsheetListenerInternal::State), m_psStack(), m_parserState(parserState), m_documentInterface(documentInterface)
 {
   MWAWPageSpan pageSpan;
   pageSpan.setMargins(0);
   pageSpan.setPageSpan(1);
-  pageSpan.setFormWidth(box.size().x()/72.);
-  pageSpan.setFormLength(box.size().y()/72.);
+  pageSpan.setFormWidth(double(box.size().x())/72.);
+  pageSpan.setFormLength(double(box.size().y())/72.);
   m_ds.reset(new MWAWSpreadsheetListenerInternal::DocumentState(std::vector<MWAWPageSpan>(1, pageSpan)));
 }
 
@@ -249,7 +251,7 @@ void MWAWSpreadsheetListener::insertChar(uint8_t character)
   }
   _flushDeferredTabs();
   if (!m_ps->m_isSpanOpened) _openSpan();
-  m_ps->m_textBuffer.append((char) character);
+  m_ps->m_textBuffer.append(char(character));
 }
 
 void MWAWSpreadsheetListener::insertCharacter(unsigned char c)
@@ -261,13 +263,13 @@ void MWAWSpreadsheetListener::insertCharacter(unsigned char c)
   int unicode = m_parserState.m_fontConverter->unicode(m_ps->m_font.id(), c);
   if (unicode == -1) {
     if (c < 0x20) {
-      MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertCharacter: Find odd char %x\n", int(c)));
+      MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertCharacter: Find odd char %x\n", static_cast<unsigned int>(c)));
     }
     else
-      MWAWSpreadsheetListener::insertChar((uint8_t) c);
+      MWAWSpreadsheetListener::insertChar(static_cast<uint8_t>(c));
   }
   else
-    MWAWSpreadsheetListener::insertUnicode((uint32_t) unicode);
+    MWAWSpreadsheetListener::insertUnicode(static_cast<uint32_t>(unicode));
 }
 
 int MWAWSpreadsheetListener::insertCharacter(unsigned char c, MWAWInputStreamPtr &input, long endPos)
@@ -295,13 +297,13 @@ int MWAWSpreadsheetListener::insertCharacter(unsigned char c, MWAWInputStreamPtr
   }
   if (unicode == -1) {
     if (c < 0x20) {
-      MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertCharacter: Find odd char %x\n", int(c)));
+      MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertCharacter: Find odd char %x\n", static_cast<unsigned int>(c)));
     }
     else
-      MWAWSpreadsheetListener::insertChar((uint8_t) c);
+      MWAWSpreadsheetListener::insertChar(static_cast<uint8_t>(c));
   }
   else
-    MWAWSpreadsheetListener::insertUnicode((uint32_t) unicode);
+    MWAWSpreadsheetListener::insertUnicode(static_cast<uint32_t>(unicode));
 
   return int(pos-debPos);
 }
@@ -429,60 +431,19 @@ void MWAWSpreadsheetListener::insertField(MWAWField const &field)
     return;
   }
 
-  switch (field.m_type) {
-  case MWAWField::None:
-    break;
-  case MWAWField::PageCount:
-  case MWAWField::PageNumber:
-  case MWAWField::Title: {
+  librevenge::RVNGPropertyList propList;
+  if (field.addTo(propList)) {
     _flushDeferredTabs();
     _flushText();
     _openSpan();
-    librevenge::RVNGPropertyList propList;
-    if (field.m_type==MWAWField::Title) {
-      propList.insert("librevenge:field-type", "text:title");
-      m_documentInterface->insertField(propList);
-    }
-    else {
-      propList.insert("style:num-format", libmwaw::numberingTypeToString(field.m_numberingType).c_str());
-      if (field.m_type == MWAWField::PageNumber) {
-        propList.insert("librevenge:field-type", "text:page-number");
-        m_documentInterface->insertField(propList);
-      }
-      else {
-        propList.insert("librevenge:field-type", "text:page-count");
-        m_documentInterface->insertField(propList);
-      }
-    }
-    break;
+    m_documentInterface->insertField(propList);
+    return;
   }
-  case MWAWField::Database:
-    if (field.m_data.length())
-      MWAWSpreadsheetListener::insertUnicodeString(field.m_data.c_str());
-    else
-      MWAWSpreadsheetListener::insertUnicodeString("#DATAFIELD#");
-    break;
-  case MWAWField::Date:
-  case MWAWField::Time: {
-    std::string format(field.m_DTFormat);
-    if (format.length()==0) {
-      if (field.m_type==MWAWField::Date)
-        format="%m/%d/%y";
-      else
-        format="%I:%M:%S %p";
-    }
-    time_t now = time(0L);
-    struct tm timeinfo;
-    if (localtime_r(&now, &timeinfo)) {
-      char buf[256];
-      strftime(buf, 256, format.c_str(), &timeinfo);
-      MWAWSpreadsheetListener::insertUnicodeString(librevenge::RVNGString(buf));
-    }
-    break;
-  }
-  default:
+  librevenge::RVNGString text=field.getString();
+  if (!text.empty())
+    MWAWSpreadsheetListener::insertUnicodeString(text);
+  else {
     MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertField: must not be called with type=%d\n", int(field.m_type)));
-    break;
   }
 }
 
@@ -520,7 +481,14 @@ void MWAWSpreadsheetListener::closeLink()
 ///////////////////
 // document
 ///////////////////
-void MWAWSpreadsheetListener::setDocumentLanguage(std::string locale)
+void MWAWSpreadsheetListener::setDocumentMetaData(librevenge::RVNGPropertyList const &meta)
+{
+  librevenge::RVNGPropertyList::Iter i(meta);
+  for (i.rewind(); i.next();)
+    m_ds->m_metaData.insert(i.key(), i()->getStr());
+}
+
+void MWAWSpreadsheetListener::setDocumentLanguage(std::string const &locale)
 {
   if (!locale.length()) return;
   m_ds->m_metaData.insert("librevenge:language", locale.c_str());
@@ -586,7 +554,7 @@ MWAWPageSpan const &MWAWSpreadsheetListener::getPageSpan()
 {
   if (!m_ps->m_isPageSpanOpened)
     _openPageSpan();
-  return m_ps->m_pageSpan;
+  return m_ds->m_pageSpan;
 }
 
 
@@ -606,7 +574,7 @@ void MWAWSpreadsheetListener::_openPageSpan(bool sendHeaderFooters)
   std::vector<MWAWPageSpan>::iterator it = m_ds->m_pageList.begin();
   ++m_ps->m_currentPage;
   while (true) {
-    actPage+=(unsigned)it->getPageSpan();
+    actPage+=static_cast<unsigned>(it->getPageSpan());
     if (actPage >= m_ps->m_currentPage)
       break;
     if (++it == m_ds->m_pageList.end()) {
@@ -625,7 +593,7 @@ void MWAWSpreadsheetListener::_openPageSpan(bool sendHeaderFooters)
     m_documentInterface->openPageSpan(propList);
 
   m_ps->m_isPageSpanOpened = true;
-  m_ps->m_pageSpan = currentPage;
+  m_ds->m_pageSpan = currentPage;
 
   // we insert the header footer
   if (sendHeaderFooters)
@@ -685,8 +653,7 @@ bool MWAWSpreadsheetListener::insertFooter(MWAWSubDocumentPtr subDocument, libre
 MWAWSection const &MWAWSpreadsheetListener::getSection() const
 {
   MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::getSection: make no sense\n"));
-  static MWAWSection const badSection;
-  return badSection;
+  return m_ds->m_section;
 }
 
 bool MWAWSpreadsheetListener::openSection(MWAWSection const &)
@@ -791,7 +758,7 @@ void MWAWSpreadsheetListener::_closeListElement()
 
 int MWAWSpreadsheetListener::_getListId() const
 {
-  size_t newLevel= (size_t) m_ps->m_paragraph.m_listLevelIndex.get();
+  size_t newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get());
   if (newLevel == 0) return -1;
   int newListId = m_ps->m_paragraph.m_listId.get();
   if (newListId > 0) return newListId;
@@ -815,7 +782,11 @@ void MWAWSpreadsheetListener::_changeList()
     _closeParagraph();
 
   size_t actualLevel = m_ps->m_listOrderedLevels.size();
-  size_t newLevel= (size_t) m_ps->m_paragraph.m_listLevelIndex.get();
+  size_t newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get());
+  if (newLevel>100) {
+    MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::_changeList: find level=%d, set it to 100\n", static_cast<int>(newLevel)));
+    newLevel=100;
+  }
   int newListId = newLevel>0 ? _getListId() : -1;
   bool changeList = newLevel &&
                     (m_ps->m_list && m_ps->m_list->getId()!=newListId);
@@ -838,7 +809,7 @@ void MWAWSpreadsheetListener::_changeList()
     }
     m_parserState.m_listManager->needToSend(newListId, m_ds->m_sentListMarkers);
     m_ps->m_list = theList;
-    m_ps->m_list->setLevel((int)newLevel);
+    m_ps->m_list->setLevel(static_cast<int>(newLevel));
   }
 
   m_ps->m_listOrderedLevels.resize(newLevel, false);
@@ -849,7 +820,7 @@ void MWAWSpreadsheetListener::_changeList()
     m_ps->m_listOrderedLevels[i-1] = ordered;
 
     librevenge::RVNGPropertyList level;
-    m_ps->m_list->addTo(int(i), level);
+    m_ps->m_list->addTo(int(i), level, m_parserState.m_fontManager);
     if (ordered)
       m_documentInterface->openOrderedListLevel(level);
     else
@@ -1034,7 +1005,7 @@ void MWAWSpreadsheetListener::insertComment(MWAWSubDocumentPtr &subDocument)
 void MWAWSpreadsheetListener::insertTextBox
 (MWAWPosition const &pos, MWAWSubDocumentPtr subDocument, MWAWGraphicStyle const &frameStyle)
 {
-  if (!m_ds->m_isSheetOpened || m_ds->m_isSheetRowOpened) {
+  if (!m_ds->m_isSheetOpened || (m_ds->m_isSheetRowOpened && pos.m_anchorTo!=MWAWPosition::Cell)) {
     MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertTextBox insert a textbox outside a sheet is not implemented\n"));
     return;
   }
@@ -1050,11 +1021,11 @@ void MWAWSpreadsheetListener::insertTextBox
   closeFrame();
 }
 
-void MWAWSpreadsheetListener::insertPicture
+void MWAWSpreadsheetListener::insertShape
 (MWAWPosition const &pos, MWAWGraphicShape const &shape, MWAWGraphicStyle const &style)
 {
-  if (!m_ds->m_isSheetOpened || m_ds->m_isSheetRowOpened) {
-    MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertPicture insert a picture outside a sheet is not implemented\n"));
+  if (!m_ds->m_isSheetOpened || (m_ds->m_isSheetRowOpened && pos.m_anchorTo!=MWAWPosition::Cell)) {
+    MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertShape insert a picture outside a sheet is not implemented\n"));
     return;
   }
   // sanity check: avoid to send to many small pict
@@ -1063,7 +1034,7 @@ void MWAWSpreadsheetListener::insertPicture
     static bool first = true;
     if (first) {
       first = false;
-      MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertPicture: find too much small pictures, skip them from now\n"));
+      MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertShape: find too much small pictures, skip them from now\n"));
     }
     return;
   }
@@ -1079,8 +1050,10 @@ void MWAWSpreadsheetListener::insertPicture
       _openParagraph();
     break;
   case MWAWPosition::Unknown:
+#if !defined(__clang__)
   default:
-    MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertPicture: UNKNOWN position, insert as char position\n"));
+#endif
+    MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertShape: UNKNOWN position, insert as char position\n"));
   // fallthrough intended
   case MWAWPosition::CharBaseLine:
   case MWAWPosition::Char:
@@ -1089,6 +1062,7 @@ void MWAWSpreadsheetListener::insertPicture
     else
       _openSpan();
     break;
+  case MWAWPosition::Cell:
   case MWAWPosition::Frame:
     break;
   }
@@ -1101,7 +1075,7 @@ void MWAWSpreadsheetListener::insertPicture
   librevenge::RVNGPropertyList list;
   style.addTo(list, shape.getType()==MWAWGraphicShape::Line);
 
-  Vec2f decal = factor*pos.origin();
+  MWAWVec2f decal = factor*pos.origin();
   switch (shape.addTo(decal, style.hasSurface(), shapePList)) {
   case MWAWGraphicShape::C_Ellipse:
     m_documentInterface->defineGraphicStyle(list);
@@ -1125,17 +1099,17 @@ void MWAWSpreadsheetListener::insertPicture
     break;
   case MWAWGraphicShape::C_Bad:
     break;
+#if !defined(__clang__)
   default:
-    MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertPicture: unexpected shape\n"));
+    MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertShape: unexpected shape\n"));
     break;
+#endif
   }
 }
 
-void MWAWSpreadsheetListener::insertPicture
-(MWAWPosition const &pos, const librevenge::RVNGBinaryData &binaryData, std::string type,
- MWAWGraphicStyle const &style)
+void MWAWSpreadsheetListener::insertPicture(MWAWPosition const &pos, MWAWEmbeddedObject const &picture, MWAWGraphicStyle const &style)
 {
-  if (!m_ds->m_isSheetOpened || m_ds->m_isSheetRowOpened) {
+  if (!m_ds->m_isSheetOpened || (m_ds->m_isSheetRowOpened && pos.m_anchorTo!=MWAWPosition::Cell)) {
     MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::insertPicture insert a picture outside a sheet is not implemented\n"));
     return;
   }
@@ -1152,9 +1126,8 @@ void MWAWSpreadsheetListener::insertPicture
   if (!openFrame(pos, style)) return;
 
   librevenge::RVNGPropertyList propList;
-  propList.insert("librevenge:mime-type", type.c_str());
-  propList.insert("office:binary-data", binaryData);
-  m_documentInterface->insertBinaryObject(propList);
+  if (picture.addTo(propList))
+    m_documentInterface->insertBinaryObject(propList);
 
   closeFrame();
 }
@@ -1162,9 +1135,19 @@ void MWAWSpreadsheetListener::insertPicture
 ///////////////////
 // frame
 ///////////////////
+bool MWAWSpreadsheetListener::openGroup(MWAWPosition const &/*pos*/)
+{
+  MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::openGroup is not implemented\n"));
+  return false;
+}
+
+void MWAWSpreadsheetListener::closeGroup()
+{
+}
+
 bool MWAWSpreadsheetListener::openFrame(MWAWPosition const &pos, MWAWGraphicStyle const &style)
 {
-  if (!m_ds->m_isSheetOpened || m_ds->m_isSheetRowOpened) {
+  if (!m_ds->m_isSheetOpened || (m_ds->m_isSheetRowOpened && pos.m_anchorTo!=MWAWPosition::Cell)) {
     MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::openFrame insert a frame outside a sheet is not implemented\n"));
     return false;
   }
@@ -1206,9 +1189,21 @@ bool MWAWSpreadsheetListener::openFrame(MWAWPosition const &pos, MWAWGraphicStyl
       fPos.m_anchorTo=MWAWPosition::Paragraph;
     }
     break;
+  case MWAWPosition::Cell:
+    if (!m_ps->m_isSheetCellOpened) {
+      MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::openFrame: called with Cell position not in a sheet cell\n"));
+      return false;
+    }
+    if (pos.m_anchorCellName.empty()) {
+      MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::openFrame: can not find the cell name\n"));
+      return false;
+    }
+    break;
+#if !defined(__clang__)
   default:
     MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::openFrame: can not determine the anchor\n"));
     return false;
+#endif
   }
 
   librevenge::RVNGPropertyList propList;
@@ -1235,7 +1230,7 @@ void MWAWSpreadsheetListener::closeFrame()
 void MWAWSpreadsheetListener::_handleFrameParameters
 (librevenge::RVNGPropertyList &propList, MWAWPosition const &pos)
 {
-  Vec2f origin = pos.origin();
+  MWAWVec2f origin = pos.origin();
   librevenge::RVNGUnit unit = pos.unit();
   float inchFactor=pos.getInvUnitScale(librevenge::RVNG_INCH);
   float pointFactor = pos.getInvUnitScale(librevenge::RVNG_POINT);
@@ -1251,11 +1246,11 @@ void MWAWSpreadsheetListener::_handleFrameParameters
   if (pos.order() > 0)
     propList.insert("draw:z-index", pos.order());
   if (pos.naturalSize().x() > 4*pointFactor && pos.naturalSize().y() > 4*pointFactor) {
-    propList.insert("librevenge:naturalWidth", pos.naturalSize().x(), pos.unit());
-    propList.insert("librevenge:naturalHeight", pos.naturalSize().y(), pos.unit());
+    propList.insert("librevenge:naturalWidth", double(pos.naturalSize().x()), pos.unit());
+    propList.insert("librevenge:naturalHeight", double(pos.naturalSize().y()), pos.unit());
   }
-  Vec2f TLClip = (1.f/pointFactor)*pos.leftTopClipping();
-  Vec2f RBClip = (1.f/pointFactor)*pos.rightBottomClipping();
+  MWAWVec2f TLClip = (1.f/pointFactor)*pos.leftTopClipping();
+  MWAWVec2f RBClip = (1.f/pointFactor)*pos.rightBottomClipping();
   if (TLClip[0] > 0 || TLClip[1] > 0 || RBClip[0] > 0 || RBClip[1] > 0) {
     // in ODF1.2 we need to separate the value with ,
     std::stringstream s;
@@ -1274,6 +1269,10 @@ void MWAWSpreadsheetListener::_handleFrameParameters
     propList.insert("style:wrap", "run-through");
     propList.insert("style:run-through", "foreground");
   }
+  else if (pos.m_wrapping ==  MWAWPosition::WParallel) {
+    propList.insert("style:wrap", "parallel");
+    propList.insert("style:run-through", "foreground");
+  }
   else if (pos.m_wrapping ==  MWAWPosition::WRunThrough)
     propList.insert("style:wrap", "run-through");
   else
@@ -1286,29 +1285,31 @@ void MWAWSpreadsheetListener::_handleFrameParameters
     propList.insert("text:anchor-type", what.c_str());
     propList.insert("style:vertical-rel", what.c_str());
     propList.insert("style:horizontal-rel", what.c_str());
-    double w = m_ps->m_pageSpan.getPageWidth() - m_ps->m_paragraph.getMarginsWidth();
-    w *= inchFactor;
+    double w = m_ds->m_pageSpan.getPageWidth() - m_ps->m_paragraph.getMarginsWidth();
+    w *= double(inchFactor);
     switch (pos.m_xPos) {
     case MWAWPosition::XRight:
-      if (origin[0] < 0.0 || origin[0] > 0.0) {
+      if (origin[0] < 0 || origin[0] > 0) {
         propList.insert("style:horizontal-pos", "from-left");
-        propList.insert("svg:x", double(origin[0] - pos.size()[0] + w), unit);
+        propList.insert("svg:x", double(origin[0] - pos.size()[0]) + w, unit);
       }
       else
         propList.insert("style:horizontal-pos", "right");
       break;
     case MWAWPosition::XCenter:
-      if (origin[0] < 0.0 || origin[0] > 0.0) {
+      if (origin[0] < 0 || origin[0] > 0) {
         propList.insert("style:horizontal-pos", "from-left");
-        propList.insert("svg:x", double(origin[0] - pos.size()[0]/2.0 + w/2.0), unit);
+        propList.insert("svg:x", double(origin[0]) - double(pos.size()[0])/2.0 + w/2.0, unit);
       }
       else
         propList.insert("style:horizontal-pos", "center");
       break;
     case MWAWPosition::XLeft:
     case MWAWPosition::XFull:
+#if !defined(__clang__)
     default:
-      if (origin[0] < 0.0 || origin[0] > 0.0) {
+#endif
+      if (origin[0] < 0 || origin[0] > 0) {
         propList.insert("style:horizontal-pos", "from-left");
         propList.insert("svg:x", double(origin[0]), unit);
       }
@@ -1317,7 +1318,7 @@ void MWAWSpreadsheetListener::_handleFrameParameters
       break;
     }
 
-    if (origin[1] < 0.0 || origin[1] > 0.0) {
+    if (origin[1] < 0 || origin[1] > 0) {
       propList.insert("style:vertical-pos", "from-top");
       propList.insert("svg:y", double(origin[1]), unit);
     }
@@ -1330,10 +1331,10 @@ void MWAWSpreadsheetListener::_handleFrameParameters
     // Page position seems to do not use the page margin...
     propList.insert("text:anchor-type", "page");
     if (pos.page() > 0) propList.insert("text:anchor-page-number", pos.page());
-    double w = m_ps->m_pageSpan.getFormWidth();
-    double h = m_ps->m_pageSpan.getFormLength();
-    w *= inchFactor;
-    h *= inchFactor;
+    double w = m_ds->m_pageSpan.getFormWidth();
+    double h = m_ds->m_pageSpan.getFormLength();
+    w *= double(inchFactor);
+    h *= double(inchFactor);
 
     propList.insert("style:vertical-rel", "page");
     propList.insert("style:horizontal-rel", "page");
@@ -1343,39 +1344,41 @@ void MWAWSpreadsheetListener::_handleFrameParameters
       propList.insert("svg:height", double(h), unit);
     // fallthrough intended
     case MWAWPosition::YTop:
-      if (origin[1] < 0.0 || origin[1] > 0.0) {
+      if (origin[1] < 0 || origin[1] > 0) {
         propList.insert("style:vertical-pos", "from-top");
-        newPosition = origin[1];
-        if (newPosition > h -pos.size()[1])
-          newPosition = h - pos.size()[1];
+        newPosition = double(origin[1]);
+        if (newPosition > h -double(pos.size()[1]))
+          newPosition = h - double(pos.size()[1]);
         propList.insert("svg:y", double(newPosition), unit);
       }
       else
         propList.insert("style:vertical-pos", "top");
       break;
     case MWAWPosition::YCenter:
-      if (origin[1] < 0.0 || origin[1] > 0.0) {
+      if (origin[1] < 0 || origin[1] > 0) {
         propList.insert("style:vertical-pos", "from-top");
-        newPosition = (h - pos.size()[1])/2.0;
-        if (newPosition > h -pos.size()[1]) newPosition = h - pos.size()[1];
+        newPosition = (h - double(pos.size()[1]))/2.0;
+        if (newPosition > h -double(pos.size()[1])) newPosition = h - double(pos.size()[1]);
         propList.insert("svg:y", double(newPosition), unit);
       }
       else
         propList.insert("style:vertical-pos", "middle");
       break;
     case MWAWPosition::YBottom:
-      if (origin[1] < 0.0 || origin[1] > 0.0) {
+      if (origin[1] < 0 || origin[1] > 0) {
         propList.insert("style:vertical-pos", "from-top");
-        newPosition = h - pos.size()[1]-origin[1];
-        if (newPosition > h -pos.size()[1]) newPosition = h -pos.size()[1];
+        newPosition = h - double(pos.size()[1])-double(origin[1]);
+        if (newPosition > h -double(pos.size()[1])) newPosition = h -double(pos.size()[1]);
         else if (newPosition < 0) newPosition = 0;
         propList.insert("svg:y", double(newPosition), unit);
       }
       else
         propList.insert("style:vertical-pos", "bottom");
       break;
+#if !defined(__clang__)
     default:
       break;
+#endif
     }
 
     switch (pos.m_xPos) {
@@ -1383,7 +1386,7 @@ void MWAWSpreadsheetListener::_handleFrameParameters
       propList.insert("svg:width", double(w), unit);
     // fallthrough intended
     case MWAWPosition::XLeft:
-      if (origin[0] < 0.0 || origin[0] > 0.0) {
+      if (origin[0] < 0 || origin[0] > 0) {
         propList.insert("style:horizontal-pos", "from-left");
         propList.insert("svg:x", double(origin[0]), unit);
       }
@@ -1391,26 +1394,40 @@ void MWAWSpreadsheetListener::_handleFrameParameters
         propList.insert("style:horizontal-pos", "left");
       break;
     case MWAWPosition::XRight:
-      if (origin[0] < 0.0 || origin[0] > 0.0) {
+      if (origin[0] < 0 || origin[0] > 0) {
         propList.insert("style:horizontal-pos", "from-left");
-        propList.insert("svg:x",double(w - pos.size()[0] + origin[0]), unit);
+        propList.insert("svg:x",w - double(pos.size()[0]) + double(origin[0]), unit);
       }
       else
         propList.insert("style:horizontal-pos", "right");
       break;
     case MWAWPosition::XCenter:
-      if (origin[0] < 0.0 || origin[0] > 0.0) {
+      if (origin[0] < 0 || origin[0] > 0) {
         propList.insert("style:horizontal-pos", "from-left");
-        propList.insert("svg:x", double((w - pos.size()[0])/2. + origin[0]), unit);
+        propList.insert("svg:x", (w - double(pos.size()[0]))/2. + double(origin[0]), unit);
       }
       else
         propList.insert("style:horizontal-pos", "center");
       break;
+#if !defined(__clang__)
     default:
       break;
+#endif
     }
     return;
   }
+
+  if (pos.m_anchorTo == MWAWPosition::Cell) {
+    if (!pos.m_anchorCellName.empty())
+      propList.insert("table:end-cell-address", pos.m_anchorCellName);
+    // todo: implement also different m_xPos and m_yPos
+    if (origin[0] < 0 || origin[0] > 0)
+      propList.insert("svg:x", double(origin[0]), unit);
+    if (origin[1] < 0 || origin[1] > 0)
+      propList.insert("svg:y", double(origin[1]), unit);
+    return;
+  }
+
   if (pos.m_anchorTo != MWAWPosition::Char &&
       pos.m_anchorTo != MWAWPosition::CharBaseLine &&
       pos.m_anchorTo != MWAWPosition::Unknown) return;
@@ -1423,7 +1440,7 @@ void MWAWSpreadsheetListener::_handleFrameParameters
   switch (pos.m_yPos) {
   case MWAWPosition::YFull:
   case MWAWPosition::YTop:
-    if (origin[1] < 0.0 || origin[1] > 0.0) {
+    if (origin[1] < 0 || origin[1] > 0) {
       propList.insert("style:vertical-pos", "from-top");
       propList.insert("svg:y", double(origin[1]), unit);
     }
@@ -1431,16 +1448,18 @@ void MWAWSpreadsheetListener::_handleFrameParameters
       propList.insert("style:vertical-pos", "top");
     break;
   case MWAWPosition::YCenter:
-    if (origin[1] < 0.0 || origin[1] > 0.0) {
+    if (origin[1] < 0 || origin[1] > 0) {
       propList.insert("style:vertical-pos", "from-top");
-      propList.insert("svg:y", double(origin[1] - pos.size()[1]/2.0), unit);
+      propList.insert("svg:y", double(origin[1] - pos.size()[1]/2.0f), unit);
     }
     else
       propList.insert("style:vertical-pos", "middle");
     break;
   case MWAWPosition::YBottom:
+#if !defined(__clang__)
   default:
-    if (origin[1] < 0.0 || origin[1] > 0.0) {
+#endif
+    if (origin[1] < 0 || origin[1] > 0) {
       propList.insert("style:vertical-pos", "from-top");
       propList.insert("svg:y", double(origin[1] - pos.size()[1]), unit);
     }
@@ -1465,7 +1484,7 @@ void MWAWSpreadsheetListener::handleSubDocument(MWAWSubDocumentPtr subDocument,
   switch (subDocumentType) {
   case libmwaw::DOC_TEXT_BOX:
     m_ps->m_isTextboxOpened = true;
-    m_ps->m_pageSpan.setMargins(0.0);
+    m_ds->m_pageSpan.setMargins(0.0);
     break;
   case libmwaw::DOC_HEADER_FOOTER:
     m_ps->m_isHeaderFooterWithoutParagraph = true;
@@ -1481,7 +1500,9 @@ void MWAWSpreadsheetListener::handleSubDocument(MWAWSubDocumentPtr subDocument,
   case libmwaw::DOC_TABLE:
   case libmwaw::DOC_COMMENT_ANNOTATION:
   case libmwaw::DOC_GRAPHIC_GROUP:
+#if !defined(__clang__)
   default:
+#endif
     break;
   }
 
@@ -1546,7 +1567,8 @@ void MWAWSpreadsheetListener::_endSubDocument()
 ///////////////////
 // sheet
 ///////////////////
-void MWAWSpreadsheetListener::openSheet(std::vector<float> const &colWidth, librevenge::RVNGUnit unit, std::string const &name)
+void MWAWSpreadsheetListener::openSheet(std::vector<float> const &colWidth, librevenge::RVNGUnit unit,
+                                        std::vector<int> const &repeatColWidthNumber, std::string const &name)
 {
   if (m_ds->m_isSheetOpened) {
     MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::openSheet: called with m_isSheetOpened=true\n"));
@@ -1565,9 +1587,15 @@ void MWAWSpreadsheetListener::openSheet(std::vector<float> const &colWidth, libr
   librevenge::RVNGPropertyList propList;
   librevenge::RVNGPropertyListVector columns;
   size_t nCols = colWidth.size();
+  bool useRepeated=repeatColWidthNumber.size()==nCols;
+  if (!useRepeated&&!repeatColWidthNumber.empty()) {
+    MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::openSheet: repeatColWidthNumber seems bad\n"));
+  }
   for (size_t c = 0; c < nCols; c++) {
     librevenge::RVNGPropertyList column;
-    column.insert("style:column-width", colWidth[c], unit);
+    column.insert("style:column-width", double(colWidth[c]), unit);
+    if (useRepeated && repeatColWidthNumber[c]>1)
+      column.insert("table:number-columns-repeated", repeatColWidthNumber[c]);
     columns.append(column);
   }
   propList.insert("librevenge:columns", columns);
@@ -1590,7 +1618,7 @@ void MWAWSpreadsheetListener::closeSheet()
   _popParsingState();
 }
 
-void MWAWSpreadsheetListener::openSheetRow(float h, librevenge::RVNGUnit unit)
+void MWAWSpreadsheetListener::openSheetRow(float h, librevenge::RVNGUnit unit, int numRepeated)
 {
   if (m_ds->m_isSheetRowOpened) {
     MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::openSheetRow: called with m_isSheetRowOpened=true\n"));
@@ -1602,9 +1630,11 @@ void MWAWSpreadsheetListener::openSheetRow(float h, librevenge::RVNGUnit unit)
   }
   librevenge::RVNGPropertyList propList;
   if (h > 0)
-    propList.insert("style:row-height", h, unit);
+    propList.insert("style:row-height", double(h), unit);
   else if (h < 0)
-    propList.insert("style:min-row-height", -h, unit);
+    propList.insert("style:min-row-height", double(-h), unit);
+  if (numRepeated>1)
+    propList.insert("table:number-rows-repeated", numRepeated);
   m_documentInterface->openSheetRow(propList);
   m_ds->m_isSheetRowOpened = true;
 }
@@ -1619,7 +1649,7 @@ void MWAWSpreadsheetListener::closeSheetRow()
   m_documentInterface->closeSheetRow();
 }
 
-void MWAWSpreadsheetListener::openSheetCell(MWAWCell const &cell, MWAWCellContent const &content)
+void MWAWSpreadsheetListener::openSheetCell(MWAWCell const &cell, MWAWCellContent const &content, int numRepeated)
 {
   if (!m_ds->m_isSheetRowOpened) {
     MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::openSheetCell: called with m_isSheetRowOpened=false\n"));
@@ -1632,6 +1662,8 @@ void MWAWSpreadsheetListener::openSheetCell(MWAWCell const &cell, MWAWCellConten
 
   librevenge::RVNGPropertyList propList;
   cell.addTo(propList, m_parserState.m_fontConverter);
+  if (numRepeated>1)
+    propList.insert("table:number-columns-repeated", numRepeated);
   MWAWCell::Format const &format=cell.getFormat();
   if (!format.hasBasicFormat()) {
     int numberingId=-1;
@@ -1641,7 +1673,7 @@ void MWAWSpreadsheetListener::openSheetCell(MWAWCell const &cell, MWAWCellConten
       name << "Numbering" << numberingId;
     }
     else {
-      numberingId=(int) m_ds->m_numberingIdMap.size();
+      numberingId=static_cast<int>(m_ds->m_numberingIdMap.size());
       name << "Numbering" << numberingId;
 
       librevenge::RVNGPropertyList numList;
@@ -1660,7 +1692,7 @@ void MWAWSpreadsheetListener::openSheetCell(MWAWCell const &cell, MWAWCellConten
   if (content.m_formula.size()) {
     librevenge::RVNGPropertyListVector formulaVect;
     for (size_t i=0; i < content.m_formula.size(); ++i)
-      formulaVect.append(content.m_formula[i].getPropertyList());
+      formulaVect.append(content.m_formula[i].getPropertyList(*m_parserState.m_fontConverter, m_ps->m_font.id()));
     propList.insert("librevenge:formula", formulaVect);
   }
   bool hasFormula=!content.m_formula.empty();
@@ -1710,8 +1742,10 @@ void MWAWSpreadsheetListener::openSheetCell(MWAWCell const &cell, MWAWCellConten
       propList.insert("librevenge:value-type", format.getValueType().c_str());
       propList.insert("librevenge:value", content.m_value, librevenge::RVNG_GENERIC);
       break;
+#if !defined(__clang__)
     default:
       break;
+#endif
     }
   }
 
@@ -1840,9 +1874,9 @@ void MWAWSpreadsheetListener::openTableRow(float h, librevenge::RVNGUnit unit, b
   propList.insert("librevenge:is-header-row", headerRow);
 
   if (h > 0)
-    propList.insert("style:row-height", h, unit);
+    propList.insert("style:row-height", double(h), unit);
   else if (h < 0)
-    propList.insert("style:min-row-height", -h, unit);
+    propList.insert("style:min-row-height", double(-h), unit);
   m_documentInterface->openTableRow(propList);
   m_ps->m_isTableRowOpened = true;
 }
@@ -1857,7 +1891,7 @@ void MWAWSpreadsheetListener::closeTableRow()
   m_documentInterface->closeTableRow();
 }
 
-void MWAWSpreadsheetListener::addEmptyTableCell(Vec2i const &pos, Vec2i span)
+void MWAWSpreadsheetListener::addEmptyTableCell(MWAWVec2i const &pos, MWAWVec2i span)
 {
   if (!m_ps->m_isTableRowOpened) {
     MWAW_DEBUG_MSG(("MWAWSpreadsheetListener::addEmptyTableCell: called with m_isTableRowOpened=false\n"));
@@ -1919,9 +1953,6 @@ shared_ptr<MWAWSpreadsheetListenerInternal::State> MWAWSpreadsheetListener::_pus
   m_psStack.push_back(actual);
   m_ps.reset(new MWAWSpreadsheetListenerInternal::State);
 
-  // BEGIN: copy page properties into the new parsing state
-  m_ps->m_pageSpan = actual->m_pageSpan;
-
   m_ps->m_isNote = actual->m_isNote;
 
   return actual;
