@@ -127,17 +127,19 @@ void MWAWTable::addTablePropertiesTo(librevenge::RVNGPropertyList &propList) con
     break;
   case Left:
     propList.insert("table:align", "left");
-    propList.insert("fo:margin-left", m_leftMargin, librevenge::RVNG_POINT);
+    propList.insert("fo:margin-left", double(m_leftMargin), librevenge::RVNG_POINT);
     break;
   case Center:
     propList.insert("table:align", "center");
     break;
   case Right:
     propList.insert("table:align", "right");
-    propList.insert("fo:margin-right", m_rightMargin, librevenge::RVNG_POINT);
+    propList.insert("fo:margin-right", double(m_rightMargin), librevenge::RVNG_POINT);
     break;
+#if !defined(__clang__)
   default:
     break;
+#endif
   }
   if (mergeBorders())
     propList.insert("table:border-model","collapsing");
@@ -147,11 +149,11 @@ void MWAWTable::addTablePropertiesTo(librevenge::RVNGPropertyList &propList) con
   librevenge::RVNGPropertyListVector columns;
   for (size_t c = 0; c < nCols; ++c) {
     librevenge::RVNGPropertyList column;
-    column.insert("style:column-width", m_colsSize[c], librevenge::RVNG_POINT);
+    column.insert("style:column-width", double(m_colsSize[c]), librevenge::RVNG_POINT);
     columns.append(column);
     tableWidth += m_colsSize[c];
   }
-  propList.insert("style:width", tableWidth, librevenge::RVNG_POINT);
+  propList.insert("style:width", double(tableWidth), librevenge::RVNG_POINT);
   propList.insert("librevenge:table-columns", columns);
 }
 
@@ -169,13 +171,13 @@ void MWAWTable::sendExtraLines(MWAWListenerPtr listener) const
   rowsPos[0] = 0;
   for (size_t r = 0; r < nRows; ++r)
     rowsPos[r+1] = rowsPos[r]+
-                   (float)(m_rowsSize[r]<0?-m_rowsSize[r]:m_rowsSize[r]);
+                   float(m_rowsSize[r]<0?-m_rowsSize[r]:m_rowsSize[r]);
   size_t nColumns = m_colsSize.size();
   columnsPos.resize(nColumns+1);
   columnsPos[0] = 0;
   for (size_t c = 0; c < nColumns; ++c)
     columnsPos[c+1] = columnsPos[c]+
-                      (float)(m_colsSize[c]<0?-m_colsSize[c]:m_colsSize[c]);
+                      float(m_colsSize[c]<0?-m_colsSize[c]:m_colsSize[c]);
 
   for (size_t c = 0; c < m_cellsList.size(); ++c) {
     if (!m_cellsList[c]) continue;
@@ -184,8 +186,8 @@ void MWAWTable::sendExtraLines(MWAWListenerPtr listener) const
       continue;
     MWAWVec2i const &pos=m_cellsList[c]->position();
     MWAWVec2i const &span=m_cellsList[c]->numSpannedCells();
-    if (span[0] <= 0 || span[1] <= 0 || pos[0]+span[0] > (int)nColumns ||
-        pos[1]+span[1] > (int) nRows)
+    if (span[0] <= 0 || span[1] <= 0 || pos[0]+span[0] > static_cast<int>(nColumns) ||
+        pos[1]+span[1] > static_cast<int>(nRows))
       continue;
     MWAWBox2f box;
     box.setMin(MWAWVec2f(columnsPos[size_t(pos[0])], rowsPos[size_t(pos[1])]));
@@ -194,7 +196,7 @@ void MWAWTable::sendExtraLines(MWAWListenerPtr listener) const
 
     MWAWBorder const &border=cell.extraLineType();
     MWAWGraphicStyle pStyle;
-    pStyle.m_lineWidth=(float)border.m_width;
+    pStyle.m_lineWidth=float(border.m_width);
     pStyle.m_lineColor=border.m_color;
 
     MWAWPosition lPos(box[0], box.size(), librevenge::RVNG_POINT);
@@ -240,10 +242,10 @@ bool MWAWTable::buildStructures()
       if (actCell < 0 || pos > maxPosiblePos) {
         actCell++;
         positions.push_back(pos);
-        maxPosiblePos = float(pos+2.0); // 2 pixel ok
+        maxPosiblePos = pos+2.0f; // 2 pixel ok
       }
-      if (it->m_which == 0 && it->getPos(dim)-2.0 < maxPosiblePos)
-        maxPosiblePos = float((it->getPos(dim)+pos)/2.);
+      if (it->m_which == 0 && it->getPos(dim)-2.0f < maxPosiblePos)
+        maxPosiblePos = (it->getPos(dim)+pos)/2.f;
     }
     listPositions[dim] = positions;
   }
