@@ -167,7 +167,9 @@ std::ostream &operator<<(std::ostream &o, Information const &info)
     o << "pageBreak,";
     break;
   case Information::UNKNOWN:
+#if !defined(__clang__)
   default:
+#endif
     o << "###unknownType,";
     break;
   }
@@ -191,9 +193,11 @@ std::ostream &operator<<(std::ostream &o, Information const &info)
     case MWAWParagraph::JustificationFullAllLines:
       o << "fullAllLines[justify],";
       break;
+#if !defined(__clang__)
     default:
       o << "###unknown[justify],";
       break;
+#endif
     }
   }
   if (info.m_data.begin() > 0)
@@ -229,7 +233,9 @@ struct WindowsInfo {
       case Information::RULER:
       case Information::PAGEBREAK:
       case Information::UNKNOWN:
+#if !defined(__clang__)
       default:
+#endif
         break;
       }
     }
@@ -238,11 +244,11 @@ struct WindowsInfo {
 
   friend std::ostream &operator<<(std::ostream &o, WindowsInfo const &w);
 
-  Vec2i m_startSel, m_endSel; // start end selection (parag, char)
+  MWAWVec2i m_startSel, m_endSel; // start end selection (parag, char)
   int m_posTopY;
   std::vector<Information> m_informations;
   std::vector<int> m_firstParagLine, m_linesHeight;
-  Vec2i m_pageNumber, m_date, m_time;
+  MWAWVec2i m_pageNumber, m_date, m_time;
 };
 
 std::ostream &operator<<(std::ostream &o, WindowsInfo const &w)
@@ -316,11 +322,14 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
     MWAW_DEBUG_MSG(("MacWrtParserInternal::SubDocument::parse: unknown zone\n"));
     return;
   }
-
-  assert(m_parser);
+  MacWrtParser *parser=dynamic_cast<MacWrtParser *>(m_parser);
+  if (!parser) {
+    MWAW_DEBUG_MSG(("MacWrtParserInternal::SubDocument::parse: no parser\n"));
+    return;
+  }
 
   long pos = m_input->tell();
-  static_cast<MacWrtParser *>(m_parser)->sendWindow(m_id);
+  parser->sendWindow(m_id);
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
 }
 
@@ -334,7 +343,6 @@ bool SubDocument::operator!=(MWAWSubDocument const &doc) const
 }
 }
 
-
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
@@ -380,9 +388,7 @@ void MacWrtParser::newPage(int number)
 ////////////////////////////////////////////////////////////
 void MacWrtParser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  assert(getInput().get() != 0);
-
-  if (!checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(0L))  throw(libmwaw::ParseException());
   bool ok = true;
   try {
     // create the asciiFile
@@ -570,8 +576,8 @@ bool MacWrtParser::createZonesV3()
     MacWrtParserInternal::WindowsInfo &wInfo = m_state->m_windows[z];
     for (int p = 0; p < numParag; p++) {
       pos = input->tell();
-      int type = (int) input->readLong(2);
-      int sz = (int) input->readLong(2);
+      int type = static_cast<int>(input->readLong(2));
+      int sz = static_cast<int>(input->readLong(2));
       input->seek(pos+4+sz, librevenge::RVNG_SEEK_SET);
       if (sz < 0 || long(input->tell()) !=  pos+4+sz) {
         MWAW_DEBUG_MSG(("MacWrtParser::createZonesV3: pb with dataZone\n"));
@@ -582,7 +588,7 @@ bool MacWrtParser::createZonesV3()
       entry.setLength(sz);
       if (int(wInfo.m_informations.size()) <= p)
         continue;
-      wInfo.m_informations[(size_t)p].m_data = entry;
+      wInfo.m_informations[size_t(p)].m_data = entry;
       MacWrtParserInternal::Information::Type newType =
         MacWrtParserInternal::Information::UNKNOWN;
 
@@ -599,10 +605,10 @@ bool MacWrtParser::createZonesV3()
       default:
         break;
       }
-      if (newType != wInfo.m_informations[(size_t)p].m_type) {
+      if (newType != wInfo.m_informations[size_t(p)].m_type) {
         MWAW_DEBUG_MSG(("MacWrtParser::createZonesV3: types are inconstant\n"));
         if (newType != MacWrtParserInternal::Information::UNKNOWN)
-          wInfo.m_informations[(size_t)p].m_type = newType;
+          wInfo.m_informations[size_t(p)].m_type = newType;
       }
     }
   }
@@ -624,7 +630,7 @@ bool MacWrtParser::createZonesV3()
 bool MacWrtParser::sendWindow(int zone)
 {
   if (zone < 0 || zone >= 3) {
-    MWAW_DEBUG_MSG(("MacWrtParser::sendZone: invalid zone %d\n", zone));
+    MWAW_DEBUG_MSG(("MacWrtParser::sendWindow: invalid zone %d\n", zone));
     return false;
   }
 
@@ -645,7 +651,7 @@ bool MacWrtParser::sendWindow(int zone)
           int firstLine = info.m_firstParagLine[i];
           int lastLine = (int(i+1) < numPara) ?  info.m_firstParagLine[i+1] : int(info.m_linesHeight.size());
           for (int line = firstLine; line < lastLine; line++)
-            lineHeight.push_back(info.m_linesHeight[(size_t)line]);
+            lineHeight.push_back(info.m_linesHeight[size_t(line)]);
         }
         readText(info.m_informations[i], lineHeight);
       }
@@ -662,7 +668,9 @@ bool MacWrtParser::sendWindow(int zone)
         newPage(info.m_informations[i].m_pos.page()+2);
       break;
     case MacWrtParserInternal::Information::UNKNOWN:
+#if !defined(__clang__)
     default:
+#endif
       break;
     }
   }
@@ -704,7 +712,7 @@ bool MacWrtParser::checkHeader(MWAWHeader *header, bool /*strict*/)
   }
   input->seek(0,librevenge::RVNG_SEEK_SET);
 
-  int vers = (int) input->readULong(2);
+  int vers = static_cast<int>(input->readULong(2));
   setVersion(vers);
 
   std::string vName("");
@@ -713,15 +721,6 @@ bool MacWrtParser::checkHeader(MWAWHeader *header, bool /*strict*/)
   case 3:
     vName="v1.0-2.2";
     break;
-  case 1:
-  case 2:
-  case 4:
-  case 5:
-  case 7:
-#ifndef DEBUG
-    return false;
-#endif
-    break;
   case 6: // version 4.5 ( also version 5.01 of Claris MacWrite )
     vName="v4.5-5.01";
     break;
@@ -738,10 +737,10 @@ bool MacWrtParser::checkHeader(MWAWHeader *header, bool /*strict*/)
 
   f << "FileHeader: vers=" << vers << ",";
 
-  if (vers <= 3) fHeader.m_dataPos = (int) input->readULong(2);
+  if (vers <= 3) fHeader.m_dataPos = static_cast<int>(input->readULong(2));
 
   for (int i = 0; i < 3; i++) {
-    int numParag = (int) input->readLong(2);
+    int numParag = static_cast<int>(input->readLong(2));
     fHeader.m_numParagraphs[i] = numParag;
     if (numParag < 0) {
       MWAW_DEBUG_MSG(("MacWrtParser::checkHeader: numParagraphs is negative : %d\n",
@@ -754,17 +753,17 @@ bool MacWrtParser::checkHeader(MWAWHeader *header, bool /*strict*/)
     input->seek(6, librevenge::RVNG_SEEK_CUR); // unknown
     if (input->readLong(1)) f << "hasFooter(?);";
     if (input->readLong(1)) f << "hasHeader(?),";
-    fHeader.m_startNumberPage = (int) input->readLong(2);
+    fHeader.m_startNumberPage = static_cast<int>(input->readLong(2));
     headerSize=20;
   }
   else {
     fHeader.m_hideFirstPageHeaderFooter = (input->readULong(1)==0xFF);
 
     input->seek(7, librevenge::RVNG_SEEK_CUR); // unused + 4 display flags + active doc
-    fHeader.m_startNumberPage = (int) input->readLong(2);
-    fHeader.m_freeListPos = (long) input->readULong(4);
-    fHeader.m_freeListLength = (int) input->readULong(2);
-    fHeader.m_freeListAllocated = (int) input->readULong(2);
+    fHeader.m_startNumberPage = static_cast<int>(input->readLong(2));
+    fHeader.m_freeListPos = long(input->readULong(4));
+    fHeader.m_freeListLength = static_cast<int>(input->readULong(2));
+    fHeader.m_freeListAllocated = static_cast<int>(input->readULong(2));
     // 14 unused
   }
   f << fHeader;
@@ -772,6 +771,9 @@ bool MacWrtParser::checkHeader(MWAWHeader *header, bool /*strict*/)
   //
   input->seek(headerSize, librevenge::RVNG_SEEK_SET);
   if (!readPrintInfo()) {
+    input->seek(headerSize, librevenge::RVNG_SEEK_SET);
+    for (int i=0; i<10; ++i) // allow print info to be zero
+      if (input->readLong(2)) return false;
     input->seek(headerSize+0x78, librevenge::RVNG_SEEK_SET);
     for (int i=0; i<3; ++i)
       if (!readWindowsInfo(i) && i==2) return false;
@@ -806,20 +808,20 @@ bool MacWrtParser::readPrintInfo()
   if (!info.read(input)) return false;
   f << "Entries(PrintInfo):"<< info;
 
-  Vec2i paperSize = info.paper().size();
-  Vec2i pageSize = info.page().size();
+  MWAWVec2i paperSize = info.paper().size();
+  MWAWVec2i pageSize = info.page().size();
   if (pageSize.x() <= 0 || pageSize.y() <= 0 ||
       paperSize.x() <= 0 || paperSize.y() <= 0) return false;
 
   // define margin from print info
-  Vec2i lTopMargin= -1 * info.paper().pos(0);
-  Vec2i rBotMargin=info.paper().pos(1) - info.page().pos(1);
+  MWAWVec2i lTopMargin= -1 * info.paper().pos(0);
+  MWAWVec2i rBotMargin=info.paper().pos(1) - info.page().pos(1);
 
   // move margin left | top
   int decalX = lTopMargin.x() > 14 ? lTopMargin.x()-14 : 0;
   int decalY = lTopMargin.y() > 14 ? lTopMargin.y()-14 : 0;
-  lTopMargin -= Vec2i(decalX, decalY);
-  rBotMargin += Vec2i(decalX, decalY);
+  lTopMargin -= MWAWVec2i(decalX, decalY);
+  rBotMargin += MWAWVec2i(decalX, decalY);
 
   // decrease right | bottom
   int rightMarg = rBotMargin.x() -10;
@@ -886,27 +888,27 @@ bool MacWrtParser::readWindowsInfo(int wh)
   MWAWEntry lineHeightEntry;
 
   for (int i = 0; i < 2; i++) {
-    int x = (int) input->readLong(2);
-    int y = (int) input->readLong(2);
-    if (i == 0) info.m_startSel = Vec2i(x,y);
-    else info.m_endSel = Vec2i(x,y);
+    int x = static_cast<int>(input->readLong(2));
+    int y = static_cast<int>(input->readLong(2));
+    if (i == 0) info.m_startSel = MWAWVec2i(x,y);
+    else info.m_endSel = MWAWVec2i(x,y);
   }
 
   if (version() <= 3) {
     for (int i = 0; i < 2; i++) {
-      int val = (int) input->readLong(2);
+      int val = static_cast<int>(input->readLong(2));
       if (val) f << "unkn" << i << "=" << val << ",";
     }
   }
   else {
-    info.m_posTopY = (int) input->readLong(2);
+    info.m_posTopY = static_cast<int>(input->readLong(2));
     input->seek(2,librevenge::RVNG_SEEK_CUR); // need to redraw
-    informations.setBegin((long) input->readULong(4));
-    informations.setLength((long) input->readULong(2));
+    informations.setBegin(long(input->readULong(4)));
+    informations.setLength(long(input->readULong(2)));
     informations.setId(which);
 
-    lineHeightEntry.setBegin((long) input->readULong(4));
-    lineHeightEntry.setLength((long) input->readULong(2));
+    lineHeightEntry.setBegin(long(input->readULong(4)));
+    lineHeightEntry.setLength(long(input->readULong(2)));
     lineHeightEntry.setId(which);
 
     f << std::hex
@@ -915,11 +917,11 @@ bool MacWrtParser::readWindowsInfo(int wh)
       << std::dec;
   }
   for (int i = 0; i < 3; i++) {
-    int x = (int) input->readLong(2);
-    int y = (int) input->readLong(2);
-    if (i == 0) info.m_pageNumber = Vec2i(x,y);
-    else if (i == 1) info.m_date = Vec2i(x,y);
-    else info.m_time = Vec2i(x,y);
+    int x = static_cast<int>(input->readLong(2));
+    int y = static_cast<int>(input->readLong(2));
+    if (i == 0) info.m_pageNumber = MWAWVec2i(x,y);
+    else if (i == 1) info.m_date = MWAWVec2i(x,y);
+    else info.m_time = MWAWVec2i(x,y);
   }
   f << info;
   bool ok=true;
@@ -927,7 +929,7 @@ bool MacWrtParser::readWindowsInfo(int wh)
     input->seek(6,librevenge::RVNG_SEEK_CUR); // unknown flags: ff ff ff ff ff 00
     f << "actFont=" << input->readLong(1) << ",";
     for (int i= 0; i < 2; i++) {
-      int val = (int) input->readULong(1);
+      int val = static_cast<int>(input->readULong(1));
       if (val==255) f << "f" << i << "=true,";
     }
     f << "flg=" << input->readLong(1);
@@ -981,7 +983,7 @@ bool MacWrtParser::readLinesHeight(MWAWEntry const &entry, std::vector<int> &fir
   int numParag=0;
   while (input->tell() != endPos) {
     pos = input->tell();
-    int sz = (int) input->readULong(2);
+    int sz = static_cast<int>(input->readULong(2));
     if (pos+sz+2 > endPos) {
       MWAW_DEBUG_MSG(("MacWrtParser::readLinesHeight: find odd line\n"));
       return false;
@@ -993,7 +995,7 @@ bool MacWrtParser::readLinesHeight(MWAWEntry const &entry, std::vector<int> &fir
     f.str("");
     f << "Entries(LineHeight)[" << entry.id() << "-" << ++numParag << "]:";
     for (int c = 0; c < sz; c++) {
-      int val = (int) input->readULong(1);
+      int val = static_cast<int>(input->readULong(1));
       if (val & 0x80) {
         val &= 0x7f;
         if (!heightOk || val==0) {
@@ -1038,15 +1040,14 @@ bool MacWrtParser::readInformationsV3(int numEntries, std::vector<MacWrtParserIn
   if (numEntries == 0) return true;
 
   MWAWInputStreamPtr input = getInput();
-  long pos = input->tell();
 
   libmwaw::DebugStream f;
   for (int i = 0; i < numEntries; i++) {
-    pos = input->tell();
+    long pos = input->tell();
     MacWrtParserInternal::Information info;
     f.str("");
     f << "Entries(Information)[" << i+1 << "]:";
-    int height = (int) input->readLong(2);
+    int height = static_cast<int>(input->readLong(2));
     info.m_height = height;
     if (info.m_height < 0) {
       info.m_height = 0;
@@ -1057,9 +1058,9 @@ bool MacWrtParser::readInformationsV3(int numEntries, std::vector<MacWrtParserIn
     else
       info.m_type = MacWrtParserInternal::Information::RULER;
 
-    int y = (int) input->readLong(2);
-    info.m_pos=MWAWPosition(Vec2f(0,float(y)), Vec2f(0, float(height)), librevenge::RVNG_POINT);
-    info.m_pos.setPage((int) input->readLong(1));
+    int y = static_cast<int>(input->readLong(2));
+    info.m_pos=MWAWPosition(MWAWVec2f(0,float(y)), MWAWVec2f(0, float(height)), librevenge::RVNG_POINT);
+    info.m_pos.setPage(static_cast<int>(input->readLong(1)));
     f << info;
     informations.push_back(info);
 
@@ -1106,7 +1107,7 @@ bool MacWrtParser::readInformations(MWAWEntry const &entry, std::vector<MacWrtPa
     f.str("");
     f << "Entries(Information)[" << entry.id() << "-" << i+1 << "]:";
     MacWrtParserInternal::Information info;
-    int height = (int) input->readLong(2);
+    int height = static_cast<int>(input->readLong(2));
     if (height < 0) {
       info.m_type = MacWrtParserInternal::Information::GRAPHIC;
       height *= -1;
@@ -1117,13 +1118,13 @@ bool MacWrtParser::readInformations(MWAWEntry const &entry, std::vector<MacWrtPa
       info.m_type = MacWrtParserInternal::Information::TEXT;
     info.m_height = height;
 
-    int y = (int) input->readLong(2);
-    int page = (int) input->readULong(1);
+    int y = static_cast<int>(input->readLong(2));
+    int page = static_cast<int>(input->readULong(1));
     input->seek(3, librevenge::RVNG_SEEK_CUR); // unused
-    info.m_pos = MWAWPosition(Vec2f(0,float(y)), Vec2f(0, float(height)), librevenge::RVNG_POINT);
+    info.m_pos = MWAWPosition(MWAWVec2f(0,float(y)), MWAWVec2f(0, float(height)), librevenge::RVNG_POINT);
     info.m_pos.setPage(page);
 
-    int paragStatus = (int) input->readULong(1);
+    int paragStatus = static_cast<int>(input->readULong(1));
     switch (paragStatus & 0x3) {
     case 0:
       info.m_justify = MWAWParagraph::JustificationLeft;
@@ -1144,11 +1145,11 @@ bool MacWrtParser::readInformations(MWAWEntry const &entry, std::vector<MacWrtPa
     info.m_justifySet = (paragStatus & 0x20);
 
     // other bits used internally
-    unsigned int highPos = (unsigned int) input->readULong(1);
-    info.m_data.setBegin(long(highPos<<16)+(long)input->readULong(2));
-    info.m_data.setLength((long)input->readULong(2));
+    unsigned int highPos = static_cast<unsigned int>(input->readULong(1));
+    info.m_data.setBegin(long(highPos<<16)+long(input->readULong(2)));
+    info.m_data.setLength(long(input->readULong(2)));
 
-    int paragFormat = (int) input->readULong(2);
+    int paragFormat = static_cast<int>(input->readULong(2));
     uint32_t flags = 0;
     // bit 1 = plain
     if (paragFormat&0x2) flags |= MWAWFont::boldBit;
@@ -1232,7 +1233,7 @@ bool MacWrtParser::readText(MacWrtParserInternal::Information const &info,
   libmwaw::DebugStream f;
   f << "Entries(Text):";
 
-  int numChar = (int) input->readULong(2);
+  int numChar = static_cast<int>(input->readULong(2));
   std::string text("");
   if (!info.m_compressed) {
     if (numChar+2 >= entry.length()) {
@@ -1240,7 +1241,7 @@ bool MacWrtParser::readText(MacWrtParserInternal::Information const &info,
       return false;
     }
     for (int i = 0; i < numChar; i++)
-      text += (char) input->readULong(1);
+      text += char(input->readULong(1));
   }
   else {
     std::string compressCorr = m_state->m_compressCorr;
@@ -1257,7 +1258,7 @@ bool MacWrtParser::readText(MacWrtParserInternal::Information const &info,
             MWAW_DEBUG_MSG(("MacWrtParser::readText: text is too long\n"));
             return false;
           }
-          actualChar = (int) input->readULong(1);
+          actualChar = static_cast<int>(input->readULong(1));
           actVal = (actualChar >> 4);
         }
         else
@@ -1265,14 +1266,14 @@ bool MacWrtParser::readText(MacWrtParserInternal::Information const &info,
         actualCharSet = !actualCharSet;
         if (st == 0) {
           if (actVal == 0xf) continue;
-          text += compressCorr[(size_t) actVal];
+          text += compressCorr[size_t(actVal)];
           break;
         }
         if (st == 1) { // high bytes
           highByte = (actVal<<4);
           continue;
         }
-        text += (char)(highByte | actVal);
+        text += char(highByte | actVal);
       }
     }
   }
@@ -1284,7 +1285,7 @@ bool MacWrtParser::readText(MacWrtParserInternal::Information const &info,
     actPos++;
   }
 
-  int formatSize = (int) input->readULong(2);
+  int formatSize = static_cast<int>(input->readULong(2));
   if ((formatSize%6)!=0 || actPos+2+formatSize > entry.end()) {
     MWAW_DEBUG_MSG(("MacWrtParser::readText: format is too long\n"));
     return false;
@@ -1295,11 +1296,11 @@ bool MacWrtParser::readText(MacWrtParserInternal::Information const &info,
   std::vector<MWAWFont> listFonts;
 
   for (int i = 0; i < numFormat; i++) {
-    int tPos = (int) input->readULong(2);
+    int tPos = static_cast<int>(input->readULong(2));
 
     MWAWFont font;
-    font.setSize((float)input->readULong(1));
-    int flag = (int) input->readULong(1);
+    font.setSize(float(input->readULong(1)));
+    int flag = static_cast<int>(input->readULong(1));
     uint32_t flags = 0;
     // bit 1 = plain
     if (flag&0x1) flags |= MWAWFont::boldBit;
@@ -1310,7 +1311,7 @@ bool MacWrtParser::readText(MacWrtParserInternal::Information const &info,
     if (flag&0x20) font.set(MWAWFont::Script::super100());
     if (flag&0x40) font.set(MWAWFont::Script::sub100());
     font.setFlags(flags);
-    font.setId((int) input->readULong(2));
+    font.setId(static_cast<int>(input->readULong(2)));
     listPos.push_back(tPos);
     listFonts.push_back(font);
     f << ",f" << i << "=[pos=" << tPos;
@@ -1360,11 +1361,11 @@ bool MacWrtParser::readText(MacWrtParserInternal::Information const &info,
     int actFormat = 0;
     numChar = int(text.length());
     for (int i = 0; i < numChar; i++) {
-      if (actFormat < numFormat && i == listPos[(size_t)actFormat]) {
-        getTextListener()->setFont(listFonts[(size_t)actFormat]);
+      if (actFormat < numFormat && i == listPos[size_t(actFormat)]) {
+        getTextListener()->setFont(listFonts[size_t(actFormat)]);
         actFormat++;
       }
-      unsigned char c = (unsigned char) text[(size_t)i];
+      unsigned char c = static_cast<unsigned char>(text[size_t(i)]);
       if (c == 0x9)
         getTextListener()->insertTab();
       else if (c == 0xd)
@@ -1407,9 +1408,9 @@ bool MacWrtParser::readParagraph(MacWrtParserInternal::Information const &info)
   libmwaw::DebugStream f;
   f << "Entries(Paragraph):";
 
-  parag.m_margins[1] = float(input->readLong(2))/80.f;
-  parag.m_margins[2] = float(input->readLong(2))/80.f;
-  int justify = (int) input->readLong(1);
+  parag.m_margins[1] = double(input->readLong(2))/80.;
+  parag.m_margins[2] = double(input->readLong(2))/80.;
+  int justify = static_cast<int>(input->readLong(1));
   switch (justify) {
   case 0:
     parag.m_justify = MWAWParagraph::JustificationLeft;
@@ -1427,28 +1428,28 @@ bool MacWrtParser::readParagraph(MacWrtParserInternal::Information const &info)
     f << "##justify=" << justify << ",";
     break;
   }
-  int numTabs = (int) input->readLong(1);
+  int numTabs = static_cast<int>(input->readLong(1));
   if (numTabs < 0 || numTabs > 10) {
     f << "##numTabs=" << numTabs << ",";
     numTabs = 0;
   }
-  int highspacing = (int) input->readULong(1);
+  int highspacing = static_cast<int>(input->readULong(1));
   if (highspacing==0x80) // 6 by line
     parag.setInterline(12, librevenge::RVNG_POINT);
   else if (highspacing) {
     f << "##highSpacing=" << std::hex << highspacing << std::dec << ",";
     MWAW_DEBUG_MSG(("MacWrtParser::readParagraph: high spacing bit set=%d\n", highspacing));
   }
-  int spacing = (int) input->readLong(1);
+  int spacing = static_cast<int>(input->readLong(1));
   if (spacing < 0)
     f << "#interline=" << 1.+spacing/2.0 << ",";
   else if (spacing)
     parag.setInterline(1.+spacing/2.0, librevenge::RVNG_PERCENT);
-  parag.m_margins[0] = float(input->readLong(2))/80.f;
+  parag.m_margins[0] = double(input->readLong(2))/80.;
 
-  parag.m_tabs->resize((size_t) numTabs);
-  for (size_t i = 0; i < (size_t) numTabs; i++) {
-    int numPixel = (int) input->readLong(2);
+  parag.m_tabs->resize(size_t(numTabs));
+  for (size_t i = 0; i < size_t(numTabs); i++) {
+    int numPixel = static_cast<int>(input->readLong(2));
     MWAWTabStop::Alignment align = MWAWTabStop::LEFT;
     if (numPixel < 0) {
       align = MWAWTabStop::DECIMAL;
@@ -1499,11 +1500,11 @@ bool MacWrtParser::readPageBreak(MacWrtParserInternal::Information const &info)
 
   f << "Entries(PageBreak):";
   for (int i = 0; i < 2; i++) {
-    int val = (int) input->readLong(2);
+    int val = static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   int dim[2]= {0,0};
-  for (int i = 0; i < 2; i++) dim[i] = (int) input->readLong(2);
+  for (int i = 0; i < 2; i++) dim[i] = static_cast<int>(input->readLong(2));
   f << "pageSize(?)=" << dim[0] << "x" << dim[1] << ",";
   f << "unk=" << input->readLong(2) << ","; // find 0xd
 
@@ -1544,7 +1545,7 @@ bool MacWrtParser::readGraphic(MacWrtParserInternal::Information const &info)
 
   int dim[4];
   for (int i = 0; i < 4; i++)
-    dim[i] = (int) input->readLong(2);
+    dim[i] = static_cast<int>(input->readLong(2));
   if (dim[2] < dim[0] || dim[3] < dim[1]) {
     MWAW_DEBUG_MSG(("MacWrtParser::readGraphic: bdbox is bad\n"));
     return false;
@@ -1552,7 +1553,7 @@ bool MacWrtParser::readGraphic(MacWrtParserInternal::Information const &info)
   libmwaw::DebugStream f;
   f << "Entries(Graphic):";
 
-  Box2f box;
+  MWAWBox2f box;
   MWAWPict::ReadResult res = MWAWPictData::check(input, int(entry.length()-8), box);
   if (res == MWAWPict::MWAW_R_BAD) {
     MWAW_DEBUG_MSG(("MacWrtParser::readGraphic: can not find the picture\n"));
@@ -1560,9 +1561,9 @@ bool MacWrtParser::readGraphic(MacWrtParserInternal::Information const &info)
   }
 
 
-  Vec2f actualSize(float(dim[3]-dim[1]), float(dim[2]-dim[0])), naturalSize(actualSize);
+  MWAWVec2f actualSize(float(dim[3]-dim[1]), float(dim[2]-dim[0])), naturalSize(actualSize);
   if (box.size().x() > 0 && box.size().y()  > 0) naturalSize = box.size();
-  MWAWPosition pictPos=MWAWPosition(Vec2i(0,0),actualSize, librevenge::RVNG_POINT);
+  MWAWPosition pictPos=MWAWPosition(MWAWVec2i(0,0),actualSize, librevenge::RVNG_POINT);
   pictPos.setRelativePosition(MWAWPosition::Char);
   pictPos.setNaturalSize(naturalSize);
   f << pictPos;
@@ -1577,17 +1578,18 @@ bool MacWrtParser::readGraphic(MacWrtParserInternal::Information const &info)
       para.setInterline(1.0, librevenge::RVNG_PERCENT);
       getTextListener()->setParagraph(para);
 
-      librevenge::RVNGBinaryData data;
-      std::string type;
-      if (pict->getBinary(data,type) && !isMagicPic(data))
-        getTextListener()->insertPicture(pictPos, data, type);
+      MWAWEmbeddedObject picture;
+      if (pict->getBinary(picture) && !picture.m_dataList.empty() && !isMagicPic(picture.m_dataList[0]))
+        getTextListener()->insertPicture(pictPos, picture);
       getTextListener()->insertEOL();
 #ifdef DEBUG_WITH_FILES
-      static int volatile pictName = 0;
-      libmwaw::DebugStream f2;
-      f2 << "PICT-" << ++pictName;
-      libmwaw::Debug::dumpFile(data, f2.str().c_str());
-      ascii().skipZone(pos+8, entry.end()-1);
+      if (!picture.m_dataList.empty()) {
+        static int volatile pictName = 0;
+        libmwaw::DebugStream f2;
+        f2 << "PICT-" << ++pictName;
+        libmwaw::Debug::dumpFile(picture.m_dataList[0], f2.str().c_str());
+        ascii().skipZone(pos+8, entry.end()-1);
+      }
 #endif
     }
   }
@@ -1630,8 +1632,8 @@ bool MacWrtParser::checkFreeList()
   int num = 0;
   while (!input->isEnd()) {
     pos = input->tell();
-    long freePos = (long) input->readULong(4);
-    long sz = (long) input->readULong(4);
+    long freePos = long(input->readULong(4));
+    long sz = long(input->readULong(4));
 
     if (long(input->tell()) != pos+8) {
       MWAW_DEBUG_MSG(("MacWrtParser::checkFreeList: list is too short\n"));
