@@ -121,7 +121,9 @@ std::ostream &operator<<(std::ostream &o, Zone const &zone)
     o << "footer,";
     break;
   case Zone::Z_Unknown:
+#if !defined(__clang__)
   default:
+#endif
     break;
   }
   if (zone.m_type==Zone::Z_Header || zone.m_type==Zone::Z_Footer) {
@@ -766,18 +768,18 @@ bool MarinerWrtParser::readZoneHeader(MarinerWrtEntry const &entry, int actId, b
     case 29: // top margin
     case 30:
     case 31:
-      dim[j-28] = (int) data.value(0);
+      dim[j-28] = static_cast<int>(data.value(0));
       while (j<31)
-        dim[++j-28] = (int) dataList[d++].value(0);
+        dim[++j-28] = static_cast<int>(dataList[d++].value(0));
       zone.m_dim = MWAWBox2l(MWAWVec2l(dim[1],dim[0]), MWAWVec2l(dim[3],dim[2]));
       break;
     case 32:
     case 33:
     case 34: { // 35,36,37: front color?
       color[0]=color[1]=color[2]=0xFF;
-      color[j-32]=(unsigned char)(data.value(0)>>8);
+      color[j-32]=static_cast<unsigned char>(data.value(0)>>8);
       while (j < 34)
-        color[++j-32] = (unsigned char)(dataList[d++].value(0)>>8);
+        color[++j-32] = static_cast<unsigned char>(dataList[d++].value(0)>>8);
       zone.m_backgroundColor = MWAWColor(color[0],color[1],color[2]);
       break;
     }
@@ -866,7 +868,7 @@ bool MarinerWrtParser::readZoneDim(MarinerWrtEntry const &entry, int zoneId)
         f << "###dim" << j << "=" << data << ",";
       }
       else
-        dim[j] = (int) data.value(0);
+        dim[j] = static_cast<int>(data.value(0));
     }
     // checkme
     MWAWBox2i dimension(MWAWVec2i(dim[1],dim[0]), MWAWVec2i(dim[3],dim[2]));
@@ -994,18 +996,18 @@ bool MarinerWrtParser::readDocInfo(MarinerWrtEntry const &entry, int zoneId)
     case 7:
     case 8: // a dim?
       dim[0] = dim[1] = 0;
-      dim[j-7]= (int) dt.value(0);
+      dim[j-7]= static_cast<int>(dt.value(0));
       if (j!=8)
-        dim[++j-7] = (int) dataList[++d].value(0);
+        dim[++j-7] = static_cast<int>(dataList[++d].value(0));
       f << "dim?=" << dim[1] << "x" << dim[0] << ",";
       break;
     case 9:
     case 10:
     case 11:
     case 12:
-      margins[j-9]=(int) dt.value(0);
+      margins[j-9]=static_cast<int>(dt.value(0));
       while (j<12)
-        margins[++j-9]= (int) dataList[++d].value(0);
+        margins[++j-9]= static_cast<int>(dataList[++d].value(0));
       f << "margins=" << margins[1] << "x" << margins[0]
         << "<->"  << margins[3] << "x" << margins[2] << ",";
       break;
@@ -1032,9 +1034,9 @@ bool MarinerWrtParser::readDocInfo(MarinerWrtEntry const &entry, int zoneId)
     case 17:
     case 18: {
       color[0]=color[1]=color[2]=0;
-      color[j-16]=(unsigned char)(dt.value(0)>>8);
+      color[j-16]=static_cast<unsigned char>(dt.value(0)>>8);
       while (j < 18)
-        color[++j-16] = (unsigned char)(dataList[++d].value(0)>>8);
+        color[++j-16] = static_cast<unsigned char>(dataList[++d].value(0)>>8);
       MWAWColor col(color[0],color[1],color[2]);
       if (!col.isBlack()) f << "color=" << col << ",";
       break;
@@ -1190,7 +1192,7 @@ bool MarinerWrtParser::readZone13(MarinerWrtEntry const &entry, int)
     }
     if (j < 14) {
       int const expectedValues[]= {13,10,9,31,8,12,14,28,29,30,31,0x7f,27,0};
-      if ((int) data.value(0) != expectedValues[j])
+      if (static_cast<int>(data.value(0)) != expectedValues[j])
         f << "f" << j << "=" << data.value(0) << ",";
       continue;
     }
@@ -1205,7 +1207,7 @@ bool MarinerWrtParser::readZone13(MarinerWrtEntry const &entry, int)
         input->seek(data.m_pos.begin(), librevenge::RVNG_SEEK_SET);
         int N = int(data.m_pos.length()/2);
         for (int k = 0; k < N; k++) {
-          val = (int) input->readLong(2);
+          val = static_cast<int>(input->readLong(2));
           if (val) f << val << ",";
           else f << "_,";
         }
@@ -1220,9 +1222,9 @@ bool MarinerWrtParser::readZone13(MarinerWrtEntry const &entry, int)
     case 16:
     case 17:
       color[0]=color[1]=color[2]=0xFF;
-      color[j-15]=(unsigned char)(data.value(0)>>8);
+      color[j-15]=static_cast<unsigned char>(data.value(0)>>8);
       while (j < 17)
-        color[++j-15] = (unsigned char)(dataList[d++].value(0)>>8);
+        color[++j-15] = static_cast<unsigned char>(dataList[d++].value(0)>>8);
       col = MWAWColor(color[0],color[1],color[2]);
       if (!col.isWhite())
         f << "col0=" << col << ",";
@@ -1231,9 +1233,9 @@ bool MarinerWrtParser::readZone13(MarinerWrtEntry const &entry, int)
     case 20:
     case 21:
       color[0]=color[1]=color[2]=0xFF;
-      color[j-19]=(unsigned char)(data.value(0)>>8);
+      color[j-19]=static_cast<unsigned char>(data.value(0)>>8);
       while (j < 21)
-        color[++j-19] = (unsigned char)(dataList[d++].value(0)>>8);
+        color[++j-19] = static_cast<unsigned char>(dataList[d++].value(0)>>8);
       col = MWAWColor(color[0],color[1],color[2]);
       if (!col.isWhite())
         f << "col1=" << col << ",";
@@ -1355,9 +1357,9 @@ bool MarinerWrtParser::readEntryHeader(MarinerWrtEntry &entry)
   }
   entry.setBegin(input->tell());
   entry.setLength(length);
-  entry.m_fileType = (int) int16_t(dataList[0]);
-  entry.m_N = (int) dataList[4];
-  entry.m_value = (int) dataList[3];
+  entry.m_fileType = static_cast<int>(int16_t(dataList[0]));
+  entry.m_N = static_cast<int>(dataList[4]);
+  entry.m_value = static_cast<int>(dataList[3]);
 
   return true;
 }
@@ -1412,7 +1414,7 @@ bool MarinerWrtParser::readNumbersString(int num, std::vector<long> &res)
     else if (c >= 'A' && c <= 'F')
       val += (long(c+10-'A')<<(4*nBytes));
     else {
-      MWAW_DEBUG_MSG(("MarinerWrtParser::readNumbersString find odd char %x\n", (unsigned int)c));
+      MWAW_DEBUG_MSG(("MarinerWrtParser::readNumbersString find odd char %x\n", static_cast<unsigned int>(c)));
       break;
     }
     nBytes++;
@@ -1517,6 +1519,10 @@ bool MarinerWrtParser::checkHeader(MWAWHeader *header, bool strict)
 ////////////////////////////////////////////////////////////
 // MarinerWrtEntry/MarinerWrtStruct function
 ////////////////////////////////////////////////////////////
+MarinerWrtEntry::~MarinerWrtEntry()
+{
+}
+
 std::string MarinerWrtEntry::name() const
 {
   switch (m_fileType) {
