@@ -69,11 +69,11 @@ struct State {
   //! constructor
   State() : m_kind(MWAWDocument::MWAW_K_TEXT), m_fileHeaderSize(0),
     m_freeZoneId(0), m_typeZoneMap(), m_entryMap(), m_hasHeader(false), m_hasFooter(false),
-    m_oleParser(), m_headerParser(), m_footerParser(), m_footnoteParser(), m_frameParserMap(), m_unparsedOlesName(),
-    m_actPage(0), m_numPages(0), m_headerHeight(0), m_footerHeight(0)
+    m_oleParser(), m_headerParser(), m_footerParser(), m_footnoteParser(), m_frameParserMap(), m_unparsedOlesName(), m_actPage(0), m_numPages(0), m_headerHeight(0), m_footerHeight(0)
   {
   }
-
+  //! returns a color palette
+  std::vector<MWAWColor> const &getPalette(int vers);
   //! the type of document
   MWAWDocument::Kind m_kind;
   //! the file header size
@@ -95,13 +95,109 @@ struct State {
   std::map<std::string, shared_ptr<MsWks4Zone> > m_frameParserMap;
   //! the list of unparsed OLEs
   std::vector<std::string> m_unparsedOlesName;
-
+  //! the color palette
+  std::vector<MWAWColor> m_colorPalette[4];
   int m_actPage /** the actual page */, m_numPages /** the number of page of the final document */;
 
   int m_headerHeight /** the header height if known */,
       m_footerHeight /** the footer height if known */;
 };
 
+std::vector<MWAWColor> const &State::getPalette(int vers)
+{
+  switch (vers) {
+  case 2: {
+    if (!m_colorPalette[0].empty())
+      return m_colorPalette[0];
+    m_colorPalette[0].resize(9);
+    m_colorPalette[0][0]=MWAWColor(0,0,0); // undef
+    m_colorPalette[0][1]=MWAWColor(0,0,0);
+    m_colorPalette[0][2]=MWAWColor(255,255,255);
+    m_colorPalette[0][3]=MWAWColor(255,0,0);
+    m_colorPalette[0][4]=MWAWColor(0,255,0);
+    m_colorPalette[0][5]=MWAWColor(0,0,255);
+    m_colorPalette[0][6]=MWAWColor(0, 255,255);
+    m_colorPalette[0][7]=MWAWColor(255,0,255);
+    m_colorPalette[0][8]=MWAWColor(255,255,0);
+    return m_colorPalette[0];
+  }
+  case 3: {
+    if (!m_colorPalette[1].empty())
+      return m_colorPalette[1];
+    m_colorPalette[1].resize(256);
+    size_t ind=0;
+    for (int k = 0; k < 6; k++) {
+      for (int j = 0; j < 6; j++) {
+        for (int i = 0; i < 6; i++, ind++) {
+          if (j==5 && i==2) break;
+          m_colorPalette[1][ind]=MWAWColor(static_cast<unsigned char>(255-51*i), static_cast<unsigned char>(255-51*k), static_cast<unsigned char>(255-51*j));
+        }
+      }
+    }
+
+    // the last 2 lines
+    for (int r = 0; r < 2; r++) {
+      // the black, red, green, blue zone of 5*2
+      for (int c = 0; c < 4; c++) {
+        for (int i = 0; i < 5; i++, ind++) {
+          int val = 17*r+51*i;
+          if (c == 0) {
+            m_colorPalette[1][ind]=MWAWColor(static_cast<unsigned char>(val), static_cast<unsigned char>(val), static_cast<unsigned char>(val));
+            continue;
+          }
+          int color[3]= {0,0,0};
+          color[c-1]=val;
+          m_colorPalette[1][ind]=MWAWColor(static_cast<unsigned char>(color[0]),static_cast<unsigned char>(color[1]),static_cast<unsigned char>(color[2]));
+        }
+      }
+      // last part of j==5, i=2..5
+      for (int k = r; k < 6; k+=2) {
+        for (int i = 2; i < 6; i++, ind++)
+          m_colorPalette[1][ind]=MWAWColor(static_cast<unsigned char>(255-51*i), static_cast<unsigned char>(255-51*k), static_cast<unsigned char>(255-51*5));
+      }
+    }
+    return m_colorPalette[1];
+  }
+  case 4: {
+    if (!m_colorPalette[2].empty())
+      return m_colorPalette[2];
+    m_colorPalette[2].resize(256);
+    size_t ind=0;
+    for (int k = 0; k < 6; k++) {
+      for (int j = 0; j < 6; j++) {
+        for (int i = 0; i < 6; i++, ind++) {
+          m_colorPalette[2][ind]=
+            MWAWColor(static_cast<unsigned char>(255-51*k), static_cast<unsigned char>(255-51*j),
+                      static_cast<unsigned char>(255-51*i));
+        }
+      }
+    }
+    ind--; // remove the black color
+    for (int c = 0; c < 4; c++) {
+      unsigned char color[3] = {0,0,0};
+      unsigned char val=static_cast<unsigned char>(251);
+      for (int i = 0; i < 10; i++) {
+        val = static_cast<unsigned char>(val-17);
+        if (c == 3) m_colorPalette[2][ind++]=MWAWColor(val, val, val);
+        else {
+          color[c] = val;
+          m_colorPalette[2][ind++]=MWAWColor(color[0],color[1],color[2]);
+        }
+        if ((i%2)==1) val = static_cast<unsigned char>(val-17);
+      }
+    }
+
+    // last is black
+    m_colorPalette[2][ind++]=MWAWColor(0,0,0);
+    return m_colorPalette[2];
+  }
+  default:
+    break;
+  }
+  MWAW_DEBUG_MSG(("MsWksDocumentInternal::State::getPalette: can not find palette for version %d\n", vers));
+  return m_colorPalette[3];
+}
+
 ////////////////////////////////////////
 //! Internal: the subdocument of a MsWksDocument
 class SubDocument : public MWAWSubDocument
@@ -141,7 +237,6 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
     MWAW_DEBUG_MSG(("MsWksDocument::SubDocument::parse: no listener\n"));
     return;
   }
-  assert(m_parser);
 
   long pos = m_input->tell();
   switch (m_type) {
@@ -161,9 +256,11 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
   case Zone:
     m_document.sendZone(m_id);
     break;
+#if !defined(__clang__)
   default:
     MWAW_DEBUG_MSG(("MsWksDocument::SubDocument::parse: unexpected zone type\n"));
     break;
+#endif
   }
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
 }
@@ -185,7 +282,7 @@ bool SubDocument::operator!=(MWAWSubDocument const &doc) const
 ////////////////////////////////////////////////////////////
 MsWksDocument::MsWksDocument(MWAWInputStreamPtr input, MWAWParser &parser) :
   m_state(), m_parserState(parser.getParserState()), m_parser(&parser), m_parentDocument(0),
-  m_input(input), m_asciiFile(), m_graphParser(), m_textParser3(), m_textParser4(), m_newPage(0)
+  m_input(input), m_asciiFile(MWAWInputStreamPtr()), m_graphParser(), m_textParser3(), m_textParser4(), m_newPage(0)
 {
   m_state.reset(new MsWksDocumentInternal::State());
   m_graphParser.reset(new MsWksGraph(*this));
@@ -405,10 +502,10 @@ void MsWksDocument::sendOLE(int id, MWAWPosition const &pictPos, MWAWGraphicStyl
     MWAW_DEBUG_MSG(("MsWksDocument::sendOLE: can not find OLE%d\n", id));
     return;
   }
-  m_parserState->getMainListener()->insertPicture(pictPos, data, type, style);
+  m_parserState->getMainListener()->insertPicture(pictPos, MWAWEmbeddedObject(data, type), style);
 }
 
-void MsWksDocument::sendRBIL(int id, Vec2i const &sz)
+void MsWksDocument::sendRBIL(int id, MWAWVec2i const &sz)
 {
   MsWksGraph::SendData sendData;
   sendData.m_type = MsWksGraph::SendData::RBIL;
@@ -459,99 +556,7 @@ void MsWksDocument::sendTextbox(MWAWEntry const &entry, std::string const &frame
 ////////////////////////////////////////////////////////////
 std::vector<MWAWColor> const &MsWksDocument::getPalette(int vers)
 {
-  switch (vers) {
-  case 2: {
-    static std::vector<MWAWColor> palette;
-    palette.resize(9);
-    palette[0]=MWAWColor(0,0,0); // undef
-    palette[1]=MWAWColor(0,0,0);
-    palette[2]=MWAWColor(255,255,255);
-    palette[3]=MWAWColor(255,0,0);
-    palette[4]=MWAWColor(0,255,0);
-    palette[5]=MWAWColor(0,0,255);
-    palette[6]=MWAWColor(0, 255,255);
-    palette[7]=MWAWColor(255,0,255);
-    palette[8]=MWAWColor(255,255,0);
-    return palette;
-  }
-  case 3: {
-    static std::vector<MWAWColor> palette;
-    if (palette.size()==0) {
-      palette.resize(256);
-      size_t ind=0;
-      for (int k = 0; k < 6; k++) {
-        for (int j = 0; j < 6; j++) {
-          for (int i = 0; i < 6; i++, ind++) {
-            if (j==5 && i==2) break;
-            palette[ind]=MWAWColor((unsigned char)(255-51*i), (unsigned char)(255-51*k), (unsigned char)(255-51*j));
-          }
-        }
-      }
-
-      // the last 2 lines
-      for (int r = 0; r < 2; r++) {
-        // the black, red, green, blue zone of 5*2
-        for (int c = 0; c < 4; c++) {
-          for (int i = 0; i < 5; i++, ind++) {
-            int val = 17*r+51*i;
-            if (c == 0) {
-              palette[ind]=MWAWColor((unsigned char)val, (unsigned char)val, (unsigned char)val);
-              continue;
-            }
-            int color[3]= {0,0,0};
-            color[c-1]=val;
-            palette[ind]=MWAWColor((unsigned char)(color[0]),(unsigned char)(color[1]),(unsigned char)(color[2]));
-          }
-        }
-        // last part of j==5, i=2..5
-        for (int k = r; k < 6; k+=2) {
-          for (int i = 2; i < 6; i++, ind++)
-            palette[ind]=MWAWColor((unsigned char)(255-51*i), (unsigned char)(255-51*k), (unsigned char)(255-51*5));
-        }
-      }
-    }
-    return palette;
-  }
-  case 4: {
-    static std::vector<MWAWColor> palette;
-    if (palette.size()==0) {
-      palette.resize(256);
-      size_t ind=0;
-      for (int k = 0; k < 6; k++) {
-        for (int j = 0; j < 6; j++) {
-          for (int i = 0; i < 6; i++, ind++) {
-            palette[ind]=
-              MWAWColor((unsigned char)(255-51*k), (unsigned char)(255-51*j),
-                        (unsigned char)(255-51*i));
-          }
-        }
-      }
-      ind--; // remove the black color
-      for (int c = 0; c < 4; c++) {
-        unsigned char color[3] = {0,0,0};
-        unsigned char val=(unsigned char) 251;
-        for (int i = 0; i < 10; i++) {
-          val = (unsigned char)(val-17);
-          if (c == 3) palette[ind++]=MWAWColor(val, val, val);
-          else {
-            color[c] = val;
-            palette[ind++]=MWAWColor(color[0],color[1],color[2]);
-          }
-          if ((i%2)==1) val = (unsigned char)(val-17);
-        }
-      }
-
-      // last is black
-      palette[ind++]=MWAWColor(0,0,0);
-    }
-    return palette;
-  }
-  default:
-    break;
-  }
-  MWAW_DEBUG_MSG(("MsWksDocument::getPalette: can not find palette for version %d\n", vers));
-  static std::vector<MWAWColor> emptyPalette;
-  return emptyPalette;
+  return m_state->getPalette(vers);
 }
 
 bool MsWksDocument::getColor(int id, MWAWColor &col, int vers)
@@ -678,8 +683,8 @@ bool MsWksDocument::readPrintInfo()
   if (!input->checkPosition(pos+0x78+8) || !info.read(input)) return false;
   f << "Entries(PrintInfo):"<< info;
 
-  Vec2i paperSize = info.paper().size();
-  Vec2i pageSize = info.page().size();
+  MWAWVec2i paperSize = info.paper().size();
+  MWAWVec2i pageSize = info.page().size();
   if (pageSize.x() <= 0 || pageSize.y() <= 0 ||
       paperSize.x() <= 0 || paperSize.y() <= 0) return false;
 
@@ -688,7 +693,7 @@ bool MsWksDocument::readPrintInfo()
   int maxSize = paperSize.x() > paperSize.y() ? paperSize.x() : paperSize.y();
   f << ", margin=(";
   for (int i = 0; i < 4; i++) {
-    margin[i] = int(72.f/120.f*(float)input->readLong(2));
+    margin[i] = int(72.f/120.f*float(input->readLong(2)));
     if (margin[i] < -maxSize || margin[i] > maxSize) return false;
     f << margin[i];
     if (i != 3) f << ", ";
@@ -697,7 +702,7 @@ bool MsWksDocument::readPrintInfo()
 
   // fixme: compute the real page length here...
   // define margin from print info
-  Vec2i lTopMargin(margin[0],margin[1]), rBotMargin(margin[2],margin[3]);
+  MWAWVec2i lTopMargin(margin[0],margin[1]), rBotMargin(margin[2],margin[3]);
   lTopMargin += paperSize - pageSize;
 
   int leftMargin = lTopMargin.x();
@@ -748,10 +753,10 @@ bool MsWksDocument::readDocumentInfo(long sz)
   if (sz<=0) {
     if (input->readLong(1) != 2)
       return false;
-    docId = (int) input->readULong(1);
-    docExtra = (int) input->readULong(1);
-    flag = (int) input->readULong(1);
-    sz = (long) input->readULong(2);
+    docId = static_cast<int>(input->readULong(1));
+    docExtra = static_cast<int>(input->readULong(1));
+    flag = static_cast<int>(input->readULong(1));
+    sz = long(input->readULong(2));
     expectedSz = vers<=2 ? 0x15e : 0x9a;
   }
   long endPos = input->tell()+sz;
@@ -785,7 +790,7 @@ bool MsWksDocument::readDocumentInfo(long sz)
   pos = input->tell();
   f.str("");
   f << "DocInfo-1:";
-  int val = (int) input->readLong(2);
+  int val = static_cast<int>(input->readLong(2));
   if ((val & 0x0400) && vers >= 3) {
     f << "titlepage,";
     val &= 0xFBFF;
@@ -800,17 +805,17 @@ bool MsWksDocument::readDocumentInfo(long sz)
 
       long remain = debPos+100 - input->tell();
       for (long i = 0; i < remain; i++) {
-        unsigned char c = (unsigned char) input->readULong(1);
+        unsigned char c = static_cast<unsigned char>(input->readULong(1));
         if (c == 0) continue;
-        f << std::dec << "f"<< i << "=" << (int) c << ",";
+        f << std::dec << "f"<< i << "=" << static_cast<int>(c) << ",";
       }
     }
     f << "defFid=" << input->readULong(2) << ",";
     f << "defFsz=" << input->readULong(2)/2 << ",";
-    val = (int) input->readULong(2); // 0 or 8
+    val = static_cast<int>(input->readULong(2)); // 0 or 8
     if (val) f << "#unkn=" << val << ",";
     int dim[2];
-    for (int i = 0; i < 2; i++) dim[i] = (int) input->readULong(2);
+    for (int i = 0; i < 2; i++) dim[i] = static_cast<int>(input->readULong(2));
     f << "dim=" << dim[0] << "x" << dim[1] << ",";
     /* followed by 0 (v1) or 0|0x21|0* (v2)*/
     ascii().addPos(pos);
@@ -823,7 +828,7 @@ bool MsWksDocument::readDocumentInfo(long sz)
   // last data ( normally 26)
   int numData = int((endPos - input->tell())/2);
   for (int i = 0; i < numData; i++) {
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     switch (i) {
     case 2:
       if (val!=1) f << "firstPageNumber=" << val << ",";
@@ -855,18 +860,18 @@ bool MsWksDocument::readGroupHeaderFooter(bool header, int check)
   MWAWInputStreamPtr input=getInput();
   long debPos = input->tell();
 
-  long ptr = (long) input->readULong(2);
+  long ptr = long(input->readULong(2));
   if (input->isEnd()) return false;
   if (ptr) {
     if (check == 49) return false;
     if (check == 99) {
-      MWAW_DEBUG_MSG(("MsWksDocument::readGroupHeaderFooter: find ptr=0x%lx\n", ptr));
+      MWAW_DEBUG_MSG(("MsWksDocument::readGroupHeaderFooter: find ptr=0x%lx\n", static_cast<long unsigned int>(ptr)));
     }
   }
 
   libmwaw::DebugStream f;
 
-  int size = (int) input->readLong(2)+4;
+  int size = static_cast<int>(input->readLong(2))+4;
   int realSize = 0x11;
   if (size < realSize) return false;
   if (input->readLong(2) != 0) return false;
@@ -880,19 +885,19 @@ bool MsWksDocument::readGroupHeaderFooter(bool header, int check)
   if (!input->checkPosition(debPos+size)) return false;
 
   input->seek(debPos+6, librevenge::RVNG_SEEK_SET);
-  int N=(int) input->readLong(2);
+  int N=static_cast<int>(input->readLong(2));
   f << ", N=" << N;
   int dim[4];
   for (int i = 0; i < 4; i++)
-    dim[i] = (int) input->readLong(2);
+    dim[i] = static_cast<int>(input->readLong(2));
 
-  Box2i box(Vec2i(dim[1], dim[0]), Vec2i(dim[3], dim[2]));
+  MWAWBox2i box(MWAWVec2i(dim[1], dim[0]), MWAWVec2i(dim[3], dim[2]));
   if (box.size().x() < -2000 || box.size().y() < -2000 ||
       box.size().x() > 2000 || box.size().y() > 2000 ||
       box.min().x() < -200 || box.min().y() < -200) return false;
   if (check == 49 && box.size().x() == 0 &&  box.size().y() == 0) return false;
   f << ", BDBox =" << box;
-  int val = (int) input->readULong(1);
+  int val = static_cast<int>(input->readULong(1));
   if (val) f << ", flag=" << val;
 
   input->seek(debPos+size, librevenge::RVNG_SEEK_SET);
@@ -953,7 +958,7 @@ bool MsWksDocument::readZone(MsWksDocument::Zone &zone)
   if (input->isEnd()) return false;
   long pos = input->tell();
   MWAWEntry pict;
-  int val = (int) input->readLong(1);
+  int val = static_cast<int>(input->readLong(1));
   input->seek(-1, librevenge::RVNG_SEEK_CUR);
   switch (val) {
   case 0: {
@@ -1010,7 +1015,7 @@ bool MsWksDocument::checkHeader3(MWAWHeader *header, bool strict)
   input->seek(0,librevenge::RVNG_SEEK_SET);
 
   m_state->m_hasHeader = m_state->m_hasFooter = false;
-  int vers = (int) input->readULong(4);
+  int vers = static_cast<int>(input->readULong(4));
   switch (vers) {
   case 11:
     setVersion(4);
@@ -1027,7 +1032,7 @@ bool MsWksDocument::checkHeader3(MWAWHeader *header, bool strict)
   default:
     if (strict) return false;
 
-    MWAW_DEBUG_MSG(("MsWksDocument::checkHeader3: find unknown version 0x%x\n", vers));
+    MWAW_DEBUG_MSG(("MsWksDocument::checkHeader3: find unknown version 0x%x\n", static_cast<unsigned int>(vers)));
     // must we stop in this case, or can we continue ?
     if (vers < 0 || vers > 14) {
       MWAW_DEBUG_MSG(("MsWksDocument::checkHeader3: version too big, we stop\n"));
@@ -1041,14 +1046,14 @@ bool MsWksDocument::checkHeader3(MWAWHeader *header, bool strict)
   if (input->seek(12,librevenge::RVNG_SEEK_SET) != 0) return false;
 
   for (int i = 0; i < 3; i++) {
-    val = (int)(int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     if (val < -10 || val > 10) {
-      MWAW_DEBUG_MSG(("MsWksDocument::checkHeader3: find odd val%d=0x%x: not implemented\n", i, val));
+      MWAW_DEBUG_MSG(("MsWksDocument::checkHeader3: find odd val%d=0x%x: not implemented\n", i, static_cast<unsigned int>(val)));
       numError++;
     }
   }
   input->seek(1,librevenge::RVNG_SEEK_CUR);
-  int type = (int) input->readLong(2);
+  int type = static_cast<int>(input->readLong(2));
   switch (type) {
   // Text document
   case 1:
@@ -1090,7 +1095,7 @@ bool MsWksDocument::checkHeader3(MWAWHeader *header, bool strict)
   f << ", windowdbdbox?=(";
   for (int i = 0; i < 4; i++) f << dim[i]<<",";
   f << "),";
-  long fileHeaderSize=(long) input->readULong(4);
+  long fileHeaderSize=long(input->readULong(4));
   if (checkDatabaseFileHSize && strict) {
     if ((version()==2 && fileHeaderSize!=0x516) || (version()==3&&fileHeaderSize!=0x50))
       return false;
@@ -1101,12 +1106,12 @@ bool MsWksDocument::checkHeader3(MWAWHeader *header, bool strict)
   if (m_state->m_kind==MWAWDocument::MWAW_K_SPREADSHEET) {
     /* CHECKME: normally 0x56c, but find one time 0x56a in a v2 file
        which seems to imply that the spreadsheet begins earlier */
-    if (fileHeaderSize!=0x56c && fileHeaderSize > (long) 0x550 && input->checkPosition(fileHeaderSize+0x20))
+    if (fileHeaderSize!=0x56c && fileHeaderSize > long(0x550) && input->checkPosition(fileHeaderSize+0x20))
       m_state->m_fileHeaderSize=fileHeaderSize;
     else
       m_state->m_fileHeaderSize=0x56c;
   }
-  type = (int) input->readULong(2);
+  type = static_cast<int>(input->readULong(2));
   f << std::dec;
   switch (type) {
   case 1:
@@ -1126,12 +1131,12 @@ bool MsWksDocument::checkHeader3(MWAWHeader *header, bool strict)
     break;
   }
   f << "numlines?=" << input->readLong(2) << ",";
-  val = (int) input->readLong(1); // 0, v2: 0, 4 or -4
+  val = static_cast<int>(input->readLong(1)); // 0, v2: 0, 4 or -4
   if (val)  f << "f0=" << val << ",";
-  val = (int) input->readLong(1); // almost always 1
+  val = static_cast<int>(input->readLong(1)); // almost always 1
   if (val != 1) f << "f1=" << val << ",";
   for (int i = 11; i < headerSize/2; i++) { // v1: 0, 0, v2: 0, 0|1
-    val = (int) input->readULong(2);
+    val = static_cast<int>(input->readULong(2));
     if (!val) continue;
     f << "f" << i << "=" << std::hex << val << std::dec;
     if (version() >= 3 && i == 12) {
@@ -1168,7 +1173,7 @@ bool MsWksDocument::readDBString(long endPos, std::string &res)
   int error = 0;
   int ok = 0;
   while (input->tell() != endPos) {
-    char c = (char) input->readLong(1);
+    char c = char(input->readLong(1));
     if (c < 27 && c != '\t' && c != '\n') error++;
     else ok++;
     res += c;
@@ -1194,7 +1199,7 @@ bool MsWksDocument::readCellInFormula(MWAWCellContent::FormulaInstruction &instr
   bool ok = true;
   if (is2D) {
     bool absolute[2] = { false, false};
-    int type = (int) input->readULong(1);
+    int type = static_cast<int>(input->readULong(1));
     if (type & 0x80) {
       absolute[0] = true;
       type &= 0x7F;
@@ -1209,7 +1214,7 @@ bool MsWksDocument::readCellInFormula(MWAWCellContent::FormulaInstruction &instr
     }
     int pos[2]= {1,0};
     for (int i=0; i< 2; ++i)
-      pos[i] = (int) input->readULong(1);
+      pos[i] = static_cast<int>(input->readULong(1));
 
     if (pos[0] < 1 || pos[1] < 0) {
       if (ok) {
@@ -1217,11 +1222,11 @@ bool MsWksDocument::readCellInFormula(MWAWCellContent::FormulaInstruction &instr
       }
       return false;
     }
-    instr.m_position[0]=Vec2i(pos[1],pos[0]-1);
-    instr.m_positionRelative[0]=Vec2b(!absolute[1],!absolute[0]);
+    instr.m_position[0]=MWAWVec2i(pos[1],pos[0]-1);
+    instr.m_positionRelative[0]=MWAWVec2b(!absolute[1],!absolute[0]);
   }
   else
-    instr.m_position[0]=Vec2i((int) input->readULong(1),0);
+    instr.m_position[0]=MWAWVec2i(static_cast<int>(input->readULong(1)),0);
   return ok;
 }
 
@@ -1238,7 +1243,7 @@ bool MsWksDocument::readFormula(long endPos, MWAWCellContent &content, std::stri
   bool ok=true;
   while (input->tell() !=endPos) {
     pos = input->tell();
-    int code = (int) input->readLong(1);
+    int code = static_cast<int>(input->readLong(1));
     MWAWCellContent::FormulaInstruction instr;
     bool findEnd=false;
     switch (code) {
@@ -1252,7 +1257,7 @@ bool MsWksDocument::readFormula(long endPos, MWAWCellContent &content, std::stri
       break;
     }
     case 0x8: { // a number
-      int sz = (int) input->readULong(1);
+      int sz = static_cast<int>(input->readULong(1));
       std::string s;
       double val;
       bool isNan;
@@ -1271,7 +1276,7 @@ bool MsWksDocument::readFormula(long endPos, MWAWCellContent &content, std::stri
       break;
     }
     case 0x0c: { // function
-      int v = (int) input->readULong(1);
+      int v = static_cast<int>(input->readULong(1));
       static char const *(listFunc) [0x41] = {
         "Abs", "Sum", "Na", "Error", "ACos", "And", "ASin", "ATan",
         "ATan2", "Average", "Choose", "Cos", "Count", "Exp", "False", "FV",
@@ -1288,7 +1293,7 @@ bool MsWksDocument::readFormula(long endPos, MWAWCellContent &content, std::stri
         instr.m_content=listFunc[v/2];
       else {
         f << "###";
-        MWAW_DEBUG_MSG(("MSWksSSParser::readFormula: find unknown function %x\n", v));
+        MWAW_DEBUG_MSG(("MSWksSSParser::readFormula: find unknown function %x\n", static_cast<unsigned int>(v)));
         std::stringstream s;
         s << "Funct" << std::hex << v << std::dec;
         instr.m_content=s.str();
@@ -1346,10 +1351,10 @@ bool MsWksDocument::readFormula(long endPos, MWAWCellContent &content, std::stri
   f << std::dec << "unk1=[";
   // looks a little as a zone of cell ?? but this seems eroneous
   for (int i = 0; i < 2; i++) {
-    int v = (int) input->readULong(1);
+    int v = static_cast<int>(input->readULong(1));
 
-    int n0 = (int) input->readULong(1);
-    int n1 = (int) input->readULong(1);
+    int n0 = static_cast<int>(input->readULong(1));
+    int n1 = static_cast<int>(input->readULong(1));
     if (i == 1) f << ":";
     f << n0 << "x" << n1;
     if (v) f << "##v";
