@@ -68,22 +68,15 @@
 /** Internal: the structures of a MsWrdText */
 namespace MsWrdTextInternal
 {
-#if defined(DEBUG_WITH_FILES)
-// use cut -c13- main-2.data|sort -n to retrieve the data
-//! internal and low level: defined a second debug file
-static std::fstream &debugFile2()
-{
-  static std::fstream s_file("main-2.data", std::ios_base::out | std::ios_base::trunc);
-  return s_file;
-}
-#endif
-
 ////////////////////////////////////////
 //! Internal: the entry of MsWrdParser
 struct TextStruct : public MWAWEntry {
+  //! construtor
   TextStruct() : MWAWEntry(), m_pos(-1), m_id(0), m_type(0), m_paragraphId(-1), m_complex(false), m_extra("")
   {
   }
+  //! destructor
+  ~TextStruct();
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, TextStruct const &entry)
   {
@@ -143,6 +136,10 @@ struct TextStruct : public MWAWEntry {
   std::string m_extra;
 };
 
+TextStruct::~TextStruct()
+{
+}
+
 ////////////////////////////////////////
 //! Internal: the page
 struct Page {
@@ -267,6 +264,8 @@ struct Table : public MWAWTable {
   Table() : MWAWTable(MWAWTable::TableDimBit), m_cellPos(), m_delimiterPos(), m_height(0), m_backgroundColor(MWAWColor::white()), m_cells()
   {
   }
+  //! destructor
+  ~Table();
   //! the list of cPos corresponding to cells limits
   std::vector<long> m_cellPos;
   //! the list of the delimiter cPos (ie. end of each cell)
@@ -279,6 +278,9 @@ struct Table : public MWAWTable {
   std::vector<MWAWVariable<MsWrdStruct::Table::Cell> > m_cells;
 };
 
+Table::~Table()
+{
+}
 ////////////////////////////////////////
 //! Internal: the state of a MsWrdParser
 struct State {
@@ -287,6 +289,9 @@ struct State {
     m_plcMap(), m_filePlcMap(), m_lineList(), m_paragraphLimitMap(), m_sectionLimitList(),
     m_fontMap(), m_paragraphMap(), m_propertyMap(), m_tableCellPosSet(), m_tableMap(),
     m_paraInfoList(), m_pageList(), m_fieldList(), m_footnoteList(), m_actPage(0), m_numPages(-1)
+#if defined(DEBUG_WITH_FILES)
+    , m_debugFile()
+#endif
   {
     for (int i = 0; i < 3; i++) m_textLength[i] = 0;
   }
@@ -305,9 +310,9 @@ struct State {
     int minVal = 0, maxVal = int(m_textposList.size())-1;
     while (minVal != maxVal) {
       int mid = (minVal+1+maxVal)/2;
-      if (m_textposList[(size_t)mid].m_pos == textPos)
+      if (m_textposList[size_t(mid)].m_pos == textPos)
         return mid;
-      if (m_textposList[(size_t)mid].m_pos > textPos)
+      if (m_textposList[size_t(mid)].m_pos > textPos)
         maxVal = mid-1;
       else
         minVal = mid;
@@ -320,7 +325,7 @@ struct State {
     int tId=getTextStructId(textPos);
     if (tId==-1)
       return m_bot+textPos;
-    return m_textposList[(size_t)tId].begin() + (textPos-m_textposList[(size_t)tId].m_pos);
+    return m_textposList[size_t(tId)].begin() + (textPos-m_textposList[size_t(tId)].m_pos);
   }
   //! try to return a table which begins at a character position
   shared_ptr<Table> getTable(long cPos) const
@@ -333,6 +338,21 @@ struct State {
       return empty;
     return table;
   }
+
+#if defined(DEBUG_WITH_FILES)
+  // use cut -c13- main-2.data|sort -n to retrieve the data
+  //! internal and low level: defined a second debug file
+  std::fstream &debugFile2()
+  {
+    static bool init=false;
+    if (!init) {
+      init=true;
+      m_debugFile.open("main-2.data", std::ios_base::out | std::ios_base::trunc);
+    }
+    return m_debugFile;
+  }
+#endif
+
   //! the file version
   int m_version;
 
@@ -382,6 +402,10 @@ struct State {
   std::vector<Footnote> m_footnoteList;
 
   int m_actPage/** the actual page*/, m_numPages /** the number of page of the final document */;
+#if defined(DEBUG_WITH_FILES)
+  //! internal and low level: defined a second debug file
+  std::fstream m_debugFile;
+#endif
 };
 
 }
@@ -513,8 +537,10 @@ std::ostream &operator<<(std::ostream &o, MsWrdText::PLC const &plc)
   case MsWrdText::PLC::TextPosition:
     o << "textPos";
     break;
+#if !defined(__clang__)
   default:
     o << "#type" << char('a'+int(plc.m_type));
+#endif
   }
   if (plc.m_id < 0) o << "_";
   else o << plc.m_id;
@@ -529,8 +555,11 @@ bool MsWrdText::readHeaderTextLength()
   long endPos = pos+12;
   if (!input->checkPosition(endPos))
     return false;
-  for (int i = 0; i < 3; i++)
-    m_state->m_textLength[i]= (long) input->readULong(4);
+  for (int i = 0; i < 3; i++) {
+    const long length = long(input->readULong(4));
+    // a minimal check that the lengths are not insanely out of bounds
+    m_state->m_textLength[i]= input->checkPosition(length) ? length : 0;
+  }
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
   f << "FileHeader(textLength):text="
@@ -673,14 +702,14 @@ bool MsWrdText::readTextStruct(MsWrdEntry &entry)
   long pos = input->tell();
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
-  int type = (int) input->readLong(1);
+  int type = static_cast<int>(input->readLong(1));
   if (type != 2) {
     MWAW_DEBUG_MSG(("MsWrdText::readTextStruct: find odd type %d\n", type));
     return false;
   }
   entry.setParsed(true);
   f << "TextStruct-pos:";
-  int sz = (int) input->readULong(2);
+  int sz = static_cast<int>(input->readULong(2));
   long endPos = pos+3+sz;
   if (endPos > entry.end() || (sz%12) != 4) {
     f << "#";
@@ -692,17 +721,17 @@ bool MsWrdText::readTextStruct(MsWrdEntry &entry)
   int N=sz/12;
   long textLength=m_state->getTotalTextSize();
   std::vector<long> textPos; // checkme
-  textPos.resize((size_t) N+1);
+  textPos.resize(size_t(N+1));
   f << "pos=[" << std::hex;
   for (size_t i = 0; i <= size_t(N); i++) {
-    textPos[i] = (int) input->readULong(4);
+    textPos[i] = static_cast<int>(input->readULong(4));
     if (i && textPos[i] <= textPos[i-1]) {
       MWAW_DEBUG_MSG(("MsWrdText::readTextStruct: find backward text pos\n"));
       f << "#" << textPos[i] << ",";
       textPos[i]=textPos[i-1];
     }
     else {
-      if (i != (size_t) N && textPos[i] > textLength) {
+      if (i != size_t(N) && textPos[i] > textLength) {
         MWAW_DEBUG_MSG(("MsWrdText::readTextStruct: find a text position which is too big\n"));
         f << "#";
       }
@@ -719,13 +748,13 @@ bool MsWrdText::readTextStruct(MsWrdEntry &entry)
     MsWrdTextInternal::TextStruct tEntry;
     f.str("");
     f<< "TextStruct-pos" << i << ":";
-    tEntry.m_pos = (int) textPos[(size_t)i];
-    tEntry.m_type = (int) input->readULong(1);
+    tEntry.m_pos = static_cast<int>(textPos[size_t(i)]);
+    tEntry.m_type = static_cast<int>(input->readULong(1));
     // fN internal...
-    tEntry.m_id = (int) input->readULong(1);
-    long ptr = (long) input->readULong(4);
+    tEntry.m_id = static_cast<int>(input->readULong(1));
+    long ptr = long(input->readULong(4));
     tEntry.setBegin(ptr);
-    tEntry.setLength(textPos[(size_t)i+1]-textPos[(size_t)i]);
+    tEntry.setLength(textPos[size_t(i)+1]-textPos[size_t(i)]);
     tEntry.m_paragraphId = m_stylesManager->readPropertyModifier(tEntry.m_complex, tEntry.m_extra);
     m_state->m_textposList.push_back(tEntry);
     if (!input->checkPosition(ptr)) {
@@ -735,7 +764,7 @@ bool MsWrdText::readTextStruct(MsWrdEntry &entry)
     else {
       plc.m_id = i;
       m_state->m_plcMap.insert(std::multimap<long,PLC>::value_type
-                               (textPos[(size_t)i],plc));
+                               (textPos[size_t(i)],plc));
     }
     f << tEntry;
     input->seek(pos+8, librevenge::RVNG_SEEK_SET);
@@ -744,7 +773,7 @@ bool MsWrdText::readTextStruct(MsWrdEntry &entry)
 #if defined(DEBUG_WITH_FILES)
     f.str("");
     f<< "TextContent[" << tEntry.m_pos << "]:" << tEntry << ",";
-    MsWrdTextInternal::debugFile2() << f.str() << "\n";
+    m_state->debugFile2() << f.str() << "\n";
 #endif
   }
 
@@ -773,7 +802,7 @@ bool MsWrdText::readFontNames(MsWrdEntry &entry)
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
-  int N = (int) input->readULong(2);
+  int N = static_cast<int>(input->readULong(2));
   if (N*5+2 > entry.length()) {
     MWAW_DEBUG_MSG(("MsWrdText::readFontNames: the number of fonts seems bad\n"));
     return false;
@@ -791,11 +820,11 @@ bool MsWrdText::readFontNames(MsWrdEntry &entry)
     }
     f.str("");
     f << "FontNames-" << i << ":";
-    int val = (int) input->readLong(2);
+    int val = static_cast<int>(input->readLong(2));
     if (val) f << "f0=" << val << ",";
-    int fId = (int) input->readULong(2);
+    int fId = static_cast<int>(input->readULong(2));
     f << "fId=" << fId << ",";
-    int fSz = (int) input->readULong(1);
+    int fSz = static_cast<int>(input->readULong(1));
     if (pos +5 > entry.end()) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       MWAW_DEBUG_MSG(("MsWrdText::readFontNames: the fonts name %d seems bad\n", i));
@@ -822,7 +851,7 @@ bool MsWrdText::readFontNames(MsWrdEntry &entry)
 ////////////////////////////////////////////////////////////
 // read the zone info zone
 ////////////////////////////////////////////////////////////
-bool MsWrdText::readParagraphInfo(MsWrdEntry entry)
+bool MsWrdText::readParagraphInfo(MsWrdEntry &entry)
 {
   int vers=version();
   if (vers<=3) {
@@ -846,7 +875,7 @@ bool MsWrdText::readParagraphInfo(MsWrdEntry entry)
   std::vector<long> textPositions;
   f << "[";
   for (int i = 0; i <= N; i++) {
-    long textPos = (long) input->readULong(4);
+    long textPos = long(input->readULong(4));
     textPositions.push_back(textPos);
     f << std::hex << textPos << std::dec << ",";
   }
@@ -858,21 +887,21 @@ bool MsWrdText::readParagraphInfo(MsWrdEntry entry)
   for (int i = 0; i < N; i++) {
     pos = input->tell();
     f.str("");
-    f << "ParaInfo-Pi" << i << ":" << std::hex << textPositions[(size_t) i] << std::dec << ",";
+    f << "ParaInfo-Pi" << i << ":" << std::hex << textPositions[size_t(i)] << std::dec << ",";
     MsWrdStruct::ParagraphInfo paraMod;
     if (!paraMod.read(input, pos+6, vers))
       f << "###";
     f << paraMod;
     m_state->m_paraInfoList.push_back(paraMod);
 
-    if (textPositions[(size_t) i] > m_state->m_textLength[0]) {
+    if (textPositions[size_t(i)] > m_state->m_textLength[0]) {
       MWAW_DEBUG_MSG(("MsWrdText::readParagraphInfo: text positions is bad...\n"));
       f << "#";
     }
     else {
       plc.m_id=i;
       m_state->m_plcMap.insert(std::multimap<long,PLC>::value_type
-                               (textPositions[(size_t) i],plc));
+                               (textPositions[size_t(i)],plc));
     }
     input->seek(pos+6, librevenge::RVNG_SEEK_SET);
     ascFile.addPos(pos);
@@ -905,21 +934,21 @@ bool MsWrdText::readPageBreak(MsWrdEntry &entry)
   f << "PageBreak:";
   int N=int(entry.length()/(fSz+4));
   std::vector<long> textPos; // checkme
-  textPos.resize((size_t) N+1);
-  for (int i = 0; i <= N; i++) textPos[(size_t) i] = (long) input->readULong(4);
+  textPos.resize(size_t(N)+1);
+  for (int i = 0; i <= N; i++) textPos[size_t(i)] = long(input->readULong(4));
   PLC plc(PLC::Page);
   int prevPage=-1;
   for (int i = 0; i < N; i++) {
     MsWrdTextInternal::Page page;
     page.m_id = i;
-    page.m_type = (int) input->readULong(1);
-    page.m_values[0] = (int) input->readLong(1); // always 0,1,2
+    page.m_type = static_cast<int>(input->readULong(1));
+    page.m_values[0] = static_cast<int>(input->readLong(1)); // always 0,1,2
     for (int j = 1; j < 3; j++) // always -1, 0
-      page.m_values[j] = (int) input->readLong(2);
-    page.m_page = (int) input->readLong(2);
+      page.m_values[j] = static_cast<int>(input->readLong(2));
+    page.m_page = static_cast<int>(input->readLong(2));
     if (vers > 3)
-      page.m_values[3] = (int) input->readLong(2);
-    if (i && textPos[(size_t)i]==textPos[(size_t)i-1] && page.m_page==prevPage) {
+      page.m_values[3] = static_cast<int>(input->readLong(2));
+    if (i && textPos[size_t(i)]==textPos[size_t(i)-1] && page.m_page==prevPage) {
       // find this one time in v3...
       MWAW_DEBUG_MSG(("MsWrdText::readPageBreak: page %d is duplicated...\n", i));
       f << "#dup,";
@@ -928,18 +957,18 @@ bool MsWrdText::readPageBreak(MsWrdEntry &entry)
     prevPage=page.m_page;
     m_state->m_pageList.push_back(page);
 
-    if (textPos[(size_t)i] > m_state->m_textLength[0]) {
+    if (textPos[size_t(i)] > m_state->m_textLength[0]) {
       MWAW_DEBUG_MSG(("MsWrdText::readPageBreak: text positions is bad...\n"));
       f << "#";
     }
     else {
       plc.m_id = i;
       m_state->m_plcMap.insert(std::multimap<long,PLC>::value_type
-                               (textPos[(size_t)i],plc));
+                               (textPos[size_t(i)],plc));
     }
-    f << "[pos=" << textPos[(size_t)i] << "," << page << "],";
+    f << "[pos=" << textPos[size_t(i)] << "," << page << "],";
   }
-  f << "end=" << std::hex << textPos[(size_t)N] << std::dec << ",";
+  f << "end=" << std::hex << textPos[size_t(N)] << std::dec << ",";
   ascFile.addPos(pos);
   ascFile.addNote(f.str().c_str());
 
@@ -971,38 +1000,38 @@ bool MsWrdText::readFootnotesPos(MsWrdEntry &entry, std::vector<long> const &not
   f << "FootnotePos:";
 
   std::vector<long> textPos;
-  textPos.resize((size_t)N+1);
+  textPos.resize(size_t(N)+1);
   for (int i = 0; i <= N; i++)
-    textPos[(size_t)i]= (long) input->readULong(4);
+    textPos[size_t(i)]= long(input->readULong(4));
   long debFootnote = m_state->m_textLength[0];
   PLC plc(PLC::Footnote);
   PLC defPlc(PLC::FootnoteDef);
   for (int i = 0; i < N; i++) {
     MsWrdTextInternal::Footnote note;
     note.m_id = i;
-    note.m_pos.setBegin(debFootnote+noteDef[(size_t)i]);
-    note.m_pos.setEnd(debFootnote+noteDef[(size_t)i+1]);
-    note.m_value = (int) input->readLong(2);
+    note.m_pos.setBegin(debFootnote+noteDef[size_t(i)]);
+    note.m_pos.setEnd(debFootnote+noteDef[size_t(i)+1]);
+    note.m_value = static_cast<int>(input->readLong(2));
     m_state->m_footnoteList.push_back(note);
 
-    if (textPos[(size_t)i] > m_state->getTotalTextSize()) {
+    if (textPos[size_t(i)] > m_state->getTotalTextSize()) {
       MWAW_DEBUG_MSG(("MsWrdText::readFootnotesPos: can not find text position\n"));
       f << "#";
     }
-    else if (noteDef[(size_t)i+1] > m_state->m_textLength[1]) {
+    else if (noteDef[size_t(i)+1] > m_state->m_textLength[1]) {
       MWAW_DEBUG_MSG(("MsWrdText::readFootnotesPos: can not find definition position\n"));
       f << "#";
     }
     else {
       defPlc.m_id = plc.m_id = i;
       m_state->m_plcMap.insert(std::multimap<long,PLC>::value_type
-                               (textPos[(size_t)i], plc));
+                               (textPos[size_t(i)], plc));
       m_state->m_plcMap.insert(std::multimap<long,PLC>::value_type
                                (note.m_pos.begin(), defPlc));
     }
-    f << std::hex << textPos[(size_t)i] << std::dec << ":" << note;
+    f << std::hex << textPos[size_t(i)] << std::dec << ":" << note;
   }
-  f << "end=" << std::hex << textPos[(size_t)N] << std::dec << ",";
+  f << "end=" << std::hex << textPos[size_t(N)] << std::dec << ",";
   ascFile.addPos(entry.begin());
   ascFile.addNote(f.str().c_str());
   ascFile.addPos(entry.end());
@@ -1029,19 +1058,19 @@ bool MsWrdText::readFootnotesData(MsWrdEntry &entry)
   f << "FootnoteData[" << N << "/" << m_state->m_footnoteList.size() << "]:";
 
   std::vector<long> textPos; // checkme
-  textPos.resize((size_t)N+1);
+  textPos.resize(size_t(N)+1);
   for (int i = 0; i <= N; i++)
-    textPos[(size_t)i]= (long) input->readULong(4);
+    textPos[size_t(i)]= long(input->readULong(4));
   for (int i = 0; i < N; i++) {
-    if (textPos[(size_t)i] > m_state->m_textLength[1]) {
+    if (textPos[size_t(i)] > m_state->m_textLength[1]) {
       MWAW_DEBUG_MSG(("MsWrdText::readFootnotesData: textPositions seems bad\n"));
       f << "#";
     }
     f << "N" << i << "=[";
-    if (textPos[(size_t)i])
-      f << "pos=" << std::hex << textPos[(size_t)i] << std::dec << ",";
+    if (textPos[size_t(i)])
+      f << "pos=" << std::hex << textPos[size_t(i)] << std::dec << ",";
     for (int j = 0; j < 5; j++) { // always 0|4000, -1, 0, id, 0 ?
-      int val=(int) input->readLong(2);
+      int val=static_cast<int>(input->readLong(2));
       if (val && j == 0)
         f << std::hex << val << std::dec << ",";
       else if (val)
@@ -1050,7 +1079,7 @@ bool MsWrdText::readFootnotesData(MsWrdEntry &entry)
     }
     f << "],";
   }
-  f << "end=" << std::hex << textPos[(size_t)N] << std::dec << ",";
+  f << "end=" << std::hex << textPos[size_t(N)] << std::dec << ",";
   ascFile.addPos(entry.begin());
   ascFile.addNote(f.str().c_str());
   ascFile.addPos(entry.end());
@@ -1075,7 +1104,7 @@ bool MsWrdText::readFields(MsWrdEntry &entry, std::vector<long> const &fieldPos)
   MWAWInputStreamPtr &input= m_parserState->m_input;
   input->seek(pos, librevenge::RVNG_SEEK_SET);
 
-  long sz = (long) input->readULong(2);
+  long sz = long(input->readULong(2));
   if (entry.length() != sz) {
     MWAW_DEBUG_MSG(("MsWrdText::readFields: the zone size seems odd\n"));
     return false;
@@ -1091,7 +1120,7 @@ bool MsWrdText::readFields(MsWrdEntry &entry, std::vector<long> const &fieldPos)
       break;
     }
     pos = input->tell();
-    int fSz = (int) input->readULong(1);
+    int fSz = static_cast<int>(input->readULong(1));
     if (pos+1+fSz > entry.end()) {
       MWAW_DEBUG_MSG(("MsWrdText::readFields: can not read a string\n"));
       input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -1103,7 +1132,7 @@ bool MsWrdText::readFields(MsWrdEntry &entry, std::vector<long> const &fieldPos)
     f2.str("");
     std::string text("");
     for (int i = 0; i < fSz-endSz; i++) {
-      char c = (char) input->readULong(1);
+      char c = char(input->readULong(1));
       if (c==0) f2 << '#';
       else text+=c;
     }
@@ -1114,7 +1143,7 @@ bool MsWrdText::readFields(MsWrdEntry &entry, std::vector<long> const &fieldPos)
       for (int i = 0; i < 2; i++) text+=char(input->readULong(1));
     }
     else {
-      int id = (int) input->readULong(1);
+      int id = static_cast<int>(input->readULong(1));
       if (id >= N) {
         if (version()>=5) {
           MWAW_DEBUG_MSG(("MsWrdText::readFields: find a strange id\n"));
@@ -1131,14 +1160,14 @@ bool MsWrdText::readFields(MsWrdEntry &entry, std::vector<long> const &fieldPos)
     m_state->m_fieldList.push_back(field);
 
     f << "N" << n << "=" << field << ",";
-    if (fieldPos[(size_t)n] >= textLength) {
+    if (fieldPos[size_t(n)] >= textLength) {
       MWAW_DEBUG_MSG(("MsWrdText::readFields: text positions is bad...\n"));
       f << "#";
     }
     else {
       plc.m_id = n-1;
       m_state->m_plcMap.insert(std::multimap<long,PLC>::value_type
-                               (fieldPos[(size_t)n], plc));
+                               (fieldPos[size_t(n)], plc));
     }
   }
   if (long(input->tell()) != entry.end())
@@ -1169,8 +1198,9 @@ bool MsWrdText::readLongZone(MsWrdEntry &entry, int sz, std::vector<long> &list)
   f << entry.type() << ":";
   int N = int(entry.length()/sz);
   for (int i = 0; i < N; i++) {
-    int val = (int) input->readLong(sz);
-    list.push_back(val);
+    int val = static_cast<int>(input->readLong(sz));
+    if (input->checkPosition(val))
+      list.push_back(val);
     f << std::hex << val << std::dec << ",";
   }
 
@@ -1209,13 +1239,13 @@ void MsWrdText::prepareLines()
       MsWrdText::PLC const &plc = plcIt++->second;
       if (plc.m_type != PLC::TextPosition)
         continue;
-      if (plc.m_id < 0 || plc.m_id >= (int)numTextPos)
+      if (plc.m_id < 0 || plc.m_id >= static_cast<int>(numTextPos))
         continue;
       MsWrdTextInternal::TextStruct const &textEntry=
-        m_state->m_textposList[(size_t) plc.m_id];
+        m_state->m_textposList[size_t(plc.m_id)];
       input->seek(textEntry.begin(), librevenge::RVNG_SEEK_SET);
     }
-    char c=(char) input->readLong(1);
+    char c=char(input->readLong(1));
     ++cPos;
     if (c!=0x7 && c!=0xd && cPos!=cEnd)
       continue;
@@ -1398,7 +1428,7 @@ void MsWrdText::prepareParagraphProperties()
     MsWrdStruct::Paragraph finalPara(paragraph);
     if (textId>=0 && textId < textposSize) {
       MsWrdTextInternal::TextStruct const &textEntry=
-        m_state->m_textposList[(size_t) textId];
+        m_state->m_textposList[size_t(textId)];
       int id=textEntry.getParagraphId();
       // checkme do we need to test (textEntry.m_type&0x80)==0 here
       if (id>=0) {
@@ -1486,7 +1516,7 @@ void MsWrdText::prepareFontProperties()
           MWAW_DEBUG_MSG(("MsWrdText::prepareFontProperties: oops can not find textstruct!!!!\n"));
           break;
         }
-        MsWrdTextInternal::TextStruct const &textEntry=m_state->m_textposList[(size_t) pId];
+        MsWrdTextInternal::TextStruct const &textEntry=m_state->m_textposList[size_t(pId)];
         textPId=textEntry.getParagraphId();
         break;
       }
@@ -1505,7 +1535,9 @@ void MsWrdText::prepareFontProperties()
       case PLC::Paragraph:
       case PLC::ParagraphInfo:
       case PLC::Section:
+#if !defined(__clang__)
       default:
+#endif
         break;
       }
     }
@@ -1585,8 +1617,8 @@ void MsWrdText::prepareTableLimits()
       }
       std::map<long, int>::const_iterator pIt;
       pIt=m_state->m_paragraphLimitMap.find(line.m_cPos[0]);
-      if (pIt!=m_state->m_paragraphLimitMap.end() && pIt->second>0 && pIt->second<(int)numTextpos) {
-        MsWrdTextInternal::TextStruct const &textEntry=m_state->m_textposList[(size_t) pIt->second];
+      if (pIt!=m_state->m_paragraphLimitMap.end() && pIt->second>0 && pIt->second<static_cast<int>(numTextpos)) {
+        MsWrdTextInternal::TextStruct const &textEntry=m_state->m_textposList[size_t(pIt->second)];
         int id=textEntry.getParagraphId();
         if (id>=0) {
           MsWrdStruct::Paragraph modifier(vers);
@@ -1602,7 +1634,7 @@ void MsWrdText::prepareTableLimits()
       MsWrdStruct::Table const &table = para.m_table.get();
       size_t numCols=table.m_columns->size();
       if (!numCols || listDelimiterCells.size()!=numCols) {
-        MWAW_DEBUG_MSG(("MsWrdText::prepareTableLimits: can not find the number of row for position %ld(%d,%d)\n", line.m_cPos[0], int(listDelimiterCells.size()), (int) numCols));
+        MWAW_DEBUG_MSG(("MsWrdText::prepareTableLimits: can not find the number of row for position %ld(%d,%d)\n", line.m_cPos[0], int(listDelimiterCells.size()), static_cast<int>(numCols)));
         break;
       }
 
@@ -1707,7 +1739,7 @@ void MsWrdText::prepareData()
           f << "[###tP" << pId << "]";
         }
         else {
-          MsWrdTextInternal::TextStruct const &textEntry=m_state->m_textposList[(size_t) pId];
+          MsWrdTextInternal::TextStruct const &textEntry=m_state->m_textposList[size_t(pId)];
           pos = textEntry.begin();
 #if defined(DEBUG_WITH_FILES) && DEBUG_PARAGRAPH
           int paraId=textEntry.getParagraphId();
@@ -1737,7 +1769,7 @@ void MsWrdText::prepareData()
       case PLC::ParagraphInfo:
 #if defined(DEBUG_WITH_FILES) && DEBUG_PARAGRAPHINFO
         if (pId >= 0 && pId < int(m_state->m_paraInfoList.size())) {
-          MsWrdStruct::ParagraphInfo info=m_state->m_paraInfoList[(size_t) pId];
+          MsWrdStruct::ParagraphInfo info=m_state->m_paraInfoList[size_t(pId)];
           f << "Pi" << pId  << "=[" << info << "],";
         }
         else
@@ -1747,7 +1779,7 @@ void MsWrdText::prepareData()
       case PLC::Page:
 #if defined(DEBUG_WITH_FILES) && DEBUG_PAGE
         if (pId  >= 0 && pId < int(m_state->m_pageList.size()))
-          f << "Pg" << pId << "=[" << m_state->m_pageList[(size_t) pId] << "],";
+          f << "Pg" << pId << "=[" << m_state->m_pageList[size_t(pId)] << "],";
         else
           f << "Pg_,";
 #endif
@@ -1781,7 +1813,9 @@ void MsWrdText::prepareData()
       case PLC::FootnoteDef:
       case PLC::HeaderFooter:
       case PLC::Object:
+#if !defined(__clang__)
       default:
+#endif
         break;
       }
     }
@@ -1795,7 +1829,7 @@ void MsWrdText::prepareData()
       ascFile.addPos(pos);
       ascFile.addNote(f2.str().c_str());
 #if defined(DEBUG_WITH_FILES)
-      MsWrdTextInternal::debugFile2() << f2.str() << "\n";
+      m_state->debugFile2() << f2.str() << "\n";
 #endif
       prop.m_debugPrint = true;
     }
@@ -1873,7 +1907,9 @@ bool MsWrdText::sendText(MWAWEntry const &textEntry, bool mainZone, bool tableCe
       case PLC::Object:
       case PLC::Paragraph:
       case PLC::ParagraphInfo:
+#if !defined(__clang__)
       default:
+#endif
         break;
       }
     }
@@ -1883,7 +1919,7 @@ bool MsWrdText::sendText(MWAWEntry const &textEntry, bool mainZone, bool tableCe
       ascFile.addPos(debPos);
       ascFile.addNote(f.str().c_str());
 #if defined(DEBUG_WITH_FILES)
-      MsWrdTextInternal::debugFile2() << f.str() << "\n";
+      m_state->debugFile2() << f.str() << "\n";
 #endif
       f.str("");
       f << "TextContent["<<cPos<<"]:";
@@ -1910,7 +1946,7 @@ bool MsWrdText::sendText(MWAWEntry const &textEntry, bool mainZone, bool tableCe
       m_stylesManager->setProperty(font);
     }
     for (long p = cPos; p < cEndPos; p++) {
-      int c = (int) input->readULong(1);
+      int c = static_cast<int>(input->readULong(1));
       cPos++;
       pos++;
       switch (c) {
@@ -1999,7 +2035,7 @@ bool MsWrdText::sendText(MWAWEntry const &textEntry, bool mainZone, bool tableCe
         listener->insertUnicode(0xf8ff);
         break;
       default:
-        p+=listener->insertCharacter((unsigned char)c, input, input->tell()+(cEndPos-1-p));
+        p+=listener->insertCharacter(static_cast<unsigned char>(c), input, input->tell()+(cEndPos-1-p));
         break;
       }
       if (c)
@@ -2020,11 +2056,11 @@ bool MsWrdText::sendSection(int secId)
 {
   int textStructId=-1;
   if (!m_state->m_textposList.empty() &&
-      secId>=0 && secId+1<(int)m_state->m_sectionLimitList.size()) {
+      secId>=0 && secId+1<static_cast<int>(m_state->m_sectionLimitList.size())) {
     int tId=m_state->getTextStructId
-            (m_state->m_sectionLimitList[(size_t)secId+1]-1);
-    if (tId>=0 && tId<(int)m_state->m_textposList.size())
-      textStructId=m_state->m_textposList[(size_t)tId].getParagraphId();
+            (m_state->m_sectionLimitList[size_t(secId)+1]-1);
+    if (tId>=0 && tId<static_cast<int>(m_state->m_textposList.size()))
+      textStructId=m_state->m_textposList[size_t(tId)].getParagraphId();
   }
   return m_stylesManager->sendSection(secId, textStructId);
 }
@@ -2069,13 +2105,13 @@ bool MsWrdText::sendTable(MsWrdTextInternal::Table const &table)
           cell.setBorders(wh[i], tCell.m_borders[i].get());
         }
         if (tCell.m_backColor.isSet()) {
-          unsigned char col = (unsigned char)(tCell.m_backColor.get()*255.f);
+          unsigned char col = static_cast<unsigned char>(tCell.m_backColor.get()*255.f);
           cell.setBackgroundColor(MWAWColor(col,col,col));
         }
         else if (!table.m_backgroundColor.isWhite())
           cell.setBackgroundColor(table.m_backgroundColor);
       }
-      cell.setPosition(MWAWVec2i((int)c,(int)r));
+      cell.setPosition(MWAWVec2i(static_cast<int>(c),static_cast<int>(r)));
 
       listener->openTableCell(cell);
 
@@ -2088,7 +2124,7 @@ bool MsWrdText::sendTable(MsWrdTextInternal::Table const &table)
       else
         sendText(textData, false, true);
 #if defined(DEBUG_WITH_FILES)
-      MsWrdTextInternal::debugFile2() << "TextContent["<<cEndPos<<"]:" << char(7) << "\n";
+      m_state->debugFile2() << "TextContent["<<cEndPos<<"]:" << char(7) << "\n";
 #endif
       listener->closeTableCell();
     }
@@ -2116,7 +2152,7 @@ bool MsWrdText::sendFootnote(int id)
     listener->insertChar(' ');
     return false;
   }
-  MsWrdTextInternal::Footnote &footnote = m_state->m_footnoteList[(size_t) id];
+  MsWrdTextInternal::Footnote &footnote = m_state->m_footnoteList[size_t(id)];
   if (footnote.m_pos.isParsed())
     listener->insertChar(' ');
   else
@@ -2138,10 +2174,10 @@ bool MsWrdText::sendFieldComment(int id)
   defFont.m_font = m_stylesManager->getDefaultFont();
   m_stylesManager->setProperty(defFont);
   m_stylesManager->sendDefaultParagraph();
-  std::string const &text = m_state->m_fieldList[(size_t) id].m_text;
+  std::string const &text = m_state->m_fieldList[size_t(id)].m_text;
   if (!text.length()) listener->insertChar(' ');
   for (size_t c = 0; c < text.length(); c++)
-    listener->insertCharacter((unsigned char) text[c]);
+    listener->insertCharacter(static_cast<unsigned char>(text[c]));
   return true;
 }
 
