@@ -59,7 +59,7 @@ namespace NisusWrtParserInternal
 /** Internal structure: use to store a numbering, a variable or a version */
 struct Variable {
   //! Constructor
-  Variable(NisusWrtStruct::VariableType type = NisusWrtStruct::V_None) :
+  explicit Variable(NisusWrtStruct::VariableType type = NisusWrtStruct::V_None) :
     m_type(0), m_containerType(type), m_fieldType(-1), m_refId(-1),
     m_numberingType(libmwaw::NONE), m_startNumber(1), m_increment(1),
     m_prefix(""), m_suffix(""), m_dateFormat(0), m_sample(""), m_extra("")
@@ -166,9 +166,11 @@ std::ostream &operator<<(std::ostream &o, Variable const &num)
     break;
   case NisusWrtStruct::V_None:
     break;
+#if !defined(__clang__)
   default:
     o << "#type[container]=" << int(num.m_containerType) << ",";
     return o;
+#endif
   }
   if (num.m_refId >= 0)
     o << "refId=" << num.m_refId << ",";
@@ -451,7 +453,7 @@ bool NisusWrtParser::getReferenceData
     doneValues[size_t(var.m_refId)]=true;
     toDoValues.push_back(int(var.m_refId));
     while (toDoValues.size()) {
-      int modId = (int) toDoValues.back();
+      int modId = static_cast<int>(toDoValues.back());
       toDoValues.pop_back();
       for (size_t r = 0; r < numReset; r++) {
         if (zone.m_numberingResetList[r] != modId)
@@ -467,7 +469,7 @@ bool NisusWrtParser::getReferenceData
   std::stringstream s;
   std::string str = ref.m_prefix + ref.m_suffix;
   for (size_t p = 0; p < str.length(); p++) {
-    unsigned char c = (unsigned char) str[p];
+    unsigned char c = static_cast<unsigned char>(str[p]);
     if (c==0 || (c < 0x20 && c > numVar)) {
       MWAW_DEBUG_MSG(("NisusWrtParser::getReferenceData: find unknown variable\n"));
 #ifdef DEBUG
@@ -478,7 +480,7 @@ bool NisusWrtParser::getReferenceData
       s << libmwaw::numberingValueToString
         (m_state->m_numberingList[size_t(c-1)].m_numberingType,
          values[size_t(c-1)]);
-    else s << (char)c;
+    else s << char(c);
   }
   content=s.str();
   return true;
@@ -850,7 +852,7 @@ bool NisusWrtParser::readStringsList(MWAWEntry const &entry, std::vector<std::st
         MWAW_DEBUG_MSG(("NisusWrtParser::readStringsList: can not read strings\n"));
         return false;
       }
-      int sz = (int)input->readULong(2);
+      int sz = static_cast<int>(input->readULong(2));
       endPos = pos+2+sz;
       if (pos+2+sz > entry.end()) {
         f.str("");
@@ -868,7 +870,7 @@ bool NisusWrtParser::readStringsList(MWAWEntry const &entry, std::vector<std::st
      */
     std::string str("");
     while (input->tell() < endPos-1) {
-      int pSz = (int)input->readULong(1);
+      int pSz = static_cast<int>(input->readULong(1));
       if (pSz == 0xFF) {
         f << "_";
         pSz = 0;
@@ -882,7 +884,7 @@ bool NisusWrtParser::readStringsList(MWAWEntry const &entry, std::vector<std::st
       }
       std::string str1("");
       for (int c=0; c < pSz; c++)
-        str1 += (char) input->readULong(1);
+        str1 += char(input->readULong(1));
       f << str1 << ",";
       str += str1;
       if (simpleList) continue;
@@ -938,7 +940,9 @@ bool NisusWrtParser::readVariable(NisusWrtStruct::RecursifData const &data)
     result = &zone.m_variableList;
     break;
   case NisusWrtStruct::V_None:
+#if !defined(__clang__)
   default:
+#endif
     MWAW_DEBUG_MSG(("NisusWrtParser::readVariable: find unexpected dataType\n"));
     return false;
   }
@@ -1018,7 +1022,7 @@ bool NisusWrtParser::readVariable(NisusWrtStruct::RecursifData const &data)
       case 4: // display example
       case 10:
       case 12: { // postfix : list of fields
-        int mSz = (int) input->readULong(1);
+        int mSz = static_cast<int>(input->readULong(1));
         if (mSz+1 > entry.length()) {
           MWAW_DEBUG_MSG(("NisusWrtParser::readVariable: the dpsl seems to short\n"));
           f << "###Text";
@@ -1026,7 +1030,7 @@ bool NisusWrtParser::readVariable(NisusWrtStruct::RecursifData const &data)
         }
         std::string text("");
         for (int i = 0; i < mSz; i++)
-          text+= (char) input->readULong(1);
+          text+= char(input->readULong(1));
         static char const *(wh0[]) = { "unkn0", "prefix", "name", "comments" };
         static char const *(wh1[]) = { "unkn1", "sample", "sample", "author?" };
         static char const *(wh2[]) = { "unkn2", "suffix", "suffix", "unkn2" };
@@ -1053,7 +1057,7 @@ bool NisusWrtParser::readVariable(NisusWrtStruct::RecursifData const &data)
         break;
       }
       case -4: { // date format
-        num.m_dateFormat = (int) input->readULong(2);
+        num.m_dateFormat = static_cast<int>(input->readULong(2));
         if (!num.m_dateFormat) break; // default
         std::string format("");
         format = num.getDateFormat();
@@ -1062,7 +1066,7 @@ bool NisusWrtParser::readVariable(NisusWrtStruct::RecursifData const &data)
         break;
       }
       case 5: // style : 0=arabic, 1=roman, upperroman, abgadhawaz(arabic), alpha, upperalpha, hebrew
-        val = (long) input->readULong(2);
+        val = long(input->readULong(2));
         f << "type=";
         num.m_numberingType = libmwaw::ARABIC;
         switch (val) {
@@ -1096,19 +1100,19 @@ bool NisusWrtParser::readVariable(NisusWrtStruct::RecursifData const &data)
         }
         break;
       case 6: // start number
-        num.m_startNumber = (int) input->readLong(2);
+        num.m_startNumber = static_cast<int>(input->readLong(2));
         f << "start=" << num.m_startNumber <<",";
         break;
       case 7: // increment
-        num.m_increment = (int) input->readLong(2);
+        num.m_increment = static_cast<int>(input->readLong(2));
         f << "increment=" << num.m_increment <<",";
         break;
       case 9: // id ?
-        num.m_refId = (int) input->readULong(4);
+        num.m_refId = static_cast<int>(input->readULong(4));
         f << "refId=" << num.m_refId << ",";
         break;
       case 3:
-        num.m_fieldType = (long) input->readULong(4);
+        num.m_fieldType = long(input->readULong(4));
         switch (num.m_fieldType) {
         // 1(type 5) date ?
         case 0xe:
@@ -1147,11 +1151,11 @@ bool NisusWrtParser::readVariable(NisusWrtStruct::RecursifData const &data)
         }
         break;
       case 8: // always 0 ?
-        val = (long) input->readULong(4);
+        val = long(input->readULong(4));
         f << "g8=" << val << ",";
         break;
       case 11: // find 0-2: if numbering g11=0 means add default data, if not num data?
-        val = (long) input->readULong(4);
+        val = long(input->readULong(4));
         if (val==0) {
           f << "auto,";
           if (num.m_suffix.length())
@@ -1195,7 +1199,7 @@ bool NisusWrtParser::readNumberingReset(MWAWEntry const &entry, int zoneId)
   MWAWInputStreamPtr input = rsrcInput();
   long pos = entry.begin();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
-  int sz = (int) input->readULong(2);
+  int sz = static_cast<int>(input->readULong(2));
   if (sz+2 != entry.length() || sz%2) {
     MWAW_DEBUG_MSG(("NisusWrtParser::readNumberingReset: entry size seems odd\n"));
     return false;
@@ -1236,7 +1240,7 @@ bool NisusWrtParser::readReference(NisusWrtStruct::RecursifData const &data)
   }
   NisusWrtStruct::RecursifData const &mainData = *data.m_childList[0].m_data;
   size_t numData = mainData.m_childList.size();
-  NisusWrtParserInternal::Zone &zone = m_state->m_zones[(int) data.m_info->m_zoneType];
+  NisusWrtParserInternal::Zone &zone = m_state->m_zones[static_cast<int>(data.m_info->m_zoneType)];
   MWAWInputStreamPtr input = rsrcInput();
   libmwaw::DebugStream f, f2;
 
@@ -1284,8 +1288,8 @@ bool NisusWrtParser::readReference(NisusWrtStruct::RecursifData const &data)
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     f.str("");
     f << "Position:";
-    ref.m_textPosition.setBegin((long)input->readULong(4));
-    ref.m_textPosition.setEnd((long)input->readULong(4));
+    ref.m_textPosition.setBegin(long(input->readULong(4)));
+    ref.m_textPosition.setEnd(long(input->readULong(4)));
     f << "filePos=" << std::hex
       << ref.m_textPosition.begin() << "<->" << ref.m_textPosition.end() << std::dec << ",";
     rsrcAscii().addPos(pos-12);
@@ -1341,7 +1345,7 @@ bool NisusWrtParser::readReference(NisusWrtStruct::RecursifData const &data)
           f << "###";
           break;
         }
-        ref.m_id = (int) input->readLong(4); // some kind of id ?
+        ref.m_id = static_cast<int>(input->readLong(4)); // some kind of id ?
         f << "id?=" << ref.m_id << ",";
         break;
       case 0x7ffffffc: // find one time with 0
@@ -1359,14 +1363,14 @@ bool NisusWrtParser::readReference(NisusWrtStruct::RecursifData const &data)
           f << "###";
           break;
         }
-        int mSz = (int) input->readULong(1);
+        int mSz = static_cast<int>(input->readULong(1));
         if (mSz+1 > entry.length()) {
           f << "###";
           break;
         }
         std::string mark("");
         for (int i = 0; i < mSz; i++)
-          mark+=(char) input->readULong(1);
+          mark+=char(input->readULong(1));
         ref.m_text = mark;
         f << mark;
         break;
@@ -1432,7 +1436,7 @@ bool NisusWrtParser::readSGP1(NisusWrtStruct::RecursifData const &data)
   }
   NisusWrtStruct::RecursifData const &mainData = *data.m_childList[0].m_data;
   size_t numData = mainData.m_childList.size();
-  //  NisusWrtParserInternal::Zone &zone = m_state->m_zones[(int) data.m_info->m_zoneType];
+  //  NisusWrtParserInternal::Zone &zone = m_state->m_zones[static_cast<int>(data.m_info->m_zoneType)];
   MWAWInputStreamPtr input = rsrcInput();
   libmwaw::DebugStream f;
 
@@ -1478,7 +1482,7 @@ bool NisusWrtParser::readSGP1(NisusWrtStruct::RecursifData const &data)
           f << "###sz";
           break;
         }
-        int mSz = (int) input->readULong(1);
+        int mSz = static_cast<int>(input->readULong(1));
         if (mSz+1 > child.m_entry.length()) {
           MWAW_DEBUG_MSG(("NisusWrtParser::readSGP1: the %d text seems to short\n", child.m_type));
           f << "###sz";
@@ -1486,7 +1490,7 @@ bool NisusWrtParser::readSGP1(NisusWrtStruct::RecursifData const &data)
         }
         std::string text("");
         for (int c = 0; c < mSz; c++)
-          text+=(char) input->readULong(1);
+          text+=char(input->readULong(1));
         f << "text=" << text << ",";
         break;
       }
@@ -1509,22 +1513,22 @@ bool NisusWrtParser::readSGP1(NisusWrtStruct::RecursifData const &data)
           f << "###sz";
           break;
         }
-        val = (long) input->readULong(2); // always 0x8000 ?
+        val = long(input->readULong(2)); // always 0x8000 ?
         if (val != 0x8000) f << "f0=" << std::hex << val << std::dec << ",";
         for (int j = 0; j < 2; j++) { // find [0,-2]|0
           val = input->readLong(2);
           if (val) f << "f" << j+1 << "=" << val << ",";
         }
-        val = (long) input->readULong(2); // find 0 and 1 time 0x7101
+        val = long(input->readULong(2)); // find 0 and 1 time 0x7101
         if (val) f << "f3=" << std::hex << val << std::dec << ",";
-        int mSz = (int) input->readULong(1);
+        int mSz = static_cast<int>(input->readULong(1));
         if (mSz >= 32) {
           f << "###textSz=" << mSz << ",";
           mSz = 0;
         }
         std::string text("");
         for (int j = 0; j < mSz; j++)
-          text += (char) input->readULong(1);
+          text += char(input->readULong(1));
         if (text.length()) f << "\"" << text << "\",";
         // checkme: where does the data begins again
         input->seek(child.m_entry.begin()+40, librevenge::RVNG_SEEK_SET);
@@ -1532,7 +1536,7 @@ bool NisusWrtParser::readSGP1(NisusWrtStruct::RecursifData const &data)
           val = input->readLong(2);
           if (val) f << "g" << j << "=" << val << ",";
         }
-        val = (long) input->readULong(2); // 1|b
+        val = long(input->readULong(2)); // 1|b
         f << "unkn=" << val << ",";
         for (int j = 0; j < 8; j++) { // find always 0 here
           val = input->readLong(2);
@@ -1652,7 +1656,7 @@ bool NisusWrtParser::readPageLimit(MWAWEntry const &entry)
   for (int i = 0; i < 3; i++) {
     int dim[4];
     for (int d = 0; d < 4; d++)
-      dim[d] = (int) input->readLong(2);
+      dim[d] = static_cast<int>(input->readLong(2));
     boxes[i] = MWAWBox2i(MWAWVec2i(dim[1],dim[0]),MWAWVec2i(dim[3],dim[2]));
   }
   f << "page=" << boxes[0] << ",";
@@ -1673,8 +1677,8 @@ bool NisusWrtParser::readPageLimit(MWAWEntry const &entry)
     val = input->readLong(2);
     if (val) f << "g" << i << "=" << val << ",";
   }
-  int numColumns = (int) input->readLong(2)+1;
-  int colSeps = (int) input->readLong(2);
+  int numColumns = static_cast<int>(input->readLong(2))+1;
+  int colSeps = static_cast<int>(input->readLong(2));
   if (!dimOk) ;
   else if (numColumns <= 0 || numColumns > 8 || colSeps < 0 || colSeps *numColumns >= pageDim[0]) {
     MWAW_DEBUG_MSG(("NisusWrtParser::readPageLimit: the columns definition seems odd\n"));
@@ -1718,7 +1722,7 @@ bool NisusWrtParser::readPageLimit(MWAWEntry const &entry)
   f.str("");
   f << "Page[A]:";
   // find 0,3ea0f83e|3ea19dbd|3ea2433b|3ec00000|3ec0a57f
-  val = (long) input->readULong(4);
+  val = long(input->readULong(4));
   if (val) f << "f0=" << std::hex << val << std::dec << ",";
   // find f3=[0|1|-1]
   for (int i = 1; i < 4; i++) {
@@ -1734,7 +1738,7 @@ bool NisusWrtParser::readPageLimit(MWAWEntry const &entry)
   }
   int dim[4];
   for (int d = 0; d < 4; d++)
-    dim[d] = (int) input->readLong(2);
+    dim[d] = static_cast<int>(input->readLong(2));
   MWAWBox2i realPage = MWAWBox2i(MWAWVec2i(dim[1],dim[0]), MWAWVec2i(dim[3],dim[2]));
   if (dimOk && realPage.size()[0] >= pageDim[0] && realPage.size()[1] >= pageDim[1]) {
     LT -= realPage[0];
@@ -1768,7 +1772,7 @@ bool NisusWrtParser::readPageLimit(MWAWEntry const &entry)
   // a size ? often 114,16d
   int sz[2];
   for (int i = 0; i < 2; i++)
-    sz[i]=(int)input->readLong(2);
+    sz[i]=static_cast<int>(input->readLong(2));
   if (sz[0]||sz[1])
     f << "sz=" << sz[1] << "x" << sz[0] << ",";
   // v3: 0,0 or v4: 0x29 0x3 ?
@@ -1779,7 +1783,7 @@ bool NisusWrtParser::readPageLimit(MWAWEntry const &entry)
   }
   // another sz ? ~153,~1fc
   for (int i = 0; i < 2; i++)
-    sz[i]=(int)input->readLong(2);
+    sz[i]=static_cast<int>(input->readLong(2));
   if (sz[0]||sz[1])
     f << "sz2=" << sz[1] << "x" << sz[0] << ",";
   // 0|-1, find also g4=0xa
@@ -1796,7 +1800,7 @@ bool NisusWrtParser::readPageLimit(MWAWEntry const &entry)
   }
   // a dim
   for (int i = 0; i < 2; i++)
-    sz[i]=(int)input->readLong(2);
+    sz[i]=static_cast<int>(input->readLong(2));
   if (sz[0]||sz[1])
     f << "dim=" << sz[1] << "x" << sz[0] << ",";
   // all 0 expected k1=[0|1], k2=[0|1] k4=1
@@ -1850,7 +1854,7 @@ bool NisusWrtParser::readCPRC(MWAWEntry const &entry)
       except one time f0=1[id?], f4=1900 f6=206c [2pos?]
    */
   for (int i = 0; i < int(entry.length())/2; i++) {
-    int val = (int) input->readULong(2);
+    int val = static_cast<int>(input->readULong(2));
     if (val) f << "#f" << i << "=" << std::hex << val << std::dec << ",";
   }
 
@@ -2031,7 +2035,7 @@ bool NisusWrtParser::readFnSc(MWAWEntry const &entry)
   long val;
   val = input->readLong(2); // find 0|3|10|14
   if (val) f << "f0=" << val << ",";
-  val = (long) input->readULong(2); // find 0|4000|4034
+  val = long(input->readULong(2)); // find 0|4000|4034
   if (val) f << "f1=" << std::hex << val << std::dec << ",";
   for (int i = 0; i < 31; i++) { // always 0?
     val = input->readLong(2);
@@ -2069,7 +2073,7 @@ bool NisusWrtParser::readINFO(MWAWEntry const &entry)
   if (val != 1) f << "f0=" << val << ",";
   int select[2]; // checkme
   for (int i = 0; i < 2; i++)
-    select[i] = (int) input->readLong(4);
+    select[i] = static_cast<int>(input->readLong(4));
   if (select[0] || select[1]) {
     f << "select=" << select[0];
     if (select[1] != select[0]) f << "x" << select[1];
@@ -2080,13 +2084,13 @@ bool NisusWrtParser::readINFO(MWAWEntry const &entry)
   // a dim or 2 position ?
   int dim[4];
   for (int i = 0; i < 4; i++)
-    dim[i] = (int) input->readLong(2);
+    dim[i] = static_cast<int>(input->readLong(2));
   if (dim[0] || dim[1] || dim[2] || dim[3])
     f << "dim|pos?=" << dim[0] << "x" << dim[1]
       << "<->" << dim[2] << "x" << dim[3] << ",";
   int sz[2];
   for (int i = 0; i < 2; i++)
-    sz[i] = (int) input->readLong(2);
+    sz[i] = static_cast<int>(input->readLong(2));
   if (sz[0] || sz[1])
     f << "sz=" << sz[0] << "x" << sz[1] << ",";
   for (int i = 0; i < 2; i++) { // always 1|1
@@ -2108,18 +2112,18 @@ bool NisusWrtParser::readINFO(MWAWEntry const &entry)
     if (val) f << "f" << i << "=" << val << ",";
   }
   // 4 times the same val: 0, aa55, ffff
-  int unkn = (int) input->readULong(2);
+  int unkn = static_cast<int>(input->readULong(2));
   if (unkn) f << "unknA0=" << std::hex << unkn << std::dec << ",";
   for (int i = 1; i < 4; i++) {
-    val = (long) input->readULong(2);
+    val = long(input->readULong(2));
     if (val != unkn)
       f << "unknA" << i << "=" << std::hex << val << std::dec << ",";
   }
   // 4 times the same val: 0, ffff
-  unkn = (int) input->readULong(2);
+  unkn = static_cast<int>(input->readULong(2));
   if (unkn) f << "unknB0=" << std::hex << unkn << std::dec << ",";
   for (int i = 1; i < 4; i++) {
-    val = (long) input->readULong(2);
+    val = long(input->readULong(2));
     if (val != unkn)
       f << "unknB" << i << "=" << std::hex << val << std::dec << ",";
   }
@@ -2147,11 +2151,11 @@ bool NisusWrtParser::readINFO(MWAWEntry const &entry)
   f << "INFOC:";
 
   NisusWrtStruct::FootnoteInfo &ftInfo = m_state->m_footnoteInfo;
-  ftInfo.m_flags = (int)input->readULong(2);
-  ftInfo.m_unknown = (int)input->readLong(2);
-  ftInfo.m_distToDocument = (int)input->readLong(2);
-  ftInfo.m_distSeparator = (int)input->readLong(2);
-  ftInfo.m_separatorLength = (int)input->readLong(2);
+  ftInfo.m_flags = static_cast<int>(input->readULong(2));
+  ftInfo.m_unknown = static_cast<int>(input->readLong(2));
+  ftInfo.m_distToDocument = static_cast<int>(input->readLong(2));
+  ftInfo.m_distSeparator = static_cast<int>(input->readLong(2));
+  ftInfo.m_separatorLength = static_cast<int>(input->readLong(2));
   f << "footnote=[" << ftInfo << "],";
   rsrcAscii().addDelimiter(input->tell(), '|');
   rsrcAscii().addPos(pos);
