@@ -86,7 +86,7 @@ struct Font {
   //! a series of flags
   int m_format2;
   //! two picture dim ( orig && file ?)
-  Box2i m_pictureDim[2];
+  MWAWBox2i m_pictureDim[2];
   //! extra data
   std::string m_extra;
 };
@@ -127,6 +127,8 @@ struct Paragraph : public MWAWParagraph {
   Paragraph() : MWAWParagraph(), m_name("")
   {
   }
+  //! destructor
+  ~Paragraph();
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, Paragraph const &ind)
   {
@@ -138,6 +140,10 @@ struct Paragraph : public MWAWParagraph {
   std::string m_name;
 };
 
+Paragraph::~Paragraph()
+{
+}
+
 /** Internal structure: use to store a header */
 struct HeaderFooter {
   //! Constructor
@@ -183,9 +189,11 @@ std::ostream &operator<<(std::ostream &o, HeaderFooter const &hf)
   case MWAWHeaderFooter::ALL:
     o << "all,";
     break;
+#if !defined(__clang__)
   default:
     o << "#occurrence=" << int(hf.m_occurrence) << ",";
     break;
+#endif
   }
   o << "pos=" << hf.m_paragraph[0] << "<->" << hf.m_paragraph[1] << ",";
   o << "pos[def]=" << hf.m_textParagraph << ",";
@@ -264,7 +272,7 @@ struct PicturePara {
   //! the paragraph position
   int m_paragraph;
   //! the position
-  Box2i m_position;
+  MWAWBox2i m_position;
 };
 
 std::ostream &operator<<(std::ostream &o, PicturePara const &pict)
@@ -317,7 +325,9 @@ std::ostream &operator<<(std::ostream &o, DataPLC const &plc)
     o << "Pict";
     break;
   case P_Unknown:
+#if !defined(__clang__)
   default:
+#endif
     o << "#type=" << int(plc.m_type) << ",";
   }
   if (plc.m_id >= 0) o << plc.m_id << ",";
@@ -410,18 +420,20 @@ private:
 void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*type*/)
 {
   if (!listener.get()) {
-    MWAW_DEBUG_MSG(("SubDocument::parse: no listener\n"));
+    MWAW_DEBUG_MSG(("NisusWrtTextInternal::SubDocument::parse: no listener\n"));
+    return;
+  }
+  if (!m_textParser) {
+    MWAW_DEBUG_MSG(("NisusWrtTextInternal::SubDocument::parse: no parser\n"));
     return;
   }
-  assert(m_textParser);
-
   long pos = m_input->tell();
   if (m_type == libmwaw::DOC_NOTE)
     m_textParser->sendFootnote(m_id);
   else if (m_type == libmwaw::DOC_HEADER_FOOTER)
     m_textParser->sendHeaderFooter(m_id);
   else {
-    MWAW_DEBUG_MSG(("SubDocument::parse: oops do not know how to send this kind of document\n"));
+    MWAW_DEBUG_MSG(("NisusWrtTextInternal::SubDocument::parse: oops do not know how to send this kind of document\n"));
     return;
   }
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -516,7 +528,7 @@ void NisusWrtText::computePositions()
   std::vector<int> firstParagraphInPage;
   firstParagraphInPage.push_back(0);
   while (!input->isEnd()) {
-    char c = (char) input->readULong(1);
+    char c = char(input->readULong(1));
     if (c==0xd)
       paragraph++;
     else if (c==0xc) {
@@ -533,7 +545,7 @@ void NisusWrtText::computePositions()
   m_state->m_zones[NisusWrtStruct::Z_Main].m_entry.setId(NisusWrtStruct::Z_Main);
   // compute the header/footer pages
   int actPage = 1;
-  Vec2i headerId(-1,-1), footerId(-1,-1);
+  MWAWVec2i headerId(-1,-1), footerId(-1,-1);
   m_state->m_headersId.resize(size_t(nPages), -1);
   m_state->m_footersId.resize(size_t(nPages), -1);
   for (size_t i = 0; i < m_state->m_hfList.size(); i++) {
@@ -552,7 +564,7 @@ void NisusWrtText::computePositions()
       m_state->m_footersId[size_t(p)-1] = (p%2) ? footerId[0] : footerId[1];
     }
     actPage = hf.m_page = page;
-    Vec2i &wh = hf.m_type == MWAWHeaderFooter::HEADER ? headerId : footerId;
+    MWAWVec2i &wh = hf.m_type == MWAWHeaderFooter::HEADER ? headerId : footerId;
     switch (hf.m_occurrence) {
     case MWAWHeaderFooter::ODD:
       wh[0] = int(i);
@@ -566,8 +578,10 @@ void NisusWrtText::computePositions()
     case MWAWHeaderFooter::NEVER:
       wh[0] = wh[1] = -1;
       break;
+#if !defined(__clang__)
     default:
       break;
+#endif
     }
   }
   for (int p = actPage;  p <= nPages; p++) {
@@ -744,10 +758,10 @@ bool NisusWrtText::readFontsList(MWAWEntry const &entry)
       MWAW_DEBUG_MSG(("NisusWrtText::readFontsList: can not read flst\n"));
       return false;
     }
-    int fId = (int)input->readULong(2);
+    int fId = static_cast<int>(input->readULong(2));
     f.str("");
     f << "FontNames" << num++ << ":fId=" << std::hex << fId << std::dec << ",";
-    int pSz = (int)input->readULong(1);
+    int pSz = static_cast<int>(input->readULong(1));
 
     if (pSz+1+pos+2 > entry.end()) {
       f << "###";
@@ -759,7 +773,7 @@ bool NisusWrtText::readFontsList(MWAWEntry const &entry)
     }
     std::string name("");
     for (int c=0; c < pSz; c++)
-      name += (char) input->readULong(1);
+      name += char(input->readULong(1));
     m_parserState->m_fontConverter->setCorrespondance(fId, name);
     f << name;
     asciiFile.addPos(pos);
@@ -797,25 +811,25 @@ bool NisusWrtText::readFonts(MWAWEntry const &entry)
     pos = input->tell();
     f.str("");
     if (!isStyle)
-      font.m_pictureId = (int)input->readLong(2);
+      font.m_pictureId = static_cast<int>(input->readLong(2));
 
     if (font.m_pictureId) {
       // the two value seems to differ slightly for a picture
-      val = (long)input->readULong(2);
+      val = long(input->readULong(2));
       if (val != 0xFF01) f << "#pictFlags0=" << std::hex << val << ",";
-      font.m_pictureWidth = (int)input->readLong(2);
+      font.m_pictureWidth = static_cast<int>(input->readLong(2));
     }
     else {
-      val = (long)input->readULong(2);
+      val = long(input->readULong(2));
       if (val != 0xFF00)
         font.m_font.setId(int(val));
-      val = (long)input->readULong(2);
+      val = long(input->readULong(2));
       if (val != 0xFF00)
         font.m_font.setSize(float(val));
     }
 
     uint32_t flags=0;
-    int flag = (int) input->readULong(2);
+    int flag = static_cast<int>(input->readULong(2));
 
     if (flag&0x1) flags |= MWAWFont::boldBit;
     if (flag&0x2) flags |= MWAWFont::italicBit;
@@ -826,7 +840,7 @@ bool NisusWrtText::readFonts(MWAWEntry const &entry)
     if (flag&0x40) font.m_font.setDeltaLetterSpacing(1);
     if (flag &0xFF80)
       f << "#flags0=" << std::hex << (flag &0xFF80) << std::dec << ",";
-    flag = (int) input->readULong(2);
+    flag = static_cast<int>(input->readULong(2));
     if (flag & 1) {
       font.m_font.setUnderlineStyle(MWAWFont::Line::Simple);
       f << "underline[lower],";
@@ -838,7 +852,7 @@ bool NisusWrtText::readFonts(MWAWEntry const &entry)
     if (flag & 0x20) font.m_font.setStrikeOutStyle(MWAWFont::Line::Simple);
     if (flag & 0x40) font.m_font.setOverlineStyle(MWAWFont::Line::Simple);
     if (flag & 0x80) flags |= MWAWFont::smallCapsBit;
-    if (flag & 0x100) flags |= MWAWFont::allCapsBit;
+    if (flag & 0x100) flags |= MWAWFont::uppercaseBit;
     if (flag & 0x200) flags |= MWAWFont::boxedBit;
     if (flag & 0x400) flags |= MWAWFont::hiddenBit;
     if (flag & 0x1000) font.m_font.set(MWAWFont::Script(40,librevenge::RVNG_PERCENT,58));
@@ -848,65 +862,65 @@ bool NisusWrtText::readFonts(MWAWEntry const &entry)
       f << "#flags1=" << std::hex << (flag & 0x8800) << std::dec << ",";
     val = input->readLong(2);
     if (val) f << "#f0=" << std::hex << val << ",";
-    font.m_format = (int) input->readULong(1);
+    font.m_format = static_cast<int>(input->readULong(1));
     if (font.m_format & 8) {
       font.m_format &= 0xF7;
       flags |= MWAWFont::reverseWritingBit;
     }
-    font.m_format2 = (int) input->readULong(1);
+    font.m_format2 = static_cast<int>(input->readULong(1));
     font.m_font.setFlags(flags);
 
     int color = 0;
     // now data differs
     if (isStyle) {
-      val = (int) input->readULong(2); // find [0-3] here
+      val = static_cast<int>(input->readULong(2)); // find [0-3] here
       if (val) f << "unkn0=" << val << ",";
       for (int j = 0; j < 6; j++) { // find s0=67, s1=a728
-        val = (int) input->readULong(2);
+        val = static_cast<int>(input->readULong(2));
         if (val) f << "f" << j << "=" << std::hex << val << std::dec << ",";
       }
-      color = (int) input->readULong(2);
+      color = static_cast<int>(input->readULong(2));
     }
     else {
-      color = (int) input->readULong(2);
+      color = static_cast<int>(input->readULong(2));
       for (int j = 1; j < 6; j++) { // find always 0 here...
-        val = (int) input->readULong(2);
+        val = static_cast<int>(input->readULong(2));
         if (val) f << "#f" << j << "=" << val << ",";
       }
       bool hasMark = false;
-      val = (int) input->readULong(2);
+      val = static_cast<int>(input->readULong(2));
       if (val == 1) hasMark = true;
       else if (val) f << "#hasMark=" << val << ",";
-      val = (int) input->readULong(2);
+      val = static_cast<int>(input->readULong(2));
       if (hasMark) font.m_markId = int(val);
       else if (val) f << "#markId=" << val << ",";
       // f0=0|1 and if f0=1 then f1 is a small number between 1 and 20
       for (int j = 0; j < 18; j++) {
-        val = (int) input->readULong(2);
+        val = static_cast<int>(input->readULong(2));
         if (val) f << "g" << j << "=" << val << ",";
       }
       float expand=float(input->readLong(4))/65536.f;
       if (expand < 0 || expand > 0)
         font.m_font.setDeltaLetterSpacing(expand);
       // 0, -1 or a small number related to the variable id : probably unknowncst+vId
-      font.m_variableId = (int)input->readLong(4);
+      font.m_variableId = static_cast<int>(input->readLong(4));
       // the remaining seems to be 0 excepted for picture
       for (int j = 0; j < 4; j++) { // find 0,0,[0|d5|f5|f8|ba], big number
-        val = (int) input->readULong(2);
+        val = static_cast<int>(input->readULong(2));
         if (val) f << "h" << j << "=" << std::hex << val << std::dec << ",";
       }
       // two dim ?
       int dim[4];
       for (int st = 0; st < 2; st++) {
         for (int j = 0; j < 4; j++)
-          dim[j] = (int) input->readLong(2);
-        font.m_pictureDim[st]=Box2i(Vec2i(dim[1],dim[0]),Vec2i(dim[3],dim[2]));
+          dim[j] = static_cast<int>(input->readLong(2));
+        font.m_pictureDim[st]=MWAWBox2i(MWAWVec2i(dim[1],dim[0]),MWAWVec2i(dim[3],dim[2]));
       }
     }
 
     static const uint32_t colors[] =
     { 0, 0xFF0000, 0x00FF00, 0x0000FF, 0x00FFFF, 0xFF00FF, 0xFFFF00, 0xFFFFFF };
-    if (color < 8)
+    if (color >= 0 && color < 8)
       font.m_font.setColor(MWAWColor(colors[color]));
     else if (color != 0xFF00)
       f << "#color=" << color << ",";
@@ -957,11 +971,11 @@ bool NisusWrtText::readPosToFont(MWAWEntry const &entry, NisusWrtStruct::ZoneTyp
     pos = input->tell();
     f.str("");
     f << "PosToFont" << i << "[" << zoneId << "]:";
-    position.m_paragraph = (int) input->readULong(4); // checkme or ??? m_paragraph
-    position.m_word = (int) input->readULong(2);
-    position.m_char = (int) input->readULong(2);
+    position.m_paragraph = static_cast<int>(input->readULong(4)); // checkme or ??? m_paragraph
+    position.m_word = static_cast<int>(input->readULong(2));
+    position.m_char = static_cast<int>(input->readULong(2));
     f << "pos=" << position << ",";
-    int id = (int) input->readLong(2);
+    int id = static_cast<int>(input->readLong(2));
     f << "F" << id << ",";
     plc.m_id = id;
     zone.m_plcMap.insert(NisusWrtTextInternal::Zone::PLCMap::value_type(position, plc));
@@ -1024,7 +1038,7 @@ bool NisusWrtText::readParagraphs(MWAWEntry const &entry, NisusWrtStruct::ZoneTy
 
   long val;
   while (input->tell() != entry.end()) {
-    int num = (entry.id() == 1003) ? (int)zone.m_paragraphList.size() : -1;
+    int num = (entry.id() == 1003) ? static_cast<int>(zone.m_paragraphList.size()) : -1;
     pos = input->tell();
     f.str("");
     if (pos+8 > entry.end() || input->isEnd()) {
@@ -1036,15 +1050,15 @@ bool NisusWrtText::readParagraphs(MWAWEntry const &entry, NisusWrtStruct::ZoneTy
       return false;
     }
 
-    long nPara = (long) input->readULong(4);
+    long nPara = long(input->readULong(4));
     if (nPara == 0x7FFFFFFF) {
       input->seek(-4, librevenge::RVNG_SEEK_CUR);
       break;
     }
     NisusWrtStruct::Position textPosition;
-    textPosition.m_paragraph = (int) nPara;  // checkme or ???? + para
+    textPosition.m_paragraph = static_cast<int>(nPara);  // checkme or ???? + para
 
-    long sz = (long) input->readULong(4);
+    long sz = long(input->readULong(4));
     if (sz < 0x42 || pos+sz > entry.end()) {
       f << "RULE" << num << "[" << zoneId << "]:###";
       asciiFile.addPos(pos);
@@ -1056,7 +1070,7 @@ bool NisusWrtText::readParagraphs(MWAWEntry const &entry, NisusWrtStruct::ZoneTy
     NisusWrtTextInternal::Paragraph para;
 
     para.setInterline(double(input->readLong(4))/65536., librevenge::RVNG_POINT, MWAWParagraph::AtLeast);
-    para.m_spacings[1] = float(input->readLong(4))/65536.f/72.f;
+    para.m_spacings[1] = double(input->readLong(4))/65536./72.;
     int wh = int(input->readLong(2));
     switch (wh) {
     case 0:
@@ -1078,9 +1092,9 @@ bool NisusWrtText::readParagraphs(MWAWEntry const &entry, NisusWrtStruct::ZoneTy
     if (val) f << "#f0=" << val << ",";
 
     para.m_marginsUnit = librevenge::RVNG_INCH;
-    para.m_margins[0] = float(input->readLong(4))/65536.f/72.f;
-    para.m_margins[1] = float(input->readLong(4))/65536.f/72.f;
-    para.m_margins[2] = float(input->readLong(4))/65536.f/72.f;
+    para.m_margins[0] = double(input->readLong(4))/65536./72.;
+    para.m_margins[1] = double(input->readLong(4))/65536./72.;
+    para.m_margins[2] = double(input->readLong(4))/65536./72.;
     para.m_margins[0] =para.m_margins[0].get()-para.m_margins[1].get();
     wh = int(input->readULong(1));
     switch (wh) {
@@ -1120,8 +1134,8 @@ bool NisusWrtText::readParagraphs(MWAWEntry const &entry, NisusWrtStruct::ZoneTy
       MWAWTabStop tab;
 
       f2.str("");
-      tab.m_position = float(input->readLong(4))/72.f/65536.; // from left pos
-      val = (long) input->readULong(1);
+      tab.m_position = double(input->readLong(4))/72./65536.; // from left pos
+      val = long(input->readULong(1));
       switch (val) {
       case 1:
         break;
@@ -1141,15 +1155,15 @@ bool NisusWrtText::readParagraphs(MWAWEntry const &entry, NisusWrtStruct::ZoneTy
         f2 << "#type=" << val << ",";
         break;
       }
-      unsigned char leader=(unsigned char)input->readULong(1);
+      unsigned char leader=static_cast<unsigned char>(input->readULong(1));
       if (leader) {
         int unicode= m_parserState->m_fontConverter->unicode(3, leader);
         if (unicode==-1)
-          tab.m_leaderCharacter =(unsigned short) leader;
+          tab.m_leaderCharacter =static_cast<unsigned short>(leader);
         else
-          tab.m_leaderCharacter =(unsigned short) unicode;
+          tab.m_leaderCharacter =static_cast<unsigned short>(unicode);
       }
-      val = (long) input->readLong(2); // unused ?
+      val = long(input->readLong(2)); // unused ?
       if (val) f2 << "#unkn0=" << val << ",";
       para.m_tabs->push_back(tab);
       if (f2.str().length())
@@ -1158,7 +1172,7 @@ bool NisusWrtText::readParagraphs(MWAWEntry const &entry, NisusWrtStruct::ZoneTy
     }
 
     // ruler name
-    long pSz = ok ? (long) input->readULong(1) : 0;
+    long pSz = ok ? long(input->readULong(1)) : 0;
     if (pSz) {
       if (input->tell()+pSz != pos+sz && input->tell()+pSz+1 != pos+sz) {
         f << "name###";
@@ -1168,7 +1182,7 @@ bool NisusWrtText::readParagraphs(MWAWEntry const &entry, NisusWrtStruct::ZoneTy
       else {
         std::string str("");
         for (int i = 0; i < pSz; i++)
-          str += (char) input->readULong(1);
+          str += char(input->readULong(1));
         para.m_name = str;
       }
     }
@@ -1199,7 +1213,7 @@ bool NisusWrtText::readParagraphs(MWAWEntry const &entry, NisusWrtStruct::ZoneTy
     return true;
   }
   for (int i = 0; i < 31; i++) { // only find 0 expected f12=0|100
-    val = (long) input->readLong(2);
+    val = long(input->readLong(2));
     if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
   asciiFile.addPos(pos);
@@ -1243,7 +1257,7 @@ bool NisusWrtText::readHeaderFooter(MWAWEntry const &entry)
     hf.m_textParagraph = input->readLong(4);
     hf.m_paragraph[0] = lastPara;
     hf.m_paragraph[1] = lastPara = input->readLong(4);
-    int what = (int) input->readULong(2);
+    int what = static_cast<int>(input->readULong(2));
     switch ((what>>2)&0x3) {
     case 1:
       hf.m_type = MWAWHeaderFooter::HEADER;
@@ -1271,9 +1285,9 @@ bool NisusWrtText::readHeaderFooter(MWAWEntry const &entry)
     }
     if (what&0xFFF0) f << "#flags=" << std::hex << (what&0xFFF0) << ",";
     // find 0|0x10|0x18|0x20|0x36|0x3a|0x40|0x4c|0x66 here
-    hf.m_unknown = (int) input->readLong(2);
+    hf.m_unknown = static_cast<int>(input->readLong(2));
     for (int j = 0; j < 10; j++) { // always 0 ?
-      val = (long) input->readLong(2);
+      val = long(input->readLong(2));
       if (val) f << "g" << j << "=" << val << ",";
     }
     hf.m_extra = f.str();
@@ -1321,18 +1335,18 @@ bool NisusWrtText::readFootnotes(MWAWEntry const &entry)
     pos = input->tell();
     f.str("");
     NisusWrtTextInternal::Footnote footnote;
-    footnote.m_textPosition.m_paragraph = (int) input->readULong(4); // checkme or ??? m_paragraph
-    footnote.m_textPosition.m_word = (int) input->readULong(2);
-    footnote.m_textPosition.m_char = (int) input->readULong(2);
+    footnote.m_textPosition.m_paragraph = static_cast<int>(input->readULong(4)); // checkme or ??? m_paragraph
+    footnote.m_textPosition.m_word = static_cast<int>(input->readULong(2));
+    footnote.m_textPosition.m_char = static_cast<int>(input->readULong(2));
     footnote.m_paragraph[0] = lastParagraph;
-    lastParagraph = (int) input->readULong(4); // checkme or ??? m_paragraph
+    lastParagraph = static_cast<int>(input->readULong(4)); // checkme or ??? m_paragraph
     footnote.m_paragraph[1] = lastParagraph;
     // find f0=0|55|6f, f1=15|16|26|27|39|3a
     for (int j = 0; j < 2; j++) {
       val = input->readLong(2);
       if (val) f << "f" << j << "=" << std::hex << val << std::dec << ",";
     }
-    footnote.m_number = (int) input->readLong(2);
+    footnote.m_number = static_cast<int>(input->readLong(2));
     for (int j = 0; j < 3; j++) { // always 0 ?
       val = input->readLong(2);
       if (val) f << "g" << j << "=" << val << ",";
@@ -1341,7 +1355,7 @@ bool NisusWrtText::readFootnotes(MWAWEntry const &entry)
       input->seek(pos+24+wh*6, librevenge::RVNG_SEEK_SET);
       std::string label("");
       for (int c = 0; c < 6; c++) {
-        char ch = (char) input->readULong(1);
+        char ch = char(input->readULong(1));
         if (ch == 0)
           break;
         label += ch;
@@ -1397,12 +1411,12 @@ bool NisusWrtText::readPICD(MWAWEntry const &entry, NisusWrtStruct::ZoneType zon
     pos = input->tell();
     f.str("");
     NisusWrtTextInternal::PicturePara pict;
-    pict.m_paragraph = (int) input->readLong(4);
+    pict.m_paragraph = static_cast<int>(input->readLong(4));
     int dim[4];
     for (int j = 0; j < 4; j++)
-      dim[j] = (int) input->readLong(2);
-    pict.m_position = Box2i(Vec2i(dim[1],dim[0]), Vec2i(dim[3],dim[2]));
-    pict.m_id = (int) input->readULong(2);
+      dim[j] = static_cast<int>(input->readLong(2));
+    pict.m_position = MWAWBox2i(MWAWVec2i(dim[1],dim[0]), MWAWVec2i(dim[3],dim[2]));
+    pict.m_id = static_cast<int>(input->readULong(2));
     zone.m_pictureParaList.push_back(pict);
 
     NisusWrtStruct::Position pictPosition;
@@ -1449,7 +1463,7 @@ long NisusWrtText::findFilePos(NisusWrtStruct::ZoneType zoneId, NisusWrtStruct::
       break;
     if (pos == actPos)
       return input->tell();
-    unsigned char c = (unsigned char) input->readULong(1);
+    unsigned char c = static_cast<unsigned char>(input->readULong(1));
     // update the position
     switch (c) {
     case 0xd:
@@ -1491,15 +1505,15 @@ bool NisusWrtText::sendHeaderFooter(int hfId)
   MWAWEntry entry;
   entry.setId(NisusWrtStruct::Z_HeaderFooter);
   NisusWrtStruct::Position pos;
-  pos.m_paragraph = (int) hf.m_paragraph[0];
+  pos.m_paragraph = static_cast<int>(hf.m_paragraph[0]);
   entry.setBegin(findFilePos(NisusWrtStruct::Z_HeaderFooter, pos));
-  pos.m_paragraph = (int) hf.m_paragraph[1];
+  pos.m_paragraph = static_cast<int>(hf.m_paragraph[1]);
   entry.setEnd(findFilePos(NisusWrtStruct::Z_HeaderFooter, pos));
   if (entry.begin() < 0 || entry.length() < 0) {
     MWAW_DEBUG_MSG(("NisusWrtText::sendHeaderFooter: can not compute the headerFooter entry\n"));
     return false;
   }
-  pos.m_paragraph = (int) hf.m_paragraph[0];
+  pos.m_paragraph = static_cast<int>(hf.m_paragraph[0]);
   sendText(entry, pos);
   return true;
 }
@@ -1550,7 +1564,7 @@ bool NisusWrtText::sendText(MWAWEntry entry, NisusWrtStruct::Position firstPos)
     return false;
   }
 
-  NisusWrtStruct::ZoneType zoneId = (NisusWrtStruct::ZoneType) entry.id();
+  NisusWrtStruct::ZoneType zoneId = static_cast<NisusWrtStruct::ZoneType>(entry.id());
   if (zoneId < 0 || zoneId >= 3) {
     MWAW_DEBUG_MSG(("NisusWrtText::sendText: find unexpected zoneId: %d\n", zoneId));
     return false;
@@ -1680,7 +1694,9 @@ bool NisusWrtText::sendText(MWAWEntry entry, NisusWrtStruct::Position firstPos)
       case NisusWrtTextInternal::P_HeaderFooter:
         break;
       case NisusWrtTextInternal::P_Unknown:
+#if !defined(__clang__)
       default:
+#endif
         MWAW_DEBUG_MSG(("NisusWrtText::sendText: oops can not find unknown plc type\n"));
         f << "###";
         break;
@@ -1691,8 +1707,8 @@ bool NisusWrtText::sendText(MWAWEntry entry, NisusWrtStruct::Position firstPos)
       break;
     if (i==entry.length())
       break;
-    unsigned char c = (unsigned char) input->readULong(1);
-    str+=(char) c;
+    unsigned char c = static_cast<unsigned char>(input->readULong(1));
+    str+=char(c);
     if (c==0xd) {
       f << str;
       ascFile.addPos(pos);
@@ -1787,16 +1803,16 @@ bool NisusWrtText::sendText(MWAWEntry entry, NisusWrtStruct::Position firstPos)
         break;
       }
       if (fType != MWAWField::None)
-        listener->insertField(fType);
+        listener->insertField(MWAWField(fType));
       else if (content.length())
-        listener->insertUnicodeString(content.c_str());
+        listener->insertUnicodeString(librevenge::RVNGString(content.c_str()));
       else
         f << "#[ref]";
       break;
     }
     // checkme: find also 0x8, 0x13, 0x15, 0x1e, 0x1f in glossary
     default:
-      i+=listener->insertCharacter((unsigned char)c, input, entry.end());
+      i+=listener->insertCharacter(static_cast<unsigned char>(c), input, entry.end());
       break;
     }
   }
