@@ -85,7 +85,7 @@ struct State {
 class SubDocument : public MWAWSubDocument
 {
 public:
-  SubDocument(WriteNowParser &pars, MWAWInputStreamPtr input, WriteNowEntry pos) :
+  SubDocument(WriteNowParser &pars, MWAWInputStreamPtr input, WriteNowEntry const &pos) :
     MWAWSubDocument(&pars, input, MWAWEntry()), m_pos(pos) {}
 
   //! destructor
@@ -190,7 +190,7 @@ void WriteNowParser::newPage(int number)
 bool WriteNowParser::getColor(int colId, MWAWColor &col) const
 {
   if (colId >= 0 && colId < int(m_state->m_colorMap.size())) {
-    col = m_state->m_colorMap[(size_t)colId];
+    col = m_state->m_colorMap[size_t(colId)];
     return true;
   }
   return false;
@@ -215,12 +215,12 @@ bool WriteNowParser::sendGraphic(int gId, MWAWBox2i const &bdbox)
     MWAW_DEBUG_MSG(("WriteNowParser::sendGraphic: called with bad id=%d\n", gId));
     return false;
   }
-  if (!m_state->m_picturesList[(size_t)gId-8].isZone()) {
+  if (!m_state->m_picturesList[size_t(gId)-8].isZone()) {
     MWAW_DEBUG_MSG(("WriteNowParser::sendGraphic: called with a no zone id=%d\n", gId));
     return false;
   }
 
-  sendPicture(m_state->m_picturesList[(size_t)gId-8], bdbox);
+  sendPicture(m_state->m_picturesList[size_t(gId)-8], bdbox);
   return true;
 }
 
@@ -412,7 +412,7 @@ bool WriteNowParser::readDocEntries()
   long expectedVal[] = { 0, 0x80, 0x40000000L};
   long freePos = 0;
   for (int i = 0; i < 7; i++) { // 0, 80, 4000
-    val = (long) input->readULong(4);
+    val = long(input->readULong(4));
     if (i == 3) {
       freePos = val;
       continue;
@@ -450,11 +450,11 @@ bool WriteNowParser::readDocEntries()
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     f.str("");
     f << "DocEntries-II:";
-    m_state->m_numColumns = (int) input->readLong(1);
+    m_state->m_numColumns = static_cast<int>(input->readLong(1));
     f << "nCol=" << m_state->m_numColumns << ",";
     val = input->readLong(1);
     if (val != 1) f << "unkn=" << val << ",";
-    m_state->m_columnWidth = (int) input->readLong(2);
+    m_state->m_columnWidth = static_cast<int>(input->readLong(2));
     f << "colWidth=" << m_state->m_columnWidth << ",";
 
     ascii().addPos(pos);
@@ -480,13 +480,13 @@ bool WriteNowParser::readDocEntriesV2()
   std::stringstream s;
   f << "Entries(DocEntries):";
   for (int i = 0; i < 5; i++) {
-    int val=(int) input->readLong(1);
+    int val=static_cast<int>(input->readLong(1));
     if (val != 4 && val != 0x44) {
       MWAW_DEBUG_MSG(("WriteNowParser::readDocEntriesV2: can not find entries header:%d\n",i));
       return false;
     }
-    long dataPos = (long) input->readULong(1);
-    dataPos = (dataPos<<16)+(long) input->readULong(2);
+    long dataPos = long(input->readULong(1));
+    dataPos = (dataPos<<16)+long(input->readULong(2));
     if (!checkIfPositionValid(dataPos)) {
       MWAW_DEBUG_MSG(("WriteNowParser::readDocEntriesV2:  find an invalid position for entry:%d\n",i));
       continue;
@@ -511,7 +511,7 @@ bool WriteNowParser::readDocEntriesV2()
     }
     long actPos = input->tell();
     input->seek(dataPos, librevenge::RVNG_SEEK_SET);
-    entry.setLength((long) input->readULong(2)+2);
+    entry.setLength(long(input->readULong(2)+2));
     input->seek(actPos, librevenge::RVNG_SEEK_SET);
     m_entryManager->add(entry);
   }
@@ -527,11 +527,11 @@ bool WriteNowParser::readDocEntriesV2()
   f << "DocEntries-II:";
 
   if (version()==2) {
-    m_state->m_numColumns = (int) input->readLong(1);
+    m_state->m_numColumns = static_cast<int>(input->readLong(1));
     f << "nCol=" << m_state->m_numColumns << ",";
     long val = input->readLong(1);
     if (val != 1) f << "unkn=" << val << ",";
-    m_state->m_columnWidth = (int) input->readLong(2);
+    m_state->m_columnWidth = static_cast<int>(input->readLong(2));
     f << "colWidth=" << m_state->m_columnWidth << ",";
     ascii().addDelimiter(input->tell(),'|');
   }
@@ -572,7 +572,7 @@ bool WriteNowParser::parseGraphicZone(WriteNowEntry const &entry)
     val = input->readLong(2);
     if (val)  f << "f" << i << "=" << val << ",";
   }
-  int N = (int) input->readLong(2);
+  int N = static_cast<int>(input->readLong(2));
   f << "N?=" << N << ",";
   for (int i = 4; i < 6; i++) { // alway 0 ?
     val = input->readLong(2);
@@ -647,7 +647,7 @@ bool WriteNowParser::sendPicture(WriteNowEntry const &entry, MWAWBox2i const &bd
   f << "Entries(GraphicData):";
   f << "ptr?=" << std::hex << input->readULong(4) << std::dec << ",";
   f << "ptr2?=" << std::hex << input->readULong(4) << std::dec << ",";
-  int type = (int) input->readLong(2);
+  int type = static_cast<int>(input->readLong(2));
   if (type != 14) f << "#type=" << type << ",";
   long val;
   /* fl0 : 0[pict1] or 1[pict2] : graphic type ?, fl1 : always 0
@@ -666,7 +666,7 @@ bool WriteNowParser::sendPicture(WriteNowEntry const &entry, MWAWBox2i const &bd
   ascii().addPos(entry.begin());
   ascii().addNote(f.str().c_str());
 
-  int sz = (int) entry.length()-24;
+  int sz = static_cast<int>(entry.length())-24;
   if (sz) {
     long pos = input->tell();
     shared_ptr<MWAWPict> pict(MWAWPictData::get(input, sz));
@@ -741,10 +741,10 @@ bool WriteNowParser::readColorMap(WriteNowEntry const &entry)
     val = input->readLong(2);
     if (val) f << "f" << i << "=" << val << ",";
   }
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   for (int i = 0; i < 2; i++) { // 0
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     if (val) f << "g" << i << "=" << val << ",";
   }
   if (long(input->tell())+N*8 > entry.end()) {
@@ -758,7 +758,7 @@ bool WriteNowParser::readColorMap(WriteNowEntry const &entry)
     pos = input->tell();
     f.str("");
     f << "ColorMap[" << n << "]:";
-    int type = (int) input->readLong(1);
+    int type = static_cast<int>(input->readLong(1));
     switch (type) {
     case 1:
       f << "named(RGB),";
@@ -778,7 +778,7 @@ bool WriteNowParser::readColorMap(WriteNowEntry const &entry)
       val = input->readLong(1);
       if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
     }
-    val = (long) input->readULong(4);
+    val = long(input->readULong(4));
     defPos.push_back(pos+val);
     // fixme: used this to read the data...
     f << "defPos=" << std::hex << pos+val << std::dec << ",";
@@ -787,7 +787,7 @@ bool WriteNowParser::readColorMap(WriteNowEntry const &entry)
   }
 
   for (int n = 0; n < N; n++) {
-    pos = defPos[(size_t) n];
+    pos = defPos[size_t(n)];
     if (pos+12 > entry.end()) {
       MWAW_DEBUG_MSG(("WriteNowParser::readColorMap: can not read entry : %d\n", n));
       return false;
@@ -797,11 +797,11 @@ bool WriteNowParser::readColorMap(WriteNowEntry const &entry)
     f.str("");
     f << "ColorMapData[" << n << "]:";
     unsigned char col[4];
-    for (int i = 0; i < 4; i++) col[i] = (unsigned char)(input->readULong(2)/256);
+    for (int i = 0; i < 4; i++) col[i] = static_cast<unsigned char>(input->readULong(2)/256);
     f << "col=" << MWAWColor(col[0],col[1],col[2],col[3]) << ",";
-    m_state->m_colorMap.push_back(MWAWColor((unsigned char)col[0],(unsigned char)col[1],(unsigned char)col[2]));
+    m_state->m_colorMap.push_back(MWAWColor(static_cast<unsigned char>(col[0]),static_cast<unsigned char>(col[1]),static_cast<unsigned char>(col[2])));
 
-    int sz = (int) input->readULong(1);
+    int sz = static_cast<int>(input->readULong(1));
     if (pos+8+1+sz > entry.end()) {
       MWAW_DEBUG_MSG(("WriteNowParser::readColorMap: can not read end of entry : %d\n", n));
       return false;
@@ -833,7 +833,7 @@ bool WriteNowParser::readPrintInfo(WriteNowEntry const &entry)
   }
 
   input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
-  long sz = version() <= 2 ? 2+(long) input->readULong(2) : (long) input->readULong(4);
+  long sz = version() <= 2 ? 2+long(input->readULong(2)) : long(input->readULong(4));
   if (sz != entry.length()) {
     MWAW_DEBUG_MSG(("WriteNowParser::readPrintInfo: bad begin of last zone\n"));
     return false;
@@ -922,7 +922,7 @@ bool WriteNowParser::readGenericUnkn(WriteNowEntry const &entry)
     val = input->readLong(2);
     if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   for (int i = 0; i < 2; i++) { // 0
     val = input->readLong(2);
@@ -939,7 +939,7 @@ bool WriteNowParser::readGenericUnkn(WriteNowEntry const &entry)
     pos = input->tell();
     f.str("");
     f << entry.type() << "[" << n << "]:";
-    int type = (int) input->readULong(1);
+    int type = static_cast<int>(input->readULong(1));
     switch (type) {
     case 0:
       f << "def,";
@@ -953,7 +953,7 @@ bool WriteNowParser::readGenericUnkn(WriteNowEntry const &entry)
       val = input->readLong(1);
       if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
     }
-    val = (long) input->readULong(4);
+    val = long(input->readULong(4));
     defPos.push_back(pos+val);
     // fixme: used this to read the data...
     f << "defPos=" << std::hex << pos+val << std::dec << ",";
@@ -962,7 +962,7 @@ bool WriteNowParser::readGenericUnkn(WriteNowEntry const &entry)
   }
 
   for (int n = 0; n < N; n++) {
-    pos = defPos[(size_t) n];
+    pos = defPos[size_t(n)];
     if (pos == entry.end()) continue;
     if (pos+12 > entry.end()) {
       MWAW_DEBUG_MSG(("WriteNowParser::readGenericUnkn: can not read entry : %d\n", n));
@@ -1001,21 +1001,21 @@ WriteNowEntry WriteNowParser::readEntry()
 {
   WriteNowEntry res;
   MWAWInputStreamPtr input = getInput();
-  int val = (int) input->readULong(2);
+  int val = static_cast<int>(input->readULong(2));
   res.m_fileType = (val >> 12);
   res.m_val[0]= val & 0x0FFF;
-  res.m_val[1]= (int) input->readLong(2);
+  res.m_val[1]= static_cast<int>(input->readLong(2));
   if (res.isZoneType()) {
-    res.setBegin((long) input->readULong(4));
-    res.setLength((long) input->readULong(4));
+    res.setBegin(long(input->readULong(4)));
+    res.setLength(long(input->readULong(4)));
     if (!checkIfPositionValid(res.end())) {
       MWAW_DEBUG_MSG(("WriteNowParser::readEntry: find an invalid entry\n"));
       res.setLength(0);
     }
   }
   else {
-    res.m_val[2]= (int) input->readLong(4);
-    res.m_val[3]= (int) input->readLong(4);
+    res.m_val[2]= static_cast<int>(input->readLong(4));
+    res.m_val[3]= static_cast<int>(input->readLong(4));
   }
   return res;
 }
@@ -1039,7 +1039,7 @@ bool WriteNowParser::checkHeader(MWAWHeader *header, bool strict)
     return false;
   }
   input->seek(0, librevenge::RVNG_SEEK_SET);
-  long val = (long) input->readULong(4);
+  long val = long(input->readULong(4));
   int vers = 0;
   switch (val) {
   case 0:
@@ -1075,7 +1075,7 @@ bool WriteNowParser::checkHeader(MWAWHeader *header, bool strict)
     return true;
   }
 
-  val = (long) input->readULong(2);
+  val = long(input->readULong(2));
   if (strict && val > 3)
     return false;
 #ifndef DEBUG
@@ -1090,15 +1090,15 @@ bool WriteNowParser::checkHeader(MWAWHeader *header, bool strict)
   }
 
   // a flag ??
-  val = (long) input->readULong(2);
+  val = long(input->readULong(2));
   if (val != 0x4000) f << "fl=" << std::hex << val << std::dec << ",";
-  val = (long) input->readLong(2);
+  val = long(input->readLong(2));
   if (val) f << "f4=" << val << ",";
 
   // last entry
   WriteNowEntry entry;
-  entry.setBegin((long) input->readULong(4));
-  entry.setLength((long) input->readULong(4));
+  entry.setBegin(long(input->readULong(4)));
+  entry.setLength(long(input->readULong(4)));
   entry.m_fileType = 4;
 
   if (!checkIfPositionValid(entry.end())) {
