@@ -90,13 +90,15 @@ struct Font {
 
 /** Internal: class to store the paragraph properties */
 struct Paragraph : public MWAWParagraph {
-  //! Constructor with type
+  //! constructor
   Paragraph() : MWAWParagraph()
   {
     m_marginsUnit = librevenge::RVNG_POINT;
     for (int i = 0; i < 8; i++)
       m_values[i] = 0;
   }
+  //! destructor
+  virtual ~Paragraph();
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, Paragraph const &ind)
   {
@@ -111,6 +113,10 @@ struct Paragraph : public MWAWParagraph {
   int m_values[8];
 };
 
+Paragraph::~Paragraph()
+{
+}
+
 /** Internal: class to store a style */
 struct Style {
   Style() : m_name(""), m_nextId(-1), m_font(), m_paragraph()
@@ -166,7 +172,7 @@ struct Token {
   {
     o << "bdbox=" << tkn.m_box << ",";
     if (tkn.m_graphicZone >= 0) o << "zId=" << tkn.m_graphicZone << ",";
-    Vec2i tknSize = tkn.m_box.size();
+    MWAWVec2i tknSize = tkn.m_box.size();
     for (int i = 0; i < 2; i++) {
       if (tknSize == tkn.m_pos[i]) continue;
       o << "pos" << i << "=" << tkn.m_pos[i] << ",";
@@ -186,10 +192,10 @@ struct Token {
   int m_graphicZone;
 
   //! the bdbox
-  Box2i m_box;
+  MWAWBox2i m_box;
 
   //! two positions ( seen relative to the RB point)
-  Vec2i m_pos[2];
+  MWAWVec2i m_pos[2];
 
   //! some unknown values
   int m_values[19];
@@ -212,7 +218,7 @@ struct TableData {
   void updateCell(MWAWCell &cell) const
   {
     // as the cells can overlap a little, we build a new box
-    cell.setBdBox(Box2f(m_box.min(), m_box.max()-Vec2i(1,1)));
+    cell.setBdBox(MWAWBox2f(m_box.min(), m_box.max()-MWAWVec2i(1,1)));
     cell.setBackgroundColor(m_color);
     for (int i=0; i<4; i++) {
       MWAWBorder border;
@@ -311,7 +317,7 @@ struct TableData {
   int m_type;
 
   //! the bdbox
-  Box2i m_box;
+  MWAWBox2i m_box;
 
   //! the background color
   MWAWColor m_color;
@@ -423,6 +429,7 @@ std::ostream &operator<<(std::ostream &o, ContentZone const &z)
     break;
   case 0x10:
     o << "break,";
+    break;
   default:
     o << "type=#" << z.m_type << ",";
     break;
@@ -470,7 +477,7 @@ struct ContentZones {
 //! Internal: the cell of a WriteNowText
 struct Cell : public MWAWCell {
   //! constructor
-  Cell(WriteNowText &parser) : MWAWCell(), m_parser(parser),
+  explicit Cell(WriteNowText &parser) : MWAWCell(), m_parser(parser),
     m_zonesList(), m_footnoteList() {}
 
   //! send the content
@@ -490,7 +497,8 @@ struct Table : public MWAWTable {
   Table() : MWAWTable()
   {
   }
-
+  //! destructor
+  virtual ~Table();
   //! return a cell corresponding to id
   Cell *get(int id)
   {
@@ -502,6 +510,10 @@ struct Table : public MWAWTable {
   }
 };
 
+Table::~Table()
+{
+}
+
 ////////////////////////////////////////
 //! Internal: structure used to store the content structure
 struct Zone {
@@ -527,7 +539,7 @@ struct State {
   {
     int styleId = type == 0 ? 0 : type==1 ? 3 : type==2 ? 2 : -1;
     if (styleId >= 0 && styleId < int(m_styleList.size()))
-      return m_styleList[(size_t) styleId].m_paragraph;
+      return m_styleList[size_t(styleId)].m_paragraph;
     Paragraph res;
     if (m_version>=0 && m_version <= 2 && type==0) {
       res.m_margins[1] = 90.0;
@@ -775,13 +787,13 @@ bool WriteNowText::createZones()
       if (m_state->m_header)
         MWAW_DEBUG_MSG(("WriteNowText::createZones: header is already defined\n"));
       else
-        m_state->m_header = headerFooterList[(size_t)number];
+        m_state->m_header = headerFooterList[size_t(number)];
     }
     else if (called == 6) {
       if (m_state->m_footer)
         MWAW_DEBUG_MSG(("WriteNowText::createZones: footer is already defined\n"));
       else
-        m_state->m_footer = headerFooterList[(size_t)number];
+        m_state->m_footer = headerFooterList[size_t(number)];
     }
   }
 
@@ -831,7 +843,7 @@ shared_ptr<WriteNowTextInternal::ContentZones> WriteNowText::parseContent(WriteN
     // in 1/3 files, ptr0=begin.pos()+(flag<<15: rev?), but not in other files :-~
     long val;
     for (int i=0; i < 2; i++) {
-      val = (long) input->readULong(4);
+      val = long(input->readULong(4));
       if (!val) continue;
       f << "ptr" << i << "=" << std::hex << (val&0x7FFF) << std::dec;
       if (val>>15)
@@ -865,7 +877,7 @@ shared_ptr<WriteNowTextInternal::ContentZones> WriteNowText::parseContent(WriteN
   while (long(input->tell()) < entry.end()) {
     long pos = input->tell();
     WriteNowTextInternal::ContentZone zone;
-    int c = (int) input->readULong(1);
+    int c = static_cast<int>(input->readULong(1));
     if (c == 0xf0) {
       MWAW_DEBUG_MSG(("WriteNowText::parseContent: find 0xf0 entry\n"));
       ascFile.addPos(pos);
@@ -878,7 +890,7 @@ shared_ptr<WriteNowTextInternal::ContentZones> WriteNowText::parseContent(WriteN
     zone.m_type = type;
     if (type == 0) { // text entry
       while (long(input->tell()) != entry.end()) {
-        c = (int) input->readULong(1);
+        c = static_cast<int>(input->readULong(1));
         if (c == 0xf0) continue;
         if ((c&0xf0)==0xf0) {
           input->seek(-1, librevenge::RVNG_SEEK_CUR);
@@ -892,7 +904,13 @@ shared_ptr<WriteNowTextInternal::ContentZones> WriteNowText::parseContent(WriteN
       int numChar = 0;
       zone.m_pos[1] = entry.end();
       while (long(input->tell()) != entry.end()) {
-        c = (int) input->readULong(1);
+        if (input->isEnd() || input->tell() > entry.end()) {
+          MWAW_DEBUG_MSG(("WriteNowText::parseContent: can not read end of text\n"));
+          ascFile.addPos(pos);
+          ascFile.addNote("TextData:##");
+          return text;
+        }
+        c = static_cast<int>(input->readULong(1));
         if (c==0xf7) {
           zone.m_pos[1] = long(input->tell())-1;
           break;
@@ -907,7 +925,7 @@ shared_ptr<WriteNowTextInternal::ContentZones> WriteNowText::parseContent(WriteN
         }
       }
       if ((type == 0xb || type == 0xd) && numChar != 1) {
-        MWAW_DEBUG_MSG(("WriteNowText::parseContent: find odd size for type %x entry\n", type));
+        MWAW_DEBUG_MSG(("WriteNowText::parseContent: find odd size for type %x entry\n", static_cast<unsigned int>(type)));
         ascFile.addPos(pos);
         ascFile.addNote("TextData:##");
 
@@ -951,18 +969,17 @@ bool WriteNowText::parseZone(WriteNowEntry const &entry, std::vector<WriteNowEnt
     dataSz = 6;
     headerSz = lengthSz = 2;
   }
+  MWAWInputStreamPtr &input= m_parserState->m_input;
   if (!entry.valid() || entry.length() < headerSz
-      || (entry.length()%dataSz) !=(headerSz%dataSz)) {
+      || (entry.length()%dataSz) !=(headerSz%dataSz) || !input->checkPosition(entry.end())) {
     MWAW_DEBUG_MSG(("WriteNowText::parseZone: text zone size is invalid\n"));
     return false;
   }
 
   long endPos = entry.end();
-
-  MWAWInputStreamPtr &input= m_parserState->m_input;
   input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
-  long sz = (long) input->readULong(lengthSz);
+  long sz = long(input->readULong(lengthSz));
   if (vers>2 && sz != entry.length()) {
     MWAW_DEBUG_MSG(("WriteNowText::parseZone: bad begin of last zone\n"));
     return false;
@@ -999,7 +1016,7 @@ bool WriteNowText::parseZone(WriteNowEntry const &entry, std::vector<WriteNowEnt
   int numElts = int((entry.length()-headerSz)/dataSz);
   for (int elt=0; elt<numElts; elt++) {
     f << "entry" << elt << "=[";
-    int flags = (int) input->readULong(1);
+    int flags = static_cast<int>(input->readULong(1));
     /*  find
         40 44 45 : header ?
         60 61 64 65 : text ?
@@ -1010,25 +1027,25 @@ bool WriteNowText::parseZone(WriteNowEntry const &entry, std::vector<WriteNowEnt
     */
     f << "fl=" << std::hex << flags << std::dec << ",";
     for (int i = 0; i < 3; i++) {
-      val = (long) input->readULong(1);
+      val = long(input->readULong(1));
       if (!i && val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
       if (vers <= 2) break;
     }
 
     WriteNowEntry zEntry;
-    zEntry.setBegin((long) input->readULong(vers <= 2 ? 2 : 4));
-    if (vers > 2) zEntry.setLength((long) input->readULong(4));
+    zEntry.setBegin(long(input->readULong(vers <= 2 ? 2 : 4)));
+    if (vers > 2) zEntry.setLength(long(input->readULong(4)));
     else if (zEntry.begin() &&
              m_mainParser->checkIfPositionValid(zEntry.begin())) {
       long actPos = input->tell();
       input->seek(zEntry.begin(), librevenge::RVNG_SEEK_SET);
-      zEntry.setLength((long) input->readULong(2)+2);
+      zEntry.setLength(long(input->readULong(2))+2);
       input->seek(actPos, librevenge::RVNG_SEEK_SET);
     }
     zEntry.setType("TextData");
     zEntry.m_fileType = 4;
     zEntry.m_val[0] = flags;
-    zEntry.m_val[1] = (int) input->readLong(lengthSz);
+    zEntry.m_val[1] = static_cast<int>(input->readLong(lengthSz));
 
     if (zEntry.begin() == 0 && zEntry.length()==0) f << "_" << ",";
     else {
@@ -1090,7 +1107,7 @@ bool WriteNowText::readFontNames(WriteNowEntry const &entry)
     val = input->readLong(2);
     if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   for (int i = 0; i < 2; i++) { // 0
     val = input->readLong(2);
@@ -1107,7 +1124,7 @@ bool WriteNowText::readFontNames(WriteNowEntry const &entry)
     pos = input->tell();
     f.str("");
     f << "Fonts[" << n << "]:";
-    int type = (int) input->readULong(1);
+    int type = static_cast<int>(input->readULong(1));
     switch (type) {
     case 0:
       f << "def,";
@@ -1121,7 +1138,7 @@ bool WriteNowText::readFontNames(WriteNowEntry const &entry)
       val = input->readLong(1);
       if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
     }
-    val = (long) input->readULong(4);
+    val = long(input->readULong(4));
     defPos.push_back(pos+val);
     // fixme: used this to read the data...
     f << "defPos=" << std::hex << pos+val << std::dec << ",";
@@ -1130,7 +1147,7 @@ bool WriteNowText::readFontNames(WriteNowEntry const &entry)
   }
 
   for (int n = 0; n < N; n++) {
-    pos = defPos[(size_t) n];
+    pos = defPos[size_t(n)];
     if (pos == entry.end()) continue;
     if (pos+13 > entry.end()) {
       MWAW_DEBUG_MSG(("WriteNowText::readFontNames: can not read entry : %d\n", n));
@@ -1149,7 +1166,7 @@ bool WriteNowText::readFontNames(WriteNowEntry const &entry)
       val = input->readLong(2);
       if (val) f << "f" << i << "=" << val << ",";
     }
-    int sz = (int) input->readULong(1);
+    int sz = static_cast<int>(input->readULong(1));
     if (pos+13+sz > entry.end()) {
       MWAW_DEBUG_MSG(("WriteNowText::readFontNames: can not read entry name : %d\n", n));
       return false;
@@ -1158,7 +1175,7 @@ bool WriteNowText::readFontNames(WriteNowEntry const &entry)
     bool ok = true;
     std::string name("");
     for (int i = 0; i < sz; i++) {
-      char ch = (char) input->readULong(1);
+      char ch = char(input->readULong(1));
       if (ch == '\0') {
         MWAW_DEBUG_MSG(("WriteNowText::readFontNames: pb with name field %d\n", n));
         ok = false;
@@ -1205,9 +1222,9 @@ bool WriteNowText::readFont(MWAWInputStream &input, bool inStyle, WriteNowTextIn
   }
   input.seek(pos, librevenge::RVNG_SEEK_SET);
 
-  font.m_font.setId(m_state->getFontId((int) input.readULong(2)));
-  font.m_font.setSize((float) input.readULong(vers <= 2 ? 1 : 2));
-  int flag = (int) input.readULong(1);
+  font.m_font.setId(m_state->getFontId(static_cast<int>(input.readULong(2))));
+  font.m_font.setSize(float(input.readULong(vers <= 2 ? 1 : 2)));
+  int flag = int(input.readULong(1));
   uint32_t flags=0;
   if (flag&0x1) flags |= MWAWFont::boldBit;
   if (flag&0x2) flags |= MWAWFont::italicBit;
@@ -1223,11 +1240,11 @@ bool WriteNowText::readFont(MWAWInputStream &input, bool inStyle, WriteNowTextIn
     font.m_font.m_extra = f.str();
     return true;
   }
-  flag = (int) input.readULong(1);
+  flag = static_cast<int>(input.readULong(1));
   if (flag&0x80) font.m_font.setStrikeOutStyle(MWAWFont::Line::Simple);
   if (flag&0x7f) f << "#flag1=" << std::hex << (flag&0x7f) << std::dec << ",";
 
-  flag = (int) input.readULong(1);
+  flag = static_cast<int>(input.readULong(1));
   if (flag&0x2) {
     font.m_font.setUnderlineStyle(MWAWFont::Line::Simple);
     font.m_font.setUnderlineType(MWAWFont::Line::Double);
@@ -1248,7 +1265,7 @@ bool WriteNowText::readFont(MWAWInputStream &input, bool inStyle, WriteNowTextIn
   if (flag&0x40) font.m_font.setUnderlineStyle(MWAWFont::Line::Dot);
   if (flag&0x81) f << "#flag2=" << std::hex << (flag&0x81) << std::dec << ",";
 
-  int color = (int) input.readULong(1); // fixme find color map
+  int color = static_cast<int>(input.readULong(1)); // fixme find color map
   if (color) {
     MWAWColor col;
     if (m_mainParser->getColor(color,col))
@@ -1256,7 +1273,7 @@ bool WriteNowText::readFont(MWAWInputStream &input, bool inStyle, WriteNowTextIn
     else
       f << "#colorId=" << color << ",";
   }
-  int heightDecal = (int) input.readLong(2);
+  int heightDecal = static_cast<int>(input.readLong(2));
   if (heightDecal)
     font.m_font.set(MWAWFont::Script(float(heightDecal), librevenge::RVNG_POINT));
 
@@ -1265,14 +1282,14 @@ bool WriteNowText::readFont(MWAWInputStream &input, bool inStyle, WriteNowTextIn
 
   int act = 0;
   if (inStyle) {
-    font.m_flags[act++] = (int) input.readULong(4);
-    font.m_flags[act++] = (int) input.readLong(2);
+    font.m_flags[act++] = static_cast<int>(input.readULong(4));
+    font.m_flags[act++] = static_cast<int>(input.readLong(2));
   }
   else {
-    font.m_flags[act++] = (int) input.readLong(1); // 5: note def, 6: note pos ?
-    font.m_styleId[0] = (int) input.readULong(1)-1;
-    font.m_styleId[1] = (int) input.readULong(1)-1;
-    font.m_flags[act++] = (int) input.readLong(1); // alway 0
+    font.m_flags[act++] = static_cast<int>(input.readLong(1)); // 5: note def, 6: note pos ?
+    font.m_styleId[0] = static_cast<int>(input.readULong(1))-1;
+    font.m_styleId[1] = static_cast<int>(input.readULong(1))-1;
+    font.m_flags[act++] = static_cast<int>(input.readLong(1)); // alway 0
   }
   return true;
 }
@@ -1298,19 +1315,19 @@ bool WriteNowText::readParagraph(MWAWInputStream &input, WriteNowTextInternal::P
   /* small number, 0, small number < 3 */
   if (vers >= 3) {
     for (int i = 0; i < 2; i++)
-      ruler.m_values[actVal++] = (int) input.readULong(1);
+      ruler.m_values[actVal++] = static_cast<int>(input.readULong(1));
   }
-  ruler.m_margins[1]=(int) input.readLong(2);
-  ruler.m_margins[2]=(int) input.readLong(2);
-  ruler.m_margins[0]=(int) input.readLong(2);
+  ruler.m_margins[1]=static_cast<int>(input.readLong(2));
+  ruler.m_margins[2]=static_cast<int>(input.readLong(2));
+  ruler.m_margins[0]=static_cast<int>(input.readLong(2));
   *(ruler.m_margins[0])-=ruler.m_margins[1].get();
   int height = 0;
   if (vers >= 3) {
-    height=(int) input.readLong(2);
+    height=static_cast<int>(input.readLong(2));
     for (int i = 0; i < 3; i++)
-      ruler.m_values[actVal++] = (int) input.readULong(2);
+      ruler.m_values[actVal++] = static_cast<int>(input.readULong(2));
   }
-  int flag = (int) input.readULong(1);
+  int flag = static_cast<int>(input.readULong(1));
   switch (flag & 3) {
   case 0:
     break; // left
@@ -1329,16 +1346,16 @@ bool WriteNowText::readParagraph(MWAWInputStream &input, WriteNowTextInternal::P
   bool interlineFixed = (flag & 0x80);
   ruler.m_values[actVal++] = (flag & 0x7c);
   if (vers <= 2)
-    height=(int) input.readULong(1);
+    height=static_cast<int>(input.readULong(1));
   else
-    ruler.m_values[actVal++] = (int) input.readULong(1); // always 0
+    ruler.m_values[actVal++] = static_cast<int>(input.readULong(1)); // always 0
   ruler.m_tabs->resize(0);
   if (!input.isEnd()) {
     int previousVal = 0;
     int tab = 0;
     while (!input.isEnd()) {
       MWAWTabStop newTab;
-      int newVal = (int) input.readULong(2);
+      int newVal = static_cast<int>(input.readULong(2));
       if (tab && newVal < previousVal) {
         MWAW_DEBUG_MSG(("WriteNowText::readParagraph: find bad tab pos\n"));
         f << "#tab[" << tab << ",";
@@ -1416,7 +1433,7 @@ bool WriteNowText::readStyles(WriteNowEntry const &entry)
     val = input->readLong(2);
     if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
-  int N=(int) input->readULong(2);
+  int N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   for (int i = 0; i < 2; i++) { // 0
     val = input->readLong(2);
@@ -1435,7 +1452,7 @@ bool WriteNowText::readStyles(WriteNowEntry const &entry)
     pos = input->tell();
     f.str("");
     f << "Styles[" << n << "]:";
-    int type = (int) input->readULong(1);
+    int type = static_cast<int>(input->readULong(1));
     switch (type) {
     case 0:
       f << "def[named],";
@@ -1458,7 +1475,7 @@ bool WriteNowText::readStyles(WriteNowEntry const &entry)
       val = input->readLong(1);
       if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
     }
-    val = (long) input->readULong(4);
+    val = long(input->readULong(4));
     if (type != 0x80 && pos+val != entry.end()) {
       seenIt = seenMap.find(pos+val);
       int id = 0;
@@ -1486,7 +1503,7 @@ bool WriteNowText::readStyles(WriteNowEntry const &entry)
     WriteNowTextInternal::Style style;
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     f.str("");
-    int type = (int) input->readULong(1);
+    int type = static_cast<int>(input->readULong(1));
     style.m_values[0] = int(type>>4);// find 1, 2 or 3
     style.m_values[1] = int(type&0xF); // always 0 ?
 
@@ -1494,31 +1511,31 @@ bool WriteNowText::readStyles(WriteNowEntry const &entry)
        f3: small number : maybe a previous id?
      */
     for (int i = 2; i < 4; i++) {
-      style.m_values[i] = (int) input->readULong(1);
+      style.m_values[i] = static_cast<int>(input->readULong(1));
     }
-    style.m_nextId = (int) input->readLong(1)-1; // almost always n+1, so...
+    style.m_nextId = static_cast<int>(input->readLong(1))-1; // almost always n+1, so...
     /* f4: almost always 0, but one time f4=nextId
        f5: always=0
      */
     for (int i = 4; i < 6; i++) {
-      style.m_values[i] = (int) input->readULong(1);
+      style.m_values[i] = static_cast<int>(input->readULong(1));
     }
     for (int i = 7; i < 10; i++) { // always 0
-      style.m_values[i] = (int) input->readLong(2);
+      style.m_values[i] = static_cast<int>(input->readLong(2));
     }
     for (int i = 0; i < 6; i++) {
-      style.m_flags[i] = (int) input->readULong(2);
+      style.m_flags[i] = static_cast<int>(input->readULong(2));
     }
     for (int i = 10; i < 12; i++) { // always 0
-      style.m_values[i] = (int) input->readLong(2);
+      style.m_values[i] = static_cast<int>(input->readLong(2));
     }
     int relPos[3];
     for (int i = 0; i < 3; i++)
-      relPos[i] = (int) input->readULong(2);
-    style.m_values[12] = (int) input->readULong(2); // another pos ?
+      relPos[i] = static_cast<int>(input->readULong(2));
+    style.m_values[12] = static_cast<int>(input->readULong(2)); // another pos ?
     if (relPos[0]) { // style name
       input->seek(pos+relPos[0], librevenge::RVNG_SEEK_SET);
-      int sz = (int) input->readULong(1);
+      int sz = static_cast<int>(input->readULong(1));
       if (!sz || pos+relPos[0]+1+sz > entry.end()) {
         MWAW_DEBUG_MSG(("WriteNowText::readStyles: can not read name for entry : %ld\n", long(n)));
         f << "name[length],";
@@ -1558,7 +1575,7 @@ bool WriteNowText::readStyles(WriteNowEntry const &entry)
       f.str("");
       f << "StylesData[" << n << ":ruler]:";
       input->seek(pos+relPos[2], librevenge::RVNG_SEEK_SET);
-      int sz = (int) input->readULong(2);
+      int sz = static_cast<int>(input->readULong(2));
       input->pushLimit(pos+relPos[2]+sz);
       WriteNowTextInternal::Paragraph ruler;
       if (readParagraph(*input, ruler)) {
@@ -1596,31 +1613,31 @@ bool WriteNowText::readToken(MWAWInputStream &input, WriteNowTextInternal::Token
   input.seek(pos, librevenge::RVNG_SEEK_SET);
   int dim[4];
   for (int i=0; i < 4; i++)
-    dim[i] = (int) input.readLong(2);
-  token.m_box = Box2i(Vec2i(dim[1], dim[0]), Vec2i(dim[3], dim[2]));
+    dim[i] = static_cast<int>(input.readLong(2));
+  token.m_box = MWAWBox2i(MWAWVec2i(dim[1], dim[0]), MWAWVec2i(dim[3], dim[2]));
   int actVal = 0;
   for (int st = 0; st < 2; st++) {
-    int dim0 = (int) input.readLong(2);
-    token.m_values[actVal++] = (int) input.readLong(2); // always 0
-    token.m_values[actVal++] = (int) input.readLong(2); // always 0
-    int dim1 = (int) input.readLong(2);
-    token.m_pos[st] = Vec2i(dim1, -dim0);
+    int dim0 = static_cast<int>(input.readLong(2));
+    token.m_values[actVal++] = static_cast<int>(input.readLong(2)); // always 0
+    token.m_values[actVal++] = static_cast<int>(input.readLong(2)); // always 0
+    int dim1 = static_cast<int>(input.readLong(2));
+    token.m_pos[st] = MWAWVec2i(dim1, -dim0);
   }
   /*
     f0/f2:  0 or 1 ( very similar)
     f1/f3 : 0 or big number
    */
   for (int i = 0; i < 4; i++) {
-    token.m_values[actVal++] = (int) input.readULong(2);
+    token.m_values[actVal++] = static_cast<int>(input.readULong(2));
   }
   /*
     f8=1, f9=14
     other 0
   */
   for (int i = 0; i < 10; i++) {
-    token.m_values[actVal++] = (int) input.readLong(2);
+    token.m_values[actVal++] = static_cast<int>(input.readLong(2));
   }
-  token.m_graphicZone = (int) input.readLong(2);
+  token.m_graphicZone = static_cast<int>(input.readLong(2));
   return true;
 }
 
@@ -1631,9 +1648,9 @@ bool WriteNowText::readTokenV2(MWAWInputStream &input, WriteNowTextInternal::Tok
   long actPos = input.tell();
   int dim[2];
   for (int i=0; i < 2; i++)
-    dim[i] = (int) input.readLong(2);
-  Vec2i box(dim[1], dim[0]);
-  token.m_box=Box2i(Vec2i(0,0), box);
+    dim[i] = static_cast<int>(input.readLong(2));
+  MWAWVec2i box(dim[1], dim[0]);
+  token.m_box=MWAWBox2i(MWAWVec2i(0,0), box);
   // we need to get the size, so...
   while (!input.isEnd())
     input.seek(0x100, librevenge::RVNG_SEEK_CUR);
@@ -1642,26 +1659,25 @@ bool WriteNowText::readTokenV2(MWAWInputStream &input, WriteNowTextInternal::Tok
   if (sz <= 0) return false;
   input.seek(actPos+4, librevenge::RVNG_SEEK_SET);
   MWAWInputStreamPtr ip(&input,MWAW_shared_ptr_noop_deleter<MWAWInputStream>());
-  shared_ptr<MWAWPict> pict(MWAWPictData::get(ip, (int) sz));
+  shared_ptr<MWAWPict> pict(MWAWPictData::get(ip, static_cast<int>(sz)));
   if (!pict) {
     MWAW_DEBUG_MSG(("WriteNowParser::readTokenV2: can not read the picture\n"));
     return false;
   }
   if (!m_parserState->m_textListener) return true;
 
-  librevenge::RVNGBinaryData data;
-  std::string type;
   MWAWPosition pictPos;
   if (box.x() > 0 && box.y() > 0) {
-    pictPos=MWAWPosition(Vec2f(0,0),box, librevenge::RVNG_POINT);
+    pictPos=MWAWPosition(MWAWVec2f(0,0),box, librevenge::RVNG_POINT);
     pictPos.setNaturalSize(pict->getBdBox().size());
   }
   else
-    pictPos=MWAWPosition(Vec2f(0,0),pict->getBdBox().size(), librevenge::RVNG_POINT);
+    pictPos=MWAWPosition(MWAWVec2f(0,0),pict->getBdBox().size(), librevenge::RVNG_POINT);
   pictPos.setRelativePosition(MWAWPosition::Char);
 
-  if (pict->getBinary(data,type))
-    m_parserState->m_textListener->insertPicture(pictPos, data, type);
+  MWAWEmbeddedObject picture;
+  if (pict->getBinary(picture))
+    m_parserState->m_textListener->insertPicture(pictPos, picture);
 
   return true;
 }
@@ -1674,7 +1690,7 @@ bool WriteNowText::readTable(MWAWInputStream &input, WriteNowTextInternal::Table
   table=WriteNowTextInternal::TableData();
   long pos = input.tell();
 
-  table.m_type = (int) input.readULong(1);
+  table.m_type = static_cast<int>(input.readULong(1));
   if (input.isEnd()) {
     if (table.m_type!=0) {
       MWAW_DEBUG_MSG(("WriteNowText::readTable: find a zone will 0 size\n"));
@@ -1689,9 +1705,9 @@ bool WriteNowText::readTable(MWAWInputStream &input, WriteNowTextInternal::Table
   }
   input.seek(pos+1, librevenge::RVNG_SEEK_SET);
   int actVal = 0;
-  table.m_values[actVal++] = (int) input.readLong(1);
-  table.m_values[actVal++] = (int) input.readLong(1);
-  int backColor = (int) input.readULong(1);
+  table.m_values[actVal++] = static_cast<int>(input.readLong(1));
+  table.m_values[actVal++] = static_cast<int>(input.readLong(1));
+  int backColor = static_cast<int>(input.readULong(1));
   MWAWColor col;
   if (m_mainParser->getColor(backColor,col))
     table.m_color = col;
@@ -1699,17 +1715,17 @@ bool WriteNowText::readTable(MWAWInputStream &input, WriteNowTextInternal::Table
     MWAW_DEBUG_MSG(("WriteNowText::readTable: can not read backgroundColor: %d\n", backColor));
   }
   for (int i = 0; i < 4; i++) {
-    table.m_flags[i] = (int) input.readULong(1); // 0x80, 0x81, 5, 0 : border flag ?
-    table.m_values[actVal++] = (int) input.readLong(1); //  always 0 ?
+    table.m_flags[i] = static_cast<int>(input.readULong(1)); // 0x80, 0x81, 5, 0 : border flag ?
+    table.m_values[actVal++] = static_cast<int>(input.readLong(1)); //  always 0 ?
   }
   for (int i = 0; i < 3; i++)
-    table.m_values[actVal++] = (int) input.readLong(2); // alway 0
+    table.m_values[actVal++] = static_cast<int>(input.readLong(2)); // alway 0
 
   int dim[4];
   for (int i = 0; i < 4; i++)
-    dim[i] = (int) input.readLong(2);
-  table.m_box = Box2i(Vec2i(dim[1], dim[0]), Vec2i(dim[3], dim[2]));
-  table.m_values[actVal++] = (int) input.readLong(2);
+    dim[i] = static_cast<int>(input.readLong(2));
+  table.m_box = MWAWBox2i(MWAWVec2i(dim[1], dim[0]), MWAWVec2i(dim[3], dim[2]));
+  table.m_values[actVal++] = static_cast<int>(input.readLong(2));
 
   return true;
 }
@@ -1761,7 +1777,7 @@ bool WriteNowText::send(std::vector<WriteNowTextInternal::ContentZone> &listZone
         break;
       case 4:
         if (numFootnote < int(footnoteList.size())) {
-          cell->m_footnoteList.push_back(footnoteList[(size_t) numFootnote]);
+          cell->m_footnoteList.push_back(footnoteList[size_t(numFootnote)]);
           numFootnote++;
         }
         cell->m_zonesList.push_back(zone);
@@ -1786,7 +1802,7 @@ bool WriteNowText::send(std::vector<WriteNowTextInternal::ContentZone> &listZone
     switch (zone.m_type) {
     case 4:
       if (numFootnote < int(footnoteList.size())) {
-        m_mainParser->sendFootnote(footnoteList[(size_t) numFootnote]->m_entry);
+        m_mainParser->sendFootnote(footnoteList[size_t(numFootnote)]->m_entry);
         numFootnote++;
       }
       else {
@@ -1831,22 +1847,22 @@ bool WriteNowText::send(std::vector<WriteNowTextInternal::ContentZone> &listZone
     librevenge::RVNGBinaryData data;
     input->seek(zone.m_pos[0],librevenge::RVNG_SEEK_SET); //000a2f
     while (int(input->tell()) < zone.m_pos[1]) {
-      int ch = (int) input->readULong(1);
+      int ch = static_cast<int>(input->readULong(1));
       if (ch == 0xf0) {
-        ch = (int) input->readULong(1);
+        ch = static_cast<int>(input->readULong(1));
         if (ch & 0xf0) {
           MWAW_DEBUG_MSG(("WriteNowText::send: find odd 0xF0 following\n"));
           continue;
         }
-        data.append((unsigned char)(0xf0 | ch));
+        data.append(static_cast<unsigned char>(0xf0 | ch));
       }
       else
-        data.append((unsigned char)ch);
+        data.append(static_cast<unsigned char>(ch));
     }
 
     f.str("");
     if (zone.m_type == 0) {
-      long sz = (long) data.size();
+      long sz = long(data.size());
       const unsigned char *buffer = data.getDataBuffer();
       if (!buffer && sz) {
         MWAW_DEBUG_MSG(("WriteNowText::send: can find data buffer\n"));
@@ -2004,7 +2020,7 @@ bool WriteNowText::send(std::vector<WriteNowTextInternal::ContentZone> &listZone
       break;
     }
     default:
-      MWAW_DEBUG_MSG(("WriteNowText::send: find keyword %x\n",zone.m_type));
+      MWAW_DEBUG_MSG(("WriteNowText::send: find keyword %x\n",static_cast<unsigned int>(zone.m_type)));
       break;
     }
 
