@@ -216,7 +216,10 @@ bool File::readFileInformation()
 
   if (m_fInfoCreator=="" || m_fInfoType=="")
     return true;
-  if (m_fInfoCreator=="AB65") {
+  if (m_fInfoCreator=="2CTY") {
+    checkFInfoType("SPUB", "PublishIt") || checkFInfoType("PublishIt");
+  }
+  else if (m_fInfoCreator=="AB65") {
     checkFInfoType("AD65", "Pagemaker6.5") || checkFInfoType("Pagemaker6.5");
   }
   else if (m_fInfoCreator=="ACTA") {
@@ -277,6 +280,9 @@ bool File::readFileInformation()
     checkFInfoType("dDrw", "ClarisDraw") || checkFInfoType("dDst", "ClarisDraw[stationary]") ||
     checkFInfoType("iLib", "ClarisDraw[library]") || checkFInfoType("ClarisDraw");
   }
+  else if (m_fInfoCreator=="CRDW") {
+    checkFInfoType("CKDT","CricketDraw") || checkFInfoType("CricketDraw");
+  }
   else if (m_fInfoCreator=="DkmR") {
     checkFInfoType("TEXT","Basic text(created by DOCMaker)") || checkFInfoType("DOCMaker");
   }
@@ -289,6 +295,9 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="FH50") {
     checkFInfoType("AGD1","FreeHand 5") || checkFInfoType("FreeHand 5");
   }
+  else if (m_fInfoCreator=="FHD2") {
+    checkFInfoType("FHA2","FreeHand 2") || checkFInfoType("FHT2","FreeHand 2[template]") || checkFInfoType("FreeHand 2");
+  }
   else if (m_fInfoCreator=="FHD3") {
     checkFInfoType("FHA3","FreeHand 3") || checkFInfoType("FreeHand 3");
   }
@@ -308,6 +317,9 @@ bool File::readFileInformation()
     checkFInfoType("F#+D","RagTime Classic") || checkFInfoType("F#+F","RagTime Classic[form]") ||
     checkFInfoType("RagTime Classic");
   }
+  else if (m_fInfoCreator=="GM01") {
+    checkFInfoType("GfMt","MouseWrite") || checkFInfoType("MouseWrite");
+  }
   else if (m_fInfoCreator=="JWrt") {
     checkFInfoType("TEXT","JoliWrite") || checkFInfoType("ttro","JoliWrite[readOnly]") ||
     checkFInfoType("JoliWrite");
@@ -321,6 +333,12 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="L123") {
     checkFInfoType("LWKS","Lotus123") || checkFInfoType("Lotus123");
   }
+  else if (m_fInfoCreator=="LibW") {
+    checkFInfoType("Chnk","Microspot Media Assistant") || checkFInfoType("Microspot Media Assistant");
+  }
+  else if (m_fInfoCreator=="LETR") {
+    checkFInfoType("APPL","Take A Letter[auto]") || checkFInfoType("Take A Letter");
+  }
   else if (m_fInfoCreator=="LWTE") {
     checkFInfoType("TEXT","LightWayText") || checkFInfoType("MACR","LightWayText[MACR]") ||
     checkFInfoType("pref","LightWayText[Preferences]") ||
@@ -335,8 +353,12 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="MACD") {
     checkFInfoType("DRWG","MacDraft 1.0") || checkFInfoType("MacDraft 1.0");
   }
+  else if (m_fInfoCreator=="MACW") {
+    checkFInfoType("MWCT","MaxWrite 1.0") || checkFInfoType("MaxWrite 1.0");
+  }
   else if (m_fInfoCreator=="MD40") {
-    checkFInfoType("MDDC","MacDraft 5.0") || checkFInfoType("MacDraft 5.0");
+    checkFInfoType("MDDC","MacDraft 4-5") || checkFInfoType("MSYM","MacDraft 4-5[lib]") ||
+    checkFInfoType("MacDraft 4-5");
   }
   else if (m_fInfoCreator=="MDsr") {
     checkFInfoType("APPL","MacDoc(appli)");
@@ -395,11 +417,21 @@ bool File::readFileInformation()
     checkFInfoType("SMAC","Nisus[macros]") || checkFInfoType("edtt","Nisus[lock]") ||
     checkFInfoType("Nisus");
   }
+  else if (m_fInfoCreator=="PaPy") {
+    checkFInfoType("PAPD","Papyrus") || checkFInfoType("Papyrus");
+  }
+  else if (m_fInfoCreator=="PANT") {
+    checkFInfoType("PANT","FullPaint") || checkFInfoType("FullPaint");
+  }
+  else if (m_fInfoCreator=="PIXR") {
+    checkFInfoType("PX01","Pixel Paint") || checkFInfoType("Pixel Paint");
+  }
   else if (m_fInfoCreator=="PPNT") {
-    checkFInfoType("SLDS","Microsoft PowerPoint") || checkFInfoType("Microsoft PowerPoint");
+    checkFInfoType("SLDS","Microsoft PowerPoint") || checkFInfoType("Microsoft PowerPoint v1/2");
   }
   else if (m_fInfoCreator=="PPT3") {
-    checkFInfoType("SLD8","Microsoft PowerPoint 97-2004") || checkFInfoType("Microsoft PowerPoint 97-2004");
+    checkFInfoType("SLD3","Microsoft PowerPoint v3.0") || checkFInfoType("SLD8","Microsoft PowerPoint 97-2004") ||
+    checkFInfoType("Microsoft PowerPoint");
   }
   else if (m_fInfoCreator=="PSIP") {
     checkFInfoType("AWWP","Microsoft Works 1.0") || checkFInfoType("Microsoft Works 1.0");
@@ -437,10 +469,20 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="SSIW") {   // check me
     checkFInfoType("WordPerfect 1.0");
   }
+  else if (m_fInfoCreator==std::string("St")+char(0xd8)+"l") { // argh, not standart character
+    std::string type1=std::string("TEd")+char(0xb6); // argh, not standart character
+    checkFInfoType(type1.c_str(), "Style") || checkFInfoType("Style");
+  }
+  else if (m_fInfoCreator=="StAV") {
+    checkFInfoType("APPL", "Style[auto]") || checkFInfoType("Style");
+  }
   else if (m_fInfoCreator=="TBB5") {
     checkFInfoType("TEXT","Tex-Edit") || checkFInfoType("ttro","Tex-Edit[readOnly]") ||
     checkFInfoType("Tex-Edit");
   }
+  else if (m_fInfoCreator=="WILD") {
+    checkFInfoType("STAK", "HyperCard") || checkFInfoType("HyperCard");
+  }
   else if (m_fInfoCreator=="WNGZ") {
     checkFInfoType("WZSS","Wingz[spreadsheet]") || checkFInfoType("WZSC","Wingz[script]") ||
     checkFInfoType("Wingz");
@@ -473,6 +515,10 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="ZWRT") {
     checkFInfoType("Zart","Z-Write") || checkFInfoType("Z-Write");
   }
+  else if (m_fInfoCreator=="aca3") {
+    checkFInfoType("acf3","FreeHand v1") || checkFInfoType("act3","FreeHand v1[template]") ||
+    checkFInfoType("FreeHand v1");
+  }
   else if (m_fInfoCreator=="cAni") {
     checkFInfoType("curs","CursorAnimator") || checkFInfoType("CursorAnimator");
   }
@@ -590,7 +636,7 @@ bool File::readDataInformation()
     return true;
   }
   if (val[0]==2 && val[1]==0 && val[2]==2 && val[3]==0x262 && val[4]==0x262) {
-    m_dataResult.push_back("MacDraft");
+    m_dataResult.push_back("MacDraft 1");
     return true;
   }
   if (val[0]==0x4646 && val[1]==0x4646 && val[2]==0x3030 && val[3]==0x3030) {
@@ -627,6 +673,18 @@ bool File::readDataInformation()
     m_dataResult.push_back("HanMac Word-J");
     return true;
   }
+  if (val[0]==0x6163 && val[1]==0x6633 && val[2]<9) {
+    m_dataResult.push_back("FreeHand v1");
+    return true;
+  }
+  if (val[0]==0x4648 && val[1]==0x4432 && val[2]<20) {
+    m_dataResult.push_back("FreeHand v2");
+    return true;
+  }
+  if (val[0]==0x0447 && val[1]==0x4d30 && val[2]==0x3400) { // ^DGM04
+    m_dataResult.push_back("MouseWrite");
+    return true;
+  }
   if (val[0]==0x2550 && val[1]==0x4446) {
     m_dataResult.push_back("PDF");
     return true;
@@ -663,6 +721,17 @@ bool File::readDataInformation()
     m_dataResult.push_back("PNG");
     return true;
   }
+  if (val[3]==6 && val[4]==3 && input.length()>30) {
+    input.seek(10, InputStream::SK_SET);
+    if (val[0]==0x4d44 && val[1]==0x4443 && val[2]==0x3230) {
+      m_dataResult.push_back("MacDraft 4-5");
+      return true;
+    }
+    else if (input.readU16()==0 && input.readU16()==0x48 && input.readU16()==0x48) {
+      m_dataResult.push_back("MacDraft 4-5[lib]");
+      return true;
+    }
+  }
   if (val[0]==0xffd8 &&
       ((val[1]==0xffe0 && val[3]==0x4a46 && val[4] == 0x4946) ||
        (val[1]==0xffe1 && val[3]==0x4578 && val[4] == 0x6966) ||
@@ -728,6 +797,14 @@ bool File::readDataInformation()
       m_dataResult.push_back("ClarisDraw[library]");
     return true;
   }
+  if (val[0]==0x4348 && val[1]==0x4e4b && val[2]==0x100 && val[3]==0) {
+    m_dataResult.push_back("Style");
+    return true;
+  }
+  if (val[0]==0x5041 && val[1]==0x5031 && (val[2]>=0x1fa0 && val[2]<=0x1fbc) && val[3]==0x0fa0) {
+    m_dataResult.push_back("Papyrus");
+    return true;
+  }
   // less discriminant
   if ((val[0]==0xfe32 && val[1]==0) || (val[0]==0xfe34 && val[1]==0) ||
       (val[0] == 0xfe37 && (val[1] == 0x23 || val[1] == 0x1c))) {
@@ -770,9 +847,21 @@ bool File::readDataInformation()
     m_dataResult.push_back("Microsoft Word 2.0[pc]");
     return true;
   }
+  if (val[0]==0xabcd && val[1]==0x54) {
+    m_dataResult.push_back("DiskDoubler[archive]");
+    return true;
+  }
   if (val[0]==0x4D44) { // MD
     m_dataResult.push_back("MacDraw v0[unsure]");
   }
+  if (val[0]==0xbad && val[1]==0xdeed && val[2]==0) {
+    m_dataResult.push_back("Microsoft PowerPoint Mac");
+    return true;
+  }
+  if (val[0]==0xedde && val[1]==0xad0b && val[3]==0) {
+    m_dataResult.push_back("Microsoft PowerPoint Windows");
+    return true;
+  }
   if (val[0] == 3 || val[0] == 6) {
     int numParaPos = val[0] == 3 ? 2 : 1;
     if (val[numParaPos] < 0x1000 && val[numParaPos+1] < 0x100 && val[numParaPos+2] < 0x100)
@@ -799,7 +888,7 @@ bool File::readDataInformation()
       break;
     }
     input.seek(16, InputStream::SK_SET);
-    int type = ok ? (int) input.readU16() : -1;
+    int type = ok ? int(input.readU16()) : -1;
     switch (type) {
     case 1:
       break;
@@ -819,6 +908,31 @@ bool File::readDataInformation()
     if (ok)
       m_dataResult.push_back(s.str());
   }
+  if (val[0]==0 && (val[1]==0x7FFF || val[1]==0x8000)) {
+    m_dataResult.push_back("PixelPaint[unsure]");
+  }
+  if (val[0]>=1 && val[0]<=4) {
+    int sSz=(val[1]>>8);
+    if (sSz>=6 && sSz<=8) {
+      // check if we have a date
+      input.seek(3, InputStream::SK_SET);
+      bool ok=true;
+      int numSlash=0;
+      for (int i=0; i<sSz; ++i) {
+        char c=char(input.readU8());
+        if (c>='0' && c<='9')
+          continue;
+        if (c=='/')
+          ++numSlash;
+        else {
+          ok=false;
+          break;
+        }
+      }
+      if (ok && numSlash==2)
+        m_dataResult.push_back("Cricket Draw 1.0");
+    }
+  }
   input.seek(-4, InputStream::SK_END);
   int lVal[2];
   for (int i = 0; i < 2; i++)
@@ -834,8 +948,8 @@ bool File::readDataInformation()
     long eof = input.length();
     bool ok = true;
     for (int i = 0; i < 2; i++) {
-      long pos = (long) input.readU32();
-      long sz = (long) input.read32();
+      long pos = long(input.readU32());
+      long sz = long(input.read32());
       if (sz <= 0 || pos+sz > eof) {
         ok = false;
         break;
@@ -933,7 +1047,7 @@ bool File::printResult(std::ostream &o, int verbose) const
 }
 }
 
-void usage(char const *fName)
+static void usage(char const *fName)
 {
   std::cerr << "Usage: " << fName << " [OPTION] FILENAME\n";
   std::cerr << "\n";
@@ -947,7 +1061,7 @@ void usage(char const *fName)
   std::cerr << "\t -wNum: define the verbose level.\n";
 }
 
-int printVersion()
+static int printVersion()
 {
   std::cerr << "mwawFile " << VERSION << "\n";
   return 0;
