@@ -36,7 +36,6 @@
 #include <set>
 #include <string>
 
-#include <libmwaw_internal.hxx>
 #include "file_internal.h"
 #include "input.h"
 #include "ole.h"
@@ -48,14 +47,14 @@ unsigned short OLE::readU16(InputStream &input)
   unsigned long nRead;
   unsigned char const *data = input.read(2, nRead);
   if (!data || nRead != 2) return 0;
-  return (unsigned short)(data[0]+(data[1]<<8));
+  return static_cast<unsigned short>(data[0]+(data[1]<<8));
 }
 unsigned int OLE::readU32(InputStream &input)
 {
   unsigned long nRead;
   unsigned char const *data = input.read(4, nRead);
   if (!data || nRead != 4) return 0;
-  return (unsigned int)(data[0]+(data[1]<<8)+(data[2]<<16)+(data[3]<<24));
+  return static_cast<unsigned int>(data[0]+(data[1]<<8)+(data[2]<<16)+(data[3]<<24));
 }
 
 // header functions
@@ -76,24 +75,24 @@ bool OLE::Header::read(InputStream &input)
   }
   input.seek(0x1e, InputStream::SK_SET);
   unsigned shift;
-  shift = (unsigned) readU16(input);
+  shift = static_cast<unsigned>(readU16(input));
   if (shift <= 6 || shift >= 31)
     return false;
-  m_sizeBats[BigBat] = (unsigned)(1 << shift);
-  shift = (unsigned) readU16(input);
-  m_sizeBats[SmallBat] = (unsigned)(1 << shift);
+  m_sizeBats[BigBat] = static_cast<unsigned>(1 << shift);
+  shift = static_cast<unsigned>(readU16(input));
+  m_sizeBats[SmallBat] = static_cast<unsigned>(1 << shift);
   if (shift >= 31 || m_sizeBats[SmallBat] >= m_sizeBats[BigBat])
     return false;
 
   input.seek(0x2c, InputStream::SK_SET);
-  m_numBats[BigBatAlloc] = (unsigned) readU32(input);
-  m_startBats[Dirent] = (unsigned) readU32(input);
+  m_numBats[BigBatAlloc] = static_cast<unsigned>(readU32(input));
+  m_startBats[Dirent] = static_cast<unsigned>(readU32(input));
   input.seek(0x38, InputStream::SK_SET);
-  m_threshold = (unsigned) readU32(input);
-  m_startBats[SmallBat] = (unsigned) readU32(input);
-  m_numBats[SmallBat] = (unsigned) readU32(input);
-  m_startBats[MetaBat] = (unsigned) readU32(input);
-  m_numBats[MetaBat] = (unsigned) readU32(input);
+  m_threshold = static_cast<unsigned>(readU32(input));
+  m_startBats[SmallBat] = static_cast<unsigned>(readU32(input));
+  m_numBats[SmallBat] = static_cast<unsigned>(readU32(input));
+  m_startBats[MetaBat] = static_cast<unsigned>(readU32(input));
+  m_numBats[MetaBat] = static_cast<unsigned>(readU32(input));
 
   if (m_threshold != 4096 || !m_numBats[BigBatAlloc] ||
       (m_numBats[BigBatAlloc]<= 109 && m_numBats[MetaBat]) ||
@@ -103,7 +102,7 @@ bool OLE::Header::read(InputStream &input)
   size_t numBigBatInHeader=size_t(m_numBats[BigBatAlloc]>109 ? 109 : m_numBats[BigBatAlloc]);
   m_bigBatAlloc.resize(numBigBatInHeader);
   for (size_t i=0; i < numBigBatInHeader; i++)
-    m_bigBatAlloc[i] = (unsigned long) readU32(input);
+    m_bigBatAlloc[i] = static_cast<unsigned long>(readU32(input));
   return true;
 }
 
@@ -117,10 +116,10 @@ bool OLE::DirEntry::read(InputStream &input)
     return false;
   }
   input.seek(pos+0x40, InputStream::SK_SET);
-  unsigned name_len = (unsigned) readU16(input);
+  unsigned name_len = static_cast<unsigned>(readU16(input));
   if (name_len > 64) name_len = 64;
   // 2 = file (aka stream), 1 = directory (aka storage), 5 = root
-  m_type = (unsigned) input.readU8();
+  m_type = static_cast<unsigned>(input.readU8());
 
   input.seek(pos, InputStream::SK_SET);
   // parse name of this entry, which stored as Unicode 16-bit
@@ -136,15 +135,15 @@ bool OLE::DirEntry::read(InputStream &input)
     m_name.append(1, char(val));
   }
   input.seek(pos+0x44, InputStream::SK_SET);
-  m_left = (unsigned) readU32(input);
-  m_right = (unsigned) readU32(input);
-  m_child = (unsigned) readU32(input);
+  m_left = static_cast<unsigned>(readU32(input));
+  m_right = static_cast<unsigned>(readU32(input));
+  m_child = static_cast<unsigned>(readU32(input));
   for (int i = 0; i < 4; i++)
-    m_clsid[i]=(unsigned) readU32(input);
+    m_clsid[i]=static_cast<unsigned>(readU32(input));
 
   input.seek(pos+0x74, InputStream::SK_SET);
-  m_start = (unsigned long) readU32(input);
-  m_size = (unsigned long) readU32(input);
+  m_start = static_cast<unsigned long>(readU32(input));
+  m_size = static_cast<unsigned long>(readU32(input));
 
   // sanity checks
   m_valid = true;
@@ -276,7 +275,7 @@ bool OLE::initAllocTables()
         MWAW_DEBUG_MSG(("OLE::initAllocTables: can not find meta block position\n"));
         return false;
       }
-      m_input.seek((long) m_header.getBigBlockPos(sector), InputStream::SK_SET);
+      m_input.seek(long(m_header.getBigBlockPos(sector)), InputStream::SK_SET);
       if (m_input.atEOS()) {
         MWAW_DEBUG_MSG(("OLE::initAllocTables: can not read a meta block\n"));
         return false;
@@ -286,9 +285,9 @@ bool OLE::initAllocTables()
         if (k >= numBats)
           break;
         if (s==maxN-1)
-          sector = (unsigned) readU32(m_input);
+          sector = static_cast<unsigned>(readU32(m_input));
         else
-          bigBatAlloc[k++] = (unsigned long) readU32(m_input);
+          bigBatAlloc[k++] = static_cast<unsigned long>(readU32(m_input));
       }
       if (k >= numBats)
         break;
@@ -300,17 +299,17 @@ bool OLE::initAllocTables()
   }
 
   // read the big block alloc table
-  unsigned long numBBats=(unsigned long) numBats * (unsigned long) maxN;
+  unsigned long numBBats=static_cast<unsigned long>(numBats) * static_cast<unsigned long>(maxN);
   m_allocTable[BigBat].resize(numBBats);
   unsigned long pos = 0;
   for (size_t k=0; k < numBats; k++) {
-    m_input.seek((long) m_header.getBigBlockPos((unsigned)bigBatAlloc[k]), InputStream::SK_SET);
+    m_input.seek(long(m_header.getBigBlockPos(static_cast<unsigned>(bigBatAlloc[k]))), InputStream::SK_SET);
     for (size_t s=0; s < maxN; s++) {
       if (m_input.atEOS()) {
         MWAW_DEBUG_MSG(("OLE::initAllocTables: can not read a big alloc table block\n"));
         return false;
       }
-      unsigned long val = (unsigned long) readU32(m_input);
+      unsigned long val = static_cast<unsigned long>(readU32(m_input));
       if (val >= 0xfffffffc)
         m_allocTable[BigBat][pos++] = Eof;
       else
@@ -319,17 +318,17 @@ bool OLE::initAllocTables()
   }
   // read the small bat alloc table
   std::vector<unsigned long> smallBlocks = m_allocTable[BigBat].follow(m_header.m_startBats[SmallBat]);
-  unsigned long numSBats=(unsigned long) smallBlocks.size() * (unsigned long) maxN;
+  unsigned long numSBats=static_cast<unsigned long>(smallBlocks.size()) * static_cast<unsigned long>(maxN);
   m_allocTable[SmallBat].resize(numSBats);
   pos = 0;
   for (size_t k=0; k < smallBlocks.size(); k++) {
-    m_input.seek((long)m_header.getBigBlockPos((unsigned)smallBlocks[k]), InputStream::SK_SET);
+    m_input.seek(long(m_header.getBigBlockPos(static_cast<unsigned>(smallBlocks[k]))), InputStream::SK_SET);
     for (size_t s=0; s < maxN; s++) {
       if (m_input.atEOS()) {
         MWAW_DEBUG_MSG(("OLE::initAllocTables: can not read a small alloc table block\n"));
         return false;
       }
-      unsigned long val = (unsigned long) readU32(m_input);
+      unsigned long val = static_cast<unsigned long>(readU32(m_input));
       if (val >= 0xfffffffc)
         m_allocTable[SmallBat][pos++] = Eof;
       else
@@ -352,11 +351,11 @@ bool OLE::init()
   if (!dirBlocks.size())
     return false;
   size_t const maxDir = size_t(m_header.m_sizeBats[BigBat]/128);
-  unsigned numDBats=(unsigned) dirBlocks.size() * (unsigned) maxDir;
+  unsigned numDBats=static_cast<unsigned>(dirBlocks.size()) * static_cast<unsigned>(maxDir);
   m_dirTree.resize(numDBats);
   unsigned pos = 0;
   for (size_t k=0; k < dirBlocks.size(); k++) {
-    long fPos = (long) m_header.getBigBlockPos((unsigned) dirBlocks[k]);
+    long fPos = long(m_header.getBigBlockPos(static_cast<unsigned>(dirBlocks[k])));
     for (size_t s=0; s < maxDir; s++) {
       m_input.seek(fPos+long(128*s), InputStream::SK_SET);
       if (m_input.atEOS() || !m_dirTree.entry(pos++)->read(m_input)) {
@@ -389,11 +388,11 @@ std::string OLE::getCompObjType()
     return "";
   if (buf.size() < 28)
     return "";
-  StringStream stream(&buf[0], (unsigned long) buf.size());
+  StringStream stream(&buf[0], static_cast<unsigned long>(buf.size()));
   stream.seek(12, InputStream::SK_SET);
   unsigned clsId[4];
   for (int i = 0; i < 4; i++)
-    clsId[i]=(unsigned) readU32(stream);
+    clsId[i]=static_cast<unsigned>(readU32(stream));
   MWAW_DEBUG_MSG(("Find: %x %x %x %x\n", clsId[0], clsId[1], clsId[2], clsId[3]));
   return getCLSIDType(clsId);
 }
@@ -410,10 +409,10 @@ bool OLE::load(std::string const &name, std::vector<unsigned char> &buffer)
   buffer.resize(size_t(e->m_size));
   bool useBig=useBigBlockFor(e->m_size);
   std::vector<unsigned long> blocks=m_allocTable[useBig ? BigBat : SmallBat].follow(e->m_start);
-  unsigned long blockSize=(unsigned long)m_header.m_sizeBats[useBig ? BigBat : SmallBat];
+  unsigned long blockSize=static_cast<unsigned long>(m_header.m_sizeBats[useBig ? BigBat : SmallBat]);
   unsigned long wPos = 0;
   for (size_t b=0; b < blocks.size(); b++) {
-    long pos=getDataAddress((unsigned)blocks[b], useBig);
+    long pos=getDataAddress(static_cast<unsigned>(blocks[b]), useBig);
     if (pos <= 0) {
       MWAW_DEBUG_MSG(("OLE::load: oops can not find block address\n"));
       buffer.resize(0);
