@@ -26,8 +26,10 @@
 * in which case the provisions of the LGPLv2+ are applicable
 * instead of those above.
 */
-#ifndef _WIN32
-#define __cdecl
+#ifdef _WIN32
+#  define MWAWZIP_CDECL __cdecl
+#else
+#  define MWAWZIP_CDECL
 #endif
 
 #include <sys/stat.h>
@@ -64,13 +66,13 @@ static void usage(const char *cmdname)
   std::cerr << "\t -D: only zip the file containing a resource fork or finder information.\n";
 }
 
-int printVersion()
+static int printVersion()
 {
   std::cerr << "mwawZip " << VERSION << "\n";
   return 0;
 }
 
-int __cdecl main(int argc, char **argv)
+int MWAWZIP_CDECL main(int argc, char **argv)
 {
   bool checkZip=false;
   bool verbose=false;
@@ -116,14 +118,14 @@ int __cdecl main(int argc, char **argv)
       file.read(buff,4);
       // look for a zip file signature
       if (buff[0]=='P' && buff[1]=='K') {
-        if (((buff[2]==(char)3||buff[2]==(char)5||buff[2]==(char)7) && buff[3]==buff[2]+(char)1) ||
+        if (((buff[2]==char(3)||buff[2]==char(5)||buff[2]==char(7)) && buff[3]==buff[2]+char(1)) ||
             (buff[2]=='L'&&buff[3]=='I') || (buff[2]=='S'&&buff[3]=='p'))
           return 2;
       }
       // look for an ole file signature
-      else if (buff[0]==(char) 0xd0 && buff[1]==(char) 0xcf && buff[2]==(char) 0x11 && buff[3]==(char) 0xe0) {
+      else if (buff[0]==char(0xd0) && buff[1]==char(0xcf) && buff[2]==char(0x11) && buff[3]==char(0xe0)) {
         file.read(buff,4);
-        if (buff[0]==(char) 0xa1&&buff[1]==(char) 0xb1&&buff[2]==(char) 0x1a&&buff[3]==(char) 0xe1)
+        if (buff[0]==char(0xa1)&&buff[1]==char(0xb1) && buff[2]==char(0x1a) && buff[3]==char(0xe1))
           return 2;
       }
       // look for a binhex file signature
