@@ -100,7 +100,7 @@ protected:
   //! small structure used to store a directory and its file
   struct Directory {
     //! constructor
-    Directory(std::string const &dir);
+    explicit Directory(std::string const &dir);
     //! try to add a file checking if a file with the same name already exist
     bool add(shared_ptr<InputStream> input, char const *base, std::ostream &output);
     /** try to write the central information in output
